@@ -40,15 +40,15 @@ Base_DB_Table_Data::~Base_DB_Table_Data()
 {
 }
 
-Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data_field_only(const sharedptr<const Field>& field) const
+Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data_field_only(const std::shared_ptr<const Field>& field) const
 {
-  sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+  std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
   layout_item->set_full_field_details(field);
 
   return get_entered_field_data(layout_item);
 }
 
-Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data(const sharedptr<const LayoutItem_Field>& /* field */) const
+Gnome::Gda::Value Base_DB_Table_Data::get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& /* field */) const
 {
   //Override this to use Field::set_data() too.
 
@@ -70,7 +70,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
   Document* document = get_document();
 
-  sharedptr<const Field> fieldPrimaryKey = get_field_primary_key();
+  std::shared_ptr<const Field> fieldPrimaryKey = get_field_primary_key();
 
   const Glib::ustring primary_key_name = fieldPrimaryKey->get_name();
 
@@ -80,14 +80,14 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
 
   //Add values for all fields, not just the shown ones:
   //For instance, we must always add the primary key, and fields with default/calculated/lookup/auto-incremented values:
-  for(type_vec_fields::const_iterator iter = m_TableFields.begin(); iter != m_TableFields.end(); ++iter)
+  for(const auto& item : m_TableFields)
   {
     //TODO: Search for the non-related field with the name, not just the field with the name:
-    type_vecConstLayoutFields::const_iterator iterFind = std::find_if(fieldsToAdd.begin(), fieldsToAdd.end(), predicate_FieldHasName<LayoutItem_Field>((*iter)->get_name()));
+    type_vecConstLayoutFields::const_iterator iterFind = std::find_if(fieldsToAdd.begin(), fieldsToAdd.end(), predicate_FieldHasName<LayoutItem_Field>(item->get_name()));
     if(iterFind == fieldsToAdd.end())
     {
-      sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-      layout_item->set_full_field_details(*iter);
+      std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+      layout_item->set_full_field_details(item);
 
       fieldsToAdd.push_back(layout_item);
     }
@@ -102,9 +102,8 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
   type_map_added map_added;
   Glib::RefPtr<Gnome::Gda::Set> params = Gnome::Gda::Set::create();
 
-  for(type_vecConstLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
+  for(const auto& layout_item : fieldsToAdd)
   {
-    sharedptr<const LayoutItem_Field> layout_item = *iter;
     const Glib::ustring field_name = layout_item->get_name();
     if(!layout_item->get_has_relationship_name()) //TODO: Allow people to add a related record also by entering new data in a related field of the related record.
     {
@@ -113,7 +112,7 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
       {
         Gnome::Gda::Value value;
 
-        const sharedptr<const Field>& field = layout_item->get_full_field_details();
+        const std::shared_ptr<const Field>& field = layout_item->get_full_field_details();
         if(!field)
           continue;
         
@@ -133,12 +132,12 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
           //If the default value should be calculated, then calculate it:
           if(field->get_has_calculation())
           {
-            const Glib::ustring calculation = field->get_calculation();
-            const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, fieldPrimaryKey, primary_key_value);
+            const auto calculation = field->get_calculation();
+            const auto field_values = get_record_field_values_for_calculation(m_table_name, fieldPrimaryKey, primary_key_value);
 
             //We need the connection when we run the script, so that the script may use it.
             // TODO: Is this function supposed to throw an exception?
-            sharedptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
+            std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
 
             Glib::ustring error_message; //TODO: Check this.
             value =
@@ -195,21 +194,19 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
   //Put it all together to create the record with these field values:
   if(!map_added.empty())
   {
-    const bool test = DbUtils::query_execute(builder);
+    const auto test = DbUtils::query_execute(builder);
     if(!test)
       std::cerr << G_STRFUNC << ": INSERT failed." << std::endl;
     else
     {
-      Gtk::TreeModel::iterator row = get_row_selected(); //Null and ignored for details views.
+      auto row = get_row_selected(); //Null and ignored for details views.
       set_primary_key_value(row, primary_key_value); //Needed by Box_Data_List::on_adddel_user_changed().
 
       //Update any lookups, related fields, or calculations:
-      for(type_vecConstLayoutFields::const_iterator iter = fieldsToAdd.begin(); iter != fieldsToAdd.end(); ++iter)
+      for(const auto& layout_item : fieldsToAdd)
       {
-        sharedptr<const LayoutItem_Field> layout_item = *iter;
-
         //TODO_Performance: We just set this with set_entered_field_data() above. Maybe we could just remember it.
-        const Gnome::Gda::Value field_value = get_entered_field_data(layout_item);
+        const auto field_value = get_entered_field_data(layout_item);
 
         const LayoutFieldInRecord field_in_record(layout_item, m_table_name, fieldPrimaryKey, primary_key_value);
 
@@ -231,15 +228,15 @@ bool Base_DB_Table_Data::record_new(bool use_entered_data, const Gnome::Gda::Val
   return false; //Failed.
 }
 
-bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const LayoutItem_Field>& layout_item_parent,
-  const sharedptr<const Relationship>& relationship,
-  const sharedptr<const Field>& primary_key_field,
+bool Base_DB_Table_Data::add_related_record_for_field(const std::shared_ptr<const LayoutItem_Field>& layout_item_parent,
+  const std::shared_ptr<const Relationship>& relationship,
+  const std::shared_ptr<const Field>& primary_key_field,
   const Gnome::Gda::Value& primary_key_value_provided,
   Gnome::Gda::Value& primary_key_value_used)
 {
   Gnome::Gda::Value primary_key_value = primary_key_value_provided;
 
-  const bool related_record_exists = get_related_record_exists(relationship, primary_key_value);
+  const auto related_record_exists = get_related_record_exists(relationship, primary_key_value);
   if(related_record_exists)
   {
     //No problem, the SQL command below will update this value in the related table.
@@ -266,7 +263,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
   }
   else
   {
-    const bool key_is_auto_increment = primary_key_field->get_auto_increment();
+    const auto key_is_auto_increment = primary_key_field->get_auto_increment();
 
     //If we would have to set an otherwise auto-increment key to add the record.
     if( key_is_auto_increment && !Conversions::value_is_empty(primary_key_value) )
@@ -298,11 +295,10 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
         //Generate the new key value;
       }
 
-      Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
-      builder->set_table(relationship->get_to_table());
-      builder->add_field_value(primary_key_field->get_name(), primary_key_value);
-      const bool test = DbUtils::query_execute(builder);
-      if(!test)
+      Glib::RefPtr<Gnome::Gda::SqlBuilder> builder_insert = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_INSERT);
+      builder_insert->set_table(relationship->get_to_table());
+      builder_insert->add_field_value(primary_key_field->get_name(), primary_key_value);
+      if(!DbUtils::query_execute(builder_insert))
       {
         std::cerr << G_STRFUNC << ": INSERT failed." << std::endl;
         return false;
@@ -311,7 +307,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
       if(key_is_auto_increment)
       {
         //Set the key in the parent table
-        sharedptr<LayoutItem_Field> item_from_key = sharedptr<LayoutItem_Field>::create();
+        std::shared_ptr<LayoutItem_Field> item_from_key = std::make_shared<LayoutItem_Field>();
         item_from_key->set_name(relationship->get_from_field());
 
         //Show the new from key in the parent table's layout:
@@ -319,7 +315,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
 
         //Set it in the database too:
         Document* document = get_document();
-        sharedptr<Field> field_from_key = DbUtils::get_fields_for_table_one_field(document,
+        std::shared_ptr<Field> field_from_key = DbUtils::get_fields_for_table_one_field(document,
           relationship->get_from_table(), relationship->get_from_field()); //TODO_Performance.
         if(!field_from_key)
         {
@@ -327,7 +323,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
           return false;
         }
 
-        sharedptr<Field> parent_primary_key_field = get_field_primary_key();
+        std::shared_ptr<Field> parent_primary_key_field = get_field_primary_key();
         if(!parent_primary_key_field)
         {
           std::cerr << G_STRFUNC << ": get_field_primary_key() failed. table = " << get_table_name() << std::endl;
@@ -335,7 +331,7 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
         }
         else
         {
-          const Gnome::Gda::Value parent_primary_key_value = get_primary_key_value_selected();
+          const auto parent_primary_key_value = get_primary_key_value_selected();
           if(parent_primary_key_value.is_null())
           {
             std::cerr << G_STRFUNC << ": get_primary_key_value_selected() failed. table = " << get_table_name() << std::endl;
@@ -343,18 +339,17 @@ bool Base_DB_Table_Data::add_related_record_for_field(const sharedptr<const Layo
           }
           else
           {
-            const Glib::ustring target_table = relationship->get_from_table();
-            Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+            const auto target_table = relationship->get_from_table();
+            Glib::RefPtr<Gnome::Gda::SqlBuilder> builder_update =
               Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
-            builder->set_table(target_table);
-            builder->add_field_value_as_value(relationship->get_from_field(), primary_key_value);
-            builder->set_where(
-              builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-                builder->add_field_id(parent_primary_key_field->get_name(), target_table),
-                builder->add_expr(parent_primary_key_value)) );
+            builder_update->set_table(target_table);
+            builder_update->add_field_value_as_value(relationship->get_from_field(), primary_key_value);
+            builder_update->set_where(
+              builder_update->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
+                builder_update->add_field_id(parent_primary_key_field->get_name(), target_table),
+                builder_update->add_expr(parent_primary_key_value)) );
 
-            const bool test = DbUtils::query_execute(builder);
-            if(!test)
+            if(!DbUtils::query_execute(builder_update))
             {
               std::cerr << G_STRFUNC << ": UPDATE failed." << std::endl;
               return false;
@@ -399,7 +394,7 @@ bool Base_DB_Table_Data::confirm_delete_record()
 
 bool Base_DB_Table_Data::record_delete(const Gnome::Gda::Value& primary_key_value)
 {
-  sharedptr<Field> field_primary_key = get_field_primary_key();
+  std::shared_ptr<Field> field_primary_key = get_field_primary_key();
   if(field_primary_key && !Conversions::value_is_empty(primary_key_value))
   {
     Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
@@ -423,7 +418,7 @@ Base_DB_Table_Data::type_signal_record_changed Base_DB_Table_Data::signal_record
 }
 
 
-bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relationship>& relationship, const Gnome::Gda::Value& key_value)
+bool Base_DB_Table_Data::get_related_record_exists(const std::shared_ptr<const Relationship>& relationship, const Gnome::Gda::Value& key_value)
 {
   BusyCursor cursor(AppWindow::get_appwindow());
 
@@ -435,8 +430,8 @@ bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relatio
 
   //TODO_Performance: It's very possible that this is slow.
   //We don't care how many records there are, only whether there are more than zero.
-  const Glib::ustring to_field = relationship->get_to_field();
-  const Glib::ustring related_table = relationship->get_to_table();
+  const auto to_field = relationship->get_to_field();
+  const auto related_table = relationship->get_to_table();
 
   //TODO_Performance: Is this the best way to just find out whether there is one record that meets this criteria?
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
@@ -464,22 +459,21 @@ bool Base_DB_Table_Data::get_related_record_exists(const sharedptr<const Relatio
 
 /** Get the shown fields that are in related tables, via a relationship using @a field_name changes.
  */
-Base_DB_Table_Data::type_vecConstLayoutFields Base_DB_Table_Data::get_related_fields(const sharedptr<const LayoutItem_Field>& field) const
+Base_DB_Table_Data::type_vecConstLayoutFields Base_DB_Table_Data::get_related_fields(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
   type_vecConstLayoutFields result;
 
   const Document* document = dynamic_cast<const Document*>(get_document());
   if(document)
   {
-    const Glib::ustring field_name = field->get_name(); //At the moment, relationships can not be based on related fields on the from side.
-    for(type_vecConstLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end();  ++iter)
+    const auto field_name = field->get_name(); //At the moment, relationships can not be based on related fields on the from side.
+    for(const auto& layout_field : m_FieldsShown)
     {
-      const sharedptr<const LayoutItem_Field> layout_field = *iter;
       //Examine each field that looks up its data from a relationship:
       if(layout_field->get_has_relationship_name())
       {
         //Get the relationship information:
-        sharedptr<const Relationship> relationship = document->get_relationship(m_table_name, layout_field->get_relationship_name());
+        std::shared_ptr<const Relationship> relationship = document->get_relationship(m_table_name, layout_field->get_relationship_name());
         if(relationship)
         {
           //If the relationship uses the specified field:
@@ -534,8 +528,8 @@ void Base_DB_Table_Data::refresh_related_fields(const LayoutFieldInRecord& field
 
         for(guint uiCol = 0; uiCol < cols_count; ++uiCol)
         {
-          const Gnome::Gda::Value value = result->get_value_at(uiCol, 0 /* row */);
-          sharedptr<const LayoutItem_Field> layout_item = *iterFields;
+          const auto value = result->get_value_at(uiCol, 0 /* row */);
+          std::shared_ptr<const LayoutItem_Field> layout_item = *iterFields;
           if(!layout_item)
             std::cerr << G_STRFUNC << ": The layout_item was null." << std::endl;
           else
