@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "config.h" //For GLOM_ENABLE_POSTGRESQL
@@ -40,11 +40,11 @@ const bool Dialog_Connection::glade_developer(false);
 Dialog_Connection::Dialog_Connection(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   Base_DB(),
-  m_entry_host(0),
-  m_entry_user(0),
-  m_entry_password(0),
-  m_label_database(0),
-  m_label_note(0)
+  m_entry_host(nullptr),
+  m_entry_user(nullptr),
+  m_entry_password(nullptr),
+  m_label_database(nullptr),
+  m_label_note(nullptr)
 {
   builder->get_widget("entry_host", m_entry_host);
   builder->get_widget("entry_user", m_entry_user);
@@ -57,13 +57,13 @@ Dialog_Connection::~Dialog_Connection()
 {
 }
 
-sharedptr<SharedConnection> Dialog_Connection::connect_to_server_with_connection_settings() const
+std::shared_ptr<SharedConnection> Dialog_Connection::connect_to_server_with_connection_settings() const
 {
   //std::cout << "debug: Dialog_Connection::connect_to_server_with_connection_settings()" << std::endl;
 
   //TODO: BusyCursor busy_cursor(get_app_window());
 
-  sharedptr<SharedConnection> result(0);
+  std::shared_ptr<SharedConnection> result;
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   g_assert(connection_pool);
@@ -71,7 +71,7 @@ sharedptr<SharedConnection> Dialog_Connection::connect_to_server_with_connection
   //Set the connection details in the ConnectionPool singleton.
   //The ConnectionPool will now use these every time it tries to connect.
 
-  const Document* document = get_document();
+  const auto document = get_document();
   if(!document)
     return result;
 
@@ -160,7 +160,7 @@ void Dialog_Connection::load_from_document()
     if(user.empty())
     {
       //Default to the UNIX user name, which is often the same as the Postgres user name:
-      const char* pchUser = getenv("USER"); 
+      const auto pchUser = getenv("USER"); 
       if(pchUser)
         user = pchUser;
     }
