@@ -82,11 +82,11 @@ private:
     {
       if(name == "glom_document") //See document_glom.cc for the #defines.
       {
-        for(AttributeList::const_iterator iter = attributes.begin(); iter != attributes.end(); ++ iter)
+        for(const auto& item : attributes)
         {
-          if(iter->name == "database_title")
+          if(item.name == "database_title")
           {
-            m_title = iter->value;
+            m_title = item.value;
 
             // Stop parsing here because we have what we need:
             xmlStopParser(context_);
@@ -114,7 +114,7 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
 {
 #ifdef GLOM_ENABLE_CLIENT_ONLY
   //Don't mention creation of new documents in client-only mode:
-  Gtk::Label* label = 0;
+  Gtk::Label* label = nullptr;
   builder->get_widget("existing_or_new_label", label);
   label->set_text(_("Open a Document"));
 #endif //GLOM_ENABLE_CLIENT_ONLY
@@ -168,21 +168,19 @@ Dialog_ExistingOrNew::Dialog_ExistingOrNew(BaseObjectType* cobject, const Glib::
 #endif
 
   // Add recently used files
-  typedef std::vector< Glib::RefPtr<Gtk::RecentInfo> > type_vec_infos;
-  type_vec_infos infos = Gtk::RecentManager::get_default()->get_items();
-  for(type_vec_infos::const_iterator iter = infos.begin(); iter != infos.end(); ++ iter)
+  const auto infos = Gtk::RecentManager::get_default()->get_items();
+  for(const auto& info : infos)
   {
-    Glib::RefPtr<Gtk::RecentInfo> info = *iter;
     if(info->get_mime_type() == "application/x-glom")
     {
-      Gtk::TreeModel::iterator iter = m_existing_model->append(m_iter_existing_recent->children());
+      auto iter = m_existing_model->append(m_iter_existing_recent->children());
       (*iter)[m_existing_columns.m_col_title] = info->get_display_name();
       (*iter)[m_existing_columns.m_col_time] = info->get_modified();
       (*iter)[m_existing_columns.m_col_recent_info] = info;
     }
   }
 
-  const Gtk::TreeNodeChildren& children = m_iter_existing_recent->children();
+  const auto children = m_iter_existing_recent->children();
   if(children.begin() == children.end())
     m_iter_existing_recent_dummy = create_dummy_item_existing(m_iter_existing_recent, _("No recently used documents available."));
 
@@ -264,16 +262,13 @@ bool Dialog_ExistingOrNew::list_examples()
 
   try
   {
-    typedef std::vector<std::string> type_vec_strings;
-    const type_vec_strings examples = Gio::Resource::enumerate_children_global(examples_dir);
+    const auto examples = Gio::Resource::enumerate_children_global(examples_dir);
     
     bool example_found = false;
-    for(type_vec_strings::const_iterator iter = examples.begin(); iter != examples.end(); ++iter)
+    for(const auto& example_name : examples)
     {
-      const std::string example_name = *iter;
-
-      const std::string full_path = Glib::build_filename(examples_dir, example_name);
-      const Glib::ustring title = get_title_from_example(full_path);
+      const auto full_path = Glib::build_filename(examples_dir, example_name);
+      const auto title = get_title_from_example(full_path);
       if(!title.empty())
       {
         append_example(title, full_path);
@@ -298,15 +293,15 @@ Dialog_ExistingOrNew::~Dialog_ExistingOrNew()
   if(m_service_monitor)
   {
     g_object_unref(m_service_monitor);
-    m_service_monitor = 0;
+    m_service_monitor = nullptr;
   }
 
   // Release the service infos in the treestore
   if(!m_iter_existing_network_dummy.get())
   {
-    const Gtk::TreeNodeChildren& children = m_iter_existing_network->children();
-    for(Gtk::TreeModel::iterator iter = children.begin(); iter != children.end(); ++ iter)
-      epc_service_info_unref((*iter)[m_existing_columns.m_col_service_info]);
+    const auto children = m_iter_existing_network->children();
+    for(const auto& item : children)
+      epc_service_info_unref(item[m_existing_columns.m_col_service_info]);
   }
 #endif
 
@@ -314,7 +309,7 @@ Dialog_ExistingOrNew::~Dialog_ExistingOrNew()
 
 bool Dialog_ExistingOrNew::on_existing_select_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::Path& path, bool /* path_currently_selected */)
 {
-  Gtk::TreeModel::iterator iter = model->get_iter(path);
+  auto iter = model->get_iter(path);
 #ifndef G_OS_WIN32
   if(iter == m_iter_existing_network)
     return false; /* Do not allow parent nodes to be selected. */
@@ -328,7 +323,7 @@ bool Dialog_ExistingOrNew::on_existing_select_func(const Glib::RefPtr<Gtk::TreeM
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 bool Dialog_ExistingOrNew::on_new_select_func(const Glib::RefPtr<Gtk::TreeModel>& model, const Gtk::TreeModel::Path& path, bool /* path_currently_selected */)
 {
-  Gtk::TreeModel::iterator iter = model->get_iter(path);
+  auto iter = model->get_iter(path);
   if(iter == m_iter_new_template)
     return false; /* Do not allow parent nodes to be selected. */
   else
@@ -383,7 +378,7 @@ Dialog_ExistingOrNew::Action Dialog_ExistingOrNew::get_action() const
 Glib::ustring Dialog_ExistingOrNew::get_uri() const
 {
   Gtk::TreeModel::iterator iter;
-  const Action action = get_action_impl(iter);
+  const auto action = get_action_impl(iter);
 
   #ifndef GLOM_ENABLE_CLIENT_ONLY
   if(action == NEW_FROM_TEMPLATE)
@@ -436,19 +431,19 @@ Glib::ustring Dialog_ExistingOrNew::get_service_name() const
 }
 #endif
 
-std::auto_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_item_existing(const Gtk::TreeModel::iterator& parent, const Glib::ustring& text)
+std::shared_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_item_existing(const Gtk::TreeModel::iterator& parent, const Glib::ustring& text)
 {
-  Gtk::TreeModel::iterator iter = m_existing_model->append(parent->children());
+  auto iter = m_existing_model->append(parent->children());
   (*iter)[m_existing_columns.m_col_title] = text;
-  return std::auto_ptr<Gtk::TreeModel::iterator>(new Gtk::TreeModel::iterator(iter));
+  return std::shared_ptr<Gtk::TreeModel::iterator>(new Gtk::TreeModel::iterator(iter));
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-std::auto_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_item_new(const Gtk::TreeModel::iterator& parent, const Glib::ustring& text)
+std::shared_ptr<Gtk::TreeModel::iterator> Dialog_ExistingOrNew::create_dummy_item_new(const Gtk::TreeModel::iterator& parent, const Glib::ustring& text)
 {
-  Gtk::TreeModel::iterator iter = m_new_model->append(parent->children());
+  auto iter = m_new_model->append(parent->children());
   (*iter)[m_new_columns.m_col_title] = text;
-  return std::auto_ptr<Gtk::TreeModel::iterator>(new Gtk::TreeModel::iterator(iter));
+  return std::shared_ptr<Gtk::TreeModel::iterator>(new Gtk::TreeModel::iterator(iter));
 }
 #endif //GLOM_ENABLE_CLIENT_ONLY
 
@@ -599,7 +594,7 @@ void Dialog_ExistingOrNew::update_ui_sensitivity()
 
   if(m_notebook->get_current_page() == 0)
   {
-    const int count = m_existing_view->get_selection()->count_selected_rows();
+    const auto count = m_existing_view->get_selection()->count_selected_rows();
 
     if(count == 0)
     {
@@ -607,7 +602,7 @@ void Dialog_ExistingOrNew::update_ui_sensitivity()
     }
     else
     {
-      Gtk::TreeModel::iterator sel = m_existing_view->get_selection()->get_selected();
+      auto sel = m_existing_view->get_selection()->get_selected();
       sensitivity = (sel != m_iter_existing_recent);
 #ifndef G_OS_WIN32
       sensitivity = sensitivity && (sel != m_iter_existing_network);
@@ -622,7 +617,7 @@ void Dialog_ExistingOrNew::update_ui_sensitivity()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   else
   {
-    const int count = m_new_view->get_selection()->count_selected_rows();
+    const auto count = m_new_view->get_selection()->count_selected_rows();
 
     if(count == 0)
     {
@@ -630,7 +625,7 @@ void Dialog_ExistingOrNew::update_ui_sensitivity()
     }
     else
     {
-      Gtk::TreeModel::iterator sel = m_new_view->get_selection()->get_selected();
+      auto sel = m_new_view->get_selection()->get_selected();
       sensitivity = (sel != m_iter_new_template &&
                      (!m_iter_new_template_dummy.get() || sel != *m_iter_new_template_dummy));
     }
@@ -650,7 +645,7 @@ Glib::ustring Dialog_ExistingOrNew::get_title_from_example(const std::string& re
     
     //TODO: Really do this asynchronously?
     m_current_buffer.reset(new buffer);
-    const int bytes_read = stream->read(m_current_buffer->buf, buffer::SIZE);
+    const auto bytes_read = stream->read(m_current_buffer->buf, buffer::SIZE);
     const std::string data(m_current_buffer->buf, bytes_read);
     // TODO: Check that data is valid UTF-8, the last character might be truncated
 
@@ -684,10 +679,10 @@ void Dialog_ExistingOrNew::append_example(const Glib::ustring& title, const std:
 
   try
   {
-    const bool is_first_item = m_iter_new_template_dummy.get();
+    const auto is_first_item = m_iter_new_template_dummy.get();
 
     // Add to list.
-    Gtk::TreeModel::iterator iter = m_new_model->append(m_iter_new_template->children());
+    auto iter = m_new_model->append(m_iter_new_template->children());
     (*iter)[m_new_columns.m_col_title] = title;
     (*iter)[m_new_columns.m_col_template_uri] = "resource://" + resource_name; //GFile understands this for actual files, though not directories.
 
@@ -722,7 +717,7 @@ void Dialog_ExistingOrNew::on_service_found(const Glib::ustring& name, EpcServic
 {
   //Translator hint: This is <Service Name> on <Host> (via Network Interface such as eth0).
   gchar* title = g_strdup_printf(_("%s on %s (via %s)"), name.c_str(), epc_service_info_get_host(info), epc_service_info_get_interface(info));
-  Gtk::TreeModel::iterator iter = m_existing_model->prepend(m_iter_existing_network->children());
+  auto iter = m_existing_model->prepend(m_iter_existing_network->children());
   (*iter)[m_existing_columns.m_col_title] = title;
   (*iter)[m_existing_columns.m_col_time] = std::time(0); /* sort more recently discovered items above */
   (*iter)[m_existing_columns.m_col_service_name] = name;
@@ -742,12 +737,12 @@ void Dialog_ExistingOrNew::on_service_found(const Glib::ustring& name, EpcServic
 void Dialog_ExistingOrNew::on_service_removed(const Glib::ustring& name, const Glib::ustring& /* type */)
 {
   // Find the entry with the given name
-  const Gtk::TreeNodeChildren& children = m_iter_existing_network->children();
-  for(Gtk::TreeModel::iterator iter = children.begin(); iter != children.end(); ++ iter)
+  const auto children = m_iter_existing_network->children();
+  for(auto iter = children.begin(); iter != children.end(); ++ iter)
   {
     if((*iter)[m_existing_columns.m_col_service_name] == name)
     {
-      const bool was_expanded = m_existing_view->row_expanded(m_existing_model->get_path(iter));
+      const auto was_expanded = m_existing_view->row_expanded(m_existing_model->get_path(iter));
 
       // Remove from store
       epc_service_info_unref((*iter)[m_existing_columns.m_col_service_info]);
@@ -813,7 +808,7 @@ void Dialog_ExistingOrNew::on_select_clicked()
     filter->set_name("Glom files");
     dialog.add_filter(filter);
 
-    const int response_id = dialog.run();
+    const auto response_id = dialog.run();
     if(response_id == Gtk::RESPONSE_OK)
     {
       m_chosen_uri = dialog.get_uri();
