@@ -34,14 +34,14 @@ const bool Dialog_InvalidData::glade_developer(false);
  */
 bool glom_show_dialog_invalid_data(Field::glom_field_type glom_type)
 {
-  Dialog_InvalidData* dialog = 0;
+  Dialog_InvalidData* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return false;
     
   dialog->set_example_data(glom_type);
   //dialog->set_transient_for(*this);
-  const int response = Glom::UiUtils::dialog_run_with_help(dialog);
+  const auto response = Glom::UiUtils::dialog_run_with_help(dialog);
   
   delete dialog;
   return (response == 2); //The glade file has a response of 2 for the Revert button.
@@ -49,7 +49,7 @@ bool glom_show_dialog_invalid_data(Field::glom_field_type glom_type)
 
 Dialog_InvalidData::Dialog_InvalidData(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_label(0)
+  m_label(nullptr)
 {
   builder->get_widget("label_example_data", m_label);
 }
