@@ -73,29 +73,29 @@ namespace Glom
 
 Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : PlaceHolder(cobject, builder),
-  m_pLabel_Table_DataMode(0),
-  m_pLabel_Table_FindMode(0),
+  m_pLabel_Table_DataMode(nullptr),
+  m_pLabel_Table_FindMode(nullptr),
   m_Box_RecordsCount(Gtk::ORIENTATION_HORIZONTAL, UiUtils::DEFAULT_SPACING_SMALL),
   m_Button_FindAll(_("Find All")),
-  m_stack_mode(0),
-  m_pBox_Tables(0),
-  m_pDialog_Tables(0),
-  m_pBox_QuickFind(0),
-  m_pEntry_QuickFind(0),
-  m_pButton_QuickFind(0),
+  m_stack_mode(nullptr),
+  m_pBox_Tables(nullptr),
+  m_pDialog_Tables(nullptr),
+  m_pBox_QuickFind(nullptr),
+  m_pEntry_QuickFind(nullptr),
+  m_pButton_QuickFind(nullptr),
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  m_pDialog_Reports(0),
-  m_pDialogLayoutReport(0),
-  m_pBox_Reports(0),
-  m_pDialog_PrintLayouts(0),
-  m_pDialogLayoutPrint(0),
-  m_pBox_PrintLayouts(0),
-  m_pDialog_Fields(0),
-  m_pDialog_Relationships(0),
-  m_dialog_addrelatedtable(0),
-  m_window_relationships_overview(0),
+  m_pDialog_Reports(nullptr),
+  m_pDialogLayoutReport(nullptr),
+  m_pBox_Reports(nullptr),
+  m_pDialog_PrintLayouts(nullptr),
+  m_pDialogLayoutPrint(nullptr),
+  m_pBox_PrintLayouts(nullptr),
+  m_pDialog_Fields(nullptr),
+  m_pDialog_Relationships(nullptr),
+  m_dialog_addrelatedtable(nullptr),
+  m_window_relationships_overview(nullptr),
 #endif // !GLOM_ENABLE_CLIENT_ONLY
-  m_pDialogConnection(0)
+  m_pDialogConnection(nullptr)
 {
   m_pLabel_Table_DataMode = Gtk::manage(new Gtk::Label(_("No Table Selected")));
   m_pLabel_Table_DataMode->show();
@@ -127,7 +127,7 @@ Frame_Glom::Frame_Glom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   m_pBox_QuickFind->show_all_children();
   m_pBox_QuickFind->hide();
 
-  PlaceHolder* placeholder_quickfind = 0;
+  PlaceHolder* placeholder_quickfind = nullptr;
   builder->get_widget_derived("vbox_quickfind", placeholder_quickfind);
   if(placeholder_quickfind)
     placeholder_quickfind->add(*m_pBox_QuickFind);
@@ -180,7 +180,7 @@ Frame_Glom::~Frame_Glom()
     remove_view(m_pBox_Tables);
 
   delete m_pDialog_Tables;
-  m_pDialog_Tables = 0;
+  m_pDialog_Tables = nullptr;
 
   remove_view(&m_Notebook_Data); //Also a composite view.
   remove_view(&m_Notebook_Find); //Also a composite view.
@@ -190,7 +190,7 @@ Frame_Glom::~Frame_Glom()
   {
     remove_view(m_pDialogConnection);
     delete m_pDialogConnection;
-    m_pDialogConnection = 0;
+    m_pDialogConnection = nullptr;
   }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
@@ -204,42 +204,42 @@ Frame_Glom::~Frame_Glom()
   {
     remove_view(m_pDialog_Relationships);
     delete m_pDialog_Relationships;
-    m_pDialog_Relationships = 0;
+    m_pDialog_Relationships = nullptr;
   }
 
   if(m_pDialogLayoutReport)
   {
     remove_view(m_pDialogLayoutReport);
     delete m_pDialogLayoutReport;
-    m_pDialogLayoutReport = 0;
+    m_pDialogLayoutReport = nullptr;
   }
 
   if(m_pDialogLayoutPrint)
   {
     remove_view(m_pDialogLayoutPrint);
     delete m_pDialogLayoutPrint;
-    m_pDialogLayoutPrint = 0;
+    m_pDialogLayoutPrint = nullptr;
   }
 
   if(m_pDialog_Fields)
   {
     remove_view(m_pDialog_Fields);
     delete m_pDialog_Fields;
-    m_pDialog_Fields = 0;
+    m_pDialog_Fields = nullptr;
   }
 
   if(m_dialog_addrelatedtable)
   {
     remove_view(m_dialog_addrelatedtable);
     delete m_dialog_addrelatedtable;
-    m_dialog_addrelatedtable = 0;
+    m_dialog_addrelatedtable = nullptr;
   }
 
   if(m_window_relationships_overview)
   {
     remove_view(m_window_relationships_overview);
     delete m_window_relationships_overview;
-    m_window_relationships_overview = 0;
+    m_window_relationships_overview = nullptr;
   }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
@@ -372,10 +372,10 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
       //then sort by the ID, just so we sort by something, so that the order is predictable:
       if(found_set.m_sort_clause.empty())
       {
-        sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
+        std::shared_ptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
         if(field_primary_key)
         {
-          sharedptr<LayoutItem_Field> layout_item_sort = sharedptr<LayoutItem_Field>::create();
+          std::shared_ptr<LayoutItem_Field> layout_item_sort = std::make_shared<LayoutItem_Field>();
           layout_item_sort->set_full_field_details(field_primary_key);
 
           found_set.m_sort_clause.clear();
@@ -384,7 +384,7 @@ void Frame_Glom::show_table_allow_empty(const Glib::ustring& table_name, const G
           //because that would be too slow.
           //The user can explicitly request a sort later, by clicking on a column header.
           //TODO_Performance: This causes an almost-duplicate COUNT query (we do it in the treemodel too), but it's not that slow.
-          sharedptr<LayoutItem_Field> layout_item_temp = sharedptr<LayoutItem_Field>::create();
+          std::shared_ptr<LayoutItem_Field> layout_item_temp = std::make_shared<LayoutItem_Field>();
           layout_item_temp->set_full_field_details(field_primary_key);
           type_vecLayoutFields layout_fields;
           layout_fields.push_back(layout_item_temp);
@@ -461,7 +461,7 @@ bool Frame_Glom::attempt_change_usermode_to_developer()
 
   //Check whether the current user has developer privileges:
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  sharedptr<SharedConnection> sharedconnection = connection_pool->connect();
+      std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect();
 
   // Default to true; if we don't support users, we always have
   // priviliges to change things in developer mode.
@@ -573,7 +573,7 @@ void Frame_Glom::on_menu_file_export()
 
   //const int index_primary_key = fieldsSequence.size() - 1;
 
-  const FoundSet found_set = m_Notebook_Data.get_found_set();
+  const auto found_set = m_Notebook_Data.get_found_set();
 
   std::fstream the_stream(filepath.c_str(), std::ios_base::out | std::ios_base::trunc);
   if(!the_stream)
@@ -615,9 +615,9 @@ void Frame_Glom::export_data_to_vector(Document::type_example_rows& the_vector,
 
         for(guint col_index = 0; col_index < columns_count; ++col_index)
         {
-          const Gnome::Gda::Value value = result->get_value_at(col_index, row_index);
+          const auto value = result->get_value_at(col_index, row_index);
 
-          sharedptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
+          std::shared_ptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
           //if(layout_item->m_field.get_glom_type() != Field::TYPE_IMAGE) //This is too much data.
           //{
 
@@ -665,23 +665,23 @@ void Frame_Glom::export_data_to_stream(std::ostream& the_stream, const FoundSet&
 
         for(guint col_index = 0; col_index < columns_count; ++col_index)
         {
-          const Gnome::Gda::Value value = result->get_value_at(col_index, row_index);
+          const auto value = result->get_value_at(col_index, row_index);
 
-          sharedptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
+          std::shared_ptr<const LayoutItem_Field> layout_item = fieldsSequence[col_index];
           //if(layout_item->m_field.get_glom_type() != Field::TYPE_IMAGE) //This is too much data.
           //{
             if(!row_string.empty())
               row_string += ",";
 
             //Output data in canonical SQL format, ignoring the user's locale, and ignoring the layout formatting:
-            sharedptr<const Field> field = layout_item->get_full_field_details();
+            std::shared_ptr<const Field> field = layout_item->get_full_field_details();
             if(!field)
             {
               std::cerr << G_STRFUNC << ": A field was null." << std::endl;
               return;
             }
 
-            const Glib::ustring field_text = field->to_file_format(value);
+            const auto field_text = field->to_file_format(value);
 
             if(layout_item->get_glom_type() == Field::TYPE_IMAGE) //This is too much data.
             {
@@ -749,7 +749,7 @@ void Frame_Glom::on_menu_file_import()
     {
       file_chooser.hide();
 
-      Dialog_Import_CSV* dialog = 0;
+      Dialog_Import_CSV* dialog = nullptr;
       Glom::Utils::get_glade_widget_derived_with_warning(dialog);
       if(!dialog) //Unlikely and it already warns on stderr.
         return;
@@ -761,7 +761,7 @@ void Frame_Glom::on_menu_file_import()
       {
         dialog->hide();
 
-        Dialog_Import_CSV_Progress* progress_dialog = 0;
+        Dialog_Import_CSV_Progress* progress_dialog = nullptr;
         Glom::Utils::get_glade_widget_derived_with_warning(progress_dialog);
         int response = Gtk::RESPONSE_OK;
         if(!progress_dialog)
@@ -778,7 +778,7 @@ void Frame_Glom::on_menu_file_import()
 
           remove_view(progress_dialog);
           delete progress_dialog;
-          progress_dialog = 0;
+          progress_dialog = nullptr;
 
           // Force update from database so the newly added entries are shown
           show_table_refresh();
@@ -824,19 +824,19 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
     dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
     dialog.add_button(_("_Share"), Gtk::RESPONSE_OK);
 
-    const int response = dialog.run();
+    const auto response = dialog.run();
     dialog.hide();
     if(response == Gtk::RESPONSE_OK)
     {
       shared = true;
 
       //Ask for a user/password if none is set:
-      const bool real_user_exists = Privs::get_developer_user_exists_with_password(document->get_hosting_mode());
+      const auto real_user_exists = Privs::get_developer_user_exists_with_password(document->get_hosting_mode());
       if(!real_user_exists)
       {
         //Ask for an initial user:
         Glib::ustring user, password;
-        const bool initial_password_provided = connection_request_initial_password(user, password);
+        const auto initial_password_provided = connection_request_initial_password(user, password);
         bool added = false;
         if(initial_password_provided)
           added = DbUtils::add_user(document, user, password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
@@ -861,7 +861,7 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
         //b) Reconnect as that user so we can remove the default user.
         //TODO: Check that this user is a developer.
         bool database_not_found = false; //Ignored;
-        const bool dev_password_known = connection_request_password_and_attempt(database_not_found, "" ,"", true /* alternative text */);
+        const auto dev_password_known = connection_request_password_and_attempt(database_not_found, "" ,"", true /* alternative text */);
         if(!dev_password_known)
         {
           shared = false;
@@ -874,8 +874,8 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
         //Remove the default no-password user, because that would be a security hole:
         //We do this after adding/using the non-default user, because we can't
         //remove a currently-used user.
-        const Document::HostingMode hosting_mode = document->get_hosting_mode();
-        const bool default_user_exists = Privs::get_default_developer_user_exists(hosting_mode);
+        const auto hosting_mode = document->get_hosting_mode();
+        const auto default_user_exists = Privs::get_default_developer_user_exists(hosting_mode);
         if(default_user_exists)
         {
           //Force a reconnection with the new password:
@@ -884,10 +884,10 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
           //Remove it, after stopping it from being the database owner:
           bool disabled = true;
           Glib::ustring default_password;
-          const Glib::ustring default_user = Privs::get_default_developer_user_name(default_password, hosting_mode);
+          const auto default_user = Privs::get_default_developer_user_name(default_password, hosting_mode);
 
           ConnectionPool* connectionpool = ConnectionPool::get_instance();
-          const bool reowned = set_database_owner_user(connectionpool->get_user());
+          const auto reowned = set_database_owner_user(connectionpool->get_user());
           bool removed = false;
           if(reowned)
             removed = DbUtils::remove_user(default_user);
@@ -930,22 +930,22 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
     dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
     dialog.add_button(_("_Stop Sharing"), Gtk::RESPONSE_OK);
 
-    const int response = dialog.run();
+    const auto response = dialog.run();
     dialog.hide();
     if(response == Gtk::RESPONSE_OK)
     {
       shared = false;
 
       //Make sure the default no-password user exists:
-      const Document::HostingMode hosting_mode = document->get_hosting_mode();
-      const bool default_user_exists = Privs::get_default_developer_user_exists(hosting_mode);
+      const auto hosting_mode = document->get_hosting_mode();
+      const auto default_user_exists = Privs::get_default_developer_user_exists(hosting_mode);
       if(!default_user_exists)
       {
         //Add it:
         Glib::ustring default_password;
-        const Glib::ustring default_user = Privs::get_default_developer_user_name(default_password, hosting_mode);
+        const auto default_user = Privs::get_default_developer_user_name(default_password, hosting_mode);
 
-        const bool added = DbUtils::add_user(document, default_user, default_password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
+        const auto added = DbUtils::add_user(document, default_user, default_password, GLOM_STANDARD_GROUP_NAME_DEVELOPER);
         if(!added)
         {
            shared = true;
@@ -970,11 +970,11 @@ bool Frame_Glom::attempt_toggle_shared(bool shared)
   if(change)
   {
     ConnectionPool* connectionpool = ConnectionPool::get_instance();
-    sharedptr<SharedConnection> sharedconnection = connectionpool->connect();
+    std::shared_ptr<SharedConnection> sharedconnection = connectionpool->connect();
     if(sharedconnection)
     {
       sharedconnection->close();
-      sharedconnection.clear();
+      sharedconnection.reset();
     }
 
     ShowProgressMessage cleanup_message(_("Stopping Database Server"));
@@ -1035,7 +1035,7 @@ void Frame_Glom::set_mode_find()
 
   const bool previously_in_data_mode = (m_Mode == MODE_Data);
 
-  const Notebook_Data::dataview list_or_details = m_Notebook_Data.get_current_view();
+  const auto list_or_details = m_Notebook_Data.get_current_view();
 
   //A workaround hack to make sure that the list view will be active when the results are shown.
   //Because the list doesn't refresh properly (to give the first result) when the Details view was active first.
@@ -1095,7 +1095,7 @@ void Frame_Glom::on_menu_Tables_AddRelatedTable()
   {
     remove_view(m_dialog_addrelatedtable);
     delete m_dialog_addrelatedtable;
-    m_dialog_addrelatedtable = 0;
+    m_dialog_addrelatedtable = nullptr;
   }
 
   Utils::get_glade_widget_derived_with_warning(m_dialog_addrelatedtable);
@@ -1166,7 +1166,7 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
     else
     {
       //Create the new table:
-      const bool result = DbUtils::create_table_with_default_fields(get_document(), table_name);
+      const auto result = DbUtils::create_table_with_default_fields(get_document(), table_name);
       if(!result)
       {
         std::cerr << G_STRFUNC << ": create_table_with_default_fields() failed." << std::endl;
@@ -1174,7 +1174,7 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
       }
 
       //Create the new relationship:
-      sharedptr<Relationship> relationship = sharedptr<Relationship>::create();
+      std::shared_ptr<Relationship> relationship = std::make_shared<Relationship>();
 
       relationship->set_name(relationship_name);
       relationship->set_title(Utils::title_from_string(relationship_name), AppWindow::get_current_locale());
@@ -1182,7 +1182,7 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
       relationship->set_from_field(from_key_name);
       relationship->set_to_table(table_name);
 
-      sharedptr<Field> related_primary_key = get_field_primary_key_for_table(table_name); //This field was created by create_table_with_default_fields().
+      std::shared_ptr<Field> related_primary_key = get_field_primary_key_for_table(table_name); //This field was created by create_table_with_default_fields().
       if(!related_primary_key)
       {
         std::cerr << G_STRFUNC << ": get_field_primary_key_for_table() failed." << std::endl;
@@ -1202,7 +1202,6 @@ void Frame_Glom::on_dialog_add_related_table_response(int response)
 
       on_dialog_tables_hide(); //Update the menu.
 
-      Gtk::Window* parent = get_app_window();
       if(parent)
         show_ok_dialog(_("Related Table Created"), _("The new related table has been created."), *parent, Gtk::MESSAGE_INFO);
     }
@@ -1321,7 +1320,7 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
   Gnome::Gda::SqlExpr where_clause_to_use = where_clause;
 
   //Prefer the quick find text if any was entered:
-  const Glib::ustring quickfind_criteria = m_pEntry_QuickFind->get_text();
+  const auto quickfind_criteria = m_pEntry_QuickFind->get_text();
   if(!quickfind_criteria.empty())
   {
     where_clause_to_use = 
@@ -1353,7 +1352,7 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
     FoundSet found_set;
     found_set.m_table_name = m_table_name;
     found_set.m_where_clause = where_clause_to_use;
-    const bool inited = m_Notebook_Data.init_db_details(found_set);
+    const auto inited = m_Notebook_Data.init_db_details(found_set);
 
     m_Notebook_Data.select_page_for_find_results();
 
@@ -1368,7 +1367,7 @@ void Frame_Glom::on_notebook_find_criteria(const Gnome::Gda::SqlExpr& where_clau
 
   if(!records_found)
   {
-    const bool find_again = UiUtils::show_warning_no_records_found(*app);
+    const auto find_again = UiUtils::show_warning_no_records_found(*app);
 
     if(!find_again)
     {
@@ -1408,7 +1407,7 @@ void Frame_Glom::show_table_title()
     table_label = m_table_name;
 
   //Show the table title in bold text, because it's important to the user.
-  const Glib::ustring title = UiUtils::bold_message(table_label);
+  const auto title = UiUtils::bold_message(table_label);
   m_pLabel_Table_DataMode->set_markup(title);
   m_pLabel_Table_FindMode->set_markup(title);
 }
@@ -1442,13 +1441,12 @@ void Frame_Glom::update_table_in_document_from_database()
     //and add to, or update Document's list of fields:
     type_vec_fields fieldsDocument = pDoc->get_table_fields(m_table_name);
 
-    for(Base_DB::type_vec_fields::const_iterator iter = fieldsDatabase.begin(); iter != fieldsDatabase.end(); ++iter)
+    for(const auto& field_database : fieldsDatabase)
     {
-      sharedptr<Field> field_database = *iter;
       if(field_database)
       {
         //Is the field already in the document?
-        type_vec_fields::iterator iterFindDoc = std::find_if( fieldsDocument.begin(), fieldsDocument.end(), predicate_FieldHasName<Field>( field_database->get_name() ) );
+        auto iterFindDoc = std::find_if( fieldsDocument.begin(), fieldsDocument.end(), predicate_FieldHasName<Field>( field_database->get_name() ) );
         if(iterFindDoc == fieldsDocument.end()) //If it was not found:
         {
           //Add it
@@ -1459,7 +1457,7 @@ void Frame_Glom::update_table_in_document_from_database()
         {
           //Compare the information:
           Glib::RefPtr<Gnome::Gda::Column> field_info_db = field_database->get_field_info();
-          sharedptr<Field> field_document =  *iterFindDoc;
+          std::shared_ptr<Field> field_document =  *iterFindDoc;
           if(field_document)
           {
             if(!field_document->field_info_from_database_is_equal( field_info_db )) //ignores auto_increment because libgda does not report it from the database properly.
@@ -1490,12 +1488,10 @@ void Frame_Glom::update_table_in_document_from_database()
     if(!fieldsDatabase.empty()) //Do not do this if getting the fields from the database failed completely, probably due to permissions.
     {
       type_vec_fields fieldsActual;
-      for(type_vec_fields::const_iterator iter = fieldsDocument.begin(); iter != fieldsDocument.end(); ++iter)
+      for(const auto& field : fieldsDocument)
       {
-        sharedptr<Field> field = *iter;
-
         //Check whether it's in the database:
-        type_vec_fields::iterator iterFindDatabase = std::find_if( fieldsDatabase.begin(), fieldsDatabase.end(), predicate_FieldHasName<Field>( field->get_name() ) );
+        auto iterFindDatabase = std::find_if( fieldsDatabase.begin(), fieldsDatabase.end(), predicate_FieldHasName<Field>( field->get_name() ) );
         if(iterFindDatabase != fieldsDatabase.end()) //If it was found
         {
           fieldsActual.push_back(field);
@@ -1541,7 +1537,7 @@ void Frame_Glom::load_from_document()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void Frame_Glom::on_menu_developer_database_preferences()
 {
-  Dialog_Database_Preferences* dialog = 0;
+  Dialog_Database_Preferences* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
@@ -1659,7 +1655,7 @@ void Frame_Glom::on_menu_developer_relationships()
 
 void Frame_Glom::on_menu_developer_users()
 {
-  Dialog_GroupsList* dialog = 0;
+  Dialog_GroupsList* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
@@ -1767,7 +1763,7 @@ void Frame_Glom::on_menu_developer_print_layouts()
 
 void Frame_Glom::on_menu_developer_script_library()
 {
-  Dialog_ScriptLibrary* dialog = 0;
+  Dialog_ScriptLibrary* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
@@ -1785,7 +1781,7 @@ void Frame_Glom::on_box_reports_selected(const Glib::ustring& report_name)
 {
   m_pDialog_Reports->hide();
 
-  sharedptr<Report> report = get_document()->get_report(m_table_name, report_name);
+  std::shared_ptr<Report> report = get_document()->get_report(m_table_name, report_name);
   if(report)
   {
     m_pDialogLayoutReport->set_transient_for(*get_app_window());
@@ -1846,7 +1842,7 @@ void Frame_Glom::on_box_print_layouts_selected(const Glib::ustring& print_layout
 
   m_pDialog_PrintLayouts->hide();
 
-  sharedptr<PrintLayout> print_layout = get_document()->get_print_layout(m_table_name, print_layout_name);
+  std::shared_ptr<PrintLayout> print_layout = get_document()->get_print_layout(m_table_name, print_layout_name);
   if(print_layout)
   {
     m_pDialogLayoutPrint->set_transient_for(*app_window);
@@ -1939,7 +1935,7 @@ bool Frame_Glom::connection_request_initial_password(Glib::ustring& user, Glib::
     return false;
 
   //Ask for a new username and password to specify when creating a new self-hosted database.
-  Dialog_InitialPassword* dialog = 0;
+  Dialog_InitialPassword* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog)
     return false;
@@ -1956,7 +1952,7 @@ bool Frame_Glom::connection_request_initial_password(Glib::ustring& user, Glib::
     //Check the password is acceptable:
     if(response == Gtk::RESPONSE_OK)
     {
-      const bool password_ok = dialog->check_password();
+      const auto password_ok = dialog->check_password();
       if(password_ok)
       {
         user = dialog->get_user();
@@ -1975,7 +1971,7 @@ bool Frame_Glom::connection_request_initial_password(Glib::ustring& user, Glib::
 
   remove_view(dialog);
   delete dialog;
-  dialog = 0;
+  dialog = nullptr;
 
   return (response == Gtk::RESPONSE_OK);
 }
@@ -2001,7 +1997,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     add_view(m_pDialogConnection); //Also a composite view.
   }
 
-  const Document::HostingMode hosting_mode = document->get_hosting_mode();
+  const auto hosting_mode = document->get_hosting_mode();
   switch(hosting_mode)
   {
     case Document::HOSTING_MODE_POSTGRES_SELF:
@@ -2011,7 +2007,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
 
       if(document->get_network_shared()) //Usually not the case when creating new documents.
       {
-        const bool test = connection_request_initial_password(user, password);
+        const auto test = connection_request_initial_password(user, password);
         if(!test)
           return false;
       }
@@ -2029,7 +2025,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
       connection_pool->set_password(password);
 
       ShowProgressMessage progress_message(_("Initializing Database Data"));
-      const bool initialized = handle_connection_initialize_errors( connection_pool->initialize(
+      const auto initialized = handle_connection_initialize_errors( connection_pool->initialize(
          sigc::mem_fun(*this, &Frame_Glom::on_connection_initialize_progress) ) );
 
       if(!initialized)
@@ -2051,7 +2047,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
       m_pDialogConnection->load_from_document(); //Get good defaults.
       m_pDialogConnection->set_transient_for(*get_app_window());
 
-      const int response = Glom::UiUtils::dialog_run_with_help(m_pDialogConnection);
+      const auto response = Glom::UiUtils::dialog_run_with_help(m_pDialogConnection);
       m_pDialogConnection->hide();
 
       if(response == Gtk::RESPONSE_OK)
@@ -2106,7 +2102,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     return false;
   }
 
-  const Glib::ustring database_name = document->get_connection_database();
+  const auto database_name = document->get_connection_database();
 
   //std::cout << "debug: database_name to create=" << database_name << std::endl;
 
@@ -2141,7 +2137,7 @@ bool Frame_Glom::connection_request_password_and_choose_new_database_name()
     try
     {
       g_assert(m_pDialogConnection);
-      sharedptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
+      std::shared_ptr<SharedConnection> sharedconnection = m_pDialogConnection->connect_to_server_with_connection_settings();
       //If no exception was thrown then the database exists.
       //But we are looking for an unused database name, so we will try again.
     }
@@ -2282,7 +2278,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
   {
     //We recreate the dialog each time to make sure it is clean of any changes:
     delete m_pDialogConnection;
-    m_pDialogConnection = 0;
+    m_pDialogConnection = nullptr;
 
     Utils::get_glade_widget_derived_with_warning(m_pDialogConnection);
     if(!m_pDialogConnection)
@@ -2310,7 +2306,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
   {
     //Later, if m_pDialogConnection is null then we assume we should use the known user/password:
     delete m_pDialogConnection;
-    m_pDialogConnection = 0;
+    m_pDialogConnection = nullptr;
   }
 
 
@@ -2329,7 +2325,7 @@ bool Frame_Glom::connection_request_password_and_attempt(bool& database_not_foun
     //Try to use the entered username/password:
     if(response == Gtk::RESPONSE_OK)
     {
-      sharedptr<SharedConnection> sharedconnection;
+      std::shared_ptr<SharedConnection> sharedconnection;
 
       //Ask for the user/password if necessary:
       //TODO: Remove any previous database setting?
@@ -2387,14 +2383,14 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
   {
     BusyCursor busycursor(*pWindowApp);
 
-    sigc::slot<void> onProgress; //TODO: Show visual feedback.
+    std::function<void()> onProgress; //TODO: Show visual feedback.
     result = DbUtils::create_database(get_document(), database_name, title, onProgress);
   }
 
   if(!result)
   {
     //Tell the user:
-    Gtk::Dialog* dialog = 0;
+    Gtk::Dialog* dialog = nullptr;
     Utils::get_glade_widget_with_warning("glom_developer.glade", "dialog_error_create_database", dialog);
     if(!dialog)
     {
@@ -2415,7 +2411,7 @@ bool Frame_Glom::create_database(const Glib::ustring& database_name, const Glib:
 
 void Frame_Glom::on_menu_report_selected(const Glib::ustring& report_name)
 {
-  const Privileges table_privs = Privs::get_current_privs(m_table_name);
+  const auto table_privs = Privs::get_current_privs(m_table_name);
 
   //Don't try to print tables that the user can't view.
   if(!table_privs.m_view)
@@ -2425,7 +2421,7 @@ void Frame_Glom::on_menu_report_selected(const Glib::ustring& report_name)
   }
 
   Document* document = get_document();
-  sharedptr<Report> report = document->get_report(m_table_name, report_name);
+  std::shared_ptr<Report> report = document->get_report(m_table_name, report_name);
   if(!report)
     return;
 
@@ -2448,10 +2444,10 @@ void Frame_Glom::on_menu_print_layout_selected(const Glib::ustring& print_layout
 
 void Frame_Glom::do_print_layout(const Glib::ustring& print_layout_name, bool preview, Gtk::Window* transient_for)
 {
-  const Document* document = get_document();
-  sharedptr<const PrintLayout> print_layout = document->get_print_layout(m_table_name, print_layout_name);
+  const auto document = get_document();
+  std::shared_ptr<const PrintLayout> print_layout = document->get_print_layout(m_table_name, print_layout_name);
     
-  const Privileges table_privs = Privs::get_current_privs(m_table_name);
+  const auto table_privs = Privs::get_current_privs(m_table_name);
 
   //Don't try to print tables that the user can't view.
   if(!table_privs.m_view)
@@ -2462,7 +2458,7 @@ void Frame_Glom::do_print_layout(const Glib::ustring& print_layout_name, bool pr
   
   //TODO: When expanding items, avoid the page gaps that the print layout's design
   //has added.  
-  const FoundSet found_set = m_Notebook_Data.get_found_set_selected();
+  const auto found_set = m_Notebook_Data.get_found_set_selected();
   //Note that found_set.m_where_clause could be empty if there are no records yet,
   //and that is acceptable if this is for a print preview while designing the print layout. 
   
@@ -2479,8 +2475,8 @@ void Frame_Glom::on_dialog_layout_report_hide()
 
   if(document && true) //m_pDialogLayoutReport->get_modified())
   {
-    const Glib::ustring original_name = m_pDialogLayoutReport->get_original_report_name();
-    sharedptr<Report> report = m_pDialogLayoutReport->get_report();
+    const auto original_name = m_pDialogLayoutReport->get_original_report_name();
+    std::shared_ptr<Report> report = m_pDialogLayoutReport->get_report();
     if(report && (original_name != report->get_name()))
       document->remove_report(m_table_name, original_name);
 
@@ -2499,8 +2495,8 @@ void Frame_Glom::on_dialog_layout_print_hide()
 
   if(document && true) //m_pDialogLayoutReport->get_modified())
   {
-    const Glib::ustring original_name = m_pDialogLayoutPrint->get_original_name();
-    sharedptr<PrintLayout> print_layout = m_pDialogLayoutPrint->get_print_layout();
+    const auto original_name = m_pDialogLayoutPrint->get_original_name();
+    std::shared_ptr<PrintLayout> print_layout = m_pDialogLayoutPrint->get_print_layout();
     if(print_layout && (original_name != print_layout->get_name()))
       document->remove_report(m_table_name, original_name);
 
@@ -2561,7 +2557,7 @@ void Frame_Glom::on_notebook_data_record_details_requested(const Glib::ustring&
 void Frame_Glom::on_notebook_data_record_selection_changed()
 {
   bool something_selected = false;
-  const FoundSet found_set = m_Notebook_Data.get_found_set_selected();
+  const auto found_set = m_Notebook_Data.get_found_set_selected();
   if(!found_set.m_where_clause.empty())
     something_selected = true;
   
@@ -2570,6 +2566,20 @@ void Frame_Glom::on_notebook_data_record_selection_changed()
     pApp->enable_menu_print_layouts_details(something_selected);  
 }
 
+namespace {
+
+static Glib::ustring ulong_as_string(gulong value)
+{
+  Glib::ustring result;
+  std::stringstream the_stream;
+  //the_stream.imbue( current_locale );
+  the_stream << value;
+  the_stream >> result;
+  return result;
+}
+
+} //anonymous namespace
+
 gulong Frame_Glom::update_records_count()
 {
   //Get the number of records available and the number found,
@@ -2581,11 +2591,7 @@ gulong Frame_Glom::update_records_count()
   //std::cout << G_STRFUNC << ": count_all=" << count_all << ", count_found=" << count_found << std::endl;
 
   std::string str_count_all, str_count_found;
-
-  std::stringstream the_stream;
-  //the_stream.imbue( current_locale );
-  the_stream << count_all;
-  the_stream >> str_count_all;
+  str_count_all = ulong_as_string(count_all);
 
   if(count_found == count_all)
   {
@@ -2598,9 +2604,7 @@ gulong Frame_Glom::update_records_count()
   }
   else
   {
-    std::stringstream the_stream; //Reusing the existing stream seems to produce an empty string.
-    the_stream << count_found;
-    the_stream >> str_count_found;
+    str_count_found = ulong_as_string(count_found);
 
     m_Button_FindAll.show();
   }
