@@ -48,7 +48,7 @@ const char* AUTODETECT_ENCODINGS_CHARSETS[] = {
   "UCS-4"
 };
 
-const guint N_AUTODETECT_ENCODINGS_CHARSETS = sizeof(AUTODETECT_ENCODINGS_CHARSETS)/sizeof(AUTODETECT_ENCODINGS_CHARSETS[0]);
+const auto N_AUTODETECT_ENCODINGS_CHARSETS = sizeof(AUTODETECT_ENCODINGS_CHARSETS)/sizeof(AUTODETECT_ENCODINGS_CHARSETS[0]);
 
 
 Glib::ustring encoding_display(const Glib::ustring& name, const Glib::ustring& charset)
@@ -97,16 +97,14 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   //Fill the list of encodings:
   m_encoding_model = Gtk::ListStore::create(m_encoding_columns);
 
-  Gtk::TreeModel::iterator iter = m_encoding_model->append();
+  auto iter = m_encoding_model->append();
   (*iter)[m_encoding_columns.m_col_name] = _("Auto Detect");
 
   // Separator:
   m_encoding_model->append();
 
-  const FileEncodings::type_list_encodings list_encodings =  FileEncodings::get_list_of_encodings();
-  for(FileEncodings::type_list_encodings::const_iterator encodings_iter = list_encodings.begin(); encodings_iter  != list_encodings.end(); ++encodings_iter)
+  for(const auto& encoding : FileEncodings::get_list_of_encodings())
   {
-    const FileEncodings::Encoding encoding = *encodings_iter;
     if(encoding.get_name().empty())
       continue;
 
@@ -116,7 +114,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
     row[m_encoding_columns.m_col_charset] = encoding.get_charset();
   }
 
-  Gtk::CellRendererText* renderer = Gtk::manage(new Gtk::CellRendererText);
+  auto renderer = Gtk::manage(new Gtk::CellRendererText);
   m_encoding_combo->set_model(m_encoding_model);
   m_encoding_combo->pack_start(*renderer);
   m_encoding_combo->set_cell_data_func(*renderer, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::encoding_data_func), sigc::ref(*renderer)));
@@ -126,7 +124,7 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   m_encoding_combo->signal_changed().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_combo_encoding_changed));
 
   // TODO: Reset parser encoding on selection changed.
-  m_parser = std::auto_ptr<CsvParser>(new CsvParser(get_current_encoding().c_str()));
+  m_parser = std::make_shared<CsvParser>(get_current_encoding().c_str());
   m_parser->signal_file_read_error().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_file_read_error));
   m_parser->signal_have_display_name().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_have_display_name));
   m_parser->signal_encoding_error().connect(sigc::mem_fun(*this, &Dialog_Import_CSV::on_parser_encoding_error));
@@ -152,8 +150,8 @@ Dialog_Import_CSV::Dialog_Import_CSV(BaseObjectType* cobject, const Glib::RefPtr
   the_c_time.tm_mday = 22; //starts at 1
 
   //Get the ISO (not current locale) text representation:
-  const Glib::ustring date_text = Glom::Conversions::format_date(the_c_time, std::locale::classic() /* ignored */, true /* iso_format */);
-  const Glib::ustring advice = Glib::ustring::compose(_("Note that the source file should contain numbers and dates in international ISO format. For instance, 22nd November 2008 should be %1."), date_text);
+  const auto date_text = Glom::Conversions::format_date(the_c_time, std::locale::classic() /* ignored */, true /* iso_format */);
+  const auto advice = Glib::ustring::compose(_("Note that the source file should contain numbers and dates in international ISO format. For instance, 22nd November 2008 should be %1."), date_text);
   m_advice_label->set_text(advice);
   //std::cout << "DEBUG: advice=" << advice << std::endl;
 
@@ -179,7 +177,7 @@ void Dialog_Import_CSV::import(const Glib::ustring& uri, const Glib::ustring& in
 {
   clear();
 
-  Document* document = get_document();
+  auto document = get_document();
   if(!document)
   {
     show_error_dialog(_("No Document Available"), _("You need to open a document to import the data into a table."));
@@ -197,13 +195,12 @@ void Dialog_Import_CSV::import(const Glib::ustring& uri, const Glib::ustring& in
     m_target_table->set_markup("<b>" + Glib::Markup::escape_text(into_table) + "</b>");
 
     m_field_model = Gtk::ListStore::create(m_field_columns);
-    Gtk::TreeModel::iterator tree_iter = m_field_model->append();
-    (*tree_iter)[m_field_columns.m_col_field_name] = _("<None>");
+    auto tree_iter_none = m_field_model->append();
+    (*tree_iter_none)[m_field_columns.m_col_field_name] = _("<None>");
 
     const Document::type_vec_fields fields(document->get_table_fields(into_table));
-    for(Document::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++ iter)
+    for (const auto& field : fields)
     {
-      sharedptr<Field> field = *iter;
       if(!field)
         continue;
 
@@ -212,9 +209,9 @@ void Dialog_Import_CSV::import(const Glib::ustring& uri, const Glib::ustring& in
       // automatically anyway.
       if(!field->get_primary_key() || !field->get_auto_increment())
       {
-        Gtk::TreeModel::iterator tree_iter = m_field_model->append();
-        (*tree_iter)[m_field_columns.m_col_field] = *iter;
-        (*tree_iter)[m_field_columns.m_col_field_name] = (*iter)->get_name();
+        auto tree_iter = m_field_model->append();
+        (*tree_iter)[m_field_columns.m_col_field] = field;
+        (*tree_iter)[m_field_columns.m_col_field_name] = field->get_name();
       }
     }
 
@@ -228,10 +225,10 @@ void Dialog_Import_CSV::import(const Glib::ustring& uri, const Glib::ustring& in
   }
 }
 
-sharedptr<const Field> Dialog_Import_CSV::get_field_for_column(guint col) const
+std::shared_ptr<const Field> Dialog_Import_CSV::get_field_for_column(guint col) const
 {
   if(col >= m_fields.size())
-    return sharedptr<const Field>();
+    return std::shared_ptr<const Field>();
 
   return m_fields[col];
 }
@@ -279,8 +276,8 @@ void Dialog_Import_CSV::show_error_dialog(const Glib::ustring&, const Glib::ustr
 
 void Dialog_Import_CSV::encoding_data_func(const Gtk::TreeModel::iterator& iter, Gtk::CellRendererText& renderer)
 {
-  const Glib::ustring name = (*iter)[m_encoding_columns.m_col_name];
-  const Glib::ustring charset = (*iter)[m_encoding_columns.m_col_charset];
+  const auto name = (*iter)[m_encoding_columns.m_col_name];
+  const auto charset = (*iter)[m_encoding_columns.m_col_charset];
 
   renderer.set_property("text", encoding_display(name, charset));
 }
@@ -293,7 +290,7 @@ bool Dialog_Import_CSV::row_separator_func(const Glib::RefPtr<Gtk::TreeModel>& /
 
 void Dialog_Import_CSV::on_combo_encoding_changed()
 {
-  const int active = m_encoding_combo->get_active_row_number();
+  const auto active = m_encoding_combo->get_active_row_number();
 
   switch(active)
   {
@@ -325,7 +322,7 @@ void Dialog_Import_CSV::on_first_line_as_title_toggled()
   {
     m_sample_view->set_headers_visible(true);
     Gtk::TreeModel::Path path("1");
-    Gtk::TreeModel::iterator iter = m_sample_model->get_iter(path);
+    auto iter = m_sample_model->get_iter(path);
 
     // Remove the first row from the view
     if(iter && (*iter)[m_sample_columns.m_col_row] == 0)
@@ -333,7 +330,7 @@ void Dialog_Import_CSV::on_first_line_as_title_toggled()
       m_sample_model->erase(iter);
 
       // Add another row to the end, if one is loaded.
-      const guint last_index = m_sample_model->children().size();
+      const auto last_index = m_sample_model->children().size();
       iter = m_sample_model->append();
       (*iter)[m_sample_columns.m_col_row] = last_index;
     }
@@ -344,7 +341,7 @@ void Dialog_Import_CSV::on_first_line_as_title_toggled()
 
     // Check whether row 0 is displayed
     Gtk::TreeModel::Path path("1");
-    Gtk::TreeModel::iterator iter = m_sample_model->get_iter(path);
+    auto iter = m_sample_model->get_iter(path);
 
     //if((!iter || (*iter)[m_sample_columns.m_col_row] != 0) && !m_parser->get_rows_empty() && m_sample_rows->get_value_as_int() > 0)
     if((!iter || (*iter)[m_sample_columns.m_col_row] != 0) &&
@@ -359,7 +356,7 @@ void Dialog_Import_CSV::on_first_line_as_title_toggled()
       (*iter)[m_sample_columns.m_col_row] = 0;
 
       // Remove last row if we hit the limit
-      const guint sample_rows = m_sample_model->children().size() - 1;
+      const auto sample_rows = m_sample_model->children().size() - 1;
       if(sample_rows > static_cast<guint>(m_sample_rows->get_value_as_int()))
       {
         //m_sample_model->erase(m_sample_model->children().rbegin());
@@ -378,7 +375,8 @@ void Dialog_Import_CSV::on_sample_rows_changed()
   if(!m_sample_model)
     return;
 
-  const guint current_sample_rows = m_sample_model->children().size() - 1;
+  const auto children_size = m_sample_model->children().size();
+  const guint current_sample_rows = (children_size == 0 ? 0 : children_size - 1);
   const guint new_sample_rows = m_sample_rows->get_value_as_int();
 
   if(current_sample_rows > new_sample_rows)
@@ -386,7 +384,7 @@ void Dialog_Import_CSV::on_sample_rows_changed()
     // +1 for the "target field" row
     Gtk::TreeModel::Path path(1);
     path[0] = new_sample_rows + 1;
-    Gtk::TreeModel::iterator iter = m_sample_model->get_iter(path);
+    auto iter = m_sample_model->get_iter(path);
 
     while(iter != m_sample_model->children().end())
       iter = m_sample_model->erase(iter);
@@ -400,7 +398,7 @@ void Dialog_Import_CSV::on_sample_rows_changed()
 
     for(guint i = current_sample_rows; i < new_sample_rows; ++i, ++row_index)
     {
-      Gtk::TreeModel::iterator iter = m_sample_model->append();
+      auto iter = m_sample_model->append();
       (*iter)[m_sample_columns.m_col_row] = row_index;
     }
   }
@@ -408,7 +406,7 @@ void Dialog_Import_CSV::on_sample_rows_changed()
 
 Glib::ustring Dialog_Import_CSV::get_current_encoding() const
 {
-  Gtk::TreeModel::iterator iter = m_encoding_combo->get_active();
+  auto iter = m_encoding_combo->get_active();
   const Glib::ustring encoding = (*iter)[m_encoding_columns.m_col_charset];
 
   if(encoding.empty())
@@ -426,7 +424,7 @@ void Dialog_Import_CSV::begin_parse()
   if(m_auto_detect_encoding != -1)
   {
     const char* encoding_charset = AUTODETECT_ENCODINGS_CHARSETS[m_auto_detect_encoding];
-    const Glib::ustring encoding_name = FileEncodings::get_name_of_charset(encoding_charset);
+    const auto encoding_name = FileEncodings::get_name_of_charset(encoding_charset);
     m_encoding_info->set_text(Glib::ustring::compose(_("Encoding detected as: %1"), encoding_display(encoding_name, encoding_charset)));
   }
   else
@@ -480,7 +478,7 @@ void Dialog_Import_CSV::on_parser_line_scanned(CsvParser::type_row_strings row,
   if(!m_sample_model)
   {
     setup_sample_model(row);
-    Gtk::TreeModel::iterator iter = m_sample_model->append();
+    auto iter = m_sample_model->append();
     // -1 means the row to select target fields (see special handling in cell data funcs)
     (*iter)[m_sample_columns.m_col_row] = -1;
   }
@@ -488,14 +486,14 @@ void Dialog_Import_CSV::on_parser_line_scanned(CsvParser::type_row_strings row,
   // Add the row to the treeview if there are not yet as much sample rows
   // as the user has chosen (note the first row is to choose the target fields,
   // not a sample row, which is why we do -1 here).
-  const guint sample_rows = m_sample_model->children().size() - 1;
+  const auto sample_rows = m_sample_model->children().size() - 1;
 
   // Don't add if this is the first line and m_first_line_as_title is active:
   if(row_number > 1 || !m_first_line_as_title->get_active())
   {
     if(sample_rows < static_cast<guint>(m_sample_rows->get_value_as_int()))
     {
-      Gtk::TreeModel::iterator tree_iter = m_sample_model->append();
+      auto tree_iter = m_sample_model->append();
       (*tree_iter)[m_sample_columns.m_col_row] = row_number;
     }
   }
@@ -511,8 +509,8 @@ void Dialog_Import_CSV::setup_sample_model(const CsvParser::type_row_strings& ro
   m_fields.resize(row.size());
 
   // Start with a column showing the line number.
-  Gtk::CellRendererText* text = Gtk::manage(new Gtk::CellRendererText);
-  Gtk::TreeViewColumn* col = Gtk::manage(new Gtk::TreeViewColumn(_("Line")));
+  auto text = Gtk::manage(new Gtk::CellRendererText);
+  auto col = Gtk::manage(new Gtk::TreeViewColumn(_("Line")));
   col->pack_start(*text, false);
   col->set_cell_data_func(*text, sigc::mem_fun(*this, &Dialog_Import_CSV::line_data_func));
   m_sample_view->append_column(*col);
@@ -529,7 +527,7 @@ void Dialog_Import_CSV::setup_sample_model(const CsvParser::type_row_strings& ro
 Gtk::TreeViewColumn* Dialog_Import_CSV::create_sample_column(const Glib::ustring& title, guint index)
 {
   Gtk::TreeViewColumn* col = new Gtk::TreeViewColumn(title);
-  Gtk::CellRendererCombo* cell = create_sample_cell(index);
+  auto cell = create_sample_cell(index);
   col->pack_start(*Gtk::manage(cell), true);
   col->set_cell_data_func(*cell, sigc::bind(sigc::mem_fun(*this, &Dialog_Import_CSV::field_data_func), index));
   col->set_sizing(Gtk::TREE_VIEW_COLUMN_AUTOSIZE);
@@ -549,8 +547,8 @@ Gtk::CellRendererCombo* Dialog_Import_CSV::create_sample_cell(guint index)
 
 void Dialog_Import_CSV::line_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter)
 {
-  const int row = (*iter)[m_sample_columns.m_col_row];
-  Gtk::CellRendererText* renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
+  const auto row = (*iter)[m_sample_columns.m_col_row];
+  auto renderer_text = dynamic_cast<Gtk::CellRendererText*>(renderer);
   if(!renderer_text)
     throw std::logic_error("CellRenderer is not a CellRendererText in line_data_func");
 
@@ -562,8 +560,8 @@ void Dialog_Import_CSV::line_data_func(Gtk::CellRenderer* renderer, const Gtk::T
 
 void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::TreeModel::iterator& iter, guint column_number)
 {
-  const int row = (*iter)[m_sample_columns.m_col_row];
-  Gtk::CellRendererCombo* renderer_combo = dynamic_cast<Gtk::CellRendererCombo*>(renderer);
+  const auto row = (*iter)[m_sample_columns.m_col_row];
+  auto renderer_combo = dynamic_cast<Gtk::CellRendererCombo*>(renderer);
   if(!renderer_combo) throw std::logic_error("CellRenderer is not a CellRendererCombo in field_data_func");
 
   Glib::ustring text;
@@ -571,7 +569,7 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 
   if(row == -1)
   {
-    sharedptr<Field> field = m_fields[column_number];
+    std::shared_ptr<Field> field = m_fields[column_number];
     if(field)
       text = field->get_name();
     else
@@ -586,11 +584,11 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 
     if(column_number < m_fields.size())
     {
-      sharedptr<Field> field = m_fields[column_number];
+      std::shared_ptr<Field> field = m_fields[column_number];
 
       if(row != -1) // && static_cast<unsigned int>(row) < m_parser->get_rows_count())
       {
-          const Glib::ustring& orig_text = m_parser->get_data(row, column_number);
+          const auto orig_text = m_parser->get_data(row, column_number);
 
           if(field)
           {
@@ -598,7 +596,7 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
             {
               /* Exported data is always stored in postgres format */
               bool success = false;
-              const Gnome::Gda::Value value = field->from_file_format(orig_text, success);
+              const auto value = field->from_file_format(orig_text, success);
               if(!success)
                 text = _("<Import Failure>");
               else
@@ -641,33 +639,33 @@ void Dialog_Import_CSV::field_data_func(Gtk::CellRenderer* renderer, const Gtk::
 void Dialog_Import_CSV::on_field_edited(const Glib::ustring& path, const Glib::ustring& new_text, guint column_number)
 {
   Gtk::TreeModel::Path treepath(path);
-  Gtk::TreeModel::iterator iter = m_sample_model->get_iter(treepath);
+  auto iter = m_sample_model->get_iter(treepath);
 
   // Lookup field indicated by new_text
-  const Gtk::TreeNodeChildren& children = m_field_model->children();
-  for(Gtk::TreeModel::iterator field_iter = children.begin(); field_iter != children.end(); ++ field_iter)
+  const auto children = m_field_model->children();
+  for(auto field_iter = children.begin(); field_iter != children.end(); ++ field_iter)
   {
     if( (*field_iter)[m_field_columns.m_col_field_name] == new_text)
     {
-      sharedptr<Field> field = (*field_iter)[m_field_columns.m_col_field];
+      std::shared_ptr<Field> field = (*field_iter)[m_field_columns.m_col_field];
       // Check whether another column is already using that field
-      type_vec_fields::iterator vec_field_iter = std::find(m_fields.begin(), m_fields.end(), field);
+      auto vec_field_iter = std::find(m_fields.begin(), m_fields.end(), field);
       // Reset the old column since two different columns cannot be imported into the same field
-      if(vec_field_iter != m_fields.end()) *vec_field_iter = sharedptr<Field>();
+      if(vec_field_iter != m_fields.end()) *vec_field_iter = std::shared_ptr<Field>();
 
       m_fields[column_number] = field;
 
       // Update the rows, so they are redrawn, doing a conversion to the new type.
-      const Gtk::TreeNodeChildren& sample_children = m_sample_model->children();
+      const auto sample_children = m_sample_model->children();
       // Create a TreeModel::Path with initial index 0. We need a TreeModel::Path for the row_changed() call
-      Gtk::TreeModel::Path path("0");
+      Gtk::TreeModel::Path path_changed("0");
 
-      for(Gtk::TreeModel::iterator sample_iter = sample_children.begin(); sample_iter != sample_children.end(); ++ sample_iter)
+      for(auto sample_iter = sample_children.begin(); sample_iter != sample_children.end(); ++ sample_iter)
       {
         if(sample_iter != iter)
-          m_sample_model->row_changed(path, sample_iter);
+          m_sample_model->row_changed(path_changed, sample_iter);
 
-        path.next();
+        path_changed.next();
       }
 
       validate_primary_key();
@@ -687,7 +685,7 @@ void Dialog_Import_CSV::validate_primary_key()
   {
     // Allow the import button to be pressed when the value for the primary key
     // has been chosen:
-    sharedptr<Field> primary_key = get_field_primary_key_for_table(get_target_table_name());
+    auto primary_key = get_field_primary_key_for_table(get_target_table_name());
     bool primary_key_selected = false;
 
     if(primary_key && !primary_key->get_auto_increment())
@@ -698,9 +696,9 @@ void Dialog_Import_CSV::validate_primary_key()
       primary_key_selected = false;
       if(!m_parser->get_rows_empty())
       {
-        for(type_vec_fields::iterator iter = m_fields.begin(); iter != m_fields.end(); ++ iter)
+        for(const auto& field : m_fields)
         {
-          if(*iter == primary_key)
+          if(field == primary_key) //TODO: Is this just comparing shared_ptr?
           {
             primary_key_selected = true;
             break;
