@@ -104,16 +104,16 @@ void SharedConnection::close()
 }
 
 //init_db_details static data:
-ConnectionPool* ConnectionPool::m_instance = 0;
+ConnectionPool* ConnectionPool::m_instance = nullptr;
 
 ConnectionPool::ConnectionPool()
 :
-  m_epc_publisher(0),
-  m_dialog_epc_progress(0),
-  m_backend(0),
+  m_epc_publisher(nullptr),
+  m_dialog_epc_progress(nullptr),
+  m_backend(nullptr),
   m_sharedconnection_refcount(0),
   m_ready_to_connect(false),
-  m_pFieldTypes(0),
+  m_pFieldTypes(nullptr),
   m_show_debug_output(false),
   m_auto_server_shutdown(true),
   m_fake_connection(false)
@@ -123,7 +123,7 @@ ConnectionPool::ConnectionPool()
 ConnectionPool::~ConnectionPool()
 {
   delete m_pFieldTypes;
-  m_pFieldTypes = 0;
+  m_pFieldTypes = nullptr;
 }
 
 //static
@@ -147,7 +147,7 @@ void ConnectionPool::setup_from_document(const Document* document)
     {
       ConnectionPoolBackends::PostgresSelfHosted* backend = new ConnectionPoolBackends::PostgresSelfHosted;
       backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-      set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
+      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
     }
     break;
   case Document::HOSTING_MODE_POSTGRES_CENTRAL:
@@ -156,21 +156,21 @@ void ConnectionPool::setup_from_document(const Document* document)
       backend->set_host(document->get_connection_server());
       backend->set_port(document->get_connection_port());
       backend->set_try_other_ports(document->get_connection_try_other_ports());
-      set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
+      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
     }
     break;
   case Document::HOSTING_MODE_SQLITE:
     {
       ConnectionPoolBackends::Sqlite* backend = new ConnectionPoolBackends::Sqlite;
       backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-      set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
+      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
     }
     break;
   case Document::HOSTING_MODE_MYSQL_SELF:
     {
       ConnectionPoolBackends::MySQLSelfHosted* backend = new ConnectionPoolBackends::MySQLSelfHosted;
       backend->set_database_directory_uri(document->get_connection_self_hosted_directory_uri());
-      set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
+      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
     }
     break;
   case Document::HOSTING_MODE_MYSQL_CENTRAL:
@@ -179,7 +179,7 @@ void ConnectionPool::setup_from_document(const Document* document)
       backend->set_host(document->get_connection_server());
       backend->set_port(document->get_connection_port());
       backend->set_try_other_ports(document->get_connection_try_other_ports());
-      set_backend(std::auto_ptr<ConnectionPool::Backend>(backend));
+      set_backend(std::shared_ptr<ConnectionPool::Backend>(backend));
     }
     break;
 
@@ -200,7 +200,7 @@ void ConnectionPool::setup_from_document(const Document* document)
 void ConnectionPool::delete_instance()
 {
   delete m_instance;
-  m_instance = 0;
+  m_instance = nullptr;
 }
 
 bool ConnectionPool::get_ready_to_connect() const
@@ -213,7 +213,7 @@ void ConnectionPool::set_ready_to_connect(bool val)
   m_ready_to_connect = val;
 }
 
-void ConnectionPool::set_backend(std::auto_ptr<Backend> backend)
+void ConnectionPool::set_backend(std::shared_ptr<Backend> backend)
 {
   m_backend = backend;
 }
@@ -237,9 +237,9 @@ bool ConnectionPool::get_backend_supports_cursor() const
 }
 
 //static:
-sharedptr<SharedConnection> ConnectionPool::get_and_connect()
+std::shared_ptr<SharedConnection> ConnectionPool::get_and_connect()
 {
-  sharedptr<SharedConnection> result(0);
+  std::shared_ptr<SharedConnection> result;
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
   if(!connection_pool)
@@ -270,7 +270,7 @@ bool ConnectionPool::get_instance_is_ready()
 // is immediately requested again, to avoid making a new connection
 // and introspecting again, which is slow.
 // TODO: Why aren't these member variables?
-static sharedptr<SharedConnection> connection_cached;
+static std::shared_ptr<SharedConnection> connection_cached;
 static sigc::connection connection_cached_timeout_connection;
 static sigc::connection connection_cached_finished_connection;
 
@@ -279,18 +279,18 @@ static bool on_connection_pool_cache_timeout()
   //std::cout << "DEBUG: Clearing connection cache." << std::endl;
 
   //Forget the cached connection after a few seconds:
-  connection_cached.clear();
+  connection_cached.reset();
 
   return false; //Don't call this again.
 }
 
 
-sharedptr<SharedConnection> ConnectionPool::connect()
+std::shared_ptr<SharedConnection> ConnectionPool::connect()
 {
   //std::cout << G_STRFUNC << ": debug" << std::endl;
 
   //Don't try to connect if we don't have a backend to connect to.
-  g_return_val_if_fail(m_backend.get(), sharedptr<SharedConnection>(0));
+  g_return_val_if_fail(m_backend.get(), std::shared_ptr<SharedConnection>());
 
   if(get_ready_to_connect() || m_fake_connection)
   {
@@ -302,7 +302,7 @@ sharedptr<SharedConnection> ConnectionPool::connect()
     //If the connection is already open (because it is being used by somebody):
     else if(m_refGdaConnection)
     {
-      sharedptr<SharedConnection> sharedConnection( new SharedConnection(m_refGdaConnection) );
+      std::shared_ptr<SharedConnection> sharedConnection( new SharedConnection(m_refGdaConnection) );
 
       //Ask for notification when the SharedConnection has been finished with:
       //TODO: Note that we are overwriting the connection to a signal of a
@@ -355,7 +355,7 @@ sharedptr<SharedConnection> ConnectionPool::connect()
           //update_meta_store_table_names() has been known to throw an exception.
           //Glom is mostly unusable when it fails, but that's still better than a crash.
           //std::cout << G_STRFUNC << ": Before update_meta_store_table_name()" << std::endl;
-          const bool test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
+          const auto test = m_refGdaConnection->update_meta_store_table_names(m_backend->get_public_schema_name());
           if(!test && !m_fake_connection)
           {
             std::cerr << G_STRFUNC << ": update_meta_store_table_names() failed without an exception." << std::endl;
@@ -398,7 +398,7 @@ sharedptr<SharedConnection> ConnectionPool::connect()
     //std::cerr << G_STRFUNC << ": not ready to connect." << std::endl;
   }
 
-  return sharedptr<SharedConnection>(0);
+  return std::shared_ptr<SharedConnection>();
 }
 
 void ConnectionPool::create_database(const SlotProgress& slot_progress, const Glib::ustring& database_name)
@@ -426,14 +426,14 @@ bool ConnectionPool::save_backup(const SlotProgress& slot_progress, const std::s
 {
   g_assert(m_backend.get());
 
-  const std::string old_uri = m_backend->get_database_directory_uri();
+  const auto old_uri = m_backend->get_database_directory_uri();
 
   std::string uri;
   try
   {
     //TODO_MySQL:
     //TODO: Avoid the copy/paste of glom_postgres_data and make it work for sqlite too.
-    const std::string subdir = Glib::build_filename(path_dir, "glom_postgres_data");
+    const auto subdir = Glib::build_filename(path_dir, "glom_postgres_data");
     uri = Glib::filename_to_uri(subdir);
   }
   catch(const Glib::Error& ex)
@@ -443,7 +443,7 @@ bool ConnectionPool::save_backup(const SlotProgress& slot_progress, const std::s
   }
 
   m_backend->set_database_directory_uri(uri);
-  const bool result = m_backend->save_backup(slot_progress, m_user, m_password, m_database);
+  const auto result = m_backend->save_backup(slot_progress, m_user, m_password, m_database);
   m_backend->set_database_directory_uri(old_uri);
   return result;
 }
@@ -452,7 +452,7 @@ bool ConnectionPool::convert_backup(const SlotProgress& slot_progress, const std
 {
   g_assert(m_backend.get());
 
-  const bool result = m_backend->convert_backup(slot_progress, backup_data_file_path, m_user, m_password, m_database);
+  const auto result = m_backend->convert_backup(slot_progress, backup_data_file_path, m_user, m_password, m_database);
   if(!result)
     return false;
 
@@ -525,7 +525,7 @@ Gnome::Gda::SqlOperatorType ConnectionPool::get_string_find_operator() const
 void ConnectionPool::invalidate_connection()
 {
   //std::cerr << G_STRFUNC << ": debug" << std::endl;
-  connection_cached.clear();
+  connection_cached.reset();
   connection_cached_timeout_connection.disconnect();
   connection_cached_finished_connection.disconnect();
 
@@ -536,7 +536,7 @@ void ConnectionPool::invalidate_connection()
   m_sharedconnection_refcount = 0;
 
   delete m_pFieldTypes;
-  m_pFieldTypes = 0;
+  m_pFieldTypes = nullptr;
 }
 
 void ConnectionPool::on_sharedconnection_finished()
@@ -568,27 +568,25 @@ void ConnectionPool::on_sharedconnection_finished()
 //static
 bool ConnectionPool::handle_error_cerr_only()
 {
-  sharedptr<SharedConnection> sharedconnection = get_and_connect();
+  std::shared_ptr<SharedConnection> sharedconnection = get_and_connect();
 
   if(sharedconnection)
   {
     Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
 
-    typedef std::vector< Glib::RefPtr<Gnome::Gda::ConnectionEvent> > type_list_errors;
-    type_list_errors list_errors = gda_connection->get_events();
+    const auto list_errors = gda_connection->get_events();
 
     if(!list_errors.empty())
     {
       Glib::ustring error_details;
-      for(type_list_errors::iterator iter = list_errors.begin(); iter != list_errors.end(); ++iter)
+      for(const auto& event : list_errors)
       {
-        Glib::RefPtr<Gnome::Gda::ConnectionEvent> event = *iter;
         if(event && (event->get_event_type() == Gnome::Gda::CONNECTION_EVENT_ERROR))
         {
           if(!error_details.empty())
             error_details += '\n'; //Add newline after each error.
 
-          error_details += (*iter)->get_description();
+          error_details += event->get_description();
           std::cerr << G_STRFUNC << ": Internal error (Database): " << error_details << std::endl;
         }
       }
@@ -635,7 +633,7 @@ ConnectionPool::StartupErrors ConnectionPool::startup(const SlotProgress& slot_p
   if(!m_backend.get())
     return Backend::STARTUPERROR_FAILED_UNKNOWN_REASON;
 
-  const Backend::StartupErrors started = m_backend->startup(slot_progress, network_shared);
+  const auto started = m_backend->startup(slot_progress, network_shared);
   if(started != Backend::STARTUPERROR_NONE)
     return started;
 
@@ -716,14 +714,14 @@ bool ConnectionPool::connect_nothrow()
 }
 
 //TODO: Why do we use throw() here and on change_columns()?
-bool ConnectionPool::add_column(const Glib::ustring& table_name, const sharedptr<const Field>& field) throw()
+bool ConnectionPool::add_column(const Glib::ustring& table_name, const std::shared_ptr<const Field>& field) throw()
 {
   if(!connect_nothrow())
     return false;
 
   try
   {
-    const bool result = m_backend->add_column(m_refGdaConnection, table_name, field);
+    const auto result = m_backend->add_column(m_refGdaConnection, table_name, field);
     m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name());
     return result;
   }
@@ -742,7 +740,7 @@ bool ConnectionPool::drop_column(const Glib::ustring& table_name, const Glib::us
 
   try
   {
-    const bool result = m_backend->drop_column(m_refGdaConnection, table_name, field_name);
+    const auto result = m_backend->drop_column(m_refGdaConnection, table_name, field_name);
     m_refGdaConnection->update_meta_store_table(table_name, m_backend->get_public_schema_name());
     return result;
   }
@@ -754,7 +752,7 @@ bool ConnectionPool::drop_column(const Glib::ustring& table_name, const Glib::us
   return false;
 }
 
-bool ConnectionPool::change_column(const Glib::ustring& table_name, const sharedptr<const Field>& field_old, const sharedptr<const Field>& field) throw()
+bool ConnectionPool::change_column(const Glib::ustring& table_name, const std::shared_ptr<const Field>& field_old, const std::shared_ptr<const Field>& field) throw()
 {
   type_vec_const_fields old_fields(1, field_old);
   type_vec_const_fields new_fields(1, field);
@@ -767,7 +765,7 @@ bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_
   if(!connect_nothrow())
     return false;
 
-  const bool result = m_backend->change_columns(m_refGdaConnection, table_name, old_fields, new_fields);
+  const auto result = m_backend->change_columns(m_refGdaConnection, table_name, old_fields, new_fields);
 
   try
   {
@@ -789,8 +787,8 @@ bool ConnectionPool::change_columns(const Glib::ustring& table_name, const type_
   type_vec_const_fields::const_iterator iter_new = new_fields.begin();
   while( (iter_old != old_fields.end()) && (iter_new != new_fields.end()) )
   {
-    const sharedptr<const Field> field_old = *iter_old;
-    const sharedptr<const Field> field_new = *iter_new;
+    const std::shared_ptr<const Field> field_old = *iter_old;
+    const std::shared_ptr<const Field> field_new = *iter_new;
     if(field_old && field_new
       && field_old->get_auto_increment() != field_new->get_auto_increment())
     {
@@ -836,11 +834,11 @@ EpcContents* ConnectionPool::on_publisher_document_requested(EpcPublisher* /* pu
   if(!connection_pool)
     return 0;
 
-  const Document* document = connection_pool->get_document();
+  const auto document = connection_pool->get_document();
   if(!document)
     return 0;
 
-  const Glib::ustring contents = document->get_contents();
+  const auto contents = document->get_contents();
   //std::cout << "debug: " << G_STRFUNC << ": returning: " << std::endl << "  " << contents << std::endl;
   return epc_contents_new_dup ("text/plain", (void*)contents.c_str(), -1);
 }
@@ -857,7 +855,7 @@ gboolean ConnectionPool::on_publisher_document_authentication(EpcAuthContext* co
   g_return_val_if_fail(connection_pool, false);
 
   // Check if the username/password are correct:
-  const gchar* password = epc_auth_context_get_password(context);
+  const auto password = epc_auth_context_get_password(context);
   g_return_val_if_fail(password, false); //TODO: This seems to happen once before this callback is called again properly.
 
   //std::cout << "debug: " << G_STRFUNC << ": username=" << user_name << ", password=" << password << std::endl;
@@ -865,7 +863,7 @@ gboolean ConnectionPool::on_publisher_document_authentication(EpcAuthContext* co
   g_return_val_if_fail(connection_pool->m_backend.get(), false);
 
   //Attempt a connection with this username/password:
-  std::auto_ptr<ExceptionConnection> error;
+  std::shared_ptr<ExceptionConnection> error;
   Glib::RefPtr<Gnome::Gda::Connection> connection = connection_pool->m_backend->connect(connection_pool->get_database(), user_name, password);
 
   if(connection)
@@ -886,7 +884,7 @@ void ConnectionPool::on_epc_progress_begin(const gchar* /* title */, gpointer us
   //We ignore the title parameter because there is no way that libepc could know what Glom wants to say.
 
   ConnectionPool* connection_pool = (ConnectionPool*)user_data;
-  if(connection_pool)
+  if(connection_pool && connection_pool->m_epc_slot_begin)
     connection_pool->m_epc_slot_begin();
 }
 
@@ -896,14 +894,14 @@ void ConnectionPool::on_epc_progress_update(gdouble /* progress */, const gchar*
   //TODO: Show the progress in a ProgressBar.
 
   ConnectionPool* connection_pool = (ConnectionPool*)user_data;
-  if(connection_pool)
+  if(connection_pool && connection_pool->m_epc_slot_progress)
     connection_pool->m_epc_slot_progress();
 }
 
 void ConnectionPool::on_epc_progress_end(gpointer user_data)
 {
   ConnectionPool* connection_pool = (ConnectionPool*)user_data;
-  if(connection_pool)
+  if(connection_pool && connection_pool->m_epc_slot_done)
     connection_pool->m_epc_slot_done();
 }
 
@@ -930,7 +928,7 @@ void ConnectionPool::avahi_start_publishing()
 #endif
 
   //Publish the document contents over HTTPS (discoverable via avahi):
-  const Document* document = get_document();
+  const auto document = get_document();
   if(!document)
     return;
 
@@ -962,7 +960,7 @@ void ConnectionPool::avahi_start_publishing()
     epc_publisher_set_service_cookie(m_epc_publisher, m_database.c_str());
 
   //Start the publisher, serving HTTPS:
-  GError* error = 0;
+  GError* error = nullptr;
   epc_publisher_run_async(m_epc_publisher, &error);
   if(error)
   {
@@ -988,7 +986,7 @@ void ConnectionPool::avahi_stop_publishing()
   epc_publisher_quit(m_epc_publisher);
 #endif // !G_OS_WIN32
   g_object_unref(m_epc_publisher);
-  m_epc_publisher = 0;
+  m_epc_publisher = nullptr;
 }
 #endif // !G_OS_WIN32
 
