@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/connectionpool_backends/backend.h>
@@ -65,10 +65,10 @@ bool Backend::set_network_shared(const SlotProgress& /* slot_progress */, bool /
   return true; //Success at doing nothing.
 }
 
-bool Backend::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const sharedptr<const Field>& field)
+bool Backend::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const std::shared_ptr<const Field>& field)
 {
-  Glib::RefPtr<Gnome::Gda::ServerProvider> provider = connection->get_provider();
-  Glib::RefPtr<Gnome::Gda::ServerOperation> operation = provider->create_operation(connection, Gnome::Gda::SERVER_OPERATION_ADD_COLUMN);
+  auto provider = connection->get_provider();
+  auto operation = provider->create_operation(connection, Gnome::Gda::SERVER_OPERATION_ADD_COLUMN);
 
   //TODO: Quote table_name and field_name?
   operation->set_value_at("/COLUMN_DEF_P/TABLE_NAME", table_name);
@@ -82,8 +82,8 @@ bool Backend::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection,
 
 bool Backend::drop_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
-  Glib::RefPtr<Gnome::Gda::ServerProvider> provider = connection->get_provider();
-  Glib::RefPtr<Gnome::Gda::ServerOperation> operation = provider->create_operation(connection, Gnome::Gda::SERVER_OPERATION_DROP_COLUMN);
+  auto provider = connection->get_provider();
+  auto operation = provider->create_operation(connection, Gnome::Gda::SERVER_OPERATION_DROP_COLUMN);
 
   //TODO: Quote table name and column name?
   operation->set_value_at("/COLUMN_DESC_P/TABLE_NAME", table_name);
