@@ -70,16 +70,16 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
 {
   //We must specify _some_ database even when we just want to create a database.
   //This _might_ be different on some systems. I hope not. murrayc
-  const Glib::ustring default_database = "template1";
-  //const Glib::ustring& actual_database = (!database.empty()) ? database : default_database;;
-  const Glib::ustring cnc_string_main = "HOST=" + DbUtils::gda_cnc_string_encode(m_host)
+  const auto default_database = "template1";
+  //const auto actual_database = (!database.empty()) ? database : default_database;;
+  const auto cnc_string_main = "HOST=" + DbUtils::gda_cnc_string_encode(m_host)
    + ";PORT=" + DbUtils::gda_cnc_string_encode(port);
-  const Glib::ustring cnc_string = cnc_string_main + ";DB_NAME=" + DbUtils::gda_cnc_string_encode(database);
+  const auto cnc_string = cnc_string_main + ";DB_NAME=" + DbUtils::gda_cnc_string_encode(database);
 
   Glib::RefPtr<Gnome::Gda::Connection> connection;
   Glib::RefPtr<Gnome::Gda::DataModel> data_model;
 
-  const Glib::ustring auth_string = create_auth_string(username, password);
+  const auto auth_string = create_auth_string(username, password);
 
 #ifdef GLOM_CONNECTION_DEBUG
   std::cout << std::endl << "DEBUG: Glom: trying to connect on port=" << port << std::endl;
@@ -112,13 +112,13 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
     std::cout << "debug: " << G_STRFUNC << ": Attempting to connect without specifying the database." << std::endl;
 #endif
 
-    const Glib::ustring cnc_string = cnc_string_main + ";DB_NAME=" + DbUtils::gda_cnc_string_encode(default_database);
+    const auto cnc_string_with_db = cnc_string_main + ";DB_NAME=" + DbUtils::gda_cnc_string_encode(default_database);
     Glib::RefPtr<Gnome::Gda::Connection> temp_conn;
-    Glib::ustring auth_string = create_auth_string(username, password);
+    //auto auth_string = create_auth_string(username, password);
     try
     {
       temp_conn = Gnome::Gda::Connection::open_from_string("PostgreSQL",
-        cnc_string, auth_string,
+        cnc_string_with_db, auth_string,
         Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
     }
     catch(const Glib::Error& /* ex */)
@@ -139,16 +139,16 @@ Glib::RefPtr<Gnome::Gda::Connection> Postgres::attempt_connect(const Glib::ustri
 
   if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
   {
-    const Gnome::Gda::Value value = data_model->get_value_at(0, 0);
+    const auto value = data_model->get_value_at(0, 0);
     if(value.get_value_type() == G_TYPE_STRING)
     {
-      const Glib::ustring version_text = value.get_string();
+      const auto version_text = value.get_string();
       //This seems to have the format "PostgreSQL 7.4.11 on i486-pc-linux"
       const Glib::ustring namePart = "PostgreSQL ";
-      const Glib::ustring::size_type posName = version_text.find(namePart);
+      const auto posName = version_text.find(namePart);
       if(posName != Glib::ustring::npos)
       {
-        const Glib::ustring versionPart = version_text.substr(namePart.size());
+        const auto versionPart = version_text.substr(namePart.size());
         m_postgres_server_version = strtof(versionPart.c_str(), 0);
 
 #ifdef GLOM_CONNECTION_DEBUG
@@ -186,14 +186,14 @@ bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connec
 		  if(old_fields[i]->get_field_info()->get_g_type() != new_fields[i]->get_field_info()->get_g_type())
 		  {
 		    // Create a temporary column
-		    sharedptr<Field> temp_field = glom_sharedptr_clone(new_fields[i]);
+		    auto temp_field = glom_sharedptr_clone(new_fields[i]);
 		    temp_field->set_name(TEMP_COLUMN_NAME);
 		    // The temporary column must not be primary key as long as the original
 		    // (primary key) column is still present, because there cannot be two
 		    // primary key columns.
 		    temp_field->set_primary_key(false);
 
-		    const bool added = add_column(connection, table_name, temp_field);
+		    const auto added = add_column(connection, table_name, temp_field);
                     if(!added)
                     {
                       std::cerr << G_STRFUNC << ": add_column() failed." << std::endl;
@@ -201,8 +201,8 @@ bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connec
                     }
 
 		    Glib::ustring conversion_command;
-		    const Glib::ustring field_name_old_quoted = DbUtils::escape_sql_id(old_fields[i]->get_name());
-		    const Field::glom_field_type old_field_type = old_fields[i]->get_glom_type();
+		    const auto field_name_old_quoted = DbUtils::escape_sql_id(old_fields[i]->get_name());
+		    const auto old_field_type = old_fields[i]->get_glom_type();
 
 		    if(Field::get_conversion_possible(old_fields[i]->get_glom_type(), new_fields[i]->get_glom_type()))
 		    {
@@ -379,9 +379,9 @@ bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connec
     {
       connection->rollback_transaction(TRANSACTION_NAME);
     }
-    catch(const Glib::Error& ex)
+    catch(const Glib::Error& ex_rollback)
     {
-      std::cerr << G_STRFUNC << ": Could not rollback the transaction: Exception: " << ex.what() << std::endl;
+      std::cerr << G_STRFUNC << ": Could not rollback the transaction: Exception: " << ex_rollback.what() << std::endl;
     }
   }
   
@@ -390,12 +390,14 @@ bool Postgres::change_columns(const Glib::RefPtr<Gnome::Gda::Connection>& connec
 
 bool Postgres::attempt_create_database(const SlotProgress& slot_progress, const Glib::ustring& database_name, const Glib::ustring& host, const Glib::ustring& port, const Glib::ustring& username, const Glib::ustring& password)
 {
-  slot_progress();
+  if(slot_progress)
+    slot_progress();
 
   Glib::RefPtr<Gnome::Gda::ServerOperation> op = 
     Gnome::Gda::ServerOperation::prepare_create_database("PostgreSQL", database_name);
 
-  slot_progress();
+  if(slot_progress)  
+    slot_progress();
 
   g_assert(op);
   try
@@ -412,7 +414,8 @@ bool Postgres::attempt_create_database(const SlotProgress& slot_progress, const
     return false;
   }
 
-  slot_progress();
+  if(slot_progress)
+    slot_progress();
 
   return true;
 }
@@ -421,10 +424,10 @@ bool Postgres::check_postgres_gda_client_is_available()
 {
   //This API is horrible.
   //See libgda bug http://bugzilla.gnome.org/show_bug.cgi?id=575754
-  Glib::RefPtr<Gnome::Gda::DataModel> model = Gnome::Gda::Config::list_providers();
+  auto model = Gnome::Gda::Config::list_providers();
   if(model && model->get_n_columns() && model->get_n_rows())
   {
-    Glib::RefPtr<Gnome::Gda::DataModelIter> iter = model->create_iter();
+    auto iter = model->create_iter();
 
     do
     {
@@ -443,7 +446,7 @@ bool Postgres::check_postgres_gda_client_is_available()
       if(name.get_value_type() != G_TYPE_STRING)
         continue;
 
-      const Glib::ustring name_as_string = name.get_string();
+      const auto name_as_string = name.get_string();
       //std::cout << "DEBUG: Provider name:" << name_as_string << std::endl;
       if(name_as_string == "PostgreSQL")
         return true;
@@ -467,7 +470,7 @@ std::string Postgres::get_path_to_postgres_executable(const std::string& program
   // share/postgresql which would be nice to separate the postgres stuff
   // from the other shared data. We can perhaps still change this later by
   // building postgres with another prefix than /local/pgsql.
-  gchar* installation_directory = g_win32_get_package_installation_directory_of_module(0);
+  auto installation_directory = g_win32_get_package_installation_directory_of_module(0);
   std::string test;
 
   try
@@ -490,7 +493,7 @@ std::string Postgres::get_path_to_postgres_executable(const std::string& program
   }
 
   // Look in PATH otherwise
-  std::string path = Glib::find_program_in_path(real_program);
+  auto path = Glib::find_program_in_path(real_program);
   if(quoted)
     path = Glib::shell_quote(path);
   return path;
@@ -498,7 +501,7 @@ std::string Postgres::get_path_to_postgres_executable(const std::string& program
   // POSTGRES_UTILS_PATH is defined in config.h, based on the configure.
   try
   {
-    std::string path = Glib::build_filename(POSTGRES_UTILS_PATH, program + EXEEXT);
+    auto path = Glib::build_filename(POSTGRES_UTILS_PATH, program + EXEEXT);
     if(quoted)
       path = Glib::shell_quote(path);
     return path;
@@ -515,7 +518,7 @@ std::string Postgres::get_path_to_postgres_executable(const std::string& program
 Glib::ustring Postgres::port_as_string(unsigned int port_num)
 {
   Glib::ustring result;
-  char* cresult = g_strdup_printf("%u", port_num);
+  auto cresult = g_strdup_printf("%u", port_num);
   if(cresult)
     result = cresult;
   g_free(cresult);
@@ -536,7 +539,7 @@ bool Postgres::save_password_to_pgpass(const Glib::ustring username, const Glib:
   filepath_previous.clear();
   filepath_original.clear();
 
-  const std::string filepath_pgpass = get_absolute_pgpass_filepath();
+  const auto filepath_pgpass = get_absolute_pgpass_filepath();
   filepath_original = filepath_pgpass;
 
   //Move any existing file out of the way:
@@ -572,7 +575,7 @@ bool Postgres::save_password_to_pgpass(const Glib::ustring username, const Glib:
     return false;
   }
 
-  const bool result = create_text_file(uri, contents, true /* current user only */);
+  const auto result = create_text_file(uri, contents, true /* current user only */);
   if(!result)
   {
     std::cerr << G_STRFUNC << ": create_text_file() failed." << std::endl;
@@ -625,20 +628,20 @@ bool Postgres::save_backup(const SlotProgress& slot_progress, const Glib::ustrin
   // Save the password to ~/.pgpass, because this is the only way to use
   // pg_dump without it asking for the password:
   std::string pgpass_backup, pgpass_original;
-  const bool pgpass_created = save_password_to_pgpass(username, password, pgpass_backup, pgpass_original);
+  const auto pgpass_created = save_password_to_pgpass(username, password, pgpass_backup, pgpass_original);
   if(!pgpass_created)
   {
     std::cerr << G_STRFUNC << ": save_password_to_pgpass() failed." << std::endl;
     return false;
   }
 
-  const std::string path_backup = get_self_hosting_backup_path(std::string(), true /* create parent directory if necessary */);
+  const auto path_backup = get_self_hosting_backup_path(std::string(), true /* create parent directory if necessary */);
   if(path_backup.empty())
     return false;
 
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  const std::string command_dump = get_path_to_postgres_executable("pg_dump") +
+  const auto command_dump = get_path_to_postgres_executable("pg_dump") +
     " --format=c " + // The default (plain) format cannot be used with pg_restore.
     " --create --file=" + Glib::shell_quote(path_backup) +
     " --host=" + Glib::shell_quote(m_host) +
@@ -649,7 +652,7 @@ bool Postgres::save_backup(const SlotProgress& slot_progress, const Glib::ustrin
 
   //std::cout << "DEBUG: command_dump=" << command_dump << std::endl;
 
-  const bool result = Glom::Spawn::execute_command_line_and_wait(command_dump, slot_progress);
+  const auto result = Glom::Spawn::execute_command_line_and_wait(command_dump, slot_progress);
 
   //Move the previously-existing .pgpass file back:
   //TODO: Really, we should just edit the file instead of completely replacing it,
@@ -715,7 +718,7 @@ bool Postgres::convert_backup(const SlotProgress& slot_progress, const std::stri
   // Save the password to ~/.pgpass, because this is the only way to use
   // pg_dump without it asking for the password:
   std::string pgpass_backup, pgpass_original;
-  const bool pgpass_created = save_password_to_pgpass(username, password, pgpass_backup, pgpass_original);
+  const auto pgpass_created = save_password_to_pgpass(username, password, pgpass_backup, pgpass_original);
   if(!pgpass_created)
   {
     std::cerr << G_STRFUNC << ": save_password_to_pgpass() failed." << std::endl;
@@ -724,7 +727,7 @@ bool Postgres::convert_backup(const SlotProgress& slot_progress, const std::stri
 
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  const std::string command_restore = get_path_to_postgres_executable("pg_restore") +
+  const auto command_restore = get_path_to_postgres_executable("pg_restore") +
     " -d " + database_name + //TODO: Quote database name?
     " --host=" + Glib::shell_quote(m_host) +
     " --port=" + port_as_string(m_port) +
@@ -735,7 +738,7 @@ bool Postgres::convert_backup(const SlotProgress& slot_progress, const std::stri
 
   //TODO: Put the password in .pgpass
 
-  const bool result = Glom::Spawn::execute_command_line_and_wait(command_restore, slot_progress);
+  const auto result = Glom::Spawn::execute_command_line_and_wait(command_restore, slot_progress);
 
   //Move the previously-existing .pgpass file back:
   //TODO: Really, we should just edit the file instead of completely replacing it,
@@ -759,7 +762,7 @@ bool Postgres::convert_backup(const SlotProgress& slot_progress, const std::stri
 std::string Postgres::get_self_hosting_path(bool create, const std::string& child_directory)
 {
   //Get the filepath of the directory that we should create:
-  const std::string dbdir_uri = m_database_directory_uri;
+  const auto dbdir_uri = m_database_directory_uri;
   //std::cout << "debug: dbdir_uri=" << dbdir_uri << std::endl;
 
   std::string dbdir;
@@ -829,7 +832,7 @@ bool Postgres::create_directory_filepath(const std::string& filepath)
   if(filepath.empty())
     return false;
 
-  const int mkdir_succeeded = g_mkdir_with_parents(filepath.c_str(), 0770);
+  const auto mkdir_succeeded = g_mkdir_with_parents(filepath.c_str(), 0770);
   if(mkdir_succeeded == -1)
   {
     std::cerr << G_STRFUNC << ": Error from g_mkdir_with_parents() while trying to create directory: " << filepath << std::endl;
@@ -846,7 +849,7 @@ bool Postgres::file_exists_filepath(const std::string& filepath)
   if(filepath.empty())
     return false;
 
-  const Glib::RefPtr<Gio::File> file = Gio::File::create_for_path(filepath);
+  const auto file = Gio::File::create_for_path(filepath);
   return file && file->query_exists();
 }
 
@@ -855,7 +858,7 @@ bool Postgres::file_exists_uri(const std::string& uri) const
   if(uri.empty())
     return false;
 
-  const Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(uri);
+  const auto file = Gio::File::create_for_uri(uri);
   return file && file->query_exists();
 }
 
@@ -866,7 +869,7 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
   if(file_uri.empty())
     return false;
 
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(file_uri);
+  auto file = Gio::File::create_for_uri(file_uri);
   Glib::RefPtr<Gio::FileOutputStream> stream;
 
   //Create the file if it does not already exist:
@@ -901,11 +904,11 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
   catch(const Gio::Error& ex)
   {
 #else
-  std::auto_ptr<Gio::Error> error;
+  std::shared_ptr<Gio::Error> error;
   stream.create(error);
   if(error.get())
   {
-    const Gio::Error& ex = *error.get();
+    const auto ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
     std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while creating file." << std::endl
@@ -920,7 +923,7 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
 
 
   gssize bytes_written = 0;
-  const std::string::size_type contents_size = contents.size();
+  const auto contents_size = contents.size();
 #ifdef GLIBMM_EXCEPTIONS_ENABLED
   try
   {
@@ -933,7 +936,7 @@ bool Postgres::create_text_file(const std::string& file_uri, const std::string&
   bytes_written = stream->write(contents.data(), contents_size, error);
   if(error.get())
   {
-    Gio::Error& ex = *error.get();
+    auto ex = *error.get();
 #endif
     // If the operation was not successful, print the error and abort
     std::cerr << G_STRFUNC << ": ConnectionPool::create_text_file(): exception while writing to file." << std::endl
