@@ -123,7 +123,7 @@ bool PostgresSelfHosted::install_postgres(const SlotProgress& /* slot_progress *
   //so there is no need to start a Glom service after installation at system startup,
   //though it will not hurt Glom if you do that.
   const gchar *packages[] = { "postgresql-8.1", 0 };
-  const bool result = gst_packages_install(parent_window->gobj() /* parent window */, packages);
+  const auto result = gst_packages_install(parent_window->gobj() /* parent window */, packages);
   if(result)
   {
     std::cout << "Glom: gst_packages_install() reports success." << std::endl;
@@ -160,28 +160,17 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   }
 
   //Get the filepath of the directory that we should create:
-  const std::string dbdir_uri = m_database_directory_uri;
+  const auto dbdir_uri = m_database_directory_uri;
   //std::cout << "debug: dbdir_uri=" << dbdir_uri << std::endl;
 
   if(file_exists_uri(dbdir_uri))
     return INITERROR_DIRECTORY_ALREADY_EXISTS;
 
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return INITERROR_OTHER;
-  }
-
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   //std::cout << "debug: dbdir=" << dbdir << std::endl;
   g_assert(!dbdir.empty());
 
-  const bool dbdir_created = create_directory_filepath(dbdir);
+  const auto dbdir_created = create_directory_filepath(dbdir);
   if(!dbdir_created)
   {
     std::cerr << G_STRFUNC << ": Couldn't create directory: " << dbdir << std::endl;
@@ -190,7 +179,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   }
 
   //Create the config directory:
-  const std::string dbdir_config = get_self_hosting_config_path(true /* create */);
+  const auto dbdir_config = get_self_hosting_config_path(true /* create */);
   if(dbdir_config.empty())
   {
     std::cerr << G_STRFUNC << ": Couldn't create the config directory: " << dbdir << std::endl;
@@ -202,7 +191,7 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   set_network_shared(slot_progress, m_network_shared); //Creates pg_hba.conf
 
   //Check that there is not an existing data directory:
-  const std::string dbdir_data = get_self_hosting_data_path(true /* create */);
+  const auto dbdir_data = get_self_hosting_data_path(true /* create */);
   if(dbdir_data.empty())
   {
     std::cerr << G_STRFUNC << ": Couldn't create the data directory: " << dbdir << std::endl;
@@ -213,31 +202,24 @@ Backend::InitErrors PostgresSelfHosted::initialize(const SlotProgress& slot_prog
   // initdb creates a new postgres database cluster:
 
   //Get file:// URI for the tmp/ directory:
-  const std::string temp_pwfile = Utils::get_temp_file_path("glom_initdb_pwfile");
-  const Glib::ustring temp_pwfile_uri = Glib::filename_to_uri(temp_pwfile);
-  const bool pwfile_creation_succeeded = create_text_file(temp_pwfile_uri, password);
+  const auto temp_pwfile = Utils::get_temp_file_path("glom_initdb_pwfile");
+  const auto temp_pwfile_uri = Glib::filename_to_uri(temp_pwfile);
+  const auto pwfile_creation_succeeded = create_text_file(temp_pwfile_uri, password);
   g_assert(pwfile_creation_succeeded);
 
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  // We set the default locale, with --locale, to avoid the database's initial locale
-  // from being based on the current environment, because we want the database to be
-  // as portable as possible.
-  // See http://www.postgresql.org/docs/current/static/app-initdb.html
-  const std::string command_initdb = get_path_to_postgres_executable("initdb") +
-    " -D " + Glib::shell_quote(dbdir_data) +
-    " -U " + initial_username +
-    " --pwfile=" + Glib::shell_quote(temp_pwfile) +
-    " --locale=C";
+  const std::string command_initdb = get_path_to_postgres_executable("initdb") + " -D " + Glib::shell_quote(dbdir_data) +
+                                        " -U " + initial_username + " --pwfile=" + Glib::shell_quote(temp_pwfile);
 
   //Note that --pwfile takes the password from the first line of a file. It's an alternative to supplying it when prompted on stdin.
-  const bool result = Glom::Spawn::execute_command_line_and_wait(command_initdb, slot_progress);
+  const auto result = Glom::Spawn::execute_command_line_and_wait(command_initdb, slot_progress);
   if(!result)
   {
     std::cerr << G_STRFUNC << ": Error while attempting to create self-hosting database." << std::endl;
   }
 
-  const int temp_pwfile_removed = g_remove(temp_pwfile.c_str()); //Of course, we don't want this to stay around. It would be a security risk.
+  const auto temp_pwfile_removed = g_remove(temp_pwfile.c_str()); //Of course, we don't want this to stay around. It would be a security risk.
   g_assert(temp_pwfile_removed == 0);
 
   return result ? INITERROR_NONE : INITERROR_COULD_NOT_START_SERVER;
@@ -247,11 +229,11 @@ Glib::ustring PostgresSelfHosted::get_postgresql_utils_version(const SlotProgres
 {
   Glib::ustring result;
 
-  const std::string command = get_path_to_postgres_executable("pg_ctl") + " --version";
+  const auto command = get_path_to_postgres_executable("pg_ctl") + " --version";
 
   //The first command does not return, but the second command can check whether it succeeded:
   std::string output;
-  const bool spawn_result = Glom::Spawn::execute_command_line_and_wait(command, slot_progress, output);
+  const auto spawn_result = Glom::Spawn::execute_command_line_and_wait(command, slot_progress, output);
   if(!spawn_result)
   {
     std::cerr << G_STRFUNC << ": Error while attempting to discover the pg_ctl version." << std::endl;
@@ -283,11 +265,8 @@ Glib::ustring PostgresSelfHosted::get_postgresql_utils_version(const SlotProgres
   //std::cout << "DEBUG: vec.size() == " << vec.size() << std::endl;
 
   // We get, for instance, "\n" and 8.4.1" and "\n".
-  for(type_vec_strings::const_iterator iter = vec.begin();
-       iter != vec.end();
-       ++iter)
+  for(const auto& str : vec)
   {
-    const Glib::ustring str = *iter;
     if(!str.empty())
       return str; //Found.
   }
@@ -299,7 +278,7 @@ float PostgresSelfHosted::get_postgresql_utils_version_as_number(const SlotProgr
 {
   float result = 0;
 
-  const Glib::ustring version_str = get_postgresql_utils_version(slot_progress);
+  const auto version_str = get_postgresql_utils_version(slot_progress);
 
   Glib::RefPtr<Glib::Regex> regex;
 
@@ -319,24 +298,20 @@ float PostgresSelfHosted::get_postgresql_utils_version_as_number(const SlotProgr
   if(!regex)
     return result;
 
-  typedef std::vector<Glib::ustring> type_vec_strings;
-  const type_vec_strings vec = regex->split(version_str, Glib::REGEX_MATCH_NOTEMPTY);
+  const auto vec = regex->split(version_str, Glib::REGEX_MATCH_NOTEMPTY);
   //std::cout << "DEBUG: str == " << version_str << std::endl;
   //std::cout << "DEBUG: vec.size() == " << vec.size() << std::endl;
 
   //We need to loop over the numbers because we get some "" items that we want to ignore:
   guint count = 0; //We want 2 numbers.
-  for(type_vec_strings::const_iterator iter = vec.begin();
-       iter != vec.end();
-       ++iter)
+  for(const auto& str : vec)
   {
     //std::cout << "regex item: START" << *iter << "END" << std::endl;
 
-    const Glib::ustring str = *iter;
     if(str.empty())
       continue;
 
-    const float num = atoi(str.c_str());
+    const auto num = atoi(str.c_str());
     if(count == 0)
       result = num;
     else if(count == 1)
@@ -366,7 +341,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
     return STARTUPERROR_NONE; //Just do it once.
   }
 
-  const std::string dbdir_uri = m_database_directory_uri;
+  const auto dbdir_uri = m_database_directory_uri;
 
   if(!(file_exists_uri(dbdir_uri)))
   {
@@ -374,26 +349,15 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
     return STARTUPERROR_FAILED_NO_MAIN_DIRECTORY;
   }
 
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return STARTUPERROR_FAILED_UNKNOWN_REASON;
-  }
-
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   g_assert(!dbdir.empty());
 
-  const std::string dbdir_data = Glib::build_filename(dbdir, FILENAME_DATA);
-  const Glib::ustring dbdir_data_uri = Glib::filename_to_uri(dbdir_data);
+  const auto dbdir_data = Glib::build_filename(dbdir, FILENAME_DATA);
+  const auto dbdir_data_uri = Glib::filename_to_uri(dbdir_data);
   if(!(file_exists_uri(dbdir_data_uri)))
   {
-    const std::string dbdir_backup = Glib::build_filename(dbdir, FILENAME_BACKUP);
-    const Glib::ustring dbdir_backup_uri = Glib::filename_to_uri(dbdir_backup);
+    const auto dbdir_backup = Glib::build_filename(dbdir, FILENAME_BACKUP);
+    const auto dbdir_backup_uri = Glib::filename_to_uri(dbdir_backup);
     if(file_exists_uri(dbdir_backup_uri))
     {
       std::cerr << G_STRFUNC << ": There is no data, but there is backup data." << std::endl;
@@ -410,7 +374,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   //Attempt to ensure that the config files are correct:
   set_network_shared(slot_progress, m_network_shared); //Creates pg_hba.conf
 
-  const unsigned int available_port = discover_first_free_port(PORT_POSTGRESQL_SELF_HOSTED_START, PORT_POSTGRESQL_SELF_HOSTED_END);
+  const auto available_port = discover_first_free_port(PORT_POSTGRESQL_SELF_HOSTED_START, PORT_POSTGRESQL_SELF_HOSTED_END);
   //std::cout << "debug: " << G_STRFUNC << ":() : debug: Available port for self-hosting: " << available_port << std::endl;
   if(available_port == 0)
   {
@@ -419,18 +383,18 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   }
 
   //TODO: Performance:
-  const std::string port_as_text = Glib::Ascii::dtostr(available_port);
+  const auto port_as_text = Glib::Ascii::dtostr(available_port);
 
   // -D specifies the data directory.
   // -c config_file= specifies the configuration file
   // -k specifies a directory to use for the socket. This must be writable by us.
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  const std::string dbdir_config = Glib::build_filename(dbdir, "config");
-  const std::string dbdir_hba = Glib::build_filename(dbdir_config, "pg_hba.conf");
-  const std::string dbdir_pid = Glib::build_filename(dbdir, "pid");
-  const std::string listen_address = (m_network_shared ? "*" : "localhost");
-  const std::string command_postgres_start = get_path_to_postgres_executable("postgres") + " -D " + Glib::shell_quote(dbdir_data)
+  const auto dbdir_config = Glib::build_filename(dbdir, "config");
+  const auto dbdir_hba = Glib::build_filename(dbdir_config, "pg_hba.conf");
+  const auto dbdir_pid = Glib::build_filename(dbdir, "pid");
+  const auto listen_address = (m_network_shared ? "*" : "localhost");
+  const auto command_postgres_start = get_path_to_postgres_executable("postgres") + " -D " + Glib::shell_quote(dbdir_data)
                                   + " -p " + port_as_text
                                   + " -h " + listen_address
                                   + " -c hba_file=" + Glib::shell_quote(dbdir_hba)
@@ -440,7 +404,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
 
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  const std::string command_check_postgres_has_started = get_path_to_postgres_executable("pg_ctl") + " status -D " + Glib::shell_quote(dbdir_data);
+  const auto command_check_postgres_has_started = get_path_to_postgres_executable("pg_ctl") + " status -D " + Glib::shell_quote(dbdir_data);
 
   //For postgres 8.1, this is "postmaster is running".
   //For postgres 8.2, this is "server is running".
@@ -452,7 +416,7 @@ Backend::StartupErrors PostgresSelfHosted::startup(const SlotProgress& slot_prog
   const std::string second_command_success_text = "is running"; //TODO: This is not a stable API. Also, watch out for localisation.
 
   //The first command does not return, but the second command can check whether it succeeded:
-  const bool result = Glom::Spawn::execute_command_line_and_wait_until_second_command_returns_success(command_postgres_start, command_check_postgres_has_started, slot_progress, second_command_success_text);
+  const auto result = Glom::Spawn::execute_command_line_and_wait_until_second_command_returns_success(command_postgres_start, command_check_postgres_has_started, slot_progress, second_command_success_text);
   if(!result)
   {
     std::cerr << G_STRFUNC << ": Error while attempting to self-host a database." << std::endl;
@@ -471,20 +435,20 @@ void PostgresSelfHosted::show_active_connections()
   builder->select_add_field("*", "pg_stat_activity");
   builder->select_add_target("pg_stat_activity");
  
-  Glib::RefPtr<Gnome::Gda::Connection> gda_connection = connect(m_saved_database_name, m_saved_username, m_saved_password);
+  auto gda_connection = connect(m_saved_database_name, m_saved_username, m_saved_password);
   if(!gda_connection)
     std::cerr << G_STRFUNC << ": connection failed." << std::endl;
   
-  Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
+  auto datamodel = DbUtils::query_execute_select(builder);
   if(!datamodel)
     std::cerr << G_STRFUNC << ": pg_stat_activity SQL query failed." << std::endl;
   
-  const int rows_count = datamodel->get_n_rows(); 
+  const auto rows_count = datamodel->get_n_rows(); 
   if(datamodel->get_n_rows() < 1)
     std::cerr << G_STRFUNC << ": pg_stat_activity SQL query returned no rows." << std::endl;
 
   std::cout << "Active connections according to a pg_stat_activity SQL query:" << std::endl;
-  const int cols_count = datamodel->get_n_columns();
+  const auto cols_count = datamodel->get_n_columns();
   for(int row = 0; row < rows_count; ++row)
   {
     for(int col = 0; col < cols_count; ++col)
@@ -511,22 +475,11 @@ bool PostgresSelfHosted::cleanup(const SlotProgress& slot_progress)
   if(!get_self_hosting_active())
     return true; //Don't try to stop it if we have not started it.
 
-  const std::string dbdir_uri = m_database_directory_uri;
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return false;
-  }
-
+  const auto dbdir_uri = m_database_directory_uri;
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
   g_assert(!dbdir.empty());
 
-  const std::string dbdir_data = Glib::build_filename(dbdir, FILENAME_DATA);
+  const auto dbdir_data = Glib::build_filename(dbdir, FILENAME_DATA);
 
 
   // TODO: Detect other instances on the same computer, and use a different port number,
@@ -539,9 +492,8 @@ bool PostgresSelfHosted::cleanup(const SlotProgress& slot_progress)
   // TODO: Warn about connected clients on other computers? Warn those other users?
   // Make sure to use double quotes for the executable path, because the
   // CreateProcess() API used on Windows does not support single quotes.
-  const std::string command_postgres_stop = get_path_to_postgres_executable("pg_ctl") + " -D " + Glib::shell_quote(dbdir_data) + " stop -m fast";
-  const bool result = Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, slot_progress);
-  if(!result)
+  const auto command_postgres_stop = get_path_to_postgres_executable("pg_ctl") + " -D " + Glib::shell_quote(dbdir_data) + " stop -m fast";
+  if(!Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, slot_progress))
   {
     std::cerr << G_STRFUNC << ": Error while attempting to stop self-hosting of the database. Trying again."  << std::endl;
     
@@ -557,8 +509,7 @@ bool PostgresSelfHosted::cleanup(const SlotProgress& slot_progress)
     
     //I've seen it fail when running under valgrind, and there are reports of failures in bug #420962.
     //Maybe it will help to try again:
-    const bool result = Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, slot_progress);
-    if(!result)
+    if(!Glom::Spawn::execute_command_line_and_wait(command_postgres_stop, slot_progress))
     {
       std::cerr << G_STRFUNC << ": Error while attempting (for a second time) to stop self-hosting of the database."  << std::endl;
       return false;
@@ -578,33 +529,22 @@ bool PostgresSelfHosted::set_network_shared(const SlotProgress& /* slot_progress
 
   m_network_shared = network_shared;
 
-
-  const std::string dbdir_uri = m_database_directory_uri;
-  std::string dbdir;
-  try
-  {
-    dbdir = Glib::filename_from_uri(dbdir_uri);
-  }
-  catch(const Glib::ConvertError& ex)
-  {
-    std::cerr << G_STRFUNC << "Glib::filename_from_uri() failed: " << ex.what() << std::endl;
-
-    return false;
-  }
+  const auto dbdir_uri = m_database_directory_uri;
+  const auto dbdir = Glib::filename_from_uri(dbdir_uri);
 
   const std::string dbdir_uri_config = dbdir_uri + "/config";
-  const char* default_conf_contents = 0;
+  const char* default_conf_contents = nullptr;
 
   // Choose the configuration contents based on 
   // whether we want to be network-shared:
-  //const float postgresql_version = get_postgresql_utils_version_as_number(slot_progress);
+  //const auto postgresql_version = get_postgresql_utils_version_as_number(slot_progress);
   //std::cout << "DEBUG: postgresql_version=" << postgresql_version << std::endl;
 
   default_conf_contents = m_network_shared ? DEFAULT_CONFIG_PG_HBA_REMOTE : DEFAULT_CONFIG_PG_HBA_LOCAL;
 
   //std::cout << "DEBUG: default_conf_contents=" << default_conf_contents << std::endl;
 
-  const bool hba_conf_creation_succeeded = create_text_file(dbdir_uri_config + "/pg_hba.conf", default_conf_contents);
+  const auto hba_conf_creation_succeeded = create_text_file(dbdir_uri_config + "/pg_hba.conf", default_conf_contents);
   g_assert(hba_conf_creation_succeeded);
   if(!hba_conf_creation_succeeded)
     return false;
@@ -658,7 +598,7 @@ Glib::RefPtr<Gnome::Gda::Connection> PostgresSelfHosted::connect(const Glib::ust
         std::cout << "debug: " << G_STRFUNC << ": Waiting and retrying the connection due to suspected too-early success of pg_ctl. retries=" << count_retries << ", max_retries=" << m_network_shared << std::endl;
 
         //Wait:
-        Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
+        auto mainloop = Glib::MainLoop::create(false);
           sigc::connection connection_timeout = Glib::signal_timeout().connect(
           sigc::bind(sigc::ptr_fun(&on_timeout_delay), sigc::ref(mainloop)),
           1000 /* 1 second */);
@@ -693,7 +633,7 @@ bool PostgresSelfHosted::create_database(const SlotProgress& slot_progress, cons
 unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_port, unsigned int end_port)
 {
   //Open a socket so we can try to bind it to a port:
-  const int fd = socket(AF_INET, SOCK_STREAM, 0);
+  const auto fd = socket(AF_INET, SOCK_STREAM, 0);
   if(fd == -1)
   {
 #ifdef G_OS_WIN32
@@ -715,7 +655,7 @@ unsigned int PostgresSelfHosted::discover_first_free_port(unsigned int start_por
   {
     sa.sin_port = htons(port_to_try);
 
-    const int result = bind(fd, (sockaddr*)&sa, sizeof(sa));
+    const auto result = bind(fd, (sockaddr*)&sa, sizeof(sa));
     bool available = false;
     if(result == 0)
        available = true;
