@@ -46,10 +46,10 @@ Glib::RefPtr<Gnome::Gda::Connection> Sqlite::connect(const Glib::ustring& databa
   // Check if the database file exists. If it does not, then we don't try to
   // connect. libgda would create the database file if necessary, but we need
   // to ensure slightly different semantics.
-  Glib::RefPtr<Gio::File> db_dir = Gio::File::create_for_uri(m_database_directory_uri);
-  Glib::RefPtr<Gio::File> db_file = db_dir->get_child(database + ".db");
+  auto db_dir = Gio::File::create_for_uri(m_database_directory_uri);
+  auto db_file = db_dir->get_child(database + ".db");
 
-  const bool file_exists = Glom::Utils::file_exists(db_file);
+  const auto file_exists = Glom::Utils::file_exists(db_file);
   if(!file_exists)
   {
     //We don't warn here because the caller gets an exception anyway,
@@ -67,11 +67,11 @@ Glib::RefPtr<Gnome::Gda::Connection> Sqlite::connect(const Glib::ustring& databa
     else
     {
       // Convert URI to path, for GDA connection string
-      const std::string database_directory = db_dir->get_path();
+      const auto database_directory = db_dir->get_path();
 
-      const Glib::ustring cnc_string = "DB_DIR=" + DbUtils::gda_cnc_string_encode(database_directory) + 
+      const auto cnc_string = "DB_DIR=" + DbUtils::gda_cnc_string_encode(database_directory) + 
         ";DB_NAME=" + DbUtils::gda_cnc_string_encode(database);
-      const Glib::ustring auth_string = Glib::ustring::compose("USERNAME=%1;PASSWORD=%2", 
+      const auto auth_string = Glib::ustring::compose("USERNAME=%1;PASSWORD=%2", 
         DbUtils::gda_cnc_string_encode(username), DbUtils::gda_cnc_string_encode(password));
 
       if(fake_connection)
@@ -113,21 +113,24 @@ bool Sqlite::create_database(const SlotProgress& slot_progress, const Glib::ustr
     return false;
   }
  
-  slot_progress();
+  if(slot_progress)  
+    slot_progress();
  
-  Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(m_database_directory_uri);
-  const std::string database_directory = file->get_path();
-  const Glib::ustring cnc_string = Glib::ustring::compose("DB_DIR=%1;DB_NAME=%2", 
+  auto file = Gio::File::create_for_uri(m_database_directory_uri);
+  const auto database_directory = file->get_path();
+  const auto cnc_string = Glib::ustring::compose("DB_DIR=%1;DB_NAME=%2", 
     DbUtils::gda_cnc_string_encode(database_directory), DbUtils::gda_cnc_string_encode(database_name));
 
-  slot_progress();
+  if(slot_progress)  
+    slot_progress();
 
   Glib::RefPtr<Gnome::Gda::Connection> cnc =
     Gnome::Gda::Connection::open_from_string("SQLite",
       cnc_string, "",
       Gnome::Gda::CONNECTION_OPTIONS_SQL_IDENTIFIERS_CASE_SENSITIVE);
 
-  slot_progress();
+  if(slot_progress)  
+    slot_progress();
 
   return true;
 }
@@ -136,12 +139,12 @@ bool Sqlite::create_database(const SlotProgress& slot_progress, const Glib::ustr
 bool Sqlite::add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, GdaMetaTableColumn* column, unsigned int i)
 {
   //TODO: Quote column name?
-  const Glib::ustring name_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_NAME/%1", i);
-  const Glib::ustring type_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_TYPE/%1", i);
-  const Glib::ustring pkey_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_PKEY/%1", i);
-  const Glib::ustring nnul_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_NNUL/%1", i);
+  const auto name_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_NAME/%1", i);
+  const auto type_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_TYPE/%1", i);
+  const auto pkey_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_PKEY/%1", i);
+  const auto nnul_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_NNUL/%1", i);
   // TODO: Find out whether the column is unique.
-  const Glib::ustring default_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_DEFAULT/%1", i);
+  const auto default_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_DEFAULT/%1", i);
 
   operation->set_value_at(name_path, column->column_name);
   operation->set_value_at(type_path, column->column_type);
@@ -156,14 +159,14 @@ bool Sqlite::add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::Serve
   return true;
 }
 
-bool Sqlite::add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, const sharedptr<const Field>& column, unsigned int i)
+bool Sqlite::add_column_to_server_operation(const Glib::RefPtr<Gnome::Gda::ServerOperation>& operation, const std::shared_ptr<const Field>& column, unsigned int i)
 {
   //TODO: Quote column name?
-  const Glib::ustring name_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_NAME/%1", i);
-  const Glib::ustring type_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_TYPE/%1", i);
-  const Glib::ustring pkey_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_PKEY/%1", i);
-  const Glib::ustring unique_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_UNIQUE/%1", i);
-  const Glib::ustring default_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_DEFAULT/%1", i);
+  const auto name_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_NAME/%1", i);
+  const auto type_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_TYPE/%1", i);
+  const auto pkey_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_PKEY/%1", i);
+  const auto unique_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_UNIQUE/%1", i);
+  const auto default_path = Glib::ustring::compose("/FIELDS_A/@COLUMN_DEFAULT/%1", i);
 
   operation->set_value_at(name_path, column->get_name());
   operation->set_value_at(type_path, column->get_sql_type());
@@ -178,14 +181,14 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
   static const gchar TEMPORARY_TABLE_NAME[] = "GLOM_TEMP_TABLE"; // TODO: Make sure this is unique.
   static const gchar TRANSACTION_NAME[] = "GLOM_RECREATE_TABLE_TRANSACTION";
 
-  Glib::RefPtr<Gnome::Gda::MetaStore> store = connection->get_meta_store();
-  Glib::RefPtr<Gnome::Gda::MetaStruct> metastruct = Gnome::Gda::MetaStruct::create(store, Gnome::Gda::META_STRUCT_FEATURE_NONE);
+  auto store = connection->get_meta_store();
+  auto metastruct = Gnome::Gda::MetaStruct::create(store, Gnome::Gda::META_STRUCT_FEATURE_NONE);
 
-  GdaMetaDbObject* object = metastruct->complement(Gnome::Gda::META_DB_TABLE, Gnome::Gda::Value(), Gnome::Gda::Value(), Gnome::Gda::Value(table_name));
+  auto object = metastruct->complement(Gnome::Gda::META_DB_TABLE, Gnome::Gda::Value(), Gnome::Gda::Value(), Gnome::Gda::Value(table_name));
   if(!object)
     return false;
 
-  Glib::RefPtr<Gnome::Gda::ServerOperation> operation = connection->get_provider()->create_operation(connection, Gnome::Gda::SERVER_OPERATION_CREATE_TABLE);
+  auto operation = connection->get_provider()->create_operation(connection, Gnome::Gda::SERVER_OPERATION_CREATE_TABLE);
   if(!operation)
     return false;
 
@@ -208,7 +211,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
     {
       // If it was removed, and added again, then it has changed, so use the
       // definition from the added_fields vector.
-      type_vec_fields::const_iterator iter = std::find_if(fields_added.begin(), fields_added.end(), predicate_FieldHasName<Field>(column->column_name));
+      auto iter = std::find_if(fields_added.begin(), fields_added.end(), predicate_FieldHasName<Field>(column->column_name));
       if(iter == fields_added.end())
         continue;
       else
@@ -219,7 +222,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
     if(!trans_fields.empty())
       trans_fields += ',';
 
-    const type_mapFieldChanges::const_iterator changed_iter = fields_changed.find(column->column_name);
+    const auto changed_iter = fields_changed.find(column->column_name);
     if(changed_iter != fields_changed.end())
     {
       // Convert values to date or time, accordingly.
@@ -293,19 +296,18 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
     }
   }
 
-  for(type_vec_const_fields::const_iterator iter = fields_added.begin(); iter != fields_added.end(); ++ iter)
+  for(const auto& field : fields_added)
   {
     // Add new fields to the table. Fields that have changed have already
     // been handled above.
-    const sharedptr<const Field>& field = *iter;
-    type_vec_strings::const_iterator removed_iter = std::find(fields_removed.begin(), fields_removed.end(), field->get_name());
+    auto removed_iter = std::find(fields_removed.begin(), fields_removed.end(), field->get_name());
     if(removed_iter == fields_removed.end())
     {
       add_column_to_server_operation(operation, field, i++);
 
       if(!trans_fields.empty())
         trans_fields += ',';
-      const Gnome::Gda::Value default_value = field->get_default_value();
+      const auto default_value = field->get_default_value();
       if(default_value.get_value_type() != G_TYPE_NONE && !default_value.is_null())
         trans_fields += field->sql(default_value, connection);
       else
@@ -331,7 +333,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
 
   try
   {
-    connection->begin_transaction(TRANSACTION_NAME, Gnome::Gda::TRANSACTION_ISOLATION_SERVER_DEFAULT);
+    connection->begin_transaction(TRANSACTION_NAME, Gnome::Gda::TRANSACTION_ISOLATION_UNKNOWN);
   }
   catch(const Glib::Error& ex)
   {
@@ -347,7 +349,7 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
 
     if(!trans_fields.empty())
     {
-      const Glib::ustring query_insert = "INSERT INTO " + DbUtils::escape_sql_id(TEMPORARY_TABLE_NAME) + " SELECT " + trans_fields + " FROM " + DbUtils::escape_sql_id(table_name);
+      const auto query_insert = "INSERT INTO " + DbUtils::escape_sql_id(TEMPORARY_TABLE_NAME) + " SELECT " + trans_fields + " FROM " + DbUtils::escape_sql_id(table_name);
       //std::cout << "debug: query_insert=" << query_insert << std::endl;
       connection->statement_execute_non_select(query_insert);
       connection->statement_execute_non_select("DROP TABLE " + DbUtils::escape_sql_id(table_name));
@@ -367,16 +369,16 @@ bool Sqlite::recreate_table(const Glib::RefPtr<Gnome::Gda::Connection>& connecti
     {
       connection->rollback_transaction(TRANSACTION_NAME);
     }
-    catch(const Glib::Error& ex)
+    catch(const Glib::Error& ex_rollback)
     {
-       std::cerr << G_STRFUNC << ": Could not revert the transaction. exception=" << ex.what() << std::endl;
+       std::cerr << G_STRFUNC << ": Could not revert the transaction. exception=" << ex_rollback.what() << std::endl;
     }
   }
 
   return false;
 }
 
-bool Sqlite::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const sharedptr<const Field>& field)
+bool Sqlite::add_column(const Glib::RefPtr<Gnome::Gda::Connection>& connection, const Glib::ustring& table_name, const std::shared_ptr<const Field>& field)
 {
   // Sqlite does not support adding primary key columns. So recreate the table
   // in that case.
