@@ -54,12 +54,12 @@ public:
     return (element.get_name() == m_strName);
   }
 
-  bool operator() (const sharedptr<T_Element>& element)
+  bool operator() (const std::shared_ptr<T_Element>& element)
   {
     return (element->get_name() == m_strName);
   }
 
-  bool operator() (const sharedptr<const T_Element>& element)
+  bool operator() (const std::shared_ptr<const T_Element>& element)
   {
     return (element->get_name() == m_strName);
   }
@@ -95,9 +95,11 @@ public:
 
   Field();
   Field(const Field& src);
+  Field(Field&& src) = delete;
   ~Field();
 
   Field& operator=(const Field& src);
+  Field& operator=(Field&& src) = delete;
 
   bool operator==(const Field& src) const;
   bool operator!=(const Field& src) const;
@@ -150,8 +152,8 @@ public:
   //Lookup stuff:
   bool get_is_lookup() const;
 
-  sharedptr<Relationship> get_lookup_relationship() const;
-  void set_lookup_relationship(const sharedptr<Relationship>& strRelationship);
+  std::shared_ptr<Relationship> get_lookup_relationship() const;
+  void set_lookup_relationship(const std::shared_ptr<Relationship>& strRelationship);
 
   Glib::ustring get_lookup_field() const;
   void set_lookup_field(const Glib::ustring& strField);
@@ -232,6 +234,8 @@ private:
 
   static void init_map();
 
+  GType get_gda_data_type_with_fallback(const Gnome::Gda::Value& value);
+
   //The glom type to be used for the gda type:
   typedef std::map<GType, glom_field_type> type_map_gda_type_to_glom_type;
   static type_map_gda_type_to_glom_type m_map_gda_type_to_glom_type;
@@ -251,7 +255,7 @@ private:
   glom_field_type m_glom_type;
   Glib::RefPtr<Gnome::Gda::Column> m_field_info;
 
-  sharedptr<Relationship> m_lookup_relationship;
+  std::shared_ptr<Relationship> m_lookup_relationship;
   Glib::ustring m_strLookupField;
   Glib::ustring m_calculation;
   bool m_visible; //Whether it will be shown to the user.
