@@ -35,6 +35,14 @@ FoundSet::FoundSet(const FoundSet& src)
 {
 }
 
+FoundSet::FoundSet(FoundSet&& src)
+:  m_table_name(std::move(src.m_table_name)),
+   m_extra_join(std::move(src.m_extra_join)),
+   m_where_clause(std::move(src.m_where_clause)),
+   m_sort_clause(std::move(src.m_sort_clause))
+{
+}
+
 FoundSet& FoundSet::operator=(const FoundSet& src)
 {
   m_table_name = src.m_table_name;
@@ -45,4 +53,14 @@ FoundSet& FoundSet::operator=(const FoundSet& src)
   return *this;
 }
 
+FoundSet& FoundSet::operator=(FoundSet&& src)
+{
+  m_table_name = std::move(src.m_table_name);
+  m_extra_join = std::move(src.m_extra_join);
+  m_where_clause = std::move(src.m_where_clause);
+  m_sort_clause = std::move(src.m_sort_clause);
+
+  return *this;
+}
+
 } //namespace Glom
