@@ -82,13 +82,24 @@ Glib::ustring Conversions::format_date(const tm& tm_data)
 #define GLOM_NON_TRANSLATED_LOCALE_DATE_FORMAT "%x"
 
 // The % format to use to print and interpret dates, with 4-digit years:
-static const gchar* c_locale_date_format = 0;
+static const gchar* c_locale_date_format = nullptr;
 
 static inline const char* glom_get_locale_date_format()
 {
   if(!c_locale_date_format)
   {
     //Get the current LC_TIME value:
+
+    //Unset LANGUAGE because it affects what setlocale(LC_TIME, NULL) returns,
+    //though it doesn't affect what, for instance, printf() uses. So unsetting
+    //it lets us get the correct LC_TIME locale.
+    const char* ENV_LANGUAGE = "LANGUAGE";
+    char* language = getenv(ENV_LANGUAGE);
+    if(language)
+      language = g_strdup(language);
+
+    setenv(ENV_LANGUAGE, "", 1 /* replace */);
+
     //We copy the string because setlocale() probably returns the same array
     //each time.
     //Even when the LC_TIME environment variable is not set, we still seem
@@ -97,9 +108,9 @@ static inline const char* glom_get_locale_date_format()
     if(lc_time)
       lc_time = g_strdup(lc_time);
 
-    std::cout << "DEBUG: LC_TIME: " << lc_time << std::endl;
+    //std::cout << "DEBUG: LC_TIME: " << lc_time << std::endl;
 
-    char* old_lc_messages = 0;
+    char* old_lc_messages = nullptr;
     bool changed_lc_messages = false;
 
     if(lc_time)
@@ -139,8 +150,14 @@ static inline const char* glom_get_locale_date_format()
       setlocale(LC_MESSAGES, old_lc_messages);
     }
 
+    //Restore this:
+    if(language) { //setenv() can't take NULL for this.
+      setenv(ENV_LANGUAGE, language, 1 /* replace */);
+   }
+
     g_free(old_lc_messages);
     g_free(lc_time);
+    g_free(language);
   }
 
   //std::cout << G_STRFUNC << ": c_locale_date_format=" << c_locale_date_format << std::endl;
@@ -170,7 +187,7 @@ bool Conversions::sanity_check_date_parsing()
   the_c_time.tm_mday = 22; //starts at 1
 
   //Get the current locale's text representation:
-  const Glib::ustring date_text = format_date(the_c_time);
+  const auto date_text = format_date(the_c_time);
   //std::cout << "DEBUG: 22nd November 2008 in this locale has this text represention: " << date_text << std::endl;
 
   //Try to parse it:
@@ -210,7 +227,7 @@ bool Conversions::sanity_check_date_text_representation_uses_4_digit_years(bool
   the_c_time.tm_mday = 22; //starts at 1
 
   //Get the current locale's text representation:
-  const Glib::ustring date_text = format_date(the_c_time);
+  const auto date_text = format_date(the_c_time);
 
   if(debug_output)
   {
@@ -220,7 +237,7 @@ bool Conversions::sanity_check_date_text_representation_uses_4_digit_years(bool
   //See if the year appears in full in that date.
   //There are probably some locales for which this fails.
   //Please tell us if there are.
-  const Glib::ustring::size_type pos = date_text.find("2008");
+  const auto pos = date_text.find("2008");
   if(pos == Glib::ustring::npos)
   {
     //Note to translators: If you see this error in the terminal at startup then you need to translate the %x elsewhere.
@@ -253,7 +270,7 @@ Glib::ustring Conversions::format_tm(const tm& tm_data, const std::locale& local
 
   // Get a time_put face:
   typedef std::time_put<char> type_time_put;
-  const type_time_put& tp = std::use_facet<type_time_put>(locale);
+  const auto& tp = std::use_facet<type_time_put>(locale);
 
   //type_iterator begin(the_stream);
   tp.put(the_stream /* iter to beginning of stream */, the_stream, ' ' /* fill */, &tm_data, format, format + strlen(format) /* 'E' */ /* use locale's alternative format */);
@@ -282,7 +299,7 @@ Glib::ustring Conversions::format_tm(const tm& tm_data, const std::locale& local
   /*
   //This is based on the code in Glib::Date::format_string(), which only deals with dates, but not times:
 
-  const std::string locale_format = Glib::locale_from_utf8("%X"); //%x means "is replaced by the locale's appropriate time representation".
+  const auto locale_format = Glib::locale_from_utf8("%X"); //%x means "is replaced by the locale's appropriate time representation".
   gsize bufsize = std::max<gsize>(2 * locale_format.size(), 128);
 
   do
@@ -292,7 +309,7 @@ Glib::ustring Conversions::format_tm(const tm& tm_data, const std::locale& local
     // Set the first byte to something other than '\0', to be able to
     // recognize whether strftime actually failed or just returned "".
     buf.get()[0] = '\1';
-    const gsize len = strftime(buf.get(), bufsize, locale_format.c_str(), &tm_data);
+    const auto len = strftime(buf.get(), bufsize, locale_format.c_str(), &tm_data);
 
     if(len != 0 || buf.get()[0] == '\0')
     {
@@ -352,7 +369,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
 
 double Conversions::get_double_for_gda_value_numeric(const Gnome::Gda::Value& value)
 {
-  const GType vtype = value.get_value_type();
+  const auto vtype = value.get_value_type();
   if(vtype != GDA_TYPE_NUMERIC)
   {
     // Note that in case the database system does not support GdaNumeric
@@ -380,7 +397,7 @@ double Conversions::get_double_for_gda_value_numeric(const Gnome::Gda::Value& va
     }
   }
 
-  const Gnome::Gda::Numeric numeric = value.get_numeric();
+  const auto numeric = value.get_numeric();
   return numeric.get_double();
 }
 
@@ -466,7 +483,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
   }
   else if(glom_type == Field::TYPE_NUMERIC)
   {
-    const GType value_type = value.get_value_type();
+    const auto value_type = value.get_value_type();
     if(value_type != GDA_TYPE_NUMERIC
       && value_type != G_TYPE_DOUBLE
       && value_type != G_TYPE_INT) //SQLite uses int for summary field results.
@@ -475,7 +492,7 @@ Glib::ustring Conversions::get_text_for_gda_value(Field::glom_field_type glom_ty
       return value.to_string();
     }
 
-    const double number = get_double_for_gda_value_numeric(value);
+    const auto number = get_double_for_gda_value_numeric(value);
 
     //Get the locale-specific text representation, in the required format:
     std::stringstream another_stream;
@@ -642,7 +659,7 @@ Gnome::Gda::Value Conversions::parse_value(Field::glom_field_type glom_type, con
     if(!(numeric_format.m_currency_symbol.empty()))
     {
       //Remove the currency symbol:
-      const Glib::ustring prefix = text_to_parse.substr(0, numeric_format.m_currency_symbol.size());
+      const auto prefix = text_to_parse.substr(0, numeric_format.m_currency_symbol.size());
       if(text_to_parse.substr(0, numeric_format.m_currency_symbol.size()) == numeric_format.m_currency_symbol)
       {
         text_to_parse = text_to_parse.substr(numeric_format.m_currency_symbol.size());
@@ -728,8 +745,8 @@ tm Conversions::parse_date(const Glib::ustring& text, const std::locale& locale,
   //because std::get_time() stupidly parses _only_ that format.
   //Some implementations parse extra formats, in unspecified/non-standard ways, but not g++'s libstdc++
   //So just use the fallback instead. It's probably good enough.
-  const bool is_iso_locale = (locale == std::locale::classic());
-  const bool skip_time_get = !is_iso_locale && (strcmp(GLOM_NON_TRANSLATED_LOCALE_DATE_FORMAT, glom_get_locale_date_format()) != 0);
+  const auto is_iso_locale = (locale == std::locale::classic());
+  const auto skip_time_get = !is_iso_locale && (strcmp(GLOM_NON_TRANSLATED_LOCALE_DATE_FORMAT, glom_get_locale_date_format()) != 0);
 
   std::ios_base::iostate err = std::ios_base::goodbit;  //The initialization is essential because time_get seems to a) not initialize this output argument and b) check its value.
 
@@ -745,7 +762,7 @@ tm Conversions::parse_date(const Glib::ustring& text, const std::locale& locale,
     typedef std::time_get<char> type_time_get;
     typedef type_time_get::iter_type type_iterator;
 
-    const type_time_get& tg = std::use_facet<type_time_get>(locale);
+    const auto& tg = std::use_facet<type_time_get>(locale);
 
     type_iterator the_begin(the_stream);
     type_iterator the_end;
@@ -880,7 +897,7 @@ tm Conversions::parse_time(const Glib::ustring& text, const std::locale& locale,
   // Get a time_get facet:
   typedef std::istreambuf_iterator<char, std::char_traits<char> > type_iterator;
   typedef std::time_get<char, type_iterator> type_time_get;
-  const type_time_get& tg = std::use_facet<type_time_get>(locale);
+  const auto& tg = std::use_facet<type_time_get>(locale);
 
   type_iterator the_begin(the_stream);
   type_iterator the_end;
@@ -968,7 +985,7 @@ tm Conversions::parse_tm(const Glib::ustring& text, const std::locale& locale, c
   // Get a time_get facet:
   typedef std::istreambuf_iterator<char, std::char_traits<char> > type_iterator;
   typedef std::time_get<char, type_iterator> type_time_get;
-  const type_time_get& tg = std::use_facet<type_time_get>(locale);
+  const auto& tg = std::use_facet<type_time_get>(locale);
 
   the_stream << text;
 
@@ -1060,12 +1077,12 @@ static bool vtype_is_numeric(GType vtype)
 
 Gnome::Gda::Value Conversions::convert_value(const Gnome::Gda::Value& value, Field::glom_field_type target_glom_type)
 {
-  const GType gvalue_type_target = Field::get_gda_type_for_glom_type(target_glom_type);
-  const GType gvalue_type_source = value.get_value_type();
+  const auto gvalue_type_target = Field::get_gda_type_for_glom_type(target_glom_type);
+  const auto gvalue_type_source = value.get_value_type();
   if(gvalue_type_source == gvalue_type_target)
     return value; //No conversion necessary, and no loss of precision.
   
-  const Field::glom_field_type source_glom_type = Field::get_glom_type_for_gda_type(gvalue_type_source);
+  const auto source_glom_type = Field::get_glom_type_for_gda_type(gvalue_type_source);
   if(source_glom_type == target_glom_type)
   {
     //Try to return the canonical type, 
@@ -1073,13 +1090,13 @@ Gnome::Gda::Value Conversions::convert_value(const Gnome::Gda::Value& value, Fie
     if((target_glom_type == Field::TYPE_NUMERIC) && 
       (vtype_is_numeric(gvalue_type_source)))
     {
-      const double number = get_double_for_gda_value_numeric(value);
+      const auto number = get_double_for_gda_value_numeric(value);
       return parse_value(number);
     }
   }
 
   //Fallback for other conversions:
-  const Glib::ustring text = get_text_for_gda_value(source_glom_type, value, std::locale::classic(), NumericFormat(), true /* iso_format */);
+  const auto text = get_text_for_gda_value(source_glom_type, value, std::locale::classic(), NumericFormat(), true /* iso_format */);
   bool test = false;
   return parse_value(target_glom_type, text, test, true /* iso_format */);
 }
