@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/data_structure/layout/layoutitem_field.h>
@@ -60,7 +60,7 @@ LayoutItem* LayoutItem_Field::clone() const
 
 bool LayoutItem_Field::operator==(const LayoutItem_Field& src) const
 {
-  bool result = LayoutItem_WithFormatting::operator==(src) &&
+  auto result = LayoutItem_WithFormatting::operator==(src) &&
     UsesRelationship::operator==(src) &&
     (m_priv_view == src.m_priv_view) &&
     (m_priv_edit == src.m_priv_edit) &&
@@ -179,7 +179,7 @@ bool LayoutItem_Field::get_editable_and_allowed() const
   //The relationship might forbid editing of any fields through itself:
   if(get_has_relationship_name())
   {
-    sharedptr<const Relationship> rel = get_relationship();
+    std::shared_ptr<const Relationship> rel = get_relationship();
     if(rel)
     {
       if(!(rel->get_allow_edit()))
@@ -254,7 +254,7 @@ const Formatting& LayoutItem_Field::get_formatting_used() const
 
 Formatting::HorizontalAlignment LayoutItem_Field::get_formatting_used_horizontal_alignment(bool for_details_view) const
 {
-  const Formatting& format = get_formatting_used();
+  const auto format = get_formatting_used();
   Formatting::HorizontalAlignment alignment = 
     format.get_horizontal_alignment();
   
@@ -276,7 +276,7 @@ Formatting::HorizontalAlignment LayoutItem_Field::get_formatting_used_horizontal
 
 bool LayoutItem_Field::get_formatting_used_has_translatable_choices() const
 {
-  const Formatting& formatting = get_formatting_used();
+  const auto formatting = get_formatting_used();
   if(!formatting.get_has_custom_choices())
     return false;
 
@@ -288,7 +288,7 @@ bool LayoutItem_Field::get_formatting_used_has_translatable_choices() const
 }
 
 
-void LayoutItem_Field::set_full_field_details(const sharedptr<const Field>& field)
+void LayoutItem_Field::set_full_field_details(const std::shared_ptr<const Field>& field)
 {
 
   if(field)
@@ -303,12 +303,12 @@ void LayoutItem_Field::set_full_field_details(const sharedptr<const Field>& fiel
   else
   {
     //std::cout << "LayoutItem_Field::set_full_field_details(null): previous name=" << m_name << std::endl;
-    m_field = sharedptr<const Field>();
+    m_field = std::shared_ptr<const Field>();
     m_field_cache_valid = false;
   }
 }
 
-sharedptr<const Field> LayoutItem_Field::get_full_field_details() const
+std::shared_ptr<const Field> LayoutItem_Field::get_full_field_details() const
 {
   return m_field;
 }
@@ -322,25 +322,25 @@ Field::glom_field_type LayoutItem_Field::get_glom_type() const
 }
 
 
-sharedptr<const CustomTitle> LayoutItem_Field::get_title_custom() const
+std::shared_ptr<const CustomTitle> LayoutItem_Field::get_title_custom() const
 {
   return m_title_custom;
 }
 
-sharedptr<CustomTitle> LayoutItem_Field::get_title_custom()
+std::shared_ptr<CustomTitle> LayoutItem_Field::get_title_custom()
 {
   return m_title_custom;
 }
 
-void LayoutItem_Field::set_title_custom(const sharedptr<CustomTitle>& title)
+void LayoutItem_Field::set_title_custom(const std::shared_ptr<CustomTitle>& title)
 {
   m_title_custom = title;
 }
 
-bool LayoutItem_Field::is_same_field(const sharedptr<const LayoutItem_Field>& field) const
+bool LayoutItem_Field::is_same_field(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
-  const UsesRelationship* uses_a = this;
-  const UsesRelationship* uses_b = &(*field);
+  const auto uses_a = this;
+  const auto uses_b = &(*field);
   if(!uses_a || !uses_b)
     return false; //Shouldn't happen.
     
