@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/data_structure/layout/layoutitem_image.h>
@@ -48,7 +48,7 @@ LayoutItem* LayoutItem_Image::clone() const
 
 bool LayoutItem_Image::operator==(const LayoutItem_Image& src) const
 {
-  bool result = LayoutItem::operator==(src) && 
+  auto result = LayoutItem::operator==(src) && 
                 (m_image == src.m_image);
 
   return result;
