@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "layoutitem_withformatting.h"
@@ -40,7 +40,7 @@ LayoutItem_WithFormatting::~LayoutItem_WithFormatting()
 
 bool LayoutItem_WithFormatting::operator==(const LayoutItem_WithFormatting& src) const
 {
-  bool result = LayoutItem::operator==(src) && 
+  auto result = LayoutItem::operator==(src) && 
                 (m_formatting == src.m_formatting);
 
   return result;
@@ -63,7 +63,7 @@ const Formatting& LayoutItem_WithFormatting::get_formatting_used() const
 
 Formatting::HorizontalAlignment LayoutItem_WithFormatting::get_formatting_used_horizontal_alignment(bool /* for_details_view */) const
 {
-  const Formatting& format = get_formatting_used();
+  const auto format = get_formatting_used();
   Formatting::HorizontalAlignment alignment = 
     format.get_horizontal_alignment();
   
