@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
  
 #include <libglom/data_structure/layout/report_parts/layoutitem_fieldsummary.h>
@@ -61,14 +61,14 @@ LayoutItem_FieldSummary& LayoutItem_FieldSummary::operator=(const LayoutItem_Fie
 
 Glib::ustring LayoutItem_FieldSummary::get_title_or_name(const Glib::ustring& locale) const
 {
-  const Glib::ustring field_title = get_full_field_details()->get_title_or_name(locale);
+  const auto field_title = get_full_field_details()->get_title_or_name(locale);
 
   return get_summary_type_name(m_summary_type) + ": " + field_title; //TODO: Allow a more human-readable title for summary headings.
 }
 
 Glib::ustring LayoutItem_FieldSummary::get_title(const Glib::ustring& locale) const
 {
-  const Glib::ustring field_title = get_full_field_details()->get_title(locale);
+  const auto field_title = get_full_field_details()->get_title(locale);
 
   return get_summary_type_name(m_summary_type) + ": " + field_title; //TODO: Allow a more human-readable title for summary headings.
 }
@@ -120,7 +120,7 @@ void LayoutItem_FieldSummary::set_summary_type_from_sql(const Glib::ustring& sum
     m_summary_type = TYPE_INVALID;
 }
 
-void LayoutItem_FieldSummary::set_field(const sharedptr<LayoutItem_Field>& field)
+void LayoutItem_FieldSummary::set_field(const std::shared_ptr<LayoutItem_Field>& field)
 {
   if(field)
     LayoutItem_Field::operator=(*field);
@@ -128,7 +128,7 @@ void LayoutItem_FieldSummary::set_field(const sharedptr<LayoutItem_Field>& field
 
 Glib::ustring LayoutItem_FieldSummary::get_layout_display_name() const
 {
-  Glib::ustring result = get_layout_display_name_field();
+  auto result = get_layout_display_name_field();
 
   if(m_summary_type == TYPE_INVALID)
     result = _("No summary chosen");
