@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/data_structure/print_layout.h>
@@ -31,7 +31,7 @@ PrintLayout::PrintLayout()
   m_page_count(1) //A sensible default
 {
   m_translatable_item_type = TRANSLATABLE_TYPE_PRINT_LAYOUT;
-  m_layout_group = sharedptr<LayoutGroup>::create();
+  m_layout_group = std::make_shared<LayoutGroup>();
 }
 
 PrintLayout::PrintLayout(const PrintLayout& src)
@@ -75,12 +75,12 @@ void PrintLayout::set_show_table_title(bool show_table_title)
   m_show_table_title = show_table_title;
 }
 
-sharedptr<LayoutGroup> PrintLayout::get_layout_group()
+std::shared_ptr<LayoutGroup> PrintLayout::get_layout_group()
 {
   return m_layout_group;
 }
 
-sharedptr<const LayoutGroup> PrintLayout::get_layout_group() const
+std::shared_ptr<const LayoutGroup> PrintLayout::get_layout_group() const
 {
   return m_layout_group;
 }
