@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <libglom/data_structure/report.h>
@@ -27,7 +27,7 @@ Report::Report()
 : m_show_table_title(true)
 {
   m_translatable_item_type = TRANSLATABLE_TYPE_REPORT;
-  m_layout_group = sharedptr<LayoutGroup>::create();
+  m_layout_group = std::make_shared<LayoutGroup>();
 }
 
 Report::Report(const Report& src)
@@ -58,12 +58,12 @@ void Report::set_show_table_title(bool show_table_title)
 }
 
 
-sharedptr<LayoutGroup> Report::get_layout_group()
+std::shared_ptr<LayoutGroup> Report::get_layout_group()
 {
   return m_layout_group;
 }
 
-sharedptr<const LayoutGroup> Report::get_layout_group() const
+std::shared_ptr<const LayoutGroup> Report::get_layout_group() const
 {
   return m_layout_group;
 }
