@@ -46,11 +46,11 @@ Privs::type_vec_strings Privs::get_database_groups()
   Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
   if(data_model)
   {
-    const int rows_count = data_model->get_n_rows();
+    const auto rows_count = data_model->get_n_rows();
     for(int row = 0; row < rows_count; ++row)
     {
-      const Gnome::Gda::Value value = data_model->get_value_at(0, row);
-      const Glib::ustring name = value.get_string();
+      const auto value = data_model->get_value_at(0, row);
+      const auto name = value.get_string();
       result.push_back(name);
     }
   }
@@ -61,9 +61,9 @@ Privs::type_vec_strings Privs::get_database_groups()
 bool Privs::get_default_developer_user_exists(Document::HostingMode hosting_mode)
 {
   Glib::ustring default_password;
-  const Glib::ustring default_user = get_default_developer_user_name(default_password, hosting_mode);
+  const auto default_user = get_default_developer_user_name(default_password, hosting_mode);
 
-  const type_vec_strings users = get_database_users();
+  const auto users = get_database_users();
   type_vec_strings::const_iterator iterFind = std::find(users.begin(), users.end(), default_user);
   if(iterFind != users.end())
     return true; //We assume that the password is what it should be and that it has developer rights.
@@ -74,12 +74,11 @@ bool Privs::get_default_developer_user_exists(Document::HostingMode hosting_mode
 bool Privs::get_developer_user_exists_with_password(Document::HostingMode hosting_mode)
 {
   Glib::ustring default_password;
-  const Glib::ustring default_user = get_default_developer_user_name(default_password, hosting_mode);
+  const auto default_user = get_default_developer_user_name(default_password, hosting_mode);
 
-  const type_vec_strings users = get_database_users();
-  for(type_vec_strings::const_iterator iter = users.begin(); iter != users.end(); ++iter)
+  const auto users = get_database_users();
+  for(const auto& user : users)
   {
-    const Glib::ustring user = *iter;
     if(user == default_user)
       continue;
 
@@ -124,62 +123,62 @@ Privs::type_vec_strings Privs::get_database_users(const Glib::ustring& group_nam
     Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
     if(data_model)
     {
-      const int rows_count = data_model->get_n_rows();
+      const auto rows_count = data_model->get_n_rows();
       for(int row = 0; row < rows_count; ++row)
       {
-        const Gnome::Gda::Value value = data_model->get_value_at(0, row);
-        const Glib::ustring name = value.get_string();
+        const auto value = data_model->get_value_at(0, row);
+        const auto name = value.get_string();
         result.push_back(name);
       }
     }
   }
   else
   {
-    Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+    Glib::RefPtr<Gnome::Gda::SqlBuilder> builderGroup =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
-    builder->select_add_field("groname", "pg_group");
-    builder->select_add_field("grolist", "pg_group");
-    builder->select_add_target("pg_group");
-    builder->set_where(
-      builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-        builder->add_field_id("groname", "pg_group"),
-        builder->add_expr(group_name)));
+    builderGroup->select_add_field("groname", "pg_group");
+    builderGroup->select_add_field("grolist", "pg_group");
+    builderGroup->select_add_target("pg_group");
+    builderGroup->set_where(
+      builderGroup->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
+        builderGroup->add_field_id("groname", "pg_group"),
+        builderGroup->add_expr(group_name)));
     //TODO: Show SQL.
-    Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
-    if(data_model && data_model->get_n_rows())
+    Glib::RefPtr<Gnome::Gda::DataModel> data_model_group = DbUtils::query_execute_select(builderGroup);
+    if(data_model_group && data_model_group->get_n_rows())
     {
-      const int rows_count = data_model->get_n_rows();
+      const auto rows_count = data_model_group->get_n_rows();
       for(int row = 0; row < rows_count; ++row)
       {
-        const Gnome::Gda::Value value = data_model->get_value_at(1, row); //Column 1 is the /* the user list.
+        const auto value_group = data_model_group->get_value_at(1, row); //Column 1 is the /* the user list.
         //pg_group is a string, formatted, bizarrely, like so: "{100, 101}".
 
         Glib::ustring group_list;
-        if(!value.is_null())
-          group_list = value.get_string();
+        if(!value_group.is_null())
+          group_list = value_group.get_string();
 
         type_vec_strings vecUserIds = pg_list_separate(group_list);
-        for(type_vec_strings::const_iterator iter = vecUserIds.begin(); iter != vecUserIds.end(); ++iter)
+        for(const auto& userId: vecUserIds)
         {
           //TODO_Performance: Can we do this in one SQL SELECT?
-          Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
+          Glib::RefPtr<Gnome::Gda::SqlBuilder> builderUser =
             Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
-          builder->select_add_field("usename", "pg_user");
-          builder->select_add_target("pg_user");
-          builder->set_where(
-            builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
-              builder->add_field_id("usesysid", "pg_user"),
-              builder->add_expr(*iter)));
-          Glib::RefPtr<Gnome::Gda::DataModel> data_model = DbUtils::query_execute_select(builder);
-          if(data_model && data_model->get_n_rows() && data_model->get_n_columns())
+          builderUser->select_add_field("usename", "pg_user");
+          builderUser->select_add_target("pg_user");
+          builderUser->set_where(
+            builderUser->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_EQ,
+              builderUser->add_field_id("usesysid", "pg_user"),
+              builderUser->add_expr(userId)));
+          Glib::RefPtr<Gnome::Gda::DataModel> data_model_user = DbUtils::query_execute_select(builderUser);
+          if(data_model_user && data_model_user->get_n_rows() && data_model_user->get_n_columns())
           {
-            const Gnome::Gda::Value value = data_model->get_value_at(0, 0);
+            const auto value_user = data_model_user->get_value_at(0, 0);
             //std::cout << G_STRFUNC << "DEBUG:  username=" << value.get_string() << std::endl; 
-            result.push_back(value.get_string());
+            result.push_back(value_user.get_string());
           }
           else
           {
-            std::cerr << G_STRFUNC << ": user not found in pg_user table: " << *iter << std::endl;
+            std::cerr << G_STRFUNC << ": user not found in pg_user table: " << userId << std::endl;
           }
         }
 
@@ -248,7 +247,7 @@ bool Privs::set_table_privileges(const Glib::ustring& group_name, const Glib::us
 
   strQuery += " GROUP " + DbUtils::escape_sql_id(group_name);
 
-  const bool test = DbUtils::query_execute_string(strQuery);
+  const auto test = DbUtils::query_execute_string(strQuery);
   if(!test)
   {
     std::cerr << G_STRFUNC << ": GRANT failed." << std::endl;
@@ -274,7 +273,7 @@ bool Privs::set_table_privileges(const Glib::ustring& group_name, const Glib::us
 
 static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
 {
-  sharedptr<SharedConnection> sharedconnection;
+  std::shared_ptr<SharedConnection> sharedconnection;
   try
   {
      sharedconnection = ConnectionPool::get_and_connect();
@@ -287,7 +286,7 @@ static Glib::RefPtr<Gnome::Gda::Connection> get_connection()
   if(!sharedconnection)
   {
     std::cerr << G_STRFUNC << ": No connection yet." << std::endl;
-    return Glib::RefPtr<Gnome::Gda::Connection>(0);
+    return Glib::RefPtr<Gnome::Gda::Connection>();
   }
 
   Glib::RefPtr<Gnome::Gda::Connection> gda_connection = sharedconnection->get_gda_connection();
@@ -334,7 +333,7 @@ Privileges Privs::get_table_privileges(const Glib::ustring& group_name, const Gl
   //The table name must be quoted if it needs to be quoted,
   //but not quoted if it is does not need to be quoted,
   //because it must match how it was created, and libgda probably did not quote it unless necessary.
-  const Glib::ustring table_name_for_arg = connection->quote_sql_identifier(table_name);
+  const auto table_name_for_arg = connection->quote_sql_identifier(table_name);
   args_base.push_back(builder->add_expr(table_name_for_arg));
 
   std::vector<Gnome::Gda::SqlBuilder::Id> args = args_base;
@@ -400,13 +399,13 @@ Privs::type_vec_strings Privs::get_groups_of_user(const Glib::ustring& user)
 
   //Look at each group:
   type_vec_strings groups = get_database_groups();
-  for(type_vec_strings::const_iterator iter = groups.begin(); iter != groups.end(); ++iter)
+  for(const auto& group : groups)
   {
     //See whether the user is in this group:
-    if(get_user_is_in_group(user, *iter))
+    if(get_user_is_in_group(user, group))
     {
       //Add the group to the result:
-      result.push_back(*iter);
+      result.push_back(group);
     }
   }
 
@@ -415,7 +414,7 @@ Privs::type_vec_strings Privs::get_groups_of_user(const Glib::ustring& user)
 
 bool Privs::get_user_is_in_group(const Glib::ustring& user, const Glib::ustring& group)
 {
-  const type_vec_strings users = get_database_users(group);
+  const auto users = get_database_users(group);
   type_vec_strings::const_iterator iterFind = std::find(users.begin(), users.end(), user);
   return (iterFind != users.end());
 }
@@ -425,7 +424,7 @@ bool Privs::on_privs_privileges_cache_timeout(const Glib::ustring& table_name)
   //std::cout << "debug: " << G_STRFUNC << ": table=" << table_name << std::endl;
 
   //Forget the cached privileges after a few seconds:
-  type_map_privileges::iterator iter = m_privileges_cache.find(table_name);
+  auto iter = m_privileges_cache.find(table_name);
   if(iter != m_privileges_cache.end())
   {
     //std::cout << "debug: " << G_STRFUNC << ": Cleared cache for table=" << table_name << std::endl;
@@ -464,7 +463,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
   //std::cout << "debug: " << G_STRFUNC << ": Getting non-cached." << std::endl;
 
   ConnectionPool* connection_pool = ConnectionPool::get_instance();
-  const Glib::ustring current_user = connection_pool->get_user();
+  const auto current_user = connection_pool->get_user();
 
   //Is the user in the special developers group?
   /*
@@ -475,14 +474,14 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
     result.m_developer = true;
   }
   */
-  sharedptr<SharedConnection> sharedconnection = connection_pool->connect();
+  std::shared_ptr<SharedConnection> sharedconnection = connection_pool->connect();
   if(sharedconnection && sharedconnection->get_gda_connection()->supports_feature(Gnome::Gda::CONNECTION_FEATURE_USERS))
   {
     //Get the "true" rights for any groups that the user is in:
-    type_vec_strings groups = get_groups_of_user(current_user);
-    for(type_vec_strings::const_iterator iter = groups.begin(); iter != groups.end(); ++iter)
+    const type_vec_strings groups = get_groups_of_user(current_user);
+    for(const auto& group : groups)
     {
-      Privileges privs = get_table_privileges(*iter, table_name);
+      const auto privs = get_table_privileges(group, table_name);
 
       if(privs.m_view)
         result.m_view = true;
@@ -515,7 +514,7 @@ Privileges Privs::get_current_privs(const Glib::ustring& table_name)
   //TODO: Make sure we handle the failure well in that unlikely case.
 
   //Stop the existing timeout if it has not run yet.
-  type_map_cache_timeouts::iterator iter_connection = m_map_cache_timeouts.find(table_name);
+  auto iter_connection = m_map_cache_timeouts.find(table_name);
   if(iter_connection != m_map_cache_timeouts.end())
     iter_connection->second.disconnect();
 
