@@ -39,7 +39,7 @@ namespace Glom
 
 //Set the object's member data, from the parameters supplied when creating the object:
 PyGlomRecord::PyGlomRecord()
-: m_document(0),
+: m_document(nullptr),
   m_read_only(false)
 {
 }
@@ -87,12 +87,11 @@ boost::python::object PyGlomRecord::get_related()
     m_related = boost::python::object(new PyGlomRelated()); //TODO_NotSure
 
     //Fill it:
-    Document::type_vec_relationships vecRelationships = m_document->get_relationships(m_table_name);
     PyGlomRelated::type_map_relationships map_relationships;
-    for(Document::type_vec_relationships::const_iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
+    for(const auto& relationship : m_document->get_relationships(m_table_name))
     {
-      if(*iter)
-        map_relationships[(*iter)->get_name()] = *iter;
+      if(relationship)
+        map_relationships[relationship->get_name()] = relationship;
     }
 
     boost::python::extract<PyGlomRelated*> extractor(m_related);
@@ -140,7 +139,7 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   if(extractor.check())
     field_name = extractor;
 
-  sharedptr<const Field> field = m_document->get_field(m_table_name, field_name);
+  std::shared_ptr<const Field> field = m_document->get_field(m_table_name, field_name);
   if(!field)
   {
      std::cerr << G_STRFUNC << ": field=" << field_name << " not found in table=" << m_table_name << std::endl;
@@ -212,14 +211,14 @@ void PyGlomRecord::setitem(const boost::python::object& key, const boost::python
   //TODO: Do dependent calculations and lookups. Or just do them for all fields for this record when finishing the script?
 }
 
-void PyGlomRecord::set_fields(const PyGlomRecord::type_map_field_values& field_values, const Document* document, const Glib::ustring& table_name, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_field_value, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
+void PyGlomRecord::set_fields(const PyGlomRecord::type_map_field_values& field_values, const Document* document, const Glib::ustring& table_name, const std::shared_ptr<const Field>& key_field, const Gnome::Gda::Value& key_field_value, const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection)
 {
   m_map_field_values = field_values;
   /* Just for debugging:
-  for(type_map_field_values::const_iterator iter = field_values.begin(); iter != field_values.end(); ++iter)
+  for(const auto& the_pair : field_values)
   {
-    const Gnome::Gda::Value value = iter->second;
-    std::cout << "debug: " << G_STRFUNC << ": field name=" << iter->first << ", type=" << g_type_name(value.get_value_type()) << std::endl;
+    const Gnome::Gda::Value value =the_pair.second;
+    std::cout << "debug: " << G_STRFUNC << ": field name=" << the_pair.first << ", type=" << g_type_name(value.get_value_type()) << std::endl;
   }
   */
 
