@@ -46,14 +46,14 @@ PyGlomRelated::type_map_relationships::size_type PyGlomRelated::len() const
 
 boost::python::object PyGlomRelated::getitem(const boost::python::object& cppitem)
 {
-  boost::python::extract<std::string> extractor(cppitem);
-  if(extractor.check())
+  boost::python::extract<std::string> extractor_item(cppitem);
+  if(extractor_item.check())
   {
-    const std::string key = extractor;
+    const std::string key = extractor_item;
     if(!key.empty())
     {
       //Return a cached item if possible:
-      PyGlomRelated::type_map_relatedrecords::iterator iterCacheFind = m_map_relatedrecords.find(key);
+      auto iterCacheFind = m_map_relatedrecords.find(key);
       if(iterCacheFind != m_map_relatedrecords.end())
       {
         //Return a reference to the cached item:
@@ -67,13 +67,13 @@ boost::python::object PyGlomRelated::getitem(const boost::python::object& cppite
         if(iterFind != m_map_relationships.end())
         {
           //Get the value of the from_key in the parent record.
-          sharedptr<Relationship> relationship = iterFind->second;
-          const Glib::ustring from_key = relationship->get_from_field();
+          std::shared_ptr<Relationship> relationship = iterFind->second;
+          const auto from_key = relationship->get_from_field();
 
-          boost::python::extract<PyGlomRecord*> extractor(m_record);
-          if(extractor.check())
+          boost::python::extract<PyGlomRecord*> extractor_record(m_record);
+          if(extractor_record.check())
           {
-            PyGlomRecord* record = extractor;
+            PyGlomRecord* record = extractor_record;
             PyGlomRecord::type_map_field_values::const_iterator iterFromKey = record->m_map_field_values.find(from_key);
             if(iterFromKey != record->m_map_field_values.end())
             {
@@ -81,7 +81,7 @@ boost::python::object PyGlomRelated::getitem(const boost::python::object& cppite
 
               //TODO_Performance:
               //Get the full field details so we can sqlize its value:
-              sharedptr<const Field> from_key_field = record->m_document->get_field(record->m_table_name, from_key);
+              std::shared_ptr<const Field> from_key_field = record->m_document->get_field(record->m_table_name, from_key);
               if(from_key_field)
               {
                 //Return a new RelatedRecord:
