@@ -32,7 +32,7 @@ namespace Glom
 {
 
 ReportBuilder::ReportBuilder(const std::locale& locale)
-: m_document(0),
+: m_document(nullptr),
   m_locale(locale)
 {
   m_locale_id = Utils::locale_simplify(locale.name());
@@ -42,18 +42,16 @@ ReportBuilder::~ReportBuilder()
 {
 }
 
-bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::Element& parent_node, const sharedptr<LayoutGroup>& group)
+bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::Element& parent_node, const std::shared_ptr<LayoutGroup>& group)
 {
   //Add XML node:
   xmlpp::Element* node = parent_node.add_child(group->get_report_part_id());
 
   //Add child parts:
   type_vecLayoutItems itemsToGet;
-  for(LayoutGroup::type_list_items::iterator iterChildren = group->m_list_items.begin(); iterChildren != group->m_list_items.end(); ++iterChildren)
+  for(const auto& item : group->m_list_items)
   {
-    sharedptr<LayoutItem> item = *iterChildren;
-
-    sharedptr<LayoutItem_Text> item_text = sharedptr<LayoutItem_Text>::cast_dynamic(item);
+    std::shared_ptr<LayoutItem_Text> item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
     if(item_text)
     {
       if(!report_build_records_text(found_set, *node, item_text))
@@ -64,7 +62,7 @@ bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::
     }
     else
     {
-      sharedptr<LayoutItem_Image> item_image = sharedptr<LayoutItem_Image>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_Image> item_image = std::dynamic_pointer_cast<LayoutItem_Image>(item);
       if(item_image)
       {
         if(!report_build_records_image(found_set, *node, item_image))
@@ -75,7 +73,7 @@ bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::
       }
       else
       {
-        sharedptr<LayoutItem_Field> pField = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+        std::shared_ptr<LayoutItem_Field> pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
         if(pField)
         {
           guint col_index = 0; //ignored.
@@ -87,7 +85,7 @@ bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::
         }
         else
         {
-          sharedptr<LayoutItem_VerticalGroup> vertical_group = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(item);
+          std::shared_ptr<LayoutItem_VerticalGroup> vertical_group = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
           if(vertical_group)
           {
             //Reuse (a bit hacky) this function for the header and footer:
@@ -106,18 +104,16 @@ bool ReportBuilder::report_build_headerfooter(const FoundSet& found_set, xmlpp::
   return true;
 }
 
-bool ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Element& parent_node, const sharedptr<LayoutItem_Summary>& summary)
+bool ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Element& parent_node, const std::shared_ptr<LayoutItem_Summary>& summary)
 {
   //Add XML node:
   xmlpp::Element* node = parent_node.add_child(summary->get_report_part_id());
 
   //Get fields
   type_vecLayoutItems itemsToGet;
-  for(LayoutGroup::type_list_items::iterator iterChildren = summary->m_list_items.begin(); iterChildren != summary->m_list_items.end(); ++iterChildren)
+  for(const auto& item : summary->m_list_items)
   {
-    sharedptr<LayoutItem> item = *iterChildren;
-
-    sharedptr<LayoutItem_GroupBy> pGroupBy = sharedptr<LayoutItem_GroupBy>::cast_dynamic(item);
+    std::shared_ptr<LayoutItem_GroupBy> pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
     if(pGroupBy)
     {
       //Recurse, adding a sub-groupby block:
@@ -129,7 +125,7 @@ bool ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Eleme
     }
     else
     {
-      sharedptr<LayoutItem_Summary> pSummary = sharedptr<LayoutItem_Summary>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_Summary> pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(item);
       if(pSummary)
       {
         //Recurse, adding a summary block:
@@ -167,15 +163,13 @@ bool ReportBuilder::report_build_summary(const FoundSet& found_set, xmlpp::Eleme
 
 
 
-bool ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xmlpp::Element& node, const sharedptr<LayoutItem_GroupBy>& group_by)
+bool ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xmlpp::Element& node, const std::shared_ptr<LayoutItem_GroupBy>& group_by)
 {
   //Get data and add child rows:
   type_vecLayoutItems itemsToGet;
-  for(LayoutGroup::type_list_items::iterator iterChildren = group_by->m_list_items.begin(); iterChildren != group_by->m_list_items.end(); ++iterChildren)
+  for(const auto& item : group_by->m_list_items)
   {
-    sharedptr<LayoutItem> item = *iterChildren;
-
-    sharedptr<LayoutItem_GroupBy> pGroupBy = sharedptr<LayoutItem_GroupBy>::cast_dynamic(item);
+    std::shared_ptr<LayoutItem_GroupBy> pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
     if(pGroupBy)
     {
       //Recurse, adding a sub-groupby block:
@@ -187,7 +181,7 @@ bool ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xml
     }
     else
     {
-      sharedptr<LayoutItem_Summary> pSummary = sharedptr<LayoutItem_Summary>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_Summary> pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(item);
       if(pSummary)
       {
         //Recurse, adding a summary block:
@@ -219,16 +213,16 @@ bool ReportBuilder::report_build_groupby_children(const FoundSet& found_set, xml
   return true;
 }
 
-bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp::Element& parent_node, const sharedptr<LayoutItem_GroupBy>& group_by)
+bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp::Element& parent_node, const std::shared_ptr<LayoutItem_GroupBy>& group_by)
 {
   //Get the possible heading values.
   if(group_by->get_has_field_group_by())
   {
-    sharedptr<LayoutItem_Field> field_group_by = group_by->get_field_group_by();
+    std::shared_ptr<LayoutItem_Field> field_group_by = group_by->get_field_group_by();
     DbUtils::layout_item_fill_field_details(get_document(), found_set_parent.m_table_name, field_group_by);
 
     //Get the possible group values, ignoring repeats by using GROUP BY.
-    const Glib::ustring group_field_table_name = field_group_by->get_table_used(found_set_parent.m_table_name);
+    const auto group_field_table_name = field_group_by->get_table_used(found_set_parent.m_table_name);
 
     Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
@@ -253,7 +247,7 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
       const guint rows_count = datamodel->get_n_rows();
       for(guint row = 0; row < rows_count; ++row)
       {
-        const Gnome::Gda::Value group_value = datamodel->get_value_at(0 /* col*/, row); //TODO: Catch exceptions.
+        const auto group_value = datamodel->get_value_at(0 /* col*/, row); //TODO: Catch exceptions.
 
 
         //Add XML node:
@@ -283,9 +277,8 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
           xmlpp::Element* nodeSecondaryFields = nodeGroupBy->add_child("secondary_fields");
 
           type_vecLayoutItems itemsToGet;
-          for(LayoutGroup::type_list_items::iterator iterChildren = group_by->get_secondary_fields()->m_list_items.begin(); iterChildren != group_by->get_secondary_fields()->m_list_items.end(); ++iterChildren)
+          for(const auto& item : group_by->get_secondary_fields()->m_list_items)
           {
-            sharedptr<LayoutItem> item = *iterChildren;
             itemsToGet.push_back( glom_sharedptr_clone(item) );
           }
 
@@ -320,13 +313,11 @@ bool ReportBuilder::report_build_groupby(const FoundSet& found_set_parent, xmlpp
   return true;
 }
 
-bool ReportBuilder::report_build_records_get_fields(const FoundSet& found_set, const sharedptr<LayoutGroup>& group, type_vecLayoutFields& items)
+bool ReportBuilder::report_build_records_get_fields(const FoundSet& found_set, const std::shared_ptr<LayoutGroup>& group, type_vecLayoutFields& items)
 {
-  for(LayoutGroup::type_list_items::iterator iterChildren = group->m_list_items.begin(); iterChildren != group->m_list_items.end(); ++iterChildren)
+  for(const auto& item : group->m_list_items)
   {
-    sharedptr<LayoutItem> item = *iterChildren;
-
-    sharedptr<LayoutItem_VerticalGroup> pVerticalGroup = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(item);
+    std::shared_ptr<LayoutItem_VerticalGroup> pVerticalGroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
     if(pVerticalGroup)
     {
       if(!report_build_records_get_fields(found_set, pVerticalGroup, items))
@@ -337,7 +328,7 @@ bool ReportBuilder::report_build_records_get_fields(const FoundSet& found_set, c
     }
     else
     {
-      sharedptr<LayoutItem_Field> pField = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_Field> pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
       if(pField)
         items.push_back(pField);
     }
@@ -351,10 +342,9 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
   if(!items.empty())
   {
     //Add Field headings:
-    for(type_vecLayoutItems::const_iterator iter = items.begin(); iter != items.end(); ++iter)
+    for(const auto& layout_item : items)
     {
-      sharedptr<LayoutItem> layout_item = *iter;
-      sharedptr<LayoutItem_Field> layoutitem_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+      std::shared_ptr<LayoutItem_Field> layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
 
       //This adds a field heading (and therefore, column) for fields, or for a vertical group.
       xmlpp::Element* nodeFieldHeading = parent_node.add_child("field_heading");
@@ -367,15 +357,14 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
 
     //Get list of fields to get from the database.
     Utils::type_vecLayoutFields fieldsToGet;
-    for(type_vecLayoutItems::const_iterator iter = items.begin(); iter != items.end(); ++iter)
+    for(const auto& layout_item : items)
     {
-      sharedptr<LayoutItem> layout_item = *iter;
-      sharedptr<LayoutItem_Field> layoutitem_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+      std::shared_ptr<LayoutItem_Field> layoutitem_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
       if(layoutitem_field)
         fieldsToGet.push_back(layoutitem_field);
       else
       {
-        sharedptr<LayoutItem_VerticalGroup> vertical_group = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(layout_item);
+        std::shared_ptr<LayoutItem_VerticalGroup> vertical_group = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(layout_item);
         if(vertical_group)
         {
           //Get all the fields in this group:
@@ -395,7 +384,7 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
 
     Glib::RefPtr<Gnome::Gda::SqlBuilder> sql_query = Utils::build_sql_select_with_where_clause(found_set.m_table_name,
       fieldsToGet,
-      found_set.m_where_clause, sharedptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
+      found_set.m_where_clause, std::shared_ptr<const Relationship>() /* extra_join */, found_set.m_sort_clause,
       limit);
 
     Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(sql_query);
@@ -413,10 +402,9 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
         xmlpp::Element* nodeRow = parent_node.add_child("row");
 
         guint colField = 0;
-        for(type_vecLayoutItems::const_iterator iter = items.begin(); iter != items.end(); ++iter)
+        for(const auto& item : items)
         {
-          sharedptr<LayoutItem> item = *iter;
-          sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+          std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
           if(field)
           {
             if(!report_build_records_field(found_set, *nodeRow, field, datamodel, row, colField))
@@ -427,7 +415,7 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
           }
           else
           {
-            sharedptr<LayoutItem_Text> item_text = sharedptr<LayoutItem_Text>::cast_dynamic(item);
+            std::shared_ptr<LayoutItem_Text> item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
             if(item_text)
             {
               if(!report_build_records_text(found_set, *nodeRow, item_text))
@@ -438,7 +426,7 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
             }
             else
             {
-              sharedptr<LayoutItem_VerticalGroup> item_verticalgroup = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(item);
+              std::shared_ptr<LayoutItem_VerticalGroup> item_verticalgroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
               if(item_verticalgroup)
               {
                 if(!report_build_records_vertical_group(found_set, *nodeRow, item_verticalgroup, datamodel, row, colField))
@@ -461,9 +449,9 @@ bool ReportBuilder::report_build_records(const FoundSet& found_set, xmlpp::Eleme
   return true;
 }
 
-bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp::Element& nodeParent, const sharedptr<const LayoutItem_Field>& field, const Glib::RefPtr<Gnome::Gda::DataModel>& datamodel, guint row, guint& colField, bool vertical)
+bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp::Element& nodeParent, const std::shared_ptr<const LayoutItem_Field>& field, const Glib::RefPtr<Gnome::Gda::DataModel>& datamodel, guint row, guint& colField, bool vertical)
 {
-  const Field::glom_field_type field_type = field->get_glom_type();
+  const auto field_type = field->get_glom_type();
 
   xmlpp::Element* nodeField = nodeParent.add_child(field->get_report_part_id());
   if(field_type == Field::TYPE_NUMERIC)
@@ -473,7 +461,6 @@ bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
     nodeField->set_attribute("vertical", "true");
 
   Gnome::Gda::Value value;
-  Glib::ustring text_value;
 
   if(!datamodel) //We call this for headers and footers too.
   {
@@ -483,15 +470,15 @@ bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
     builder->set_table(field->get_table_used(found_set.m_table_name));
     builder->select_add_field(field->get_name(), found_set.m_table_name);
     builder->select_set_limit(1);
-    Glib::RefPtr<Gnome::Gda::DataModel> datamodel = DbUtils::query_execute_select(builder);
+    Glib::RefPtr<Gnome::Gda::DataModel> datamodel_syspref = DbUtils::query_execute_select(builder);
 
-    if(!datamodel)
+    if(!datamodel_syspref)
     {
       std::cerr << G_STRFUNC << ": The SQL query failed." << std::endl;
       return false;
     }
 
-    value = datamodel->get_value_at(colField, row); //TODO: Catch exceptions.
+    value = datamodel_syspref->get_value_at(colField, row); //TODO: Catch exceptions.
     colField = 0;
   }
   else
@@ -509,11 +496,11 @@ bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
     Glib::ustring text_value = Conversions::get_text_for_gda_value(field_type, value, m_locale, field->get_formatting_used().m_numeric_format);
 
     //The Postgres summary functions return NULL when summarising NULL records, but 0 is more sensible:
-    if(text_value.empty() && sharedptr<const LayoutItem_FieldSummary>::cast_dynamic(field) && (field_type == Field::TYPE_NUMERIC))
+    if(text_value.empty() && std::dynamic_pointer_cast<const LayoutItem_FieldSummary>(field) && (field_type == Field::TYPE_NUMERIC))
     {
       //Use get_text_for_gda_value() instead of "0" so we get the correct numerical formatting:
-      const Gnome::Gda::Value value = Conversions::parse_value(0);
-      text_value = Conversions::get_text_for_gda_value(field_type, value, m_locale, field->get_formatting_used().m_numeric_format);
+      const auto value_zero = Conversions::parse_value(0);
+      text_value = Conversions::get_text_for_gda_value(field_type, value_zero, m_locale, field->get_formatting_used().m_numeric_format);
     }
 
     nodeField->set_attribute("value", text_value);
@@ -524,7 +511,7 @@ bool ReportBuilder::report_build_records_field(const FoundSet& found_set, xmlpp:
   return true;
 }
 
-bool ReportBuilder::report_build_records_text(const FoundSet& /* found_set */, xmlpp::Element& nodeParent, const sharedptr<const LayoutItem_Text>& textobject, bool vertical)
+bool ReportBuilder::report_build_records_text(const FoundSet& /* found_set */, xmlpp::Element& nodeParent, const std::shared_ptr<const LayoutItem_Text>& textobject, bool vertical)
 {
   //Text object:
   xmlpp::Element* nodeField = nodeParent.add_child(textobject->get_report_part_id()); //We reuse this node type for text objects.
@@ -536,7 +523,7 @@ bool ReportBuilder::report_build_records_text(const FoundSet& /* found_set */, x
   return true;
 }
 
-bool ReportBuilder::report_build_records_image(const FoundSet& /* found_set */, xmlpp::Element& nodeParent, const sharedptr<const LayoutItem_Image>& imageobject, bool vertical)
+bool ReportBuilder::report_build_records_image(const FoundSet& /* found_set */, xmlpp::Element& nodeParent, const std::shared_ptr<const LayoutItem_Image>& imageobject, bool vertical)
 {
   //Text object:
   xmlpp::Element* nodeImage = nodeParent.add_child(imageobject->get_report_part_id()); //We reuse this node type for text objects.
@@ -548,15 +535,13 @@ bool ReportBuilder::report_build_records_image(const FoundSet& /* found_set */,
   return true;
 }
 
-bool ReportBuilder::report_build_records_vertical_group(const FoundSet& found_set, xmlpp::Element& parentNode, const sharedptr<LayoutItem_VerticalGroup>& group, const Glib::RefPtr<Gnome::Gda::DataModel>& datamodel, guint row, guint& field_index)
+bool ReportBuilder::report_build_records_vertical_group(const FoundSet& found_set, xmlpp::Element& parentNode, const std::shared_ptr<LayoutItem_VerticalGroup>& group, const Glib::RefPtr<Gnome::Gda::DataModel>& datamodel, guint row, guint& field_index)
 {
   xmlpp::Element* nodeGroupVertical = parentNode.add_child(group->get_report_part_id());
 
-  for(LayoutGroup::type_list_items::iterator iterChildren = group->m_list_items.begin(); iterChildren != group->m_list_items.end(); ++iterChildren)
+  for(const auto& item : group->m_list_items)
   {
-    sharedptr<LayoutItem> item = *iterChildren;
-
-    sharedptr<LayoutItem_VerticalGroup> pVerticalGroup = sharedptr<LayoutItem_VerticalGroup>::cast_dynamic(item);
+    std::shared_ptr<LayoutItem_VerticalGroup> pVerticalGroup = std::dynamic_pointer_cast<LayoutItem_VerticalGroup>(item);
     if(pVerticalGroup)
     {
       if(!report_build_records_vertical_group(found_set, *nodeGroupVertical, pVerticalGroup, datamodel, row, field_index))
@@ -567,7 +552,7 @@ bool ReportBuilder::report_build_records_vertical_group(const FoundSet& found_se
     }
     else
     {
-      sharedptr<LayoutItem_Field> pField = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_Field> pField = std::dynamic_pointer_cast<LayoutItem_Field>(item);
       if(pField)
       {
         if(!report_build_records_field(found_set, *nodeGroupVertical, pField, datamodel, row, field_index, true /* vertical, so we get a row for each field too. */))
@@ -578,7 +563,7 @@ bool ReportBuilder::report_build_records_vertical_group(const FoundSet& found_se
       }
       else
       {
-        sharedptr<LayoutItem_Text> pText = sharedptr<LayoutItem_Text>::cast_dynamic(item);
+        std::shared_ptr<LayoutItem_Text> pText = std::dynamic_pointer_cast<LayoutItem_Text>(item);
         if(pText)
         {
           if(!report_build_records_text(found_set, *nodeGroupVertical, pText, true))
@@ -595,12 +580,12 @@ bool ReportBuilder::report_build_records_vertical_group(const FoundSet& found_se
 }
 
 //TODO: Return a URI
-std::string ReportBuilder::report_build_and_save(const FoundSet& found_set, const sharedptr<const Report>& report)
+std::string ReportBuilder::report_build_and_save(const FoundSet& found_set, const std::shared_ptr<const Report>& report)
 {
-  const Glib::ustring contents = report_build(found_set, report);
+  const auto contents = report_build(found_set, report);
 
  //Save it to a temporary file and show it in a browser:
-  const Glib::ustring temp_uri = Utils::get_temp_file_uri("glom_printout", "html");
+  const auto temp_uri = Utils::get_temp_file_uri("glom_printout", "html");
   std::cout << G_STRFUNC << ": temp_uri=" << temp_uri << std::endl;
 
   Glib::RefPtr<Gio::File> file = Gio::File::create_for_uri(temp_uri);
@@ -628,7 +613,7 @@ std::string ReportBuilder::report_build_and_save(const FoundSet& found_set, cons
 
   //Write the data to the output uri
   gssize bytes_written = 0;
-  const Glib::ustring::size_type result_bytes = contents.bytes();
+  const auto result_bytes = contents.bytes();
   try
   {
     bytes_written = stream->write(contents.data(), result_bytes);
@@ -646,7 +631,7 @@ std::string ReportBuilder::report_build_and_save(const FoundSet& found_set, cons
 }
  
 
-Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const sharedptr<const Report>& report)
+Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const std::shared_ptr<const Report>& report)
 {
   //Create a DOM Document with the XML:
   xmlpp::DomParser dom_parser;;
@@ -676,13 +661,11 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const share
 
   type_vecLayoutItems itemsToGet_TopLevel;
 
-  const sharedptr<const LayoutGroup> group = report->get_layout_group();
-  for(LayoutGroup::type_list_items::const_iterator iter = group->m_list_items.begin(); iter != group->m_list_items.end(); ++iter)
+  const std::shared_ptr<const LayoutGroup> group = report->get_layout_group();
+  for(const auto& pPart : group->m_list_items)
   {
-    sharedptr<LayoutItem> pPart = *iter;
-
     //The Group, and the details for each record in the group:
-    sharedptr<LayoutItem_GroupBy> pGroupBy = sharedptr<LayoutItem_GroupBy>::cast_dynamic(pPart);
+    std::shared_ptr<LayoutItem_GroupBy> pGroupBy = std::dynamic_pointer_cast<LayoutItem_GroupBy>(pPart);
     if(pGroupBy)
     {
       if(!report_build_groupby(found_set, *nodeParent, pGroupBy))
@@ -693,7 +676,7 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const share
     }
     else
     {
-      sharedptr<LayoutItem_Summary> pSummary = sharedptr<LayoutItem_Summary>::cast_dynamic(pPart);
+      std::shared_ptr<LayoutItem_Summary> pSummary = std::dynamic_pointer_cast<LayoutItem_Summary>(pPart);
       if(pSummary)
       {
         //Recurse, adding a summary block:
@@ -705,11 +688,11 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const share
       }
       else
       {
-        sharedptr<LayoutGroup> pGroup = sharedptr<LayoutGroup>::cast_dynamic(pPart);
+        std::shared_ptr<LayoutGroup> pGroup = std::dynamic_pointer_cast<LayoutGroup>(pPart);
         if(pGroup)
         {
-          sharedptr<LayoutItem_Header> pHeader = sharedptr<LayoutItem_Header>::cast_dynamic(pPart);
-          sharedptr<LayoutItem_Footer> pFooter = sharedptr<LayoutItem_Footer>::cast_dynamic(pPart);
+          std::shared_ptr<LayoutItem_Header> pHeader = std::dynamic_pointer_cast<LayoutItem_Header>(pPart);
+          std::shared_ptr<LayoutItem_Footer> pFooter = std::dynamic_pointer_cast<LayoutItem_Footer>(pPart);
           if(pHeader || pFooter)
           {
             //Recurse, adding a summary block:
@@ -740,7 +723,7 @@ Glib::ustring ReportBuilder::report_build(const FoundSet& found_set, const share
   return GlomXslUtils::transform(*pDocument, "print_report_to_html.xsl");
 }
 
-static void fill_standard_list_report_fill(const sharedptr<Report>& report, const sharedptr<const LayoutGroup>& layout_group)
+static void fill_standard_list_report_fill(const std::shared_ptr<Report>& report, const std::shared_ptr<const LayoutGroup>& layout_group)
 {
   if(!report)
     return;
@@ -748,29 +731,27 @@ static void fill_standard_list_report_fill(const sharedptr<Report>& report, cons
   if(!layout_group)
     return;
 
-  for(LayoutGroup::type_list_items::const_iterator iter = layout_group->m_list_items.begin(); iter != layout_group->m_list_items.end(); ++iter)
+  for(const auto& item : layout_group->m_list_items)
   {
-    const sharedptr<const LayoutItem> item = *iter;
     if(!item)
       continue;
 
-    const sharedptr<LayoutItem> unconst = sharedptr<LayoutItem>::cast_const(item); //TODO: Avoid this?
+    const auto unconst = std::const_pointer_cast<LayoutItem>(item); //TODO: Avoid this?
     report->get_layout_group()->add_item(unconst);
   }
 }
 
-sharedptr<Report> ReportBuilder::create_standard_list_report(const Document* document, const Glib::ustring& table_name)
+std::shared_ptr<Report> ReportBuilder::create_standard_list_report(const Document* document, const Glib::ustring& table_name)
 {
-  sharedptr<Report> result(new Report());
+  std::shared_ptr<Report> result(new Report());
   result->set_name("list");
   //Translators: This is a noun. It is the title of a report.
   result->set_title_original(_("List"));
 
   const Document::type_list_layout_groups layout_groups = 
     document->get_data_layout_groups("list", table_name); //TODO: layout_platform.
-  for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+  for(const auto& group : layout_groups)
   {
-    const sharedptr<const LayoutGroup> group = *iter;
     if(group)
       fill_standard_list_report_fill(result, group);
   }
