@@ -27,7 +27,7 @@
 #include <glibmm/fileutils.h>
 #include <glibmm/miscutils.h>
 #include <glibmm/i18n.h>
-#include <memory> //For auto_ptr.
+#include <memory> //For shared_ptr.
 #include <stdexcept>
 #include <iostream>
 
@@ -98,14 +98,14 @@ private:
   static HANDLE create_redirect_file(std::string& filename)
   {
     static unsigned int redirect_seq = 0;
-    const gchar* appdata = getenv("APPDATA");
+    const auto appdata = getenv("APPDATA");
     filename = Glib::ustring::compose("%1\\glom_spawn_redirect_%2.txt", std::string(appdata), ++ redirect_seq);
 
     // Allow the redirect file to be inherited by the child process, so
     // it can write to it.
     SECURITY_ATTRIBUTES security_attr;
     security_attr.nLength = sizeof(security_attr);
-    security_attr.lpSecurityDescriptor = 0;
+    security_attr.lpSecurityDescriptor = nullptr;
     security_attr.bInheritHandle = true;
 
     HANDLE result = CreateFile(filename.c_str(), GENERIC_WRITE, FILE_SHARE_READ | FILE_SHARE_DELETE, &security_attr, CREATE_ALWAYS, FILE_ATTRIBUTE_NORMAL, 0);
@@ -168,11 +168,11 @@ public:
 #ifdef G_OS_WIN32
     startup_info.cb = sizeof(startup_info);
     startup_info.dwFlags = STARTF_USESTDHANDLES;
-    startup_info.lpReserved = 0;
-    startup_info.lpDesktop = 0;
-    startup_info.lpTitle = 0;
-    startup_info.cbReserved2 = 0;
-    startup_info.lpReserved2 = 0;
+    startup_info.lpReserved = nullptr;
+    startup_info.lpDesktop = nullptr;
+    startup_info.lpTitle = nullptr;
+    startup_info.cbReserved2 = nullptr;
+    startup_info.lpReserved2 = nullptr;
     startup_info.hStdInput = INVALID_HANDLE_VALUE;
 
     if(redirect & REDIRECT_STDOUT)
@@ -300,16 +300,16 @@ private:
 #endif
 };
 
-static std::auto_ptr<const SpawnInfo> spawn_async(const Glib::ustring& command_line, int redirect)
+static std::shared_ptr<const SpawnInfo> spawn_async(const Glib::ustring& command_line, int redirect)
 {
-  return std::auto_ptr<const SpawnInfo>(new SpawnInfo(command_line, redirect));
+  return std::shared_ptr<const SpawnInfo>(new SpawnInfo(command_line, redirect));
 }
 
 /**
  * @param return_status: The return value of the command.
  * @result Whether we successfully ended the async spawn.
  */
-static bool spawn_async_end(std::auto_ptr<const SpawnInfo> info, std::string* stdout_text = 0, std::string* stderr_text = 0, int* return_status = 0)
+static bool spawn_async_end(std::shared_ptr<const SpawnInfo> info, std::string* stdout_text = 0, std::string* stderr_text = 0, int* return_status = 0)
 {
   if(stdout_text)
     info->get_stdout(*stdout_text);
@@ -334,7 +334,7 @@ static int spawn_sync(const Glib::ustring& command_line, std::string* stdout_tex
 
   Glib::RefPtr<Glib::MainLoop> mainloop = Glib::MainLoop::create(false);
 
-  std::auto_ptr<const SpawnInfo> info = spawn_async(command_line, redirect_flags); //This could throw
+  std::shared_ptr<const SpawnInfo> info = spawn_async(command_line, redirect_flags); //This could throw
   info->signal_finished().connect(
     sigc::bind(sigc::ptr_fun(&on_spawn_info_finished), sigc::ref(mainloop) ) );
 
@@ -342,7 +342,7 @@ static int spawn_sync(const Glib::ustring& command_line, std::string* stdout_tex
   mainloop->run();
 
   int return_status = 0;
-  const bool returned = spawn_async_end(info, stdout_text, stderr_text, &return_status);
+  const auto returned = spawn_async_end(info, stdout_text, stderr_text, &return_status);
   g_assert(returned);
   return return_status;
 }
@@ -353,7 +353,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
 {
   //Show UI progress feedback while we wait for the command to finish:
 
-  std::auto_ptr<const Impl::SpawnInfo> info;
+  std::shared_ptr<const Impl::SpawnInfo> info;
   
   try
   {
@@ -373,7 +373,8 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
   sigc::connection timeout_connection = Glib::signal_timeout().connect(
     sigc::bind_return( slot_progress, true),
     500);
-  slot_progress(); //Make sure it is called at least once.
+  if(slot_progress)
+    slot_progress(); //Make sure it is called at least once.
 
   //Block until signal_finished is called.
   mainloop->run();
@@ -382,7 +383,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
   timeout_connection.disconnect();
 
   int return_status = false;
-  const bool returned = Impl::spawn_async_end(info, 0, 0, &return_status);
+  const auto returned = Impl::spawn_async_end(info, 0, 0, &return_status);
   if(!returned)
     return false; // User closed the dialog prematurely?
 
@@ -396,7 +397,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
 
   //Show UI progress feedback while we wait for the command to finish:
 
-  std::auto_ptr<const Impl::SpawnInfo> info;
+  std::shared_ptr<const Impl::SpawnInfo> info;
   
   try
   {
@@ -417,7 +418,8 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
   sigc::connection timeout_connection = Glib::signal_timeout().connect(
     sigc::bind_return( slot_progress, true),
     500);
-  slot_progress(); //Make sure it is called at least once.
+  if(slot_progress)
+    slot_progress(); //Make sure it is called at least once.
 
   //Block until signal_finished is called.
   mainloop->run();
@@ -427,7 +429,7 @@ bool execute_command_line_and_wait(const std::string& command, const SlotProgres
 
   int return_status = false;
   std::string stdout_text, stderr_text;
-  const bool returned = Impl::spawn_async_end(info, &stdout_text, &stderr_text, &return_status);
+  const auto returned = Impl::spawn_async_end(info, &stdout_text, &stderr_text, &return_status);
   if(!returned)
     return false; // User closed the dialog prematurely?
 
@@ -535,7 +537,9 @@ namespace
        #endif //GLOM_SPAWN_DEBUG
     }
 
-    slot_progress(); //Show UI progress feedback.
+    if(slot_progress)
+      slot_progress(); //Show UI progress feedback.
+
     return true;
   }
 
@@ -558,7 +562,7 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
   std::cout << "debug: Command: " << command << std::endl;
   #endif //GLOM_SPAWN_DEBUG
 
-  std::auto_ptr<const Impl::SpawnInfo> info;
+  std::shared_ptr<const Impl::SpawnInfo> info;
 
   try
   {
@@ -582,7 +586,8 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
 
   // Call the second command once every second
   sigc::connection timeout_conn = Glib::signal_timeout().connect(sigc::bind(sigc::ptr_fun(&second_command_on_timeout), sigc::ref(second_command), sigc::ref(success_text), slot_progress, sigc::ref(mainloop)), 1000);
-  slot_progress(); //Make sure it is called at least once.
+  if(slot_progress)
+    slot_progress(); //Make sure it is called at least once.
 
   // Block until signal_finished is emitted:
   mainloop->run();
@@ -592,7 +597,7 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
 
   std::string stderr_text;
   int return_status = 0;
-  const bool success = Impl::spawn_async_end(info, 0, &stderr_text, &return_status);
+  const auto success = Impl::spawn_async_end(info, 0, &stderr_text, &return_status);
 
   if(success && (return_status == EXIT_SUCCESS))
   {
@@ -619,7 +624,7 @@ bool execute_command_line_and_wait_until_second_command_returns_success(const st
     {
       /* TODO: Allow the caller to show a dialog?
       // Command failed
-      std::auto_ptr<Gtk::MessageDialog> error_dialog;
+      std::shared_ptr<Gtk::MessageDialog> error_dialog;
       if(parent_window)
         error_dialog.reset(new Gtk::MessageDialog(*parent_window, "Child command failed", false, Gtk::MESSAGE_ERROR));
       else
