@@ -41,7 +41,7 @@ namespace Glom
 Box_Data::Box_Data()
 : m_Button_Find(_("_Find"), true)
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-  ,m_pDialogLayout(0)
+  ,m_pDialogLayout(nullptr)
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 {
   m_bUnstoredData = false;
@@ -99,13 +99,13 @@ Gnome::Gda::SqlExpr Box_Data::get_find_where_clause() const
   }
 
   //Look at each field entry and build e.g. 'Name = "Bob"'
-  for(type_vecConstLayoutFields::const_iterator iter = m_FieldsShown.begin(); iter != m_FieldsShown.end(); ++iter)
+  for(const auto& item : m_FieldsShown)
   {
-    const Gnome::Gda::Value data = get_entered_field_data(*iter);
+    const auto data = get_entered_field_data(item);
 
     if(!Conversions::value_is_empty(data))
     {
-      const sharedptr<const Field> field = (*iter)->get_full_field_details();
+      const std::shared_ptr<const Field> field = item->get_full_field_details();
       if(field)
       {
         bool use_this_field = true;
@@ -117,7 +117,7 @@ Gnome::Gda::SqlExpr Box_Data::get_find_where_clause() const
 
         if(use_this_field)
         {
-          const guint cond_id = builder->add_cond(field->sql_find_operator(),
+          const auto cond_id = builder->add_cond(field->sql_find_operator(),
             builder->add_field_id(field->get_name(), m_table_name),
             builder->add_expr( field->sql_find(data, connection) ));
 
@@ -150,7 +150,7 @@ void Box_Data::on_Button_Find()
   //m_AddDel.finish_editing();
 
   //Call the virtual method to get the find criteria for a details or list view:
-  const Gnome::Gda::SqlExpr where_clause = get_find_where_clause();
+  const auto where_clause = get_find_where_clause();
 
   //The signal handler then checks and warns if no find criteria were entered.
   signal_find_criteria.emit(where_clause);
@@ -186,12 +186,12 @@ bool Box_Data::confirm_discard_unstored_data() const
 {
   if(get_unstored_data())
   {
-    const Glib::ustring message = _("This data cannot be stored in the database because you have not provided a primary key.\nDo you really want to discard this data?");
+    const auto message = _("This data cannot be stored in the database because you have not provided a primary key.\nDo you really want to discard this data?");
     //Ask user to confirm loss of data:
     Gtk::MessageDialog dialog(UiUtils::bold_message(_("No primary key value")), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_OK_CANCEL );
     dialog.set_secondary_text(message);
     //TODO: It needs a const. I wonder if it should. murrayc. dialog.set_transient_for(*get_app_window());
-    const int iButton = dialog.run();
+    const auto iButton = dialog.run();
 
     return (iButton == Gtk::RESPONSE_OK);
   }
@@ -261,12 +261,12 @@ Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::u
       //Get the layout information from the document:
       layout_groups = document->get_data_layout_groups_plus_new_fields(layout_name, m_table_name, layout_platform);
       document->fill_layout_field_details(m_table_name, layout_groups); //TODO: Do this automatically in Document?
-      const Privileges table_privs = Privs::get_current_privs(m_table_name);
+      const auto table_privs = Privs::get_current_privs(m_table_name);
 
       //Fill in the field information for the fields mentioned in the layout:
-      for(Document::type_list_layout_groups::iterator iterGroups = layout_groups.begin(); iterGroups != layout_groups.end(); ++iterGroups)
+      for(const auto& item : layout_groups)
       {
-        fill_layout_group_field_info(*iterGroups, table_privs);
+        fill_layout_group_field_info(item, table_privs);
 
         //std::cout << "debug: Box_Data::get_data_layout_groups: " << std::endl;
         //*iterGroups->debug();
@@ -277,35 +277,34 @@ Document::type_list_layout_groups Box_Data::get_data_layout_groups(const Glib::u
   return layout_groups;
 }
 
-void Box_Data::fill_layout_group_field_info(const sharedptr<LayoutGroup>& group, const Privileges& table_privs)
+void Box_Data::fill_layout_group_field_info(const std::shared_ptr<LayoutGroup>& group, const Privileges& table_privs)
 {
   if(!group)
    return;
 
-  const Document* document = get_document();
+  const auto document = get_document();
 
   LayoutGroup::type_list_items items = group->get_items();
-  for(LayoutGroup::type_list_items::iterator iter = items.begin(); iter != items.end(); ++iter)
+  for(const auto& item : items)
   {
-    sharedptr<LayoutItem> item = *iter;
-    sharedptr<LayoutItem_Field> item_field = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+    auto item_field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
     if(item_field) //If is a field rather than some other layout item
     {
 
       if(item_field->get_has_relationship_name()) //If it's a field in a related table.
       {
         //Get the full field information:
-        const Glib::ustring relationship_name = item_field->get_relationship_name();
-        sharedptr<const Relationship> relationship = document->get_relationship(m_table_name, relationship_name);
+        const auto relationship_name = item_field->get_relationship_name();
+        std::shared_ptr<const Relationship> relationship = document->get_relationship(m_table_name, relationship_name);
         if(relationship)
         {
-          sharedptr<Field> field = DbUtils::get_fields_for_table_one_field(document, relationship->get_to_table(), item->get_name());
+          std::shared_ptr<Field> field = DbUtils::get_fields_for_table_one_field(document, relationship->get_to_table(), item->get_name());
           if(field)
           {
             item_field->set_full_field_details(field);
 
             //TODO_Performance: Don't do this repeatedly for the same table.
-            const Privileges privs = Privs::get_current_privs(relationship->get_to_table());
+            const auto privs = Privs::get_current_privs(relationship->get_to_table());
             item_field->m_priv_view = privs.m_view;
             item_field->m_priv_edit = privs.m_edit;
           }
@@ -314,7 +313,7 @@ void Box_Data::fill_layout_group_field_info(const sharedptr<LayoutGroup>& group,
       else
       {
         //Get the field info:
-        sharedptr<Field> field = DbUtils::get_fields_for_table_one_field(document, m_table_name, item_field->get_name());
+        std::shared_ptr<Field> field = DbUtils::get_fields_for_table_one_field(document, m_table_name, item_field->get_name());
         if(field)
         {
           item_field->set_full_field_details(field); //TODO_Performance: Just use this as the output arg?
@@ -325,7 +324,7 @@ void Box_Data::fill_layout_group_field_info(const sharedptr<LayoutGroup>& group,
     }
     else
     {
-      sharedptr<LayoutGroup> item_group = sharedptr<LayoutGroup>::cast_dynamic(item);
+      std::shared_ptr<LayoutGroup> item_group = std::dynamic_pointer_cast<LayoutGroup>(item);
       if(item_group) //If it is a group
       {
         //recurse, to fill the fields info in this group:
@@ -349,17 +348,17 @@ Glib::ustring Box_Data::get_layout_name() const
   return m_layout_name;
 }
 
-void Box_Data::execute_button_script(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value)
+void Box_Data::execute_button_script(const std::shared_ptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key_value)
 {
-  const Glib::ustring script = layout_item->get_script();
+  const auto script = layout_item->get_script();
   if(!UiUtils::script_check_for_pygtk2_with_warning(script, get_app_window()))
     return;
 
-  const sharedptr<Field> field_primary_key = get_field_primary_key();
-  const type_map_fields field_values = get_record_field_values_for_calculation(m_table_name, field_primary_key, primary_key_value);
+  const auto field_primary_key = get_field_primary_key();
+  const auto field_values = get_record_field_values_for_calculation(m_table_name, field_primary_key, primary_key_value);
 
   //We need the connection when we run the script, so that the script may use it.
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
+  std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(0 /* parent window */);
 
   //Allow this UI to respond to UI change requests from the Python code:
   AppPythonUICallbacks callbacks;
