@@ -33,7 +33,7 @@ namespace Glom
 {
 
 Box_Data_Calendar_Related::Box_Data_Calendar_Related()
-: m_pMenuPopup(0),
+: m_pMenuPopup(nullptr),
   m_query_column_date_field(-1)
 {
   set_size_request(400, -1); //An arbitrary default.
@@ -72,7 +72,7 @@ void Box_Data_Calendar_Related::enable_buttons()
   //m_calendar.set_allow_view_details(view_details_possible); //Don't allow the user to go to a record in a hidden table.
 }
 
-bool Box_Data_Calendar_Related::init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title)
+bool Box_Data_Calendar_Related::init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title)
 {
   //This calls the other method overload:
   return Box_Data_Portal::init_db_details(portal, show_title);
@@ -121,7 +121,7 @@ bool Box_Data_Calendar_Related::init_db_details(const Glib::ustring& parent_tabl
       LayoutWidgetBase::m_table_name, m_portal->get_to_field_used());
   }
   else
-    m_key_field.clear();
+    m_key_field.reset();
 
   enable_buttons();
 
@@ -169,32 +169,32 @@ bool Box_Data_Calendar_Related::fill_from_database()
     Gnome::Gda::Value date_end_value(date_end);
 
     //Add a WHERE clause for this date range:
-    sharedptr<const Relationship> relationship = m_portal->get_relationship();
+    std::shared_ptr<const Relationship> relationship = m_portal->get_relationship();
     Glib::ustring where_clause_to_table_name = relationship->get_to_table();
 
-    sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
-    const Glib::ustring date_field_name = derived_portal->get_date_field()->get_name();
+    std::shared_ptr<LayoutItem_CalendarPortal> derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
+    const auto date_field_name = derived_portal->get_date_field()->get_name();
 
-    sharedptr<const Relationship> relationship_related = m_portal->get_related_relationship();
+    std::shared_ptr<const Relationship> relationship_related = m_portal->get_related_relationship();
     if(relationship_related)
     {
       //Adjust the WHERE clause appropriately for the extra JOIN:
-      sharedptr<UsesRelationship> uses_rel_temp = sharedptr<UsesRelationship>::create();
+      std::shared_ptr<UsesRelationship> uses_rel_temp = std::make_shared<UsesRelationship>();
       uses_rel_temp->set_relationship(relationship);
       where_clause_to_table_name = uses_rel_temp->get_sql_join_alias_name();
     }
 
     //Add an AND to the existing where clause, to get only records within these dates, if any:
-    sharedptr<const Field> date_field = derived_portal->get_date_field();
+    std::shared_ptr<const Field> date_field = derived_portal->get_date_field();
 
     Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
       Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
-    const guint cond = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_BETWEEN,
+    const auto cond = builder->add_cond(Gnome::Gda::SQL_OPERATOR_TYPE_BETWEEN,
        builder->add_field_id(date_field->get_name(), m_found_set.m_table_name),
        builder->add_expr_as_value(date_start_value),
        builder->add_expr_as_value(date_end_value));
     builder->set_where(cond); //Might be unnecessary.
-    const Gnome::Gda::SqlExpr extra_where_clause = builder->export_expression(cond);
+    const auto extra_where_clause = builder->export_expression(cond);
 
     Gnome::Gda::SqlExpr where_clause;
     if(m_found_set.m_where_clause.empty())
@@ -217,20 +217,20 @@ bool Box_Data_Calendar_Related::fill_from_database()
     if(!(datamodel))
       return true;
 
-    const int rows_count = datamodel->get_n_rows();
+    const auto rows_count = datamodel->get_n_rows();
     if(!(rows_count > 0))
       return true;
 
     //Get the data:
     for(int row_index = 0; row_index < rows_count; ++row_index)
     {
-      const int columns_count = datamodel->get_n_columns();
+      const auto columns_count = datamodel->get_n_columns();
       if(m_query_column_date_field > columns_count)
        continue;
 
       //Get the date value for this row:
-      const Gnome::Gda::Value value_date = datamodel->get_value_at(m_query_column_date_field, row_index);
-      const Glib::Date date = value_date.get_date();
+      const auto value_date = datamodel->get_value_at(m_query_column_date_field, row_index);
+      const auto date = value_date.get_date();
 
       //Get all the values for this row:
       type_vector_values* pVector = new type_vector_values(m_FieldsShown.size());
@@ -249,12 +249,11 @@ bool Box_Data_Calendar_Related::fill_from_database()
 
 void Box_Data_Calendar_Related::clear_cached_database_values()
 {
-  for(type_map_values::iterator iter = m_map_values.begin(); iter != m_map_values.end(); ++iter)
+  for(const auto& the_pair : m_map_values)
   {
-    type_list_vectors vec = iter->second;
-    for(type_list_vectors::iterator iter = vec.begin(); iter != vec.end(); ++iter)
+    type_list_vectors vec = the_pair.second;
+    for(const auto& pValues : vec)
     {
-      type_vector_values* pValues = *iter;
       delete pValues;
     }
   }
@@ -276,7 +275,7 @@ void Box_Data_Calendar_Related::on_record_added(const Gnome::Gda::Value& primary
   if(m_key_field)
   {
     //m_key_field is the field in this table that must match another field in the parent table.
-    sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+    std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
     layout_item->set_full_field_details(m_key_field);
     //TODO: key_value = m_calendar.get_value(row, layout_item);
   }
@@ -295,13 +294,13 @@ void Box_Data_Calendar_Related::on_record_added(const Gnome::Gda::Value& primary
   }
   else
   {
-    sharedptr<Field> field_primary_key; //TODO: = m_calendar.get_key_field();
+    std::shared_ptr<Field> field_primary_key; //TODO: = m_calendar.get_key_field();
 
     //Create the link by setting the foreign key
     if(m_key_field && m_portal)
     {
       Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
-      const Glib::ustring target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
+      const auto target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
       builder->set_table(target_table);
       builder->add_field_value_as_value(m_key_field->get_name(), m_key_value);
       builder->set_where(
@@ -309,11 +308,11 @@ void Box_Data_Calendar_Related::on_record_added(const Gnome::Gda::Value& primary
           builder->add_field_id(field_primary_key->get_name(), target_table),
           builder->add_expr_as_value(primary_key_value)));
 
-      const bool test = DbUtils::query_execute(builder);
+      const auto test = DbUtils::query_execute(builder);
       if(test)
       {
         //Show it on the view, if it's visible:
-        sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+        std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
         layout_item->set_full_field_details(field_primary_key);
 
         //TODO: m_calendar.set_value(row, layout_item, m_key_value);
@@ -328,14 +327,14 @@ Box_Data_Calendar_Related::type_vecConstLayoutFields Box_Data_Calendar_Related::
 {
   type_vecConstLayoutFields layout_fields = Box_Data_Portal::get_fields_to_show();
 
-  sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
+  std::shared_ptr<LayoutItem_CalendarPortal> derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
   if(!derived_portal)
   {
     std::cerr << G_STRFUNC << ": The portal is not a LayoutItem_CalendarPortal." << std::endl;
     return layout_fields;
   }
 
-  sharedptr<const Field> date_field = derived_portal->get_date_field();
+  std::shared_ptr<const Field> date_field = derived_portal->get_date_field();
   if(!date_field)
   {
     std::cerr << G_STRFUNC << ": get_date_field() returned no field." << std::endl;
@@ -343,7 +342,7 @@ Box_Data_Calendar_Related::type_vecConstLayoutFields Box_Data_Calendar_Related::
   }
 
   //Add it to the list to ensure that we request the date (though it will not really be shown in the calendar):
-  sharedptr<LayoutItem_Field> layout_item_date_field = sharedptr<LayoutItem_Field>::create();
+  std::shared_ptr<LayoutItem_Field> layout_item_date_field = std::make_shared<LayoutItem_Field>();
   layout_item_date_field->set_full_field_details(date_field);
   layout_fields.push_back(layout_item_date_field);
   m_query_column_date_field = layout_fields.size() - 1;
@@ -359,15 +358,14 @@ void Box_Data_Calendar_Related::on_dialog_layout_hide()
 
 
   //Update the UI:
-  sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
+  std::shared_ptr<LayoutItem_CalendarPortal> derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
   init_db_details(derived_portal);
 
   Box_Data::on_dialog_layout_hide();
 
-  sharedptr<LayoutItem_CalendarPortal> pLayoutItem = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(get_layout_item());
+  std::shared_ptr<LayoutItem_CalendarPortal> pLayoutItem = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(get_layout_item());
   if(pLayoutItem)
   {
-    sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
     if(derived_portal)
       *pLayoutItem = *derived_portal;
 
@@ -379,7 +377,7 @@ void Box_Data_Calendar_Related::on_dialog_layout_hide()
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_Calendar_Related::create_layout_dialog() const
 {
-  Dialog_Layout_Calendar_Related* dialog = 0;
+  Dialog_Layout_Calendar_Related* dialog = nullptr;
   Glom::Utils::get_glade_widget_derived_with_warning(dialog);
   return dialog;
 }
@@ -389,7 +387,7 @@ void Box_Data_Calendar_Related::prepare_layout_dialog(Dialog_Layout* dialog)
   Dialog_Layout_Calendar_Related* related_dialog = dynamic_cast<Dialog_Layout_Calendar_Related*>(dialog);
   g_assert(related_dialog);
 
-  sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
+  std::shared_ptr<LayoutItem_CalendarPortal> derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
   if(derived_portal && derived_portal->get_has_relationship_name())
   {
     related_dialog->init_with_portal(m_layout_name, m_layout_platform, get_document(), derived_portal);
@@ -409,14 +407,14 @@ void Box_Data_Calendar_Related::on_calendar_month_changed()
 
 Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint month, guint day)
 {
-  sharedptr<LayoutItem_CalendarPortal> derived_portal = sharedptr<LayoutItem_CalendarPortal>::cast_dynamic(m_portal);
+  std::shared_ptr<LayoutItem_CalendarPortal> derived_portal = std::dynamic_pointer_cast<LayoutItem_CalendarPortal>(m_portal);
   if(!derived_portal)
   {
     //std::cout << "debug: " << G_STRFUNC << ": date_field is NULL" << std::endl;
     return Glib::ustring();
   }
 
-  sharedptr<const Field> date_field = derived_portal->get_date_field();
+  std::shared_ptr<const Field> date_field = derived_portal->get_date_field();
   if(!date_field)
   {
     std::cerr << G_STRFUNC << ":  get_date_field() returned no field." << std::endl;
@@ -442,9 +440,8 @@ Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint m
 
   //Look at each row for this date:
   const type_list_vectors& rows = iter_find->second;
-  for(type_list_vectors::const_iterator iter = rows.begin(); iter != rows.end(); ++iter)
+  for(const auto& pRow : rows)
   {
-    type_vector_values* pRow = *iter;
     if(!pRow)
       continue;
 
@@ -456,22 +453,21 @@ Glib::ustring Box_Data_Calendar_Related::on_calendar_details(guint year, guint m
     //instead of the ones used by the query (m_FieldsShown),
     //because we really don't want to show the extra fields (at the end) to the user:
     LayoutGroup::type_list_items items = m_portal->get_items();
-    for(LayoutGroup::type_list_items::const_iterator iter = items.begin(); iter != items.end(); ++iter)
+    for(const auto& layout_item : items)
     {
-      sharedptr<const LayoutItem> layout_item = *iter;
       if(!layout_item)
         continue;
 
       Glib::ustring text;
 
       //Text for a text item:
-      sharedptr<const LayoutItem_Text> layout_item_text = sharedptr<const LayoutItem_Text>::cast_dynamic(layout_item);
+      std::shared_ptr<const LayoutItem_Text> layout_item_text = std::dynamic_pointer_cast<const LayoutItem_Text>(layout_item);
       if(layout_item_text)
         text = layout_item_text->get_text(AppWindow::get_current_locale());
       else
       {
         //Text for a field:
-        sharedptr<const LayoutItem_Field> layout_item_field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
+        std::shared_ptr<const LayoutItem_Field> layout_item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
 
         const Gnome::Gda::Value value = (*pRow)[column_index];
         text = Conversions::get_text_for_gda_value(layout_item_field->get_glom_type(), value, layout_item_field->get_formatting_used().m_numeric_format);
@@ -541,7 +537,7 @@ void Box_Data_Calendar_Related::setup_menu(Gtk::Widget* /* this */)
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 }
 
-void Box_Data_Calendar_Related::on_calendar_button_press_event(GdkEventButton *event)
+void Box_Data_Calendar_Related::on_calendar_button_press_event(GdkEventButton *button_event)
 {
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   //Enable/Disable items.
@@ -555,16 +551,16 @@ void Box_Data_Calendar_Related::on_calendar_button_press_event(GdkEventButton *e
 #endif
 
   GdkModifierType mods;
-  gdk_window_get_device_position( gtk_widget_get_window(Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+  gdk_window_get_device_position( gtk_widget_get_window(Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
   if(mods & GDK_BUTTON3_MASK)
   {
     //Give user choices of actions on this item:
-    m_pMenuPopup->popup(event->button, event->time);
+    m_pMenuPopup->popup(button_event->button, button_event->time);
     return; //handled.
   }
   else
   {
-    if(event->type == GDK_2BUTTON_PRESS)
+    if(button_event->type == GDK_2BUTTON_PRESS)
     {
       //Double-click means edit.
       //Don't do this usually, because users sometimes double-click by accident when they just want to edit a cell.
