@@ -184,7 +184,7 @@ bool Box_Data_Details::init_db_details(const FoundSet& found_set, const Glib::us
   m_primary_key_value = primary_key_value;
   m_field_primary_key = get_field_primary_key_for_table(found_set.m_table_name);
 
-  const bool result = Box_Data::init_db_details(found_set, layout_platform); //Calls create_layout(), then fill_from_database()
+  const auto result = Box_Data::init_db_details(found_set, layout_platform); //Calls create_layout(), then fill_from_database()
 
   //This is not used much, but we create it anyway:
   m_found_set = found_set; //Not used much.
@@ -222,9 +222,9 @@ void Box_Data_Details::create_layout()
     //This map of layout groups will also contain the field information from the database:
     Document::type_list_layout_groups layout_groups = get_data_layout_groups(m_layout_name, m_layout_platform);
 
-    for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+    for(const auto& item : layout_groups)
     {
-      m_FlowTable.add_layout_group_or_derived(*iter, false /* no indent at this top level */);
+      m_FlowTable.add_layout_group(item, false /* no indent at this top level */);
     }
 
     m_FlowTable.align_child_group_labels();
@@ -248,7 +248,7 @@ bool Box_Data_Details::fill_from_database()
 
   BusyCursor busy_cursor(get_app_window());
 
-  const bool primary_key_is_empty = Conversions::value_is_empty(m_primary_key_value);
+  const auto primary_key_is_empty = Conversions::value_is_empty(m_primary_key_value);
   if(!primary_key_is_empty)
     get_document()->set_layout_record_viewed(m_table_name, m_layout_name, m_primary_key_value);
 
@@ -260,7 +260,7 @@ bool Box_Data_Details::fill_from_database()
 
   //TODO: This should keep the connection open, so we don't need to
   //reconnect many times..
-  sharedptr<SharedConnection> sharedconnection;
+  std::shared_ptr<SharedConnection> sharedconnection;
 
   try
   {
@@ -297,36 +297,36 @@ bool Box_Data_Details::fill_from_database()
       if(table_privs.m_view)
       {
         //Add extra possibly-non-visible columns that we need:
-        sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-        layout_item->set_full_field_details(m_field_primary_key);
+        std::shared_ptr<LayoutItem_Field> layout_item_pk = std::make_shared<LayoutItem_Field>();
+        layout_item_pk->set_full_field_details(m_field_primary_key);
 
         //Get the primary key index, adding the primary key if necessary:
         //TODO_Performance: Do this for create_layout() only, instead of repeating it for each refresh?:
         int index_primary_key = -1; //Arbitrary default.
         //g_warning("primary_key name = %s", m_field_primary_key->get_name().c_str());
-        const type_vecConstLayoutFields::const_iterator iterFind = std::find_if(fieldsToGet.begin(), fieldsToGet.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field>(layout_item));
+        const auto iterFind = std::find_if(fieldsToGet.begin(), fieldsToGet.end(), predicate_LayoutItem_Field_IsSameField<LayoutItem_Field>(layout_item_pk));
         if(iterFind == fieldsToGet.end())
         {
-          fieldsToGet.push_back(layout_item);
+          fieldsToGet.push_back(layout_item_pk);
           index_primary_key = fieldsToGet.size() - 1;
         }
         else
         {
           //TODO_Performance: Is there any quick way to get the index from iterFind?
           //TODO_Performance: If not, then just use this instead of the predicate.
-          const type_vecLayoutFields::size_type count = fieldsToGet.size();
+          const auto count = fieldsToGet.size();
           for(type_vecLayoutFields::size_type i = 0; i < count; ++i)
           {
-            sharedptr<const LayoutItem_Field> element = fieldsToGet[i];
+            std::shared_ptr<const LayoutItem_Field> element = fieldsToGet[i];
             if(!element)
               continue;
 
-            if(element->get_name() != layout_item->get_name())
+            if(element->get_name() != layout_item_pk->get_name())
               continue;
 
             //Compare the relationship and related relationship:
-            sharedptr<const UsesRelationship> uses_a = layout_item;
-            sharedptr<const UsesRelationship> uses_b = element;
+            std::shared_ptr<const UsesRelationship> uses_a = layout_item_pk;
+            std::shared_ptr<const UsesRelationship> uses_b = element;
             if(*uses_a == *uses_b)
             {
               index_primary_key = i;
@@ -369,7 +369,7 @@ bool Box_Data_Details::fill_from_database()
             //Get field values to show:
             for(int i = 0; i < cols_count; ++i)
             {
-              sharedptr<const LayoutItem_Field> layout_item = fieldsToGet[i];
+              std::shared_ptr<const LayoutItem_Field> layout_item = fieldsToGet[i];
 
               //Field value:
               Gnome::Gda::Value value;
@@ -424,7 +424,7 @@ void Box_Data_Details::on_button_new()
   if(m_field_primary_key && m_field_primary_key->get_auto_increment()) //If the primary key is an auto-increment:
   {
     //Just make a new record, and show it:
-    const Gnome::Gda::Value primary_key_value = DbUtils::get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name()); //TODO: This should return a Gda::Value
+    const auto primary_key_value = DbUtils::get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name()); //TODO: This should return a Gda::Value
 
     record_new(false /* use entered field data */, primary_key_value);
     refresh_data_from_database_with_primary_key(primary_key_value);
@@ -451,7 +451,7 @@ void Box_Data_Details::on_button_del()
   {
     if(confirm_delete_record())
     {
-      const bool bTest = record_delete(m_primary_key_value);
+      const auto bTest = record_delete(m_primary_key_value);
 
       if(bTest)
       {
@@ -487,17 +487,17 @@ void Box_Data_Details::on_button_nav_last()
     signal_nav_last().emit();
 }
 
-Gnome::Gda::Value Box_Data_Details::get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const
+Gnome::Gda::Value Box_Data_Details::get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
   return m_FlowTable.get_field_value(field);
 }
 
-void Box_Data_Details::set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+void Box_Data_Details::set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
   m_FlowTable.set_field_value(field, value);
 }
 
-void Box_Data_Details::set_entered_field_data(const Gtk::TreeModel::iterator& /* row */, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+void Box_Data_Details::set_entered_field_data(const Gtk::TreeModel::iterator& /* row */, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
   set_entered_field_data(field, value);
 }
@@ -512,26 +512,23 @@ void Box_Data_Details::recalculate_fields_for_related_records(const Glib::ustrin
   m_FieldsCalculationInProgress.clear();
 
   //Check all fields in the parent table:
-  const Gnome::Gda::Value primary_key_value = get_primary_key_value_selected();
-  for(type_vec_fields::iterator iter = m_TableFields.begin(); iter != m_TableFields.end(); ++iter)
+  const auto primary_key_value = get_primary_key_value_selected();
+  for(const auto& field : m_TableFields)
   {
-    const sharedptr<const Field> field = *iter;
-
     //Is this field triggered by this relationship?
-    const Field::type_list_strings triggered_by = field->get_calculation_relationships();
+    const auto triggered_by = field->get_calculation_relationships();
     Field::type_list_strings::const_iterator iterFind = std::find(triggered_by.begin(), triggered_by.end(), relationship_name);
     if(iterFind != triggered_by.end()) //If it was found
     {
-      sharedptr<Field> field = *iter;
       if(field)
       {
-        sharedptr<LayoutItem_Field> layoutitem_field = sharedptr<LayoutItem_Field>::create();
+        std::shared_ptr<LayoutItem_Field> layoutitem_field = std::make_shared<LayoutItem_Field>();
         layoutitem_field->set_full_field_details(field);
         LayoutFieldInRecord field_in_record(layoutitem_field, m_table_name, m_field_primary_key, primary_key_value);
         calculate_field(field_in_record); //And any dependencies.
 
         //Calculate anything that depends on this.
-        //sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+        //std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
         //layout_item->set_full_field_details(field);
 
         do_calculations(field_in_record, false /* recurse, reusing m_FieldsCalculationInProgress */);
@@ -642,18 +639,18 @@ void Box_Data_Details::on_flowtable_related_record_changed(const Glib::ustring&
   recalculate_fields_for_related_records(relationship_name);
 }
 
-void Box_Data_Details::on_flowtable_field_open_details_requested(const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& field_value)
+void Box_Data_Details::on_flowtable_field_open_details_requested(const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& field_value)
 {
   if(Conversions::value_is_empty(field_value))
     return; //Ignore empty ID fields.
 
   //Updating doesn't seem necessary. The field details seem to be full already.
   //Update the field details from the document:
-  ////sharedptr<LayoutItem_Field> unconst_field = sharedptr<LayoutItem_Field>::cast_const(layout_field); //A hack, because layout_field_should_have_navigation() needs to get full field details.
+  ////std::shared_ptr<LayoutItem_Field> unconst_field = std::const_pointer_cast<LayoutItem_Field>(layout_field); //A hack, because layout_field_should_have_navigation() needs to get full field details.
   //unconst_field->set_full_field_details(
   //  document->get_field(field->get_table_used(table_name), field->get_name()) ); //Otherwise get_primary_key() returns false always.
       
-  sharedptr<const Relationship> field_used_in_relationship_to_one;
+  std::shared_ptr<Relationship> field_used_in_relationship_to_one;
   const bool has_open_button = 
     DbUtils::layout_field_should_have_navigation(m_table_name, layout_field, get_document(), 
     field_used_in_relationship_to_one);
@@ -674,7 +671,7 @@ void Box_Data_Details::on_flowtable_field_open_details_requested(const sharedptr
   }
 }
 
-void Box_Data_Details::on_flowtable_script_button_clicked(const sharedptr<const LayoutItem_Button>& layout_item)
+void Box_Data_Details::on_flowtable_script_button_clicked(const std::shared_ptr<const LayoutItem_Button>& layout_item)
 {
   if(!layout_item)
   {
@@ -682,7 +679,7 @@ void Box_Data_Details::on_flowtable_script_button_clicked(const sharedptr<const
     return;
   }
   
-  const Gnome::Gda::Value primary_key_value = get_primary_key_value_selected();
+  const auto primary_key_value = get_primary_key_value_selected();
   const Glib::ustring table_name_before = m_table_name;
   execute_button_script(layout_item, primary_key_value);
 
@@ -703,12 +700,12 @@ void Box_Data_Details::on_flowtable_script_button_clicked(const sharedptr<const
   }
 }
 
-void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& field_value)
+void Box_Data_Details::on_flowtable_field_edited(const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& field_value)
 {
   if(m_ignore_signals)
     return;
 
-  const Glib::ustring strFieldName = layout_field->get_name();
+  const auto strFieldName = layout_field->get_name();
 
   Gtk::Window* window = get_app_window();
 
@@ -719,39 +716,37 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
   if(!Conversions::value_is_empty(primary_key_value)) //If there is not a stored primary key value yet:
   {
     Glib::ustring table_name;
-    sharedptr<Field> primary_key_field;
-    Gnome::Gda::Value primary_key_value;
+    std::shared_ptr<Field> primary_key_field;
 
     if(!layout_field->get_has_relationship_name())
     {
       table_name = get_table_name();
       primary_key_field = m_field_primary_key;
-      primary_key_value = get_primary_key_value_selected();
     }
     else
     {
       //If it's a related field then discover the actual table that it's in,
       //plus how to identify the record in that table.
-      const Glib::ustring relationship_name = layout_field->get_relationship_name();
+      const auto relationship_name = layout_field->get_relationship_name();
 
-      sharedptr<Relationship> relationship = document->get_relationship(get_table_name(), relationship_name);
+      std::shared_ptr<Relationship> relationship = document->get_relationship(get_table_name(), relationship_name);
       if(relationship)
       {
         table_name = relationship->get_to_table();
-        const Glib::ustring to_field_name = relationship->get_to_field();
+        const auto to_field_name = relationship->get_to_field();
         //Get the key field in the other table (the table that we will change)
         primary_key_field = DbUtils::get_fields_for_table_one_field(document, table_name, to_field_name); //TODO_Performance.
         if(primary_key_field)
         {
           //Get the value of the corresponding key in the current table (that identifies the record in the table that we will change)
-          sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+          std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
           layout_item->set_full_field_details( document->get_field(relationship->get_from_table(), relationship->get_from_field()) );
 
           primary_key_value = get_entered_field_data(layout_item);
 
           //Note: This just uses an existing record if one already exists:
           Gnome::Gda::Value primary_key_value_used;
-          const bool test = add_related_record_for_field(layout_field, relationship, primary_key_field, primary_key_value, primary_key_value_used);
+          const auto test = add_related_record_for_field(layout_field, relationship, primary_key_field, primary_key_value, primary_key_value_used);
           if(!test)
             return;
 
@@ -774,7 +769,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
     if(!check_entered_value_for_uniqueness(m_table_name, layout_field, field_value, window))
     {
       //Revert to the value in the database:
-      const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+      const auto value_old = get_field_value_in_database(field_in_record, window);
       set_entered_field_data(layout_field, value_old);
 
       return;
@@ -806,7 +801,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       {
         //Update failed.
         //Replace with correct values.
-        const Gnome::Gda::Value value_old = get_field_value_in_database(field_in_record, window);
+        const auto value_old = get_field_value_in_database(field_in_record, window);
         set_entered_field_data(layout_field, value_old);
       }
       else
@@ -817,10 +812,8 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
         /*
         bool bIsForeignKey = false;
         Document::type_vec_relationships vecRelationships = get_document()->get_relationships(m_table_name);
-        for(Document::type_vec_relationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
+        for(const auto& relationship : vecRelationships)
         {
-          const Relationship& relationship = *iter;
-
           if(relationship->get_from_field() == strFieldName)
           {
             bIsForeignKey = true;
@@ -860,10 +853,10 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
       else
       {
         //Make a new record, and show it:
-        const Gnome::Gda::Value primary_key_value = DbUtils::get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name());
+        const auto primary_key_value_autoincrement = DbUtils::get_next_auto_increment_value(m_table_name, m_field_primary_key->get_name());
 
-        record_new(true /* use entered field data */, primary_key_value);
-        refresh_data_from_database_with_primary_key(primary_key_value);
+        record_new(true /* use entered field data */, primary_key_value_autoincrement);
+        refresh_data_from_database_with_primary_key(primary_key_value_autoincrement);
       }
     }
     else
@@ -874,7 +867,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
         if(!check_entered_value_for_uniqueness(m_table_name, layout_field, field_value, window))
         {
           //Revert to a blank value:
-          const Gnome::Gda::Value value_old = Conversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
+          const auto value_old = Conversions::get_empty_value(layout_field->get_full_field_details()->get_glom_type());
           set_entered_field_data(layout_field, value_old);
         }
         else
@@ -897,7 +890,7 @@ void Box_Data_Details::on_flowtable_field_edited(const sharedptr<const LayoutIte
   } //if(get_primary_key_value_selected().size())
 }
 
-void Box_Data_Details::on_flowtable_field_choices_changed(const sharedptr<const LayoutItem_Field>& layout_field)
+void Box_Data_Details::on_flowtable_field_choices_changed(const std::shared_ptr<const LayoutItem_Field>& layout_field)
 {
   if(m_ignore_signals)
     return;
@@ -916,14 +909,14 @@ void Box_Data_Details::on_userlevel_changed(AppState::userlevels user_level)
 #endif
 }
 
-sharedptr<Field> Box_Data_Details::get_field_primary_key() const
+std::shared_ptr<Field> Box_Data_Details::get_field_primary_key() const
 {
   return m_field_primary_key;
 }
 
 void Box_Data_Details::print_layout()
 {
-  const Privileges table_privs = Privs::get_current_privs(m_table_name);
+  const auto table_privs = Privs::get_current_privs(m_table_name);
 
   //Don't try to print tables that the user can't view.
   if(!table_privs.m_view)
@@ -947,20 +940,20 @@ void Box_Data_Details::print_layout()
   //breaks because those spaces would be empty space on the page after
   //we have moved items down when expanding:
   //TODO: Squash that space when expanding custom layouts.
-  sharedptr<PrintLayout> print_layout = 
+  std::shared_ptr<PrintLayout> layout = 
     PrintLayoutUtils::create_standard(page_setup, m_table_name, document,
       false /* do not avoid page margins */);
   
   //Show the print preview window:
   AppWindow* app = AppWindow::get_appwindow();
-  PrintLayoutUtils::do_print_layout(print_layout, m_found_set,
+  PrintLayoutUtils::do_print_layout(layout, m_found_set,
     false /* not preview */, document, true /* avoid page margins */, app);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 Dialog_Layout* Box_Data_Details::create_layout_dialog() const
 {
-  Dialog_Layout_Details* dialog = 0;
+  Dialog_Layout_Details* dialog = nullptr;
   Glom::Utils::get_glade_widget_derived_with_warning(dialog);
   return dialog;
 }
@@ -971,12 +964,12 @@ void Box_Data_Details::prepare_layout_dialog(Dialog_Layout* dialog)
     dialog->init(m_layout_name, m_layout_platform, get_document(), m_table_name, m_FieldsShown); //TODO: Use m_TableFields?
 }
 
-void Box_Data_Details::show_layout_toolbar(bool show)
+void Box_Data_Details::show_layout_toolbar(bool show_toolbar)
 {
   //Remember this so we can use it in the show_all() vfunc.
-  m_show_toolbar = show;
+  m_show_toolbar = show_toolbar;
 
-  if(show)
+  if(show_toolbar)
     m_Dragbar.show();
   else
     m_Dragbar.hide();
