@@ -70,7 +70,7 @@ Box_Data_List::~Box_Data_List()
 
 void Box_Data_List::enable_buttons()
 {
-  const Privileges table_privs = Privs::get_current_privs(m_table_name);
+  const auto table_privs = Privs::get_current_privs(m_table_name);
 
     //Enable/Disable record creation and deletion:
   bool allow_create = !m_read_only;
@@ -109,7 +109,7 @@ bool Box_Data_List::fill_from_database()
 
   BusyCursor busy_cursor(get_app_window());
 
-  sharedptr<SharedConnection> sharedconnection;
+  std::shared_ptr<SharedConnection> sharedconnection;
 
   try
   {
@@ -138,7 +138,7 @@ bool Box_Data_List::fill_from_database()
       //Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
     //Do not try to show the data if the user may not view it:
-    const Privileges table_privs = Privs::get_current_privs(m_table_name);
+    const auto table_privs = Privs::get_current_privs(m_table_name);
 
     enable_buttons();
 
@@ -162,7 +162,7 @@ bool Box_Data_List::fill_from_database()
 
 void Box_Data_List::on_adddel_user_requested_edit(const Gtk::TreeModel::iterator& row)
 {
-  const Gnome::Gda::Value primary_key_value = m_AddDel.get_value_key(row); //The primary key is in the key.
+  const auto primary_key_value = m_AddDel.get_value_key(row); //The primary key is in the key.
 
   signal_user_requested_details().emit(primary_key_value);
 }
@@ -185,15 +185,13 @@ void Box_Data_List::on_adddel_user_reordered_columns()
   Document* pDoc = dynamic_cast<Document*>(get_document());
   if(pDoc)
   {
-    sharedptr<LayoutGroup> group = sharedptr<LayoutGroup>::create();
+    auto group = std::make_shared<LayoutGroup>();
     group->set_name("toplevel");
 
-    AddDel::type_vec_strings vec_field_names = m_AddDel.get_columns_order();
-
-    for(AddDel::type_vec_strings::iterator iter = vec_field_names.begin(); iter != vec_field_names.end(); ++iter)
+    for(const auto& field_name : m_AddDel.get_columns_order())
     {
-      sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-      layout_item->set_name(*iter);
+      auto layout_item = std::make_shared<LayoutItem_Field>();
+      layout_item->set_name(field_name);
       group->add_item(layout_item);
     }
 
@@ -204,12 +202,12 @@ void Box_Data_List::on_adddel_user_reordered_columns()
   }
 }
 
-void Box_Data_List::on_adddel_script_button_clicked(const sharedptr<const LayoutItem_Button>& layout_item, const Gtk::TreeModel::iterator& row)
+void Box_Data_List::on_adddel_script_button_clicked(const std::shared_ptr<const LayoutItem_Button>& layout_item, const Gtk::TreeModel::iterator& row)
 {
   if(!layout_item)
     return;
 
-  const Gnome::Gda::Value primary_key_value = get_primary_key_value(row);
+  const auto primary_key_value = get_primary_key_value(row);
 
   // TODO: Calling refresh_data_from_database(),
   // or navigating to a different table from inside the Python script,
@@ -224,7 +222,7 @@ void Box_Data_List::on_adddel_script_button_clicked(const sharedptr<const Layout
       primary_key_value));
 }
 
-bool Box_Data_List::on_script_button_idle(const sharedptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key)
+bool Box_Data_List::on_script_button_idle(const std::shared_ptr<const LayoutItem_Button>& layout_item, const Gnome::Gda::Value& primary_key)
 {
   execute_button_script(layout_item, primary_key);
 
@@ -254,7 +252,7 @@ void Box_Data_List::on_details_nav_first()
 
 void Box_Data_List::on_details_nav_previous()
 {
-  Gtk::TreeModel::iterator iter = m_AddDel.get_item_selected();
+  auto iter = m_AddDel.get_item_selected();
   if(iter)
   {
     //Don't try to select a negative record number.
@@ -270,7 +268,7 @@ void Box_Data_List::on_details_nav_previous()
 
 void Box_Data_List::on_details_nav_next()
 {
-  Gtk::TreeModel::iterator iter = m_AddDel.get_item_selected();
+  auto iter = m_AddDel.get_item_selected();
   if(iter)
   {
     //Don't go past the last record:
@@ -290,7 +288,7 @@ void Box_Data_List::on_details_nav_next()
 
 void Box_Data_List::on_details_nav_last()
 {
-  Gtk::TreeModel::iterator iter = m_AddDel.get_last_row();
+  auto iter = m_AddDel.get_last_row();
   if(iter)
   {
     m_AddDel.select_item(iter);
@@ -304,11 +302,11 @@ void Box_Data_List::on_details_nav_last()
 void Box_Data_List::on_details_record_deleted(const Gnome::Gda::Value& primary_key_value)
 {
   //Find out which row is affected:
-  Gtk::TreeModel::iterator iter = m_AddDel.get_row(primary_key_value);
+  auto iter = m_AddDel.get_row(primary_key_value);
   if(iter)
   {
     //Remove the row:
-    Gtk::TreeModel::iterator iterNext = iter;
+    auto iterNext = iter;
     iterNext++;
 
     m_AddDel.remove_item(iter);
@@ -351,7 +349,7 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_first() const
   Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
   if(model)
   {
-    Gtk::TreeModel::iterator iter = model->children().begin();
+    auto iter = model->children().begin();
     while(iter != model->children().end())
     {
       Gnome::Gda::Value value = get_primary_key_value(iter);
@@ -372,19 +370,19 @@ Gnome::Gda::Value Box_Data_List::get_primary_key_value_first() const
   return Gnome::Gda::Value();
 }
 
-Gnome::Gda::Value Box_Data_List::get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const
+Gnome::Gda::Value Box_Data_List::get_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field) const
 {
   return m_AddDel.get_value_selected(field);
 }
 
-void Box_Data_List::set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+void Box_Data_List::set_entered_field_data(const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  m_AddDel.set_value_selected(field, value);
+  return m_AddDel.set_value_selected(field, value);
 }
 
-void Box_Data_List::set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
+void Box_Data_List::set_entered_field_data(const Gtk::TreeModel::iterator& row, const std::shared_ptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value)
 {
-  m_AddDel.set_value(row, field, value);
+  return m_AddDel.set_value(row, field, value);
 }
 
 bool Box_Data_List::get_showing_multiple_records() const
@@ -415,7 +413,7 @@ void Box_Data_List::create_layout()
   m_AddDel.set_table_name(m_table_name);
 
 
-  sharedptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
+  std::shared_ptr<Field> field_primary_key = get_field_primary_key_for_table(m_table_name);
   if(!field_primary_key)
   {
     std::cerr << G_STRFUNC << ": primary key not found for table: " << m_table_name << std::endl;
@@ -430,22 +428,19 @@ void Box_Data_List::create_layout()
 
   //This map of layout groups will also contain the field information from the database:
   Document::type_list_layout_groups layout_groups = create_layout_get_layout();
-  for(Document::type_list_layout_groups::const_iterator iter = layout_groups.begin(); iter != layout_groups.end(); ++iter)
+  for(const auto& layout_group : layout_groups)
   {
-    const sharedptr<LayoutGroup> layout_group = *iter;
     if(!layout_group)
       continue;
 
-    const LayoutGroup::type_list_items child_items = layout_group->get_items_recursive();
-    for(LayoutGroup::type_list_items::const_iterator iterItems = child_items.begin(); iterItems != child_items.end(); ++iterItems)
+    const auto child_items = layout_group->get_items_recursive();
+    for(const auto& child_item : child_items)
     {
-      sharedptr<LayoutItem> child_item = *iterItems;
-
       //TODO: Set the whole thing as read-only instead:
       if(m_read_only)
         child_item->set_editable(false);
 
-      sharedptr<const LayoutItem_Field> child_field = sharedptr<const LayoutItem_Field>::cast_dynamic(child_item);
+      std::shared_ptr<const LayoutItem_Field> child_field = std::dynamic_pointer_cast<const LayoutItem_Field>(child_item);
 
       //This check has already happened in Frame_Glom::update_table_in_document_from_database().
       //It is inefficient and unnecessary to do it here too.
@@ -472,14 +467,14 @@ void Box_Data_List::create_layout()
   items_to_use = Utils::get_layout_items_plus_primary_key(items_to_use, pDoc, m_table_name);
   if(field_primary_key)
   {
-    sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+    std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
     layout_item->set_hidden();
     layout_item->set_full_field_details(m_AddDel.get_key_field());
 
     m_FieldsShown.push_back(layout_item); //TODO: Do this only if it is not already present.
   }
 
-  const Privileges table_privs = Privs::get_current_privs(m_found_set.m_table_name);
+  const auto table_privs = Privs::get_current_privs(m_found_set.m_table_name);
   m_AddDel.set_allow_view(table_privs.m_view);
     
   m_AddDel.set_found_set(m_found_set);
@@ -488,7 +483,7 @@ void Box_Data_List::create_layout()
   m_FieldsShown = get_fields_to_show();
 }
 
-sharedptr<Field> Box_Data_List::get_field_primary_key() const
+std::shared_ptr<Field> Box_Data_List::get_field_primary_key() const
 {
   return m_AddDel.get_key_field();
 }
@@ -509,7 +504,7 @@ void Box_Data_List::set_open_button_title(const Glib::ustring& title)
 
 void Box_Data_List::set_primary_key_value_selected(const Gnome::Gda::Value& primary_key_value)
 {
-  Gtk::TreeModel::iterator iter = m_AddDel.get_row(primary_key_value);
+  auto iter = m_AddDel.get_row(primary_key_value);
   if(iter)
   {
     m_AddDel.select_item(iter);
@@ -556,7 +551,7 @@ void Box_Data_List::on_dialog_layout_hide()
 
 Dialog_Layout* Box_Data_List::create_layout_dialog() const
 {
-  Dialog_Layout_List* dialog = 0;
+  Dialog_Layout_List* dialog = nullptr;
   Glom::Utils::get_glade_widget_derived_with_warning(dialog);
   return dialog;
 }
