@@ -56,7 +56,7 @@ Box_Data_Portal::~Box_Data_Portal()
 
 void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_record_primary_key_value)
 {
-  sharedptr<Field> field_primary_key = get_field_primary_key();
+  std::shared_ptr<Field> field_primary_key = get_field_primary_key();
 
   //Create the link by setting the foreign key
   if(!m_key_field)
@@ -75,7 +75,7 @@ void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_recor
     std::cerr << G_STRFUNC << ": m_portal was null." << std::endl;
   }
 
-  const Glib::ustring target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
+  const auto target_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
   Glib::RefPtr<Gnome::Gda::SqlBuilder> builder = Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_UPDATE);
     builder->set_table(target_table);
     builder->add_field_value_as_value(m_key_field->get_name(), m_key_value);
@@ -85,14 +85,14 @@ void Box_Data_Portal::make_record_related(const Gnome::Gda::Value& related_recor
         builder->add_expr_as_value(related_record_primary_key_value)));
 
   //std::cout << "debug: " << G_STRFUNC << ": setting value in db=" << primary_key_value.to_string() << std::endl;
-  const bool test = DbUtils::query_execute(builder);
+  const auto test = DbUtils::query_execute(builder);
   if(!test)
   {
     std::cerr << G_STRFUNC << ": SQL query failed." << std::endl;
   }
 }
 
-bool Box_Data_Portal::init_db_details(const sharedptr<const LayoutItem_Portal>& portal, bool show_title)
+bool Box_Data_Portal::init_db_details(const std::shared_ptr<const LayoutItem_Portal>& portal, bool show_title)
 {
   m_portal = glom_sharedptr_clone(portal);
 
@@ -160,12 +160,12 @@ bool Box_Data_Portal::refresh_data_from_database_with_foreign_key(const Gnome::G
   }
 }
 
-sharedptr<LayoutItem_Portal> Box_Data_Portal::get_portal() const
+std::shared_ptr<LayoutItem_Portal> Box_Data_Portal::get_portal() const
 {
   return m_portal;
 }
 
-sharedptr<const Field> Box_Data_Portal::get_key_field() const
+std::shared_ptr<const Field> Box_Data_Portal::get_key_field() const
 {
   return m_key_field;
 }
@@ -185,13 +185,13 @@ void Box_Data_Portal::on_record_added(const Gnome::Gda::Value& /* primary_key_va
 
 Box_Data_Portal::type_vecConstLayoutFields Box_Data_Portal::get_fields_to_show() const
 {
-  const Document* document = get_document();
+  const auto document = get_document();
   if(document && m_portal)
   {
     Document::type_list_layout_groups mapGroups;
     mapGroups.push_back(m_portal);
 
-    sharedptr<const Relationship> relationship = m_portal->get_relationship();
+    std::shared_ptr<const Relationship> relationship = m_portal->get_relationship();
     if(relationship)
     {
       type_vecConstLayoutFields result = get_table_fields_to_show_for_sequence(m_portal->get_table_used(Glib::ustring() /* not relevant */), mapGroups);
@@ -201,9 +201,9 @@ Box_Data_Portal::type_vecConstLayoutFields Box_Data_Portal::get_fields_to_show()
       /*
       if(!(m_portal->get_relationship_used_allows_edit()))
       {
-        for(type_vecConstLayoutFields::iterator iter = result.begin(); iter != result.end(); ++iter)
+        for(const auto& item : result)
         {
-          sharedptr<const LayoutItem_Field> item = *iter;
+          std::shared_ptr<const LayoutItem_Field> item = *iter;
           if(item)
             item->set_editable(false);
         }
@@ -231,12 +231,12 @@ bool Box_Data_Portal::get_has_suitable_record_to_view_details() const
   if(!m_portal)
     return false;
 
-  const Document* document = get_document();
+  const auto document = get_document();
   if(!document)
     return false;
     
   Glib::ustring navigation_table_name;
-  sharedptr<const UsesRelationship> navigation_relationship; //Ignored.
+  std::shared_ptr<const UsesRelationship> navigation_relationship; //Ignored.
   m_portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, document);
 
   return !(navigation_table_name.empty());
@@ -251,12 +251,12 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   if(!m_portal)
     return;
 
-  const Document* document = get_document();
+  const auto document = get_document();
   if(!document)
     return;
     
   Glib::ustring navigation_table_name;
-  sharedptr<const UsesRelationship> navigation_relationship;
+  std::shared_ptr<const UsesRelationship> navigation_relationship;
   m_portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, document);
   
   //if(navigation_relationship && navigation_relationship->get_relationship())
@@ -268,10 +268,10 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
     return;
 
   //Get the primary key of that table:
-  sharedptr<Field> navigation_table_primary_key = get_field_primary_key_for_table(navigation_table_name);
+  std::shared_ptr<Field> navigation_table_primary_key = get_field_primary_key_for_table(navigation_table_name);
 
   //Build a layout item to get the field's value:
-  sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
+  std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
   layout_item->set_full_field_details(navigation_table_primary_key);
 
   if(navigation_relationship)
@@ -286,8 +286,8 @@ void Box_Data_Portal::get_suitable_record_to_view_details(const Gnome::Gda::Valu
   fieldsToGet.push_back(layout_item);
 
   //For instance "invoice_line_id" if this is a portal to an "invoice_lines" table:
-  const Glib::ustring related_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
-  sharedptr<const Field> key_field = get_field_primary_key_for_table(related_table);
+  const auto related_table = m_portal->get_table_used(Glib::ustring() /* not relevant */);
+  std::shared_ptr<const Field> key_field = get_field_primary_key_for_table(related_table);
   //std::cout << "DEBUG: related table=" << related_table << ", whose primary_key=" << key_field->get_name() << ", with value=" << primary_key_value.to_string() << "getting value for: " << layout_item->get_layout_display_name() << std::endl;
 
   Glib::RefPtr<Gnome::Gda::SqlBuilder> query = Utils::build_sql_select_with_key(related_table, fieldsToGet, key_field, primary_key_value);
@@ -345,7 +345,7 @@ Document::type_list_layout_groups Box_Data_Portal::create_layout_get_layout()
   return result;
 }
 
-sharedptr<Field> Box_Data_Portal::get_field_primary_key() const
+std::shared_ptr<Field> Box_Data_Portal::get_field_primary_key() const
 {
   return m_key_field;
 }
