@@ -63,15 +63,15 @@ AppWindow* ButtonGlom::get_appwindow() const
 #ifndef GLOM_ENABLE_CLIENT_ONLY
 void ButtonGlom::on_menu_properties_activate()
 {
-  Dialog_ButtonScript* dialog = 0;
+  Dialog_ButtonScript* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
 
-  sharedptr<LayoutItem_Button> layout_item = 
-    sharedptr<LayoutItem_Button>::cast_dynamic(get_layout_item());
+  std::shared_ptr<LayoutItem_Button> layout_item = 
+    std::dynamic_pointer_cast<LayoutItem_Button>(get_layout_item());
   dialog->set_script(layout_item, m_table_name);
-  const int response = Glom::UiUtils::dialog_run_with_help(dialog);
+  const auto response = Glom::UiUtils::dialog_run_with_help(dialog);
   dialog->hide();
   if(response == Gtk::RESPONSE_OK)
   {
@@ -82,21 +82,21 @@ void ButtonGlom::on_menu_properties_activate()
   delete dialog;
 }
 
-bool ButtonGlom::on_button_press_event(GdkEventButton *event)
+bool ButtonGlom::on_button_press_event(GdkEventButton *button_event)
 {
   AppWindow* pApp = get_appwindow();
   if(pApp && pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
     GdkModifierType mods;
-    gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+    gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
     if(mods & GDK_BUTTON3_MASK)
     {
       //Give user choices of actions on this item:
-      m_pPopupMenuUtils->popup(event->button, event->time);
+      m_pPopupMenuUtils->popup(button_event->button, button_event->time);
       return true; //We handled this event.
     }
   }
-  return Gtk::Button::on_button_press_event(event);
+  return Gtk::Button::on_button_press_event(button_event);
 }
 #endif
 
