@@ -52,7 +52,7 @@ ComboGlom::ComboGlom(bool has_entry)
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
   //if(m_glom_type == Field::TYPE_NUMERIC)
-   // get_entry()->set_halign(Gtk::ALIGN_END); //Align numbers to the right.
+   // get_entry()->set_alignment(1.0); //Align numbers to the right.
 
   //Let the combo be big enough:
   set_popup_fixed_width(false);
@@ -73,8 +73,8 @@ void ComboGlom::on_fixed_cell_data(const Gtk::TreeModel::iterator& iter, Gtk::Ce
   if(!iter)
     return;
 
-  const sharedptr<const LayoutItem>& layout_item = get_layout_item();
-  const sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
+  const std::shared_ptr<const LayoutItem>& layout_item = get_layout_item();
+  const std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
   if(!field)
     return;
 
@@ -120,8 +120,8 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
   if(columns_count)
     columns_count -= 1; //The last one is the just the extra text-equivalent of the first one, for GtkComboBox with has-entry=true, or for translations.
 
-  const sharedptr<const LayoutItem>& layout_item = get_layout_item();
-  const sharedptr<const LayoutItem_Field> field = sharedptr<const LayoutItem_Field>::cast_dynamic(layout_item);
+  const std::shared_ptr<const LayoutItem>& layout_item = get_layout_item();
+  const std::shared_ptr<const LayoutItem_Field> field = std::dynamic_pointer_cast<const LayoutItem_Field>(layout_item);
 
   //For fixed (custom) choices, this will always be 1 column anyway,
   //so the for() loop here is excessive.
@@ -154,7 +154,7 @@ void ComboGlom::set_choices_fixed(const Formatting::type_list_values& list_value
   }
 }
 
-void ComboGlom::set_choices_related(const Document* document, const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboGlom::set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   ComboChoicesWithTreeModel::set_choices_related(document, layout_field, foreign_key_value);
 
@@ -174,7 +174,7 @@ void ComboGlom::set_choices_related(const Document* document, const sharedptr<co
       Glib::RefPtr<DbTreeModelWithExtraText>::cast_dynamic(model);
     if(model_db)
     {
-      const int text_col = model_db->get_text_column();
+      const auto text_col = model_db->get_text_column();
       //const GType debug_type = model_db->get_column_type(text_col);
       //std::cout << "DEBUG: text_col=" << text_col << ", debug_type=" << g_type_name(debug_type) << std::endl;
       set_entry_text_column(text_col);
@@ -191,9 +191,8 @@ void ComboGlom::set_choices_related(const Document* document, const sharedptr<co
   }
 
   guint model_column_index = 0;
-  for(type_vec_const_layout_items::const_iterator iter = m_db_layout_items.begin(); iter != m_db_layout_items.end(); ++iter)
+  for(const auto& layout_item : m_db_layout_items)
   {
-    const sharedptr<const LayoutItem> layout_item = *iter;
     if(!layout_item) //column_info.m_visible)
     {
       ++model_column_index;
@@ -233,13 +232,13 @@ void ComboGlom::check_for_change()
 
 void ComboGlom::set_value(const Gnome::Gda::Value& value)
 {
-  sharedptr<const LayoutItem_Field> layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   if(!layout_item)
     return;
 
   m_old_value = value;
 
-  Glib::RefPtr<Gtk::TreeModel> model = get_choices_model();
+  auto model = get_choices_model();
   if(!model)
   {
     std::cerr << G_STRFUNC << ": model is null." << std::endl;
@@ -251,16 +250,15 @@ void ComboGlom::set_value(const Gnome::Gda::Value& value)
   m_ignore_changed = true;
 
   bool found = false;
-  for(Gtk::TreeModel::iterator iter = model->children().begin(); iter != model->children().end(); ++iter)
+  for(const auto& row : model->children())
   {
-    const Gtk::TreeModel::Row row = *iter;
     Gnome::Gda::Value this_value;
     row.get_value(0, this_value);
 
     if(this_value == value)
     {
       found = true;
-      set_active(iter);
+      set_active(row);
       break;
     }
   }
@@ -299,7 +297,7 @@ void ComboGlom::set_value(const Gnome::Gda::Value& value)
 Gnome::Gda::Value ComboGlom::get_value() const
 {
    //Get the active row:
-   Gtk::TreeModel::iterator iter = get_active();
+   auto iter = get_active();
 
    if(iter)
    {
@@ -313,7 +311,7 @@ Gnome::Gda::Value ComboGlom::get_value() const
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-bool ComboGlom::on_button_press_event(GdkEventButton *event)
+bool ComboGlom::on_button_press_event(GdkEventButton *button_event)
 {
 g_warning("ComboGlom::on_button_press_event()");
 
@@ -334,18 +332,18 @@ g_warning("ComboGlom::on_button_press_event()");
     if(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_pMenuPopup->popup(event->button, event->time);
+        m_pMenuPopup->popup(button_event->button, button_event->time);
         return true; //We handled this event.
       }
     }
 
   }
 
-  return Gtk::ComboBox::on_button_press_event(event);
+  return Gtk::ComboBox::on_button_press_event(button_event);
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
@@ -368,7 +366,7 @@ void ComboGlom::on_changed()
 
   //This signal is emitted for every key press, but sometimes it's just to say that the active item has changed to "no active item",
   //if the text is not in the dropdown list:
-  Gtk::TreeModel::iterator iter = get_active();
+  auto iter = get_active();
 
   if(iter)
   {
