@@ -49,26 +49,25 @@ ComboAsRadioButtons::ComboAsRadioButtons()
 void ComboAsRadioButtons::init()
 {
   //if(m_glom_type == Field::TYPE_NUMERIC)
-   // get_entry()->set_halign(Gtk::ALIGN_END); //Align numbers to the right.
+   // get_entry()->set_alignment(1.0); //Align numbers to the right.
 }
 
 void ComboAsRadioButtons::set_choices_with_second(const type_list_values_with_second& list_values)
 {
   //Clear existing buttons:
-  for(type_map_buttons::iterator iter = m_map_buttons.begin();
-    iter != m_map_buttons.end(); ++iter)
+  for(const auto& the_pair : m_map_buttons)
   {
-     Gtk::RadioButton* button = iter->second;
+     auto button = the_pair.second;
      delete button;
   }
   m_map_buttons.clear();
 
-  sharedptr<LayoutItem_Field> layout_item =
-    sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
-  const Formatting& format = layout_item->get_formatting_used();
-  sharedptr<const Relationship> choice_relationship;
-  sharedptr<const LayoutItem_Field> layout_choice_first;
-  sharedptr<const LayoutGroup> layout_choice_extra;
+  std::shared_ptr<LayoutItem_Field> layout_item =
+    std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
+  const auto format = layout_item->get_formatting_used();
+  std::shared_ptr<const Relationship> choice_relationship;
+  std::shared_ptr<const LayoutItem_Field> layout_choice_first;
+  std::shared_ptr<const LayoutGroup> layout_choice_extra;
   Formatting::type_list_sort_fields choice_sort_fields; //Ignored. TODO?
   bool choice_show_all = false;
   format.get_choices_related(choice_relationship, layout_choice_first, layout_choice_extra, choice_sort_fields, choice_show_all);
@@ -79,27 +78,25 @@ void ComboAsRadioButtons::set_choices_with_second(const type_list_values_with_se
 
   //Add new buttons:
   Gtk::RadioButton::Group group;
-  for(type_list_values_with_second::const_iterator iter = list_values.begin(); iter != list_values.end(); ++iter)
+  for(const auto& the_pair : list_values)
   {
     if(layout_choice_first)
     {
-      const Glib::ustring value_first = Conversions::get_text_for_gda_value(layout_choice_first->get_glom_type(), iter->first, layout_choice_first->get_formatting_used().m_numeric_format);
-      Glib::ustring title = value_first;
+      const auto value_first = Conversions::get_text_for_gda_value(layout_choice_first->get_glom_type(), the_pair.first, layout_choice_first->get_formatting_used().m_numeric_format);
+      auto title = value_first;
 
-      const type_list_values extra_values = iter->second;
+      const auto extra_values = the_pair.second;
       if(layout_choice_extra && !extra_values.empty())
       {
         type_list_values::const_iterator iterValues = extra_values.begin();
-        for(LayoutGroup::type_list_const_items::const_iterator iterExtra = extra_fields.begin();
-          iterExtra != extra_fields.end(); ++iterExtra)
+        for(const auto& item : extra_fields)
         {
           if(iterValues != extra_values.end()) {
-            const sharedptr<const LayoutItem> item = *iterExtra;
-            const sharedptr<const LayoutItem_Field> item_field = sharedptr<const LayoutItem_Field>::cast_dynamic(item);
+            const std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
             if(item_field)
             {
               const Gnome::Gda::Value value = *iterValues; //TODO: Use a vector instead?
-              const Glib::ustring value_second = Conversions::get_text_for_gda_value(item_field->get_glom_type(), value, item_field->get_formatting_used().m_numeric_format);
+              const auto value_second = Conversions::get_text_for_gda_value(item_field->get_glom_type(), value, item_field->get_formatting_used().m_numeric_format);
 
               title += " - " + value_second; //TODO: Find a better way to join them?
             }
@@ -126,27 +123,25 @@ void ComboAsRadioButtons::set_choices_with_second(const type_list_values_with_se
 void ComboAsRadioButtons::set_choices_fixed(const Formatting::type_list_values& list_values, bool /* restricted */)
 {
   //Clear existing buttons:
-  for(type_map_buttons::iterator iter = m_map_buttons.begin();
-    iter != m_map_buttons.end(); ++iter)
+  for(const auto& the_pair : m_map_buttons)
   {
-     Gtk::RadioButton* button = iter->second;
+     Gtk::RadioButton* button = the_pair.second;
      delete button;
   }
   m_map_buttons.clear();
 
   //Add new buttons:
   Gtk::RadioButton::Group group;
-  for(Formatting::type_list_values::const_iterator iter = list_values.begin(); iter != list_values.end(); ++iter)
+  for(const auto& choicevalue : list_values)
   {
-    sharedptr<const LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+    std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
     if(layout_item)
     {
-      const sharedptr<ChoiceValue> choicevalue = *iter;
       Gnome::Gda::Value value;
       if(choicevalue)
         value = choicevalue->get_value();
 
-      const Glib::ustring value_first = Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format);
+      const auto value_first = Conversions::get_text_for_gda_value(layout_item->get_glom_type(), value, layout_item->get_formatting_used().m_numeric_format);
 
       Gtk::RadioButton* button = new Gtk::RadioButton(group, value_first);
       m_map_buttons[value_first] = button;
@@ -158,7 +153,7 @@ void ComboAsRadioButtons::set_choices_fixed(const Formatting::type_list_values&
   }
 }
 
-void ComboAsRadioButtons::set_choices_related(const Document* document, const sharedptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
+void ComboAsRadioButtons::set_choices_related(const Document* document, const std::shared_ptr<const LayoutItem_Field>& layout_field, const Gnome::Gda::Value& foreign_key_value)
 {
   const Utils::type_list_values_with_second list_values =
     Utils::get_choice_values(document, layout_field, foreign_key_value);
@@ -167,10 +162,9 @@ void ComboAsRadioButtons::set_choices_related(const Document* document, const sh
 
 ComboAsRadioButtons::~ComboAsRadioButtons()
 {
-  for(type_map_buttons::iterator iter = m_map_buttons.begin();
-    iter != m_map_buttons.end(); ++iter)
+  for(const auto& the_pair : m_map_buttons)
   {
-    Gtk::RadioButton* button = iter->second;
+    Gtk::RadioButton* button = the_pair.second;
     delete button;
   }
   m_map_buttons.clear();
@@ -185,8 +179,8 @@ void ComboAsRadioButtons::check_for_change()
   //Validate the input:
   bool success = false;
 
-  sharedptr<const LayoutItem_Field> layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
-  const Gnome::Gda::Value value = Conversions::parse_value(layout_item->get_glom_type(), new_text, layout_item->get_formatting_used().m_numeric_format, success);
+  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
+  const auto value = Conversions::parse_value(layout_item->get_glom_type(), new_text, layout_item->get_formatting_used().m_numeric_format, success);
 
   if(success)
   {
@@ -197,7 +191,7 @@ void ComboAsRadioButtons::check_for_change()
   else
   {
     //Tell the user and offer to revert or try again:
-    const bool revert = glom_show_dialog_invalid_data(layout_item->get_glom_type());
+    const auto revert = glom_show_dialog_invalid_data(layout_item->get_glom_type());
     if(revert)
     {
       set_text(m_old_text);
@@ -209,7 +203,7 @@ void ComboAsRadioButtons::check_for_change()
 
 void ComboAsRadioButtons::set_value(const Gnome::Gda::Value& value)
 {
-  sharedptr<const LayoutItem_Field> layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   if(!layout_item)
     return;
 
@@ -226,7 +220,7 @@ void ComboAsRadioButtons::set_text(const Glib::ustring& text)
 {
   m_old_text = text;
 
-  type_map_buttons::iterator iter = m_map_buttons.find(text);
+  auto iter = m_map_buttons.find(text);
   if(iter != m_map_buttons.end())
   {
     Gtk::RadioButton* button = iter->second;
@@ -242,23 +236,22 @@ void ComboAsRadioButtons::set_text(const Glib::ustring& text)
 
 Gnome::Gda::Value ComboAsRadioButtons::get_value() const
 {
-  sharedptr<const LayoutItem_Field> layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<const LayoutItem_Field> layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   bool success = false;
 
-  const Glib::ustring text = get_text();
+  const auto text = get_text();
   return Conversions::parse_value(layout_item->get_glom_type(), text, layout_item->get_formatting_used().m_numeric_format, success);
 }
 
 Glib::ustring ComboAsRadioButtons::get_text() const
 {
   //Get the active row:
-  for(type_map_buttons::const_iterator iter = m_map_buttons.begin();
-    iter != m_map_buttons.end(); ++iter)
+  for(const auto& the_pair : m_map_buttons)
   {
-    Gtk::CheckButton* button = iter->second;
+    Gtk::CheckButton* button = the_pair.second;
     if(button && button->get_active())
     {
-      return iter->first;
+      return the_pair.first;
     }
   }
 
@@ -266,7 +259,7 @@ Glib::ustring ComboAsRadioButtons::get_text() const
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-void ComboAsRadioButtons::show_context_menu(GdkEventButton *event)
+void ComboAsRadioButtons::show_context_menu(GdkEventButton *button_event)
 {
   std::cout << "ComboAsRadioButtons::show_context_menu()" << std::endl;
   AppWindow* pApp = get_appwindow();
@@ -286,27 +279,27 @@ void ComboAsRadioButtons::show_context_menu(GdkEventButton *event)
     if(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_pMenuPopup->popup(event->button, event->time);
+        m_pMenuPopup->popup(button_event->button, button_event->time);
       }
     }
   }
 }
 
-bool ComboAsRadioButtons::on_radiobutton_button_press_event(GdkEventButton *event)
+bool ComboAsRadioButtons::on_radiobutton_button_press_event(GdkEventButton *button_event)
 {
-  show_context_menu(event);
+  show_context_menu(button_event);
   return false; //Let other signal handlers handle it too.
 }
 
-bool ComboAsRadioButtons::on_button_press_event(GdkEventButton *event)
+bool ComboAsRadioButtons::on_button_press_event(GdkEventButton *button_event)
 {
-  show_context_menu(event);
+  show_context_menu(button_event);
 
-  return Gtk::Box::on_button_press_event(event);
+  return Gtk::Box::on_button_press_event(button_event);
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
