@@ -43,11 +43,11 @@
 namespace Glom
 {
 
-static DataWidgetChildren::ComboChoices* create_combo_widget_for_field(const sharedptr<LayoutItem_Field>& field)
+static DataWidgetChildren::ComboChoices* create_combo_widget_for_field(const std::shared_ptr<LayoutItem_Field>& field)
 {
-  DataWidgetChildren::ComboChoices* result = 0;
+  DataWidgetChildren::ComboChoices* result = nullptr;
   bool as_radio_buttons = false;
-  const bool restricted = field->get_formatting_used().get_choices_restricted(as_radio_buttons);
+  const auto restricted = field->get_formatting_used().get_choices_restricted(as_radio_buttons);
   if(restricted)
   {
     if(as_radio_buttons)
@@ -61,19 +61,19 @@ static DataWidgetChildren::ComboChoices* create_combo_widget_for_field(const sha
   return result;
 }
 
-DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ustring& table_name, const Document* document)
-:  m_child(0),
-   m_button_go_to_details(0)
+DataWidget::DataWidget(const std::shared_ptr<LayoutItem_Field>& field, const Glib::ustring& table_name, const Document* document)
+:  m_child(nullptr),
+   m_button_go_to_details(nullptr)
 {
-  const Field::glom_field_type glom_type = field->get_glom_type();
+  const auto glom_type = field->get_glom_type();
   set_layout_item(field, table_name);
   
   //The GNOME HIG says that labels should have ":" at the end:
   //http://library.gnome.org/devel/hig-book/stable/design-text-labels.html.en
-  const Glib::ustring title = Glib::ustring::compose(_("%1:"), item_get_title_or_name(field));
+  const auto title = Glib::ustring::compose(_("%1:"), item_get_title_or_name(field));
 
   m_child = 0;
-  LayoutWidgetField* pFieldWidget = 0;  
+  LayoutWidgetField* pFieldWidget = nullptr;  
   if(glom_type == Field::TYPE_BOOLEAN)
   {
     DataWidgetChildren::CheckButton* checkbutton = Gtk::manage( new DataWidgetChildren::CheckButton() );
@@ -186,12 +186,12 @@ DataWidget::DataWidget(const sharedptr<LayoutItem_Field>& field, const Glib::ust
     field->set_full_field_details(
       document->get_field(field->get_table_used(table_name), field->get_name()) ); //Otherwise get_primary_key() returns false always.
 
-    sharedptr<const Relationship> field_used_in_relationship_to_one;
+    std::shared_ptr<Relationship> field_used_in_relationship_to_one;
     const bool add_open_button = 
        DbUtils::layout_field_should_have_navigation(table_name, field, document, 
          field_used_in_relationship_to_one);
 
-    Gtk::Box* hbox_parent = 0; //Only used if there are extra widgets.
+    Gtk::Box* hbox_parent = nullptr; //Only used if there are extra widgets.
 
     const bool with_extra_widgets = field_used_in_relationship_to_one || add_open_button || (glom_type == Field::TYPE_DATE);
     if(with_extra_widgets)
@@ -306,15 +306,15 @@ void DataWidget::update_go_to_details_button_sensitivity()
   //an ID:
   if(m_button_go_to_details)
   {
-    const Gnome::Gda::Value value = get_value();
-    const bool enabled = !Conversions::value_is_empty(value);
+    const auto value = get_value();
+    const auto enabled = !Conversions::value_is_empty(value);
     m_button_go_to_details->set_sensitive(enabled);
   }
 }
 
 Gnome::Gda::Value DataWidget::get_value() const
 {
-  const Gtk::Widget* widget = get_data_child_widget();
+  const auto widget = get_data_child_widget();
   const LayoutWidgetField* generic_field_widget = dynamic_cast<const LayoutWidgetField*>(widget);
   if(generic_field_widget)
     return generic_field_widget->get_value();
@@ -340,9 +340,9 @@ const Gtk::Label* DataWidget::get_label() const
   return &m_label;
 }
 
-void DataWidget::set_child_size_by_field(const sharedptr<const LayoutItem_Field>& field)
+void DataWidget::set_child_size_by_field(const std::shared_ptr<const LayoutItem_Field>& field)
 {
-  const Field::glom_field_type glom_type = field->get_glom_type();
+  const auto glom_type = field->get_glom_type();
   int width = get_suitable_width(field);
 
   if(glom_type == Field::TYPE_IMAGE) //GtkImage widgets default to no size (invisible) if they are empty.
@@ -365,7 +365,7 @@ void DataWidget::set_child_size_by_field(const sharedptr<const LayoutItem_Field>
   }
 }
 
-int DataWidget::get_suitable_width(const sharedptr<const LayoutItem_Field>& field_layout)
+int DataWidget::get_suitable_width(const std::shared_ptr<const LayoutItem_Field>& field_layout)
 {
   return UiUtils::get_suitable_field_width_for_widget(*this, field_layout);
 }
@@ -420,7 +420,7 @@ void DataWidget::set_editable(bool editable)
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-bool DataWidget::on_button_press_event(GdkEventButton *event)
+bool DataWidget::on_button_press_event(GdkEventButton *button_event)
 {
   //g_warning("DataWidget::on_button_press_event_popup");
 
@@ -442,34 +442,34 @@ bool DataWidget::on_button_press_event(GdkEventButton *event)
     if(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_pMenuPopup->popup(event->button, event->time);
+        m_pMenuPopup->popup(button_event->button, button_event->time);
         return true; //We handled this event.
       }
     }
   }
 
-  return Gtk::EventBox::on_button_press_event(event);
+  return Gtk::EventBox::on_button_press_event(button_event);
 }
 
-sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name)
+std::shared_ptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name)
 {
-  return offer_field_list(table_name, sharedptr<LayoutItem_Field>());
+  return offer_field_list(table_name, std::shared_ptr<LayoutItem_Field>());
 }
 
-sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field)
+std::shared_ptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& start_field)
 {
   return offer_field_list(table_name, start_field, get_document(), get_appwindow());
 }
 
-sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const sharedptr<const LayoutItem_Field>& start_field, Document* document, AppWindow* app)
+std::shared_ptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& table_name, const std::shared_ptr<const LayoutItem_Field>& start_field, Document* document, AppWindow* app)
 {
-  sharedptr<LayoutItem_Field> result;
+  std::shared_ptr<LayoutItem_Field> result;
 
-  Dialog_ChooseField* dialog = 0;
+  Dialog_ChooseField* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
 
   if(dialog)
@@ -478,7 +478,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
     if(app)
       dialog->set_transient_for(*app);
 
-    const int response = dialog->run();
+    const auto response = dialog->run();
     dialog->hide();
     if(response == Gtk::RESPONSE_OK)
     {
@@ -492,11 +492,11 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_list(const Glib::ustring& ta
   return result;
 }
 
-sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const LayoutItem_Field>& start_field)
+std::shared_ptr<LayoutItem_Field> DataWidget::offer_field_layout(const std::shared_ptr<const LayoutItem_Field>& start_field)
 {
-  sharedptr<LayoutItem_Field> result;
+  std::shared_ptr<LayoutItem_Field> result;
 
-  Dialog_FieldLayout* dialog = 0;
+  Dialog_FieldLayout* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return result;
@@ -508,7 +508,7 @@ sharedptr<LayoutItem_Field> DataWidget::offer_field_layout(const sharedptr<const
   if(parent)
     dialog->set_transient_for(*parent);
 
-  const int response = dialog->run();
+  const auto response = dialog->run();
   dialog->hide();
   if(response == Gtk::RESPONSE_OK)
   {
@@ -526,10 +526,10 @@ void DataWidget::on_menupopup_activate_layout()
 {
   //finish_editing();
 
-  sharedptr<LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<LayoutItem_Field> layoutField = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
   if(layoutField)
   {
-    sharedptr<LayoutItem_Field> itemchosen = offer_field_list(m_table_name, layoutField);
+    std::shared_ptr<LayoutItem_Field> itemchosen = offer_field_list(m_table_name, layoutField);
     if(itemchosen)
     {
       *layoutField = *itemchosen;
@@ -542,10 +542,10 @@ void DataWidget::on_menupopup_activate_layout_properties()
 {
   //finish_editing();
 
-  sharedptr<LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<LayoutItem_Field> layoutField = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
   if(layoutField)
   {
-    sharedptr<LayoutItem_Field> itemchosen = offer_field_layout(layoutField);
+    std::shared_ptr<LayoutItem_Field> itemchosen = offer_field_layout(layoutField);
     if(itemchosen)
     {
       *layoutField = *itemchosen;
@@ -617,7 +617,7 @@ const Gtk::Widget* DataWidget::get_data_child_widget() const
 void DataWidget::on_button_new_id()
 {
   Gnome::Gda::Value chosen_id;
-  const bool chosen = offer_related_record_id_new(chosen_id);
+  const auto chosen = offer_related_record_id_new(chosen_id);
   if(!chosen)
     return;
 
@@ -630,7 +630,7 @@ void DataWidget::on_button_new_id()
 
 void DataWidget::on_button_choose_date()
 {
-  DataWidgetChildren::Dialog_ChooseDate* dialog = 0;
+  DataWidgetChildren::Dialog_ChooseDate* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
 
   if(dialog)
@@ -640,12 +640,12 @@ void DataWidget::on_button_choose_date()
       dialog->set_transient_for(*parent);
     dialog->set_date_chosen(get_value());
 
-    const int response = Glom::UiUtils::dialog_run_with_help(dialog);
+    const auto response = Glom::UiUtils::dialog_run_with_help(dialog);
     dialog->hide();
     if(response == Gtk::RESPONSE_OK)
     {
       //Get the chosen date
-      const Gnome::Gda::Value value = dialog->get_date_chosen();
+      const auto value = dialog->get_date_chosen();
       set_value(value);
 
       m_signal_edited.emit(value);
@@ -657,7 +657,7 @@ void DataWidget::on_button_choose_date()
 
 void DataWidget::on_self_style_changed(const Glib::RefPtr<Gtk::Style>& /* style */)
 {
-  sharedptr<LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<LayoutItem_Field> layoutField = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
   set_child_size_by_field(layoutField);
 }
 
@@ -668,7 +668,7 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
   //Initialize output variable:
   chosen_id = Gnome::Gda::Value();
 
-  DataWidgetChildren::Dialog_ChooseID* dialog = 0;
+  DataWidgetChildren::Dialog_ChooseID* dialog = nullptr;
   Glom::Utils::get_glade_widget_derived_with_warning(dialog);
 
   if(dialog)
@@ -681,10 +681,10 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
 
     //Discover the related table, in the relationship that uses this ID field:
     Glib::ustring related_table_name;
-    sharedptr<const LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+    std::shared_ptr<const LayoutItem_Field> layoutField = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
     if(layoutField)
     {
-      sharedptr<const Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layoutField);
+      std::shared_ptr<const Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layoutField);
       if(relationship)
         related_table_name = relationship->get_to_table();
     }
@@ -694,7 +694,7 @@ bool DataWidget::offer_related_record_id_find(Gnome::Gda::Value& chosen_id)
     dialog->init_db_details(related_table_name, Base_DB::get_active_layout_platform(get_document()));
 
 
-    const int response = dialog->run();
+    const auto response = dialog->run();
     dialog->hide();
     if(response == Gtk::RESPONSE_OK)
     {
@@ -717,7 +717,7 @@ bool DataWidget::offer_related_record_id_new(Gnome::Gda::Value& chosen_id)
   //Initialize output variable:
   chosen_id = Gnome::Gda::Value();
 
-  DataWidgetChildren::Dialog_NewRecord* dialog = 0;
+  DataWidgetChildren::Dialog_NewRecord* dialog = nullptr;
   Glom::Utils::get_glade_widget_derived_with_warning(dialog);
 
   if(dialog)
@@ -730,10 +730,10 @@ bool DataWidget::offer_related_record_id_new(Gnome::Gda::Value& chosen_id)
 
     //Discover the related table, in the relationship that uses this ID field:
     Glib::ustring related_table_name;
-    sharedptr<const LayoutItem_Field> layoutField = sharedptr<LayoutItem_Field>::cast_dynamic(get_layout_item());
+    std::shared_ptr<const LayoutItem_Field> layoutField = std::dynamic_pointer_cast<LayoutItem_Field>(get_layout_item());
     if(layoutField)
     {
-      sharedptr<const Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layoutField);
+      std::shared_ptr<const Relationship> relationship = get_document()->get_field_used_in_relationship_to_one(m_table_name, layoutField);
       if(relationship)
         related_table_name = relationship->get_to_table();
     }
@@ -743,7 +743,7 @@ bool DataWidget::offer_related_record_id_new(Gnome::Gda::Value& chosen_id)
     dialog->init_db_details(related_table_name, Base_DB::get_active_layout_platform(get_document()));
 
 
-    const int response = dialog->run();
+    const auto response = dialog->run();
     dialog->hide();
     if(response == Gtk::RESPONSE_OK)
     {
