@@ -34,24 +34,24 @@ const char* Dialog_ChooseID::glade_id("dialog_find_id");
 const bool Dialog_ChooseID::glade_developer(false);
 
 Dialog_ChooseID::Dialog_ChooseID()
-: m_label_table_name(0),
-  m_pBox_QuickFind(0),
-  m_pEntry_QuickFind(0),
-  m_pButton_QuickFind(0),
-  m_vbox_parent(0),
-  m_document(0),
+: m_label_table_name(nullptr),
+  m_pBox_QuickFind(nullptr),
+  m_pEntry_QuickFind(nullptr),
+  m_pButton_QuickFind(nullptr),
+  m_vbox_parent(nullptr),
+  m_document(nullptr),
   m_stage(STAGE_INVALID)
 {
 }
 
 Dialog_ChooseID::Dialog_ChooseID(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_label_table_name(0),
-  m_pBox_QuickFind(0),
-  m_pEntry_QuickFind(0),
-  m_pButton_QuickFind(0),
-  m_vbox_parent(0),
-  m_document(0),
+  m_label_table_name(nullptr),
+  m_pBox_QuickFind(nullptr),
+  m_pEntry_QuickFind(nullptr),
+  m_pButton_QuickFind(nullptr),
+  m_vbox_parent(nullptr),
+  m_document(nullptr),
   m_stage(STAGE_INVALID)
 {
   builder->get_widget("label_table_name", m_label_table_name);
@@ -97,7 +97,7 @@ bool Dialog_ChooseID::get_id_chosen(Gnome::Gda::Value& chosen_id) const
 
 void Dialog_ChooseID::on_button_quickfind()
 {
-  const Glib::ustring criteria = m_pEntry_QuickFind->get_text();
+  const auto criteria = m_pEntry_QuickFind->get_text();
   if(criteria.empty())
   {
     Glib::ustring message = _("You have not entered any quick find criteria.");
@@ -124,10 +124,10 @@ void Dialog_ChooseID::on_box_find_criteria(const Gnome::Gda::SqlExpr& where_clau
     FoundSet found_set = m_box_select.get_found_set();
     found_set.m_table_name = m_table_name;
     found_set.m_where_clause = where_clause;
-    const bool records_found = m_box_select.init_db_details(found_set, m_layout_platform);
+    const auto records_found = m_box_select.init_db_details(found_set, m_layout_platform);
     if(!records_found)
     {
-      const bool find_again = UiUtils::show_warning_no_records_found(*this);
+      const auto find_again = UiUtils::show_warning_no_records_found(*this);
 
       if(!find_again)
         response(Gtk::RESPONSE_CANCEL);
