@@ -82,13 +82,13 @@ void TextView::set_glom_type(Field::glom_field_type glom_type)
 
 void TextView::check_for_change()
 {
-  const Glib::ustring new_text = m_TextView.get_buffer()->get_text();
+  const auto new_text = m_TextView.get_buffer()->get_text();
   if(new_text != m_old_text)
   {
     //Validate the input:
     bool success = false;
 
-    sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
+    std::shared_ptr<const LayoutItem_Field>layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
     Gnome::Gda::Value value = Conversions::parse_value(m_glom_type, new_text, layout_item->get_formatting_used().m_numeric_format, success);
 
     if(success)
@@ -111,10 +111,10 @@ void TextView::check_for_change()
   }
 }
 
-bool TextView::on_textview_focus_out_event(GdkEventFocus* event)
+bool TextView::on_textview_focus_out_event(GdkEventFocus* focus_event)
 {
   //Call base class:
-  bool result = Gtk::ScrolledWindow::on_focus_out_event(event);
+  bool result = Gtk::ScrolledWindow::on_focus_out_event(focus_event);
 
   //The user has finished editing.
   check_for_change();
@@ -135,6 +135,7 @@ void TextView::on_activate()
 }
 */
 
+//TODO: Remove this? It doesn't seem to be used.
 void TextView::on_buffer_changed()
 {
   check_for_change();
@@ -150,7 +151,7 @@ void TextView::on_insert_text(const Glib::ustring& text, int* position)
 
 void TextView::set_value(const Gnome::Gda::Value& value)
 {
-  sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<const LayoutItem_Field>layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
   if(layout_item)
     set_text(Conversions::get_text_for_gda_value(m_glom_type, value, layout_item->get_formatting_used().m_numeric_format));
 }
@@ -167,14 +168,14 @@ Gnome::Gda::Value TextView::get_value() const
 {
   bool success = false;
 
-  sharedptr<const LayoutItem_Field>layout_item = sharedptr<const LayoutItem_Field>::cast_dynamic(get_layout_item());
+  std::shared_ptr<const LayoutItem_Field>layout_item = std::dynamic_pointer_cast<const LayoutItem_Field>(get_layout_item());
 
   TextView* pNonConstThis = const_cast<TextView*>(this); //Gtk::TextBuffer::get_text() is non-const in gtkmm <=2.6.
   return Conversions::parse_value(m_glom_type, pNonConstThis->m_TextView.get_buffer()->get_text(true), layout_item->get_formatting_used().m_numeric_format, success);
 }
 
 #ifndef GLOM_ENABLE_CLIENT_ONLY
-bool TextView::on_button_press_event(GdkEventButton *event)
+bool TextView::on_button_press_event(GdkEventButton *button_event)
 {
   //Enable/Disable items.
   //We did this earlier, but get_appwindow is more likely to work now:
@@ -193,18 +194,18 @@ bool TextView::on_button_press_event(GdkEventButton *event)
     if(pApp->get_userlevel() == AppState::USERLEVEL_DEVELOPER)
     {
       GdkModifierType mods;
-      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+      gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        m_pMenuPopup->popup(event->button, event->time);
+        m_pMenuPopup->popup(button_event->button, button_event->time);
         return true; //We handled this event.
       }
     }
 
   }
 
-  return Gtk::ScrolledWindow::on_button_press_event(event);
+  return Gtk::ScrolledWindow::on_button_press_event(button_event);
 }
 #endif // !GLOM_ENABLE_CLIENT_ONLY
 
