@@ -150,7 +150,7 @@ void DbTreeModelRow::set_value(DbTreeModel& model, int column, int row, const Db
   /*
   Glib::RefPtr<const Gnome::Gda::Column> gdacolumn = model.m_gda_datamodel->describe_column(column);
   const GType debug_type_in = value.get_value_type();
-  const GType debug_type_expected = gdacolumn->get_g_type();
+  const auto debug_type_expected = gdacolumn->get_g_type();
   if(debug_type_in != debug_type_expected)
   {
     std::cout << "debug: " << G_STRFUNC << ": expected GType=" << debug_type_expected << ", but received GType=" << debug_type_in << std::endl;
@@ -207,9 +207,9 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
 
   //Database columns:;
   {
-    for(type_vec_const_layout_items::const_iterator iter = layout_items.begin(); iter != layout_items.end(); ++iter)
+    for(const auto& item : layout_items)
     {
-      sharedptr<const LayoutItem_Field> item_field = sharedptr<const LayoutItem_Field>::cast_dynamic(*iter);
+      std::shared_ptr<const LayoutItem_Field> item_field = std::dynamic_pointer_cast<const LayoutItem_Field>(item);
       if(item_field)
       {
         if(item_field->get_glom_type() == Field::TYPE_INVALID)
@@ -226,15 +226,14 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
     //Find the primary key:
     int column_index_key = 0;
     bool key_found = false;
-    for( DbTreeModel::type_vec_const_fields::const_iterator iter = m_column_fields.begin(); iter != m_column_fields.end(); ++iter)
+    for(const auto& layout_item : m_column_fields)
     {
-      const sharedptr<const LayoutItem_Field> layout_item = *iter;
       if(!layout_item)
         continue;
 
       if( !(layout_item->get_has_relationship_name()) )
       {
-        const sharedptr<const Field> field_full = layout_item->get_full_field_details();
+        const std::shared_ptr<const Field> field_full = layout_item->get_full_field_details();
         if(!field_full)
           std::cerr << G_STRFUNC << ": The layout item (" << layout_item->get_name() << ") has no field details." << std::endl;
         else if(field_full->get_primary_key() )
@@ -250,9 +249,8 @@ DbTreeModel::DbTreeModel(const FoundSet& found_set, const type_vec_const_layout_
     if(!key_found)
     {
       std::cerr << G_STRFUNC << ": no primary key field found in the list of items:" << std::endl;
-      for(DbTreeModel::type_vec_const_fields::const_iterator iter = m_column_fields.begin(); iter != m_column_fields.end(); ++iter)
+      for(const auto& layout_item : m_column_fields)
       {
-        const sharedptr<const LayoutItem_Field> layout_item = *iter;
         if(layout_item)
           std::cerr << G_STRFUNC << ":   field: " << layout_item->get_name() << std::endl;
       }
@@ -310,12 +308,11 @@ bool DbTreeModel::refresh_from_database(const FoundSet& found_set)
     m_gda_datamodel = model_array;
 
     int col = 0;
-    for(type_vec_const_fields::const_iterator iter = m_column_fields.begin(); iter != m_column_fields.end(); ++iter)
+    for(const auto& layout_item : m_column_fields)
     {
-      sharedptr<const LayoutItem_Field> layout_item = *iter;
       if(layout_item)
       {
-        const Field::glom_field_type glom_type = layout_item->get_glom_type();
+        const auto glom_type = layout_item->get_glom_type();
         const GType gda_type = Field::get_gda_type_for_glom_type(glom_type);
         model_array->set_column_g_type(col, gda_type);
         ++col;
@@ -754,8 +751,8 @@ DbTreeModel::iterator DbTreeModel::append()
 
   //Create the iterator to the new row:
   iterator iter;
-  const bool iter_is_valid = create_iterator(datamodel_row, iter);
-  if(iter_is_valid)
+  const auto the_iter_is_valid = create_iterator(datamodel_row, iter);
+  if(the_iter_is_valid)
   {
     row_inserted(get_path(iter), iter); //Allow the TreeView to respond to the addition.
   }
@@ -849,7 +846,7 @@ DbTreeModel::DbValue DbTreeModel::get_key_value(const TreeModel::iterator& iter)
   if(check_treeiter_validity(iter))
   {
     type_datamodel_row_index datamodel_row = get_datamodel_row_index_from_tree_row_iter(iter);
-    type_map_rows::iterator iterFind = m_map_rows.find(datamodel_row);
+    auto iterFind = m_map_rows.find(datamodel_row);
     if(iterFind != m_map_rows.end())
       return iterFind->second.m_key;
     else
@@ -979,7 +976,7 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
       Glib::RefPtr<Gnome::Gda::SqlBuilder> builder =
         Gnome::Gda::SqlBuilder::create(Gnome::Gda::SQL_STATEMENT_SELECT);
 
-      const Gnome::Gda::SqlBuilder::Id id_function = builder->add_function("count", builder->add_id("*")); //TODO: Is * allowed here?
+      const auto id_function = builder->add_function("count", builder->add_id("*")); //TODO: Is * allowed here?
       builder->add_field_value_id(id_function);
 
       builder->select_add_target(m_found_set.m_table_name);
@@ -990,7 +987,7 @@ void DbTreeModel::get_record_counts(gulong& total, gulong& found) const
       {
         if(datamodel->get_n_rows())
         {
-          const Gnome::Gda::Value value = datamodel->get_value_at(0, 0);
+          const auto value = datamodel->get_value_at(0, 0);
 	  // This will probably fail on Windows, where a long is only 32 bits wide.
           total = static_cast<gulong>(value.get_int64()); //I discovered that it's a int64 by trying it.
         }
