@@ -97,9 +97,9 @@ void DbAddDel_WithButtons::set_allow_user_actions(bool bVal)
 
 void DbAddDel_WithButtons::setup_buttons()
 {
-  const bool allow_edit = get_allow_user_actions() && get_allow_view_details();
-  const bool allow_del = get_allow_user_actions() && m_allow_delete;
-  const bool allow_add = get_allow_user_actions() && m_allow_add;
+  const auto allow_edit = get_allow_user_actions() && get_allow_view_details();
+  const auto allow_del = get_allow_user_actions() && m_allow_delete;
+  const auto allow_add = get_allow_user_actions() && m_allow_add;
 
   m_Button_Add.show();
   m_Button_Add.set_property("visible", allow_add);
