@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 //#include <gtkmm/builder.h>
@@ -77,16 +77,16 @@ bool Box_DB_Table_Relationships::fill_from_database()
 
   bool result = Box_DB_Table::fill_from_database();
 
-  Document* document = get_document();
+  const Document* document = get_document();
   if(!document)
     return false;
 
   //Get relationships from the document:
-  Document::type_vec_relationships vecRelationships = document->get_relationships(m_table_name);
+  const auto vecRelationships = document->get_relationships(m_table_name);
 
   m_AddDel.remove_all();
 
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
+  std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
   if(sharedconnection)
   {
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
@@ -102,13 +102,12 @@ bool Box_DB_Table_Relationships::fill_from_database()
     //To Field choices are different for each row: set in on_adddel_signal_user_activated.
 
     //Add the relationships:
-    for(Document::type_vec_relationships::iterator iter = vecRelationships.begin(); iter != vecRelationships.end(); ++iter)
+    for(const auto& relationship : vecRelationships)
     {
-      sharedptr<const Relationship> relationship = *iter;
       if(relationship)
       {
         //Name:
-        Gtk::TreeModel::iterator iterTree = m_AddDel.add_item(relationship->get_name());
+        auto iterTree = m_AddDel.add_item(relationship->get_name());
         m_AddDel.set_value(iterTree, m_colName, relationship->get_name());
 
         //Title:
@@ -119,7 +118,7 @@ bool Box_DB_Table_Relationships::fill_from_database()
         m_AddDel.set_value(iterTree, m_colFromField, relationship->get_from_field());
 
         //To Table:
-        const Glib::ustring& strToTable = relationship->get_to_table();
+        const auto strToTable = relationship->get_to_table();
         m_AddDel.set_value(iterTree, m_colToTable, strToTable);
 
         //To Field:
@@ -139,13 +138,13 @@ void Box_DB_Table_Relationships::save_to_document()
   //Build relationships from AddDel:
   Document::type_vec_relationships vecRelationships;
 
-  const Document* document = get_document();
+  const auto document = get_document();
 
-  for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
+  for(const auto& item : m_AddDel.get_model()->children())
   {
-    const Glib::ustring old_name = m_AddDel.get_value_key(iter);
+    const auto old_name = m_AddDel.get_value_key(item);
 
-    const Glib::ustring name = m_AddDel.get_value(iter, m_colName);
+    const auto name = m_AddDel.get_value(item, m_colName);
     if(!name.empty())
     {
       //If it is a rename:
@@ -154,19 +153,19 @@ void Box_DB_Table_Relationships::save_to_document()
 
       if(std::find_if(vecRelationships.begin(), vecRelationships.end(), predicate_FieldHasName<Relationship>(name)) == vecRelationships.end()) //Don't add 2 relationships with the same name.
       {
-        sharedptr<Relationship> relationship = document->get_relationship(m_table_name, name); //Preserve other information, such as translations.
+        std::shared_ptr<Relationship> relationship = document->get_relationship(m_table_name, name); //Preserve other information, such as translations.
         if(!relationship)
-          relationship = sharedptr<Relationship>::create();
+          relationship = std::make_shared<Relationship>();
 
         relationship->set_name(name);
-        relationship->set_title(m_AddDel.get_value(iter, m_colTitle), AppWindow::get_current_locale());
-        relationship->set_title_singular(m_AddDel.get_value(iter, m_colTitleSingular), AppWindow::get_current_locale());
+        relationship->set_title(m_AddDel.get_value(item, m_colTitle), AppWindow::get_current_locale());
+        relationship->set_title_singular(m_AddDel.get_value(item, m_colTitleSingular), AppWindow::get_current_locale());
         relationship->set_from_table(m_table_name);
-        relationship->set_from_field(m_AddDel.get_value(iter, m_colFromField));
-        relationship->set_to_table(m_AddDel.get_value(iter, m_colToTable));
-        relationship->set_to_field(m_AddDel.get_value(iter, m_colToField));
-        relationship->set_allow_edit(m_AddDel.get_value_as_bool(iter, m_colAllowEdit));
-        relationship->set_auto_create(m_AddDel.get_value_as_bool(iter, m_colAutoCreate));
+        relationship->set_from_field(m_AddDel.get_value(item, m_colFromField));
+        relationship->set_to_table(m_AddDel.get_value(item, m_colToTable));
+        relationship->set_to_field(m_AddDel.get_value(item, m_colToField));
+        relationship->set_allow_edit(m_AddDel.get_value_as_bool(item, m_colAllowEdit));
+        relationship->set_auto_create(m_AddDel.get_value_as_bool(item, m_colAutoCreate));
 
         vecRelationships.push_back(relationship);
       }
@@ -234,16 +233,16 @@ void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::
   {
     BusyCursor busy_cursor(get_app_window());
 
-    const Glib::ustring old_to_field = m_AddDel.get_value(row, m_colToField);
+    const auto old_to_field = m_AddDel.get_value(row, m_colToField);
 
-    const Glib::ustring table_name = m_AddDel.get_value(row, m_colToTable);
+    const auto table_name = m_AddDel.get_value(row, m_colToTable);
 
     if(!table_name.empty())
     {
       //Set list of 'To' fields depending on table:
       m_AddDel.set_value(row, m_colToField, Glib::ustring(""));
 
-      sharedptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
+      std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(get_app_window());
       if(sharedconnection)
       {
         Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
@@ -267,13 +266,13 @@ void Box_DB_Table_Relationships::on_adddel_user_activated(const Gtk::TreeModel::
 
 void Box_DB_Table_Relationships::on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& /* rowEnd */)
 {
-  //Gtk::TreeModel::iterator iterAfter = rowEnd;
+  //auto iterAfter = rowEnd;
   //++iterAfter;
 
-  //for(Gtk::TreeModel::iterator iter = rowStart; iter != iterAfter; ++iter)
+  //for(auto iter = rowStart; iter != iterAfter; ++iter)
   //{ //AddDel::remove_item() can't cope with this.
-    Gtk::TreeModel::iterator iter = rowStart;
-    const Glib::ustring relationship_name = m_AddDel.get_value_key(iter);
+    auto iter = rowStart;
+    const auto relationship_name = m_AddDel.get_value_key(iter);
 
     //Remove the row:
     m_AddDel.remove_item(iter);
@@ -282,7 +281,7 @@ void Box_DB_Table_Relationships::on_adddel_user_requested_delete(const Gtk::Tree
     Document* document = get_document();
     if(document)
     {
-      sharedptr<const Relationship> relationship = document->get_relationship(m_table_name, relationship_name);
+      std::shared_ptr<const Relationship> relationship = document->get_relationship(m_table_name, relationship_name);
       if(relationship)
       {
         document->remove_relationship(relationship);
