@@ -114,7 +114,7 @@ void Dialog_Database_Preferences::on_treeview_cell_edited_next_value(const Glib:
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_model_autoincrements->get_iter(path);
+  auto iter = m_model_autoincrements->get_iter(path);
   if(iter != m_model_autoincrements->children().end())
   {
     Gtk::TreeModel::Row row = *iter;
@@ -150,7 +150,7 @@ void Dialog_Database_Preferences::on_treeview_cell_edited_next_value(const Glib:
 
 void Dialog_Database_Preferences::load_from_document()
 {
-  Document* document = get_document();
+  const auto document = get_document();
   m_system_prefs = DbUtils::get_database_preferences(document);
 
   //Show the data in the UI:
@@ -160,15 +160,13 @@ void Dialog_Database_Preferences::load_from_document()
 
   //Make sure that all auto-increment values are setup:
 
-  const Document::type_listTableInfo tables = document->get_tables();
-  for(Document::type_listTableInfo::const_iterator iter = tables.begin(); iter != tables.end(); ++iter)
+  for(const auto& table : document->get_tables())
   {
-    const Document::type_vec_fields fields = document->get_table_fields((*iter)->get_name());
-    for(Document::type_vec_fields::const_iterator iterFields = fields.begin(); iterFields != fields.end(); ++iterFields)
+    const Document::type_vec_fields fields = document->get_table_fields(table->get_name());
+    for(const auto& field: fields)
     {
-      sharedptr<Field> field = *iterFields;
       if(field->get_primary_key())
-        DbUtils::auto_increment_insert_first_if_necessary((*iter)->get_name(), field->get_name());
+        DbUtils::auto_increment_insert_first_if_necessary(table->get_name(), field->get_name());
     }
   }
 
@@ -197,7 +195,7 @@ void Dialog_Database_Preferences::load_from_document()
   const guint count = datamodel->get_n_rows();
   for(guint i = 0; i < count; ++i)
   {
-    Gtk::TreeModel::iterator iter = m_model_autoincrements->append();
+    auto iter = m_model_autoincrements->append();
     Gtk::TreeModel::Row row = *iter;
     row[m_columns.m_col_table] = Conversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(0, i), numeric_format);
     row[m_columns.m_col_field] = Conversions::get_text_for_gda_value(Field::TYPE_TEXT, datamodel->get_value_at(1, i), numeric_format);
@@ -271,7 +269,7 @@ void Dialog_Database_Preferences::on_button_test_script()
     return;
 
   //We need the connection when we run the script, so that the script may use it.
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(this /* parent window */);
+  std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(this /* parent window */);
 
   Glib::ustring error_message; //TODO: Check this and tell the user.
   PythonUICallbacks callbacks;
@@ -279,7 +277,7 @@ void Dialog_Database_Preferences::on_button_test_script()
     type_map_fields(),
     document,
     Glib::ustring() /* table_name */,
-    sharedptr<Field>(), Gnome::Gda::Value(), // primary key - only used when setting values in the DB, which we would not encourage in a test.
+    std::shared_ptr<Field>(), Gnome::Gda::Value(), // primary key - only used when setting values in the DB, which we would not encourage in a test.
     sharedconnection->get_gda_connection(),
     callbacks,
     error_message);
