@@ -32,8 +32,8 @@ const bool Dialog_InitialPassword::glade_developer(true);
 Dialog_InitialPassword::Dialog_InitialPassword(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
   Base_DB(),
-  m_entry_user(0),
-  m_entry_password(0)
+  m_entry_user(nullptr),
+  m_entry_password(nullptr)
 {
   builder->get_widget("entry_user", m_entry_user);
   builder->get_widget("entry_password", m_entry_password);
@@ -64,7 +64,7 @@ void Dialog_InitialPassword::load_from_document()
     if(user.empty())
     {
       //Default to the UNIX user name, which is often the same as the Postgres user name:
-      const char* pchUser = getenv("USER"); 
+      const auto pchUser = getenv("USER"); 
       if(pchUser)
         user = pchUser;
     }
