@@ -31,8 +31,8 @@ namespace Glom
 {
 
 Box_DB_Table_Definition::Box_DB_Table_Definition()
-: m_dialog_field_definition(0),
-  m_dialog_default_formatting(0)
+: m_dialog_field_definition(nullptr),
+  m_dialog_default_formatting(nullptr)
 {
   init();
 }
@@ -54,7 +54,7 @@ void Box_DB_Table_Definition::init()
   if(m_dialog_default_formatting)
   {
     add_view(m_dialog_default_formatting);
-    m_dialog_default_formatting->signal_apply().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_default_formatting_apply));
+    m_dialog_default_formatting->signal_apply().connect(sigc::mem_fun(*this, &Box_DB_Table_Definition::on_field_definition_apply));
   }
 
   pack_start(m_AddDel);
@@ -113,13 +113,13 @@ Box_DB_Table_Definition::~Box_DB_Table_Definition()
   }
 }
 
-void Box_DB_Table_Definition::fill_field_row(const Gtk::TreeModel::iterator& iter, const sharedptr<const Field>& field)
+void Box_DB_Table_Definition::fill_field_row(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const Field>& field)
 {
   m_AddDel.set_value_key(iter, field->get_name());
 
   m_AddDel.set_value(iter, m_colName, field->get_name());
 
-  const Glib::ustring title = item_get_title(field);
+  const auto title = item_get_title(field);
   m_AddDel.set_value(iter, m_colTitle, title);
 
   //Type:
@@ -129,16 +129,16 @@ void Box_DB_Table_Definition::fill_field_row(const Gtk::TreeModel::iterator& ite
   // sqlite which we store as double.
   Field::glom_field_type fieldType = field->get_glom_type();
 
-  const Glib::ustring strType = Field::get_type_name_ui( fieldType );
+  const auto strType = Field::get_type_name_ui( fieldType );
   m_AddDel.set_value(iter, m_colType, strType);
 
   //Unique:
-  const bool bUnique = field->get_unique_key();
+  const auto bUnique = field->get_unique_key();
 
   m_AddDel.set_value(iter, m_colUnique, bUnique);
 
   //Primary Key:
-  const bool bPrimaryKey = field->get_primary_key();
+  const auto bPrimaryKey = field->get_primary_key();
   m_AddDel.set_value(iter, m_colPrimaryKey, bPrimaryKey);
 }
 
@@ -163,12 +163,10 @@ bool Box_DB_Table_Definition::fill_from_database()
 
     Field::type_map_type_names mapFieldTypes = Field::get_type_names_ui();
 
-    for(type_vec_fields::iterator iter = m_vecFields.begin(); iter != m_vecFields.end(); ++iter)
+    for(const auto& field : m_vecFields)
     {
-      const sharedptr<const Field>& field = *iter;
-
       //Name:
-      Gtk::TreeModel::iterator tree_iter= m_AddDel.add_item(field->get_name());
+      auto tree_iter= m_AddDel.add_item(field->get_name());
       fill_field_row(tree_iter, field);
     }
 
@@ -193,7 +191,7 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
   Glib::ustring name = m_AddDel.get_value(row, m_colName);
   if(!name.empty())
   {
-    sharedptr<Field> field(new Field());
+    std::shared_ptr<Field> field(new Field());
     field->set_name(name);
     field->set_title( Utils::title_from_string(name) , AppWindow::get_current_locale()); //Start with a title that might be useful.
     field->set_glom_type(Field::TYPE_NUMERIC);
@@ -204,7 +202,7 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
 
     //TODO: Warn about a delay before actually doing this when the backend
     //needs to recreate the whole table.
-    const bool bTest = DbUtils::add_column(m_table_name, field, get_app_window()); //TODO: Get schema type for Field::TYPE_NUMERIC
+    const auto bTest = DbUtils::add_column(m_table_name, field, get_app_window()); //TODO: Get schema type for Field::TYPE_NUMERIC
     if(bTest)
     {
       //Store the generated title in the document:
@@ -245,18 +243,18 @@ void Box_DB_Table_Definition::on_adddel_add(const Gtk::TreeModel::iterator& row)
 
 void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd)
 {
-  Gtk::TreeModel::iterator iterAfterEnd = rowEnd;
+  auto iterAfterEnd = rowEnd;
   if(iterAfterEnd != m_AddDel.get_model()->children().end())
     ++iterAfterEnd;
 
-  for(Gtk::TreeModel::iterator iter = rowStart; iter != iterAfterEnd; ++iter)
+  for(auto iter = rowStart; iter != iterAfterEnd; ++iter)
   {
     Glib::ustring name = m_AddDel.get_value_key(iter);
     if(!name.empty())
     {
       //TODO: Warn about a delay before actually doing this when the backend
       //needs to recreate the whole table.
-      const bool test = DbUtils::drop_column(m_table_name, name);
+      const auto test = DbUtils::drop_column(m_table_name, name);
       if(test)
       {
         //update_gda_metastore_for_table(m_table_name); // already done in drop_column().
@@ -273,7 +271,7 @@ void Box_DB_Table_Definition::on_adddel_delete(const Gtk::TreeModel::iterator& r
   fill_from_database();
 }
 
-bool Box_DB_Table_Definition::check_field_change(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field_new)
+bool Box_DB_Table_Definition::check_field_change(const std::shared_ptr<const Field>& field_old, const std::shared_ptr<const Field>& field_new)
 {
   bool result = true; //Tells the caller whether to continue.
 
@@ -369,9 +367,9 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
   Document* pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
-    const Glib::ustring strFieldNameBeingEdited = m_AddDel.get_value_key(row);
+    const auto strFieldNameBeingEdited = m_AddDel.get_value_key(row);
 
-    sharedptr<const Field> constfield = pDoc->get_field(m_table_name, strFieldNameBeingEdited);
+    std::shared_ptr<const Field> constfield = pDoc->get_field(m_table_name, strFieldNameBeingEdited);
     m_Field_BeingEdited = constfield;
 
     //Get DB field info: (TODO: This might be unnecessary).
@@ -380,19 +378,19 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
       std::cerr << G_STRFUNC << ": field not found: " << strFieldNameBeingEdited << std::endl;
     else
     {
-      sharedptr<const Field> constfield = *iterFind;
-      m_Field_BeingEdited = constfield;
+      std::shared_ptr<const Field> const_field_found = *iterFind;
+      m_Field_BeingEdited = const_field_found;
 
       //Get new field definition:
-      sharedptr<Field> fieldNew = get_field_definition(row);
+      std::shared_ptr<Field> fieldNew = get_field_definition(row);
 
       //Change it:
       if(*m_Field_BeingEdited != *fieldNew) //If it has really changed.
       {
-        const bool bcontinue = check_field_change(m_Field_BeingEdited, fieldNew);
+        const auto bcontinue = check_field_change(m_Field_BeingEdited, fieldNew);
         if(bcontinue)
         {
-          sharedptr<Field> fieldNewWithModifications = change_definition(m_Field_BeingEdited, fieldNew);
+          std::shared_ptr<Field> fieldNewWithModifications = change_definition(m_Field_BeingEdited, fieldNew);
 
           //Update the row to show any extra changes (such as unique being set/unset whenever the primary key is set/unset) 
 	  // TODO: When change_definition decides to unset another column from
@@ -412,7 +410,7 @@ void Box_DB_Table_Definition::on_adddel_changed(const Gtk::TreeModel::iterator&
 
 void Box_DB_Table_Definition::on_adddel_edit(const Gtk::TreeModel::iterator& row)
 {
-  sharedptr<const Field> constfield = get_field_definition(row);
+  std::shared_ptr<const Field> constfield = get_field_definition(row);
   m_Field_BeingEdited = constfield;
 
   m_dialog_field_definition->set_field(m_Field_BeingEdited, m_table_name);
@@ -428,7 +426,7 @@ void Box_DB_Table_Definition::on_adddel_edit(const Gtk::TreeModel::iterator& row
 
 void Box_DB_Table_Definition::on_adddel_extra(const Gtk::TreeModel::iterator& row)
 {
-  sharedptr<const Field> constfield = get_field_definition(row);
+  std::shared_ptr<const Field> constfield = get_field_definition(row);
   m_Field_BeingEdited = constfield;
 
   m_dialog_default_formatting->set_field(m_Field_BeingEdited, m_table_name);
@@ -442,20 +440,20 @@ void Box_DB_Table_Definition::on_adddel_extra(const Gtk::TreeModel::iterator& ro
   m_dialog_default_formatting->show();
 }
 
-sharedptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::TreeModel::iterator& row)
+std::shared_ptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::TreeModel::iterator& row)
 {
-  sharedptr<Field> fieldResult;
+  std::shared_ptr<Field> fieldResult;
 
   //Get old field definition (to preserve anything that the user doesn't have access to):
 
-  const Glib::ustring strFieldNameBeforeEdit = m_AddDel.get_value_key(row);
+  const auto strFieldNameBeforeEdit = m_AddDel.get_value_key(row);
 
   //Glom field definition:
   Document* pDoc = static_cast<Document*>(get_document());
   if(pDoc)
   {
     Document::type_vec_fields vecFields= pDoc->get_table_fields(m_table_name);
-    Document::type_vec_fields::iterator iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeforeEdit) );
+    auto iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(strFieldNameBeforeEdit) );
 
     if((iterFind != vecFields.end()) && (*iterFind)) //If it was found:
     {
@@ -464,7 +462,7 @@ sharedptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::TreeMo
     else
     {
       //Start with a default:
-      fieldResult = sharedptr<Field>(new Field());
+      fieldResult = std::make_shared<Field>();
     }
   }
 
@@ -473,32 +471,32 @@ sharedptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::TreeMo
 
   //Start with original definitions, so that we preserve things like UNSIGNED.
   //TODO maybe use document's fieldinfo instead of m_vecFields.
-  sharedptr<const Field> field_temp = 
+  std::shared_ptr<const Field> field_temp = 
     DbUtils::get_fields_for_table_one_field(pDoc, m_table_name, strFieldNameBeforeEdit);
   if(field_temp)
   {
     Glib::RefPtr<Gnome::Gda::Column> fieldInfo = field_temp->get_field_info()->copy();
 
     //Name:
-    const Glib::ustring name = m_AddDel.get_value(row, m_colName);
+    const auto name = m_AddDel.get_value(row, m_colName);
     fieldInfo->set_name(name);
 
     //Title:
-    const Glib::ustring title = m_AddDel.get_value(row, m_colTitle);
+    const auto title = m_AddDel.get_value(row, m_colTitle);
     fieldResult->set_title(title, AppWindow::get_current_locale());
 
     //Type:
-    const Glib::ustring& strType = m_AddDel.get_value(row, m_colType);
+    const auto strType = m_AddDel.get_value(row, m_colType);
 
     const Field::glom_field_type glom_type =  Field::get_type_for_ui_name(strType);
     GType fieldType = Field::get_gda_type_for_glom_type(glom_type);
 
     //Unique:
-    const bool bUnique = m_AddDel.get_value_as_bool(row, m_colUnique);
+    const auto bUnique = m_AddDel.get_value_as_bool(row, m_colUnique);
     //TODO_gda: fieldInfo->set_unique_key(bUnique);
 
     //Primary Key:
-    const bool bPrimaryKey = m_AddDel.get_value_as_bool(row, m_colPrimaryKey);
+    const auto bPrimaryKey = m_AddDel.get_value_as_bool(row, m_colPrimaryKey);
     ///TODO_gda: fieldInfo->set_primary_key(bPrimaryKey);
 
     fieldInfo->set_g_type(fieldType);
@@ -520,11 +518,11 @@ sharedptr<Field> Box_DB_Table_Definition::get_field_definition(const Gtk::TreeMo
 
 void Box_DB_Table_Definition::on_field_definition_apply()
 {
-  sharedptr<Field> field_New = m_dialog_field_definition->get_field();
+  std::shared_ptr<Field> field_New = m_dialog_field_definition->get_field();
 
   if(*m_Field_BeingEdited != *field_New)
   {
-    const bool bcontinue = check_field_change(m_Field_BeingEdited, field_New);
+    const auto bcontinue = check_field_change(m_Field_BeingEdited, field_New);
     if(bcontinue)
     {
       change_definition(m_Field_BeingEdited, field_New);
@@ -540,11 +538,11 @@ void Box_DB_Table_Definition::on_field_definition_apply()
 
 void Box_DB_Table_Definition::on_default_formatting_apply()
 {
-  sharedptr<Field> field_New = m_dialog_default_formatting->get_field();
+  std::shared_ptr<Field> field_New = m_dialog_default_formatting->get_field();
 
   if(*m_Field_BeingEdited != *field_New)
   {
-    const bool bcontinue = check_field_change(m_Field_BeingEdited, field_New);
+    const auto bcontinue = check_field_change(m_Field_BeingEdited, field_New);
     if(bcontinue)
     {
       change_definition(m_Field_BeingEdited, field_New);
@@ -558,13 +556,13 @@ void Box_DB_Table_Definition::on_default_formatting_apply()
   m_dialog_default_formatting->hide();
 }
 
-sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<const Field>& fieldOld, const sharedptr<const Field>& field)
+std::shared_ptr<Field> Box_DB_Table_Definition::change_definition(const std::shared_ptr<const Field>& fieldOld, const std::shared_ptr<const Field>& field)
 {
   BusyCursor busy_cursor(get_app_window());
 
   //DB field definition:
 
-  sharedptr<Field> result;
+  std::shared_ptr<Field> result;
   
   if(!fieldOld || !field)
     return result;
@@ -580,10 +578,10 @@ sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<cons
     {
       //Unset the current primary key:
       //(There should be one.)
-      sharedptr<Field> existing_primary_key = get_field_primary_key_for_table(m_table_name);
+      std::shared_ptr<Field> existing_primary_key = get_field_primary_key_for_table(m_table_name);
       if(existing_primary_key)
       {
-        sharedptr<Field> existing_primary_key_unset = glom_sharedptr_clone(existing_primary_key);
+        std::shared_ptr<Field> existing_primary_key_unset = glom_sharedptr_clone(existing_primary_key);
         existing_primary_key_unset->set_primary_key(false);
 	old_fields.push_back(existing_primary_key);
 	new_fields.push_back(existing_primary_key_unset);
@@ -629,8 +627,8 @@ sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<cons
     for(unsigned int i = 0; i < old_fields.size(); ++ i)
     {
       //Find old field:
-      const Glib::ustring field_name_old = old_fields[i]->get_name();
-      Document::type_vec_fields::iterator iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(field_name_old) );
+      const auto field_name_old = old_fields[i]->get_name();
+      auto iterFind = std::find_if( vecFields.begin(), vecFields.end(), predicate_FieldHasName<Field>(field_name_old) );
       if(iterFind != vecFields.end()) //If it was found:
       {
         //Change it to the new Fields's value:
@@ -657,7 +655,7 @@ sharedptr<Field> Box_DB_Table_Definition::change_definition(const sharedptr<cons
       //Recalculate if necessary:
       if(new_fields[i]->get_has_calculation())
       {
-        const Glib::ustring calculation = new_fields[i]->get_calculation();
+        const auto calculation = new_fields[i]->get_calculation();
         if(calculation != old_fields[i]->get_calculation())
           calculate_field_in_all_records(m_table_name, new_fields[i]);
       }
@@ -683,7 +681,7 @@ void Box_DB_Table_Definition::fill_fields()
   m_vecFields = DbUtils::get_fields_for_table(get_document(), m_table_name);
 }
 
-bool Box_DB_Table_Definition::field_has_null_values(const sharedptr<const Field>& field)
+bool Box_DB_Table_Definition::field_has_null_values(const std::shared_ptr<const Field>& field)
 {
   //Note that "= Null" doesn't work, though it doesn't error either.
   //Note also that SELECT COUNT always returns 0 if all the values are NULL, so we can't use that to be more efficient.
@@ -713,7 +711,7 @@ bool Box_DB_Table_Definition::field_has_null_values(const sharedptr<const Field>
   return null_count > 0; 
 }
 
-bool Box_DB_Table_Definition::field_has_non_unique_values(const sharedptr<const Field>& field)
+bool Box_DB_Table_Definition::field_has_non_unique_values(const std::shared_ptr<const Field>& field)
 {
   long count_distinct = 0;
   long count_all = 0;
