@@ -36,7 +36,7 @@ const bool Dialog_FieldDefinition::glade_developer(true);
 
 Dialog_FieldDefinition::Dialog_FieldDefinition(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Properties(cobject, builder),
-  m_pDataWidget_DefaultValueSimple(0)
+  m_pDataWidget_DefaultValueSimple(nullptr)
 {
   builder->get_widget_derived("combobox_type", m_pCombo_Type);
 
@@ -109,7 +109,7 @@ Dialog_FieldDefinition::~Dialog_FieldDefinition()
 {
 }
 
-void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, const Glib::ustring& table_name)
+void Dialog_FieldDefinition::set_field(const std::shared_ptr<const Field>& field, const Glib::ustring& table_name)
 {
   set_blocked();
 
@@ -140,12 +140,12 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 
   //Create an appropriate DataWidget for the default value:
   delete m_pDataWidget_DefaultValueSimple;
-  m_pDataWidget_DefaultValueSimple = 0;
+  m_pDataWidget_DefaultValueSimple = nullptr;
 
   //We use a regular DataWidget for the default value, so we can reuse its functionality,
   //but it's not a real field - hence the special title.
-  sharedptr<LayoutItem_Field> layout_item = sharedptr<LayoutItem_Field>::create();
-  sharedptr<Field> field_default_value = glom_sharedptr_clone(m_Field);
+  std::shared_ptr<LayoutItem_Field> layout_item = std::make_shared<LayoutItem_Field>();
+  std::shared_ptr<Field> field_default_value = glom_sharedptr_clone(m_Field);
   field_default_value->set_name("glom_temp_default_value");
   field_default_value->set_title_original(_("Default Value"));
   layout_item->set_full_field_details(field_default_value);
@@ -175,11 +175,11 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   Document* document = dynamic_cast<Document*>(get_document());
   if(document)
   {
-    const Document::type_vec_relationships vecRelationships = document->get_relationships(table_name);
+    const auto vecRelationships = document->get_relationships(table_name);
     m_pCombo_LookupRelationship->set_relationships(vecRelationships);
   }
 
-  sharedptr<Relationship> lookup_relationship;
+  std::shared_ptr<Relationship> lookup_relationship;
   if(!disable_default_value)
     lookup_relationship = m_Field->get_lookup_relationship();
 
@@ -193,7 +193,7 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
 
 
   //Calculation:
-  const Glib::ustring calculation = field->get_calculation();
+  const auto calculation = field->get_calculation();
   if(calculation.empty())
    m_pRadio_UserEntry->set_active();
   else
@@ -213,11 +213,11 @@ void Dialog_FieldDefinition::set_field(const sharedptr<const Field>& field, cons
   Dialog_Properties::set_modified(false);
 }
 
-sharedptr<Field> Dialog_FieldDefinition::get_field() const
+std::shared_ptr<Field> Dialog_FieldDefinition::get_field() const
 {
-  sharedptr<Field> field = glom_sharedptr_clone(m_Field); //Start with the old details, to preserve anything that is not in our UI.
+  std::shared_ptr<Field> field = glom_sharedptr_clone(m_Field); //Start with the old details, to preserve anything that is not in our UI.
   // const_cast is necessary and save here for the window (jhs)
-  sharedptr<SharedConnection> sharedcnc = connect_to_server(const_cast<Dialog_FieldDefinition*>(this));
+  std::shared_ptr<SharedConnection> sharedcnc = connect_to_server(const_cast<Dialog_FieldDefinition*>(this));
   Glib::RefPtr<Gnome::Gda::Connection> cnc = sharedcnc->get_gda_connection();
 
   //Get the field info from the widgets:
@@ -237,8 +237,8 @@ sharedptr<Field> Dialog_FieldDefinition::get_field() const
   }
 
   //Lookup:
-  const bool is_lookup = m_pCheck_Lookup->get_active();
-  sharedptr<Relationship> relationship;
+  const auto is_lookup = m_pCheck_Lookup->get_active();
+  std::shared_ptr<Relationship> relationship;
   if(is_lookup)
     relationship = m_pCombo_LookupRelationship->get_selected_relationship();
   field->set_lookup_relationship(relationship);
@@ -299,10 +299,10 @@ void Dialog_FieldDefinition::enforce_constraints()
     m_pBox_ValueTab->set_sensitive(true);
   }
 
-  const bool enable_calc = m_pRadio_Calculate->get_active();
+  const auto enable_calc = m_pRadio_Calculate->get_active();
   m_pAlignment_Calculate->set_sensitive(enable_calc);
 
-  const bool enable_userentry = m_pRadio_UserEntry->get_active();
+  const auto enable_userentry = m_pRadio_UserEntry->get_active();
   m_pAlignment_UserEntry->set_sensitive(enable_userentry);
 }
 
@@ -341,21 +341,21 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
   m_pCombo_LookupField->remove_all();
 
   //Get the relationship name:
-  sharedptr<const Relationship> relationship = m_pCombo_LookupRelationship->get_selected_relationship();
+  std::shared_ptr<const Relationship> relationship = m_pCombo_LookupRelationship->get_selected_relationship();
   if(relationship)
   {
     //Get the relationship details:
     Document* document = dynamic_cast<Document*>(get_document());
     if(document)
     {
-      const Glib::ustring to_table = relationship->get_to_table();
+      const auto to_table = relationship->get_to_table();
       if(!to_table.empty())
       {
         //Get the fields in the other table, and add them to the combo:
-        const type_vec_fields fields_in_to_table = DbUtils::get_fields_for_table(document, to_table);
-        for(type_vec_fields::const_iterator iter = fields_in_to_table.begin(); iter != fields_in_to_table.end(); ++iter)
+        const auto fields_in_to_table = DbUtils::get_fields_for_table(document, to_table);
+        for(const auto& field : fields_in_to_table)
         {
-          m_pCombo_LookupField->append((*iter)->get_name());
+          m_pCombo_LookupField->append(field->get_name());
         }
       }
     }
@@ -366,7 +366,7 @@ void Dialog_FieldDefinition::on_combo_lookup_relationship_changed()
 void Dialog_FieldDefinition::on_button_edit_calculation()
 {
   //TODO: Share a global instance, to make this quicker?
-  Dialog_FieldCalculation* dialog = 0;
+  Dialog_FieldCalculation* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
@@ -376,7 +376,7 @@ void Dialog_FieldDefinition::on_button_edit_calculation()
   m_Field->set_calculation( m_pTextView_Calculation->get_buffer()->get_text() );
   dialog->set_field(m_Field, m_table_name);
   //TODO: dialog.set_transient_for(*get_app_window());
-  const int response = Glom::UiUtils::dialog_run_with_help(dialog);
+  const auto response = Glom::UiUtils::dialog_run_with_help(dialog);
   if(response == Gtk::RESPONSE_OK)
   {
     m_pTextView_Calculation->get_buffer()->set_text( dialog->get_field()->get_calculation() );
