@@ -58,25 +58,24 @@ type_list_currencies get_list_of_currency_symbols()
       if(parser)
       {
         //Walk the tree:
-        const xmlpp::Node* nodeRoot = parser.get_document()->get_root_node(); //deleted by DomParser.
+        const auto nodeRoot = parser.get_document()->get_root_node(); //deleted by DomParser.
 
-        xmlpp::Node::NodeList listNodes = nodeRoot->get_children("iso_4217_entry");
-        for(xmlpp::Node::NodeList::const_iterator iter = listNodes.begin(); iter != listNodes.end(); ++iter)
+        for(const auto& node : nodeRoot->get_children("iso_4217_entry"))
         {
-          xmlpp::Element* nodeEntry = dynamic_cast<xmlpp::Element*>(*iter);
+          xmlpp::Element* nodeEntry = dynamic_cast<xmlpp::Element*>(node);
           if(nodeEntry)
           {
             Currency currency;
 
-            const xmlpp::Attribute* attribute_code = nodeEntry->get_attribute("letter_code");
+            const auto attribute_code = nodeEntry->get_attribute("letter_code");
             if(attribute_code)
               currency.m_symbol = attribute_code->get_value();
 
-            const xmlpp::Attribute* attribute_name = nodeEntry->get_attribute("currency_name");
+            const auto attribute_name = nodeEntry->get_attribute("currency_name");
             if(attribute_name)
             {
               Glib::ustring name = _(attribute_name->get_value().c_str());
-              const char* pchTranslatedName = dgettext("iso_4217", name.c_str());
+              const auto pchTranslatedName = dgettext("iso_4217", name.c_str());
               if(pchTranslatedName)
                 name = pchTranslatedName;
 
@@ -133,18 +132,16 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
     //because this is normally what translators translate to.
     //For instance, po/ files generally contain po/de.po.
     type_list_ids list_ids_simple;
-    for(type_list_ids::const_iterator iter = list_ids.begin(); iter != list_ids.end(); ++iter)
+    for(const auto& id : list_ids)
     {
-      const Glib::ustring id = *iter;
       Glib::ustring id_language, id_country;
       split_locale_id(id, id_language, id_country);
       list_ids_simple.push_back(id_language);
     }
 
     //Add the non-specific locales:
-    for(type_list_ids::const_iterator iter = list_ids_simple.begin(); iter != list_ids_simple.end(); ++iter)
+    for(const auto& id : list_ids_simple)
     {
-      const Glib::ustring id = *iter;
       if(std::find(list_ids.begin(), list_ids.end(), id) == list_ids.end())
         list_ids.push_back(id);
     }
@@ -166,26 +163,25 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
       if(parser)
       {
         //Walk the tree:
-        const xmlpp::Node* nodeRoot = parser.get_document()->get_root_node(); //deleted by DomParser.
+        const auto nodeRoot = parser.get_document()->get_root_node(); //deleted by DomParser.
 
-        xmlpp::Node::NodeList listNodes = nodeRoot->get_children("iso_639_entry");
-        for(xmlpp::Node::NodeList::const_iterator iter = listNodes.begin(); iter != listNodes.end(); ++iter)
+        for(const auto& node : nodeRoot->get_children("iso_639_entry"))
         {
-          xmlpp::Element* nodeEntry = dynamic_cast<xmlpp::Element*>(*iter);
+          xmlpp::Element* nodeEntry = dynamic_cast<xmlpp::Element*>(node);
           if(nodeEntry)
           {
             //TODO: There are 3 codes (not each entry has each code). Is this the correct one to identify a language?
-            const xmlpp::Attribute* attribute_code = nodeEntry->get_attribute("iso_639_1_code");
+            const auto attribute_code = nodeEntry->get_attribute("iso_639_1_code");
             if(attribute_code)
             {
-              const Glib::ustring identifier = attribute_code->get_value();
+              const auto identifier = attribute_code->get_value();
               if(!identifier.empty())
               {
-                const xmlpp::Attribute* attribute_name = nodeEntry->get_attribute("name");
+                const auto attribute_name = nodeEntry->get_attribute("name");
                 if(attribute_name)
                 {
                   Glib::ustring name = attribute_name->get_value();
-                  const char* pchTranslatedName = dgettext("iso_639", name.c_str());
+                  const auto pchTranslatedName = dgettext("iso_639", name.c_str());
                   if(pchTranslatedName)
                     name = pchTranslatedName;
 
@@ -221,25 +217,24 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
       if(parser)
       {
         //Walk the tree:
-        const xmlpp::Node* nodeRoot = parser.get_document()->get_root_node(); //deleted by DomParser.
+        const auto nodeRoot = parser.get_document()->get_root_node(); //deleted by DomParser.
 
-        xmlpp::Node::NodeList listNodes = nodeRoot->get_children("iso_3166_entry");
-        for(xmlpp::Node::NodeList::const_iterator iter = listNodes.begin(); iter != listNodes.end(); ++iter)
+        for(const auto& node : nodeRoot->get_children("iso_3166_entry"))
         {
-          xmlpp::Element* nodeEntry = dynamic_cast<xmlpp::Element*>(*iter);
+          xmlpp::Element* nodeEntry = dynamic_cast<xmlpp::Element*>(node);
           if(nodeEntry)
           {
-            const xmlpp::Attribute* attribute_code = nodeEntry->get_attribute("alpha_2_code");
+            const auto attribute_code = nodeEntry->get_attribute("alpha_2_code");
             if(attribute_code)
             {
-              const Glib::ustring identifier = attribute_code->get_value();
+              const auto identifier = attribute_code->get_value();
               if(!identifier.empty())
               {
-                const xmlpp::Attribute* attribute_name = nodeEntry->get_attribute("name");
+                const auto attribute_name = nodeEntry->get_attribute("name");
                 if(attribute_name)
                 {
                   Glib::ustring name = attribute_name->get_value();
-                  const char* pchTranslatedName = dgettext("iso_3166", name.c_str());
+                  const auto pchTranslatedName = dgettext("iso_3166", name.c_str());
                   if(pchTranslatedName)
                     name = pchTranslatedName;
 
@@ -259,9 +254,9 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
 #endif // LIBXMLCPP_EXCEPTIONS_ENABLED
 
     //Use a map so we can easily check for duplicates.
-    for(type_list_ids::iterator iter = list_ids.begin(); iter != list_ids.end(); ++iter)
+    for(const auto& id : list_ids)
     {
-      const Glib::ustring identifier = Utils::locale_simplify(*iter);
+      const auto identifier = Utils::locale_simplify(id);
 
       if(map_locales.find(identifier) == map_locales.end()) //Prevent duplicates.
       {
@@ -272,14 +267,14 @@ Glib::ustring get_locale_name(const Glib::ustring& locale_id)
 
         //Get the translated human-readable names of the language and country:
         Glib::ustring name;
-        type_map_language::iterator iterFindLanguage = map_languages.find(id_language);
+        auto iterFindLanguage = map_languages.find(id_language);
         if(iterFindLanguage != map_languages.end()) //Ignore languages that are not listed by iso-codes.
         {
           name += iterFindLanguage->second;
 
           if(!id_country.empty())
           {
-            type_map_country::iterator iterFindCountry = map_country.find(id_country);
+            auto iterFindCountry = map_country.find(id_country);
             if(iterFindCountry != map_country.end())
               name += " (" + iterFindCountry->second + ')';
             else
@@ -315,9 +310,9 @@ type_list_locales get_list_of_locales()
     get_locale_name("temp"); //Fill the map.
 
     //Put the map into a list:
-    for(type_map_locales::iterator iter = map_locales.begin(); iter != map_locales.end(); ++iter)
+    for(const auto& the_pair : map_locales)
     {
-      list_locales.push_back(iter->second);
+      list_locales.push_back(the_pair.second);
     }
   }
 
