@@ -27,8 +27,8 @@ namespace Glom
 
 ComboBox_Relationship::ComboBox_Relationship(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::ComboBox(cobject),
-  m_renderer_title(0),
-  m_renderer_fromfield(0)
+  m_renderer_title(nullptr),
+  m_renderer_fromfield(nullptr)
 {
   m_model = Gtk::TreeStore::create(m_model_columns);
 
@@ -58,25 +58,25 @@ ComboBox_Relationship::~ComboBox_Relationship()
 
 }
 
-sharedptr<Relationship> ComboBox_Relationship::get_selected_relationship() const
+std::shared_ptr<Relationship> ComboBox_Relationship::get_selected_relationship() const
 {
-  Gtk::TreeModel::iterator iter = get_active();
+  auto iter = get_active();
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
     return row[m_model_columns.m_relationship];
   }
   else
-    return sharedptr<Relationship>();
+    return std::shared_ptr<Relationship>();
 }
 
-sharedptr<Relationship> ComboBox_Relationship::get_selected_relationship(sharedptr<Relationship>& related_relationship) const
+std::shared_ptr<Relationship> ComboBox_Relationship::get_selected_relationship(std::shared_ptr<Relationship>& related_relationship) const
 {
-  Gtk::TreeModel::iterator iter = get_active();
+  auto iter = get_active();
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
-    Gtk::TreeModel::iterator iterParent = row.parent();
+    auto iterParent = row.parent();
     if(iterParent)
     {
       //It's a related relationship:
@@ -87,10 +87,10 @@ sharedptr<Relationship> ComboBox_Relationship::get_selected_relationship(sharedp
       return row[m_model_columns.m_relationship];
   }
   else
-    return sharedptr<Relationship>();
+    return std::shared_ptr<Relationship>();
 }
 
-void ComboBox_Relationship::set_selected_relationship(const sharedptr<const Relationship>& relationship)
+void ComboBox_Relationship::set_selected_relationship(const std::shared_ptr<const Relationship>& relationship)
 {
   if(relationship)
     set_selected_relationship(relationship->get_name());
@@ -98,7 +98,7 @@ void ComboBox_Relationship::set_selected_relationship(const sharedptr<const Rela
     set_selected_relationship(Glib::ustring());
 }
 
-void ComboBox_Relationship::set_selected_relationship(const sharedptr<const Relationship>& relationship, const sharedptr<const Relationship>& related_relationship)
+void ComboBox_Relationship::set_selected_relationship(const std::shared_ptr<const Relationship>& relationship, const std::shared_ptr<const Relationship>& related_relationship)
 {
   if(relationship)
     set_selected_relationship(relationship->get_name(), glom_get_sharedptr_name(related_relationship));
@@ -112,30 +112,28 @@ void ComboBox_Relationship::set_selected_relationship(const Glib::ustring& relat
   Glib::RefPtr<Gtk::TreeModel> model = get_model();
   if(model)
   {
-    for(Gtk::TreeModel::iterator iter = model->children().begin(); iter != model->children().end(); ++iter)
+    for(const auto& row : model->children())
     {
-      Gtk::TreeModel::Row row = *iter;
-      sharedptr<Relationship> relationship = row[m_model_columns.m_relationship];
-      const Glib::ustring this_name = glom_get_sharedptr_name(relationship);
+      std::shared_ptr<Relationship> relationship = row[m_model_columns.m_relationship];
+      const auto this_name = glom_get_sharedptr_name(relationship);
 
       //(An empty name means Select the parent table item.)
       if(this_name == relationship_name)
       {
         if(related_relationship_name.empty())
         {
-           set_active(iter);
+           set_active(row);
            return; //success
         }
         else
         {
-          for(Gtk::TreeModel::iterator iterChildren = iter->children().begin(); iterChildren != iter->children().end(); ++iterChildren)
+          for(const auto& sub_row : row.children())
           {
-            Gtk::TreeModel::Row row = *iterChildren;
-            sharedptr<Relationship> relationship = row[m_model_columns.m_relationship];
-            const Glib::ustring this_name = glom_get_sharedptr_name(relationship);
-            if(this_name == related_relationship_name)
+            std::shared_ptr<Relationship> sub_relationship = sub_row[m_model_columns.m_relationship];
+            const auto rel_name = glom_get_sharedptr_name(sub_relationship);
+            if(rel_name == related_relationship_name)
             {
-              set_active(iterChildren);
+              set_active(sub_row);
               return; //success
             }
           }
@@ -157,35 +155,30 @@ void ComboBox_Relationship::set_relationships(Document* document, const Glib::us
   if(!document)
     return;
 
-  const Document::type_vec_relationships relationships = document->get_relationships(parent_table_name, true /* plus system properties */);
-
   m_model->clear();
 
   if(show_parent_table_name)
     set_display_parent_table(parent_table_name, document->get_table_title(parent_table_name, AppWindow::get_current_locale()));
 
   //Fill the model:
-  for(type_vec_relationships::const_iterator iter = relationships.begin(); iter != relationships.end(); ++iter)
+  for(const auto& rel : document->get_relationships(parent_table_name, true /* plus system properties */))
   {
-    Gtk::TreeModel::iterator tree_iter = m_model->append();
+    auto tree_iter = m_model->append();
     Gtk::TreeModel::Row row = *tree_iter;
 
-    sharedptr<Relationship> rel = *iter;
     row[m_model_columns.m_relationship] = rel;
     row[m_model_columns.m_separator] = false;
 
     //Children:
     if(show_related_relationships && !Document::get_relationship_is_system_properties(rel))
     {
-      const Document::type_vec_relationships sub_relationships = document->get_relationships(rel->get_to_table(), false /* plus system properties */);
-      for(type_vec_relationships::const_iterator iter = sub_relationships.begin(); iter != sub_relationships.end(); ++iter)
+      for(const auto& sub_rel : document->get_relationships(rel->get_to_table(), false /* plus system properties */))
       {
-        Gtk::TreeModel::iterator tree_iter_child = m_model->append(tree_iter->children());
-        Gtk::TreeModel::Row row = *tree_iter_child;
+        auto tree_iter_child = m_model->append(tree_iter->children());
+        Gtk::TreeModel::Row child_row = *tree_iter_child;
 
-        sharedptr<Relationship> rel = *iter;
-        row[m_model_columns.m_relationship] = rel;
-        row[m_model_columns.m_separator] = false;
+        child_row[m_model_columns.m_relationship] = sub_rel;
+        child_row[m_model_columns.m_separator] = false;
       }
     }
   }
@@ -198,12 +191,12 @@ void ComboBox_Relationship::set_relationships(const type_vec_relationships& rela
   set_display_parent_table(parent_table_name, parent_table_title);
 
   //Fill the model:
-  for(type_vec_relationships::const_iterator iter = relationships.begin(); iter != relationships.end(); ++iter)
+  for(const auto& relationship : relationships)
   {
-    Gtk::TreeModel::iterator tree_iter = m_model->append();
+    auto tree_iter = m_model->append();
     Gtk::TreeModel::Row row = *tree_iter;
 
-    row[m_model_columns.m_relationship] = *iter;
+    row[m_model_columns.m_relationship] = relationship;
     row[m_model_columns.m_separator] = false;
   }
 }
@@ -212,7 +205,7 @@ void ComboBox_Relationship::set_relationships(const type_vec_relationships& rela
 void ComboBox_Relationship::on_cell_data_name(const Gtk::TreeModel::const_iterator& iter)
 {
   Gtk::TreeModel::Row row = *iter;
-  sharedptr<Relationship> relationship = row[m_model_columns.m_relationship];
+  std::shared_ptr<Relationship> relationship = row[m_model_columns.m_relationship];
   if(relationship)
     m_renderer_name->property_text() = relationship->get_name();
   else if(get_has_parent_table())
@@ -223,15 +216,15 @@ void ComboBox_Relationship::on_cell_data_name(const Gtk::TreeModel::const_iterat
 void ComboBox_Relationship::on_cell_data_title(const Gtk::TreeModel::const_iterator& iter)
 {
   Gtk::TreeModel::Row row = *iter;
-  sharedptr<Relationship> relationship = row[m_model_columns.m_relationship];
+  std::shared_ptr<Relationship> relationship = row[m_model_columns.m_relationship];
   if(relationship)
   {
-    Gtk::TreeModel::iterator iterParent = row->parent();
+    auto iterParent = row->parent();
     if(iterParent)
     {
       //related relationship:
-      sharedptr<Relationship> parent_relationship = (*iterParent)[m_model_columns.m_relationship];
-      if(parent_relationship)
+      std::shared_ptr<Relationship> parent_relationship = (*iterParent)[m_model_columns.m_relationship];
+      if(relationship)
         m_renderer_title->set_property("text", item_get_title_or_name(parent_relationship) + "::" + item_get_title_or_name(relationship));
     }
     else
@@ -257,13 +250,13 @@ bool ComboBox_Relationship::on_row_separator(const Glib::RefPtr<Gtk::TreeModel>&
 void ComboBox_Relationship::on_cell_data_fromfield(const Gtk::TreeModel::const_iterator& iter)
 {
   Gtk::TreeModel::Row row = *iter;
-  sharedptr<Relationship> relationship = row[m_model_columns.m_relationship];
+  std::shared_ptr<Relationship> relationship = row[m_model_columns.m_relationship];
   if(relationship && relationship->get_has_fields())
   {
-    Gtk::TreeModel::iterator iterParent = iter->parent();
+    auto iterParent = iter->parent();
     if(iterParent)
     {
-      sharedptr<Relationship> parent_relationship = (*iterParent)[m_model_columns.m_relationship];
+      std::shared_ptr<Relationship> parent_relationship = (*iterParent)[m_model_columns.m_relationship];
       if(parent_relationship)
         m_renderer_fromfield->set_property("text", Glib::ustring::compose(_(" Via: %1::%2"), item_get_title(parent_relationship), relationship->get_from_field()));
     }
@@ -281,7 +274,7 @@ void ComboBox_Relationship::set_display_parent_table(const Glib::ustring& table_
   if(table_name.empty())
     return;
 
-  const bool already_added = get_has_parent_table() && !(m_model->children().empty());
+  const auto already_added = get_has_parent_table() && !(m_model->children().empty());
 
   //We don't need to recreate the model row when these change, because the callback just uses the new values.
   m_extra_table_name = table_name;
@@ -290,13 +283,13 @@ void ComboBox_Relationship::set_display_parent_table(const Glib::ustring& table_
   if(!already_added)
   {
     //Add a separator row after the table name:
-    Gtk::TreeModel::iterator tree_iter = m_model->prepend();
+    auto tree_iter = m_model->prepend();
     Gtk::TreeModel::Row row = *tree_iter;
     row[m_model_columns.m_separator] = true;
 
     tree_iter = m_model->prepend();
     row = *tree_iter;
-    row[m_model_columns.m_relationship] = sharedptr<Relationship>(); //A marker for the parent table's item. See the on_data_* signal handlers.
+    row[m_model_columns.m_relationship] = std::shared_ptr<Relationship>(); //A marker for the parent table's item. See the on_data_* signal handlers.
     row[m_model_columns.m_separator] = false;
   }
 }
@@ -306,7 +299,7 @@ void ComboBox_Relationship::set_selected_parent_table(const Glib::ustring& table
   //Save the values:
   set_display_parent_table(table_name, table_title);
 
-  set_selected_relationship(sharedptr<Relationship>()); //Select the extra item.
+  set_selected_relationship(std::shared_ptr<Relationship>()); //Select the extra item.
 }
 
 bool ComboBox_Relationship::get_has_parent_table() const
