@@ -37,13 +37,13 @@ const bool Dialog_Layout_Calendar_Related::glade_developer(true);
 
 Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Layout_List(cobject, builder),
-  m_combo_relationship(0),
-  m_checkbutton_show_child_relationships(0),
-  m_radio_navigation_automatic(0),
-  m_radio_navigation_specify(0),
-  m_label_navigation_automatic(0),
-  m_combo_navigation_specify(0),
-  m_combobox_date_field(0)
+  m_combo_relationship(nullptr),
+  m_checkbutton_show_child_relationships(nullptr),
+  m_radio_navigation_automatic(nullptr),
+  m_radio_navigation_specify(nullptr),
+  m_label_navigation_automatic(nullptr),
+  m_combo_navigation_specify(nullptr),
+  m_combobox_date_field(nullptr)
 {
   // Show the appropriate alternate widgets:
   m_box_table_widgets->hide();
@@ -87,7 +87,7 @@ Dialog_Layout_Calendar_Related::Dialog_Layout_Calendar_Related(BaseObjectType* c
 
   //The base class hid this, but we do want it here:
   //(We share one glade definition for several dialogs.)
-  Gtk::Frame* box_calendar = 0;
+  Gtk::Frame* box_calendar = nullptr;
   builder->get_widget("frame_calendar", box_calendar);
   box_calendar->show();
 
@@ -105,7 +105,7 @@ Dialog_Layout_Calendar_Related::~Dialog_Layout_Calendar_Related()
 }
 
 
-void Dialog_Layout_Calendar_Related::init_with_portal(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document* document, const sharedptr<const LayoutItem_CalendarPortal>& portal)
+void Dialog_Layout_Calendar_Related::init_with_portal(const Glib::ustring& layout, const Glib::ustring& layout_platform, Document* document, const std::shared_ptr<const LayoutItem_CalendarPortal>& portal)
 {
   m_portal = glom_sharedptr_clone(portal);
 
@@ -120,7 +120,7 @@ void Dialog_Layout_Calendar_Related::init_with_tablename(const Glib::ustring& la
 {
   if(!m_portal)
   {
-    m_portal = sharedptr<LayoutItem_CalendarPortal>::create(); //The rest of the class assumes that this is not null.
+    m_portal = std::make_shared<LayoutItem_CalendarPortal>(); //The rest of the class assumes that this is not null.
   }
 
   type_vecConstLayoutFields empty_fields; //Just to satisfy the base class.
@@ -136,7 +136,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 {
   m_modified = false;
 
-  const Glib::ustring related_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant*/);
+  const auto related_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant*/);
 
   //Update the tree models from the document
   Document* document = get_document();
@@ -168,7 +168,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
     }
 
     //Set the table name and title:
-    //sharedptr<LayoutItem_CalendarPortal> portal_temp = m_portal;
+    //std::shared_ptr<LayoutItem_CalendarPortal> portal_temp = m_portal;
     m_combo_relationship->set_selected_relationship(m_portal->get_relationship(), m_portal->get_related_relationship());
 
     Document::type_list_layout_groups mapGroups;
@@ -183,23 +183,21 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 
     m_model_items->clear();
 
-    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(const auto& group : mapGroups)
     {
-      sharedptr<const LayoutGroup> group = *iter;
-      sharedptr<const LayoutGroup> portal = sharedptr<const LayoutItem_CalendarPortal>::cast_dynamic(group);
+      std::shared_ptr<const LayoutGroup> portal = std::dynamic_pointer_cast<const LayoutItem_CalendarPortal>(group);
       if(portal)
       {
-        for(LayoutGroup::type_list_items::const_iterator iterInner = group->m_list_items.begin(); iterInner != group->m_list_items.end(); ++iterInner)
+        for(const auto& item : group->m_list_items)
         {
-          sharedptr<const LayoutItem> item = *iterInner;
-          sharedptr<const LayoutGroup> groupInner = sharedptr<const LayoutGroup>::cast_dynamic(item);
+          std::shared_ptr<const LayoutGroup> groupInner = std::dynamic_pointer_cast<const LayoutGroup>(item);
 
           if(groupInner)
             add_group(Gtk::TreeModel::iterator() /* null == top-level */, groupInner);
           else
           {
             //Add the item to the treeview:
-            Gtk::TreeModel::iterator iter = m_model_items->append();
+            auto iter = m_model_items->append();
             Gtk::TreeModel::Row row = *iter;
             row[m_model_items->m_columns.m_col_layout_item] = glom_sharedptr_clone(item);
           }
@@ -216,7 +214,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
   bool navigation_is_automatic = false;
   if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
   {
-    sharedptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
+    std::shared_ptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
     //std::cout << "debug navrel=" << navrel->get_relationship()->get_name() << std::endl;
     m_combo_navigation_specify->set_selected_relationship(navrel->get_relationship(), navrel->get_related_relationship());
   }
@@ -224,7 +222,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
   {
     navigation_is_automatic = true;
 
-    sharedptr<const Relationship> none;
+    std::shared_ptr<const Relationship> none;
     m_combo_navigation_specify->set_selected_relationship(none);
   }
 
@@ -235,7 +233,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 
 
   //Describe the automatic navigation:
-  sharedptr<const UsesRelationship> relationship_navigation_automatic
+  std::shared_ptr<const UsesRelationship> relationship_navigation_automatic
     = m_portal->get_portal_navigation_relationship_automatic(document);
   Glib::ustring automatic_navigation_description = 
     m_portal->get_relationship_name_used(); //TODO: Use get_relationship_display_name() instead?
@@ -251,7 +249,7 @@ void Dialog_Layout_Calendar_Related::update_ui(bool including_relationship_list)
 
   m_label_navigation_automatic->set_text(automatic_navigation_description);
 
-  sharedptr<Field> debugfield = m_portal->get_date_field();
+  std::shared_ptr<Field> debugfield = m_portal->get_date_field();
   if(!debugfield)
     std::cout << "debug: " << G_STRFUNC << ": date field is NULL" << std::endl;
   else
@@ -279,12 +277,10 @@ void Dialog_Layout_Calendar_Related::save_to_document()
     m_portal->remove_all_items();
 
     guint field_sequence = 1; //0 means no sequence
-    for(Gtk::TreeModel::iterator iterFields = m_model_items->children().begin(); iterFields != m_model_items->children().end(); ++iterFields)
+    for(const auto& row : m_model_items->children())
     {
-      Gtk::TreeModel::Row row = *iterFields;
-
-      sharedptr<LayoutItem> item = row[m_model_items->m_columns.m_col_layout_item];
-      const Glib::ustring field_name = item->get_name();
+      std::shared_ptr<LayoutItem> item = row[m_model_items->m_columns.m_col_layout_item];
+      const auto field_name = item->get_name();
       if(!field_name.empty())
       {
         m_portal->add_item(item); //Add it to the group:
@@ -295,10 +291,10 @@ void Dialog_Layout_Calendar_Related::save_to_document()
 
     if(m_radio_navigation_specify->get_active())
     {
-      sharedptr<Relationship> rel, rel_related;
+      std::shared_ptr<Relationship> rel, rel_related;
       rel = m_combo_navigation_specify->get_selected_relationship(rel_related);
 
-      sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
+      std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
       uses_rel->set_relationship(rel);
       uses_rel->set_related_relationship(rel_related);
 
@@ -309,13 +305,13 @@ void Dialog_Layout_Calendar_Related::save_to_document()
     else
     {
       //std::cout << "debug: set_navigation_relationship_specific(false, none)" << std::endl;
-      sharedptr<UsesRelationship> none;
+      std::shared_ptr<UsesRelationship> none;
       m_portal->set_navigation_relationship_specific(none);
     }
 
     m_portal->set_date_field( m_combobox_date_field->get_selected_field() );
 
-    sharedptr<Field> debugfield = m_portal->get_date_field();
+    std::shared_ptr<Field> debugfield = m_portal->get_date_field();
     if(!debugfield)
       std::cout << "debug: " << G_STRFUNC << ": date field is NULL" << std::endl;
     else
@@ -333,14 +329,14 @@ void Dialog_Layout_Calendar_Related::on_combo_relationship_changed()
   if(!m_portal)
     return;
 
-  sharedptr<Relationship> relationship_related;
-  sharedptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(relationship_related);
+  std::shared_ptr<Relationship> relationship_related;
+  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(relationship_related);
   if(relationship)
   {
     //Clear the list of fields if the relationship has changed, because the fields could not possible be correct for the new table:
     bool relationship_changed = false;
-    const Glib::ustring old_relationship_name = glom_get_sharedptr_name(m_portal->get_relationship());
-    const Glib::ustring old_relationship_related_name = glom_get_sharedptr_name(m_portal->get_related_relationship());
+    const auto old_relationship_name = glom_get_sharedptr_name(m_portal->get_relationship());
+    const auto old_relationship_related_name = glom_get_sharedptr_name(m_portal->get_related_relationship());
     if( (old_relationship_name != glom_get_sharedptr_name(relationship)) ||
         (old_relationship_related_name != glom_get_sharedptr_name(relationship_related)) )
       relationship_changed = true;
@@ -358,7 +354,7 @@ void Dialog_Layout_Calendar_Related::on_combo_relationship_changed()
   }
 }
 
-sharedptr<Relationship> Dialog_Layout_Calendar_Related::get_relationship() const
+std::shared_ptr<Relationship> Dialog_Layout_Calendar_Related::get_relationship() const
 {
   std::cout << "debug: I wonder if this function is used." << std::endl;
   return m_combo_relationship->get_selected_relationship();
@@ -381,15 +377,13 @@ void Dialog_Layout_Calendar_Related::on_button_add_field()
   //std::cout << "debug: related relationship=" << glom_get_sharedptr_name(m_portal->get_related_relationship()) << std::endl;
   //std::cout << "debug table used =" << m_portal->get_table_used(m_table_name) << std::endl;
 
-  type_list_field_items fields_list = offer_field_list(m_table_name, this);
-  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); ++iter_chosen)
+  for(const auto& field : offer_field_list(m_table_name, this))
   {
-    sharedptr<LayoutItem_Field> field = *iter_chosen;
     if(!field)
       continue;
 
     //Add the field details to the layout treeview:
-    Gtk::TreeModel::iterator iter =  m_model_items->append();
+    auto iter =  m_model_items->append();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
@@ -411,15 +405,15 @@ void Dialog_Layout_Calendar_Related::on_button_edit()
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
-      sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+      std::shared_ptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
+      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
 
       //Get the chosen field:
-      sharedptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
+      std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
       if(field_chosen)
       {
         //Set the field details in the layout treeview:
@@ -441,7 +435,7 @@ void Dialog_Layout_Calendar_Related::on_button_edit()
   }
 }
 
-sharedptr<LayoutItem_CalendarPortal> Dialog_Layout_Calendar_Related::get_portal_layout()
+std::shared_ptr<LayoutItem_CalendarPortal> Dialog_Layout_Calendar_Related::get_portal_layout()
 {
   return m_portal;
 }
