@@ -34,16 +34,16 @@ const bool Dialog_Layout_Export::glade_developer(true);
 
 Dialog_Layout_Export::Dialog_Layout_Export(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Layout(cobject, builder, false /* no table title */),
-  m_treeview_fields(0),
-  m_button_field_up(0),
-  m_button_field_down(0),
-  m_button_field_add(0),
-  m_button_field_delete(0),
-  m_button_field_edit(0),
-  m_label_table_name(0)
+  m_treeview_fields(nullptr),
+  m_button_field_up(nullptr),
+  m_button_field_down(nullptr),
+  m_button_field_add(nullptr),
+  m_button_field_delete(nullptr),
+  m_button_field_edit(nullptr),
+  m_label_table_name(nullptr)
 {
   builder->get_widget("label_table_name", m_label_table_name);
-  m_entry_table_title = 0; //Not in this glade file.
+  m_entry_table_title = nullptr; //Not in this glade file.
 
   builder->get_widget("treeview_fields", m_treeview_fields);
   if(m_treeview_fields)
@@ -123,9 +123,9 @@ void Dialog_Layout_Export::set_layout_groups(Document::type_list_layout_groups&
       group->set_name("main");
 
       guint field_sequence = 1; //0 means no sequence
-      for(type_vecLayoutFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
+      for(const auto& field : table_fields)
       {
-        LayoutItem_Field item = *(*iter);
+        LayoutItem_Field item = *(field);
         group->add_item(item);
 
         ++field_sequence;
@@ -135,26 +135,22 @@ void Dialog_Layout_Export::set_layout_groups(Document::type_list_layout_groups&
     }
     */
 
-    //Show the field layout
-    typedef std::list< Glib::ustring > type_listStrings;
-
+    //Show the field layout:
     m_model_fields->clear();
 
     guint field_sequence = 1; //0 means no sequence
-    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(const auto& group : mapGroups)
     {
-      sharedptr<const LayoutGroup> group = *iter;
       if(!group)
         continue;
 
       //Add the group's fields:
-      LayoutGroup::type_list_const_items items = group->get_items();
-      for(LayoutGroup::type_list_const_items::const_iterator iter = items.begin(); iter != items.end(); ++iter)
+      for(const auto& base_item : group->get_items())
       {
-        sharedptr<const LayoutItem_Field> item = sharedptr<const LayoutItem_Field>::cast_dynamic(*iter); 
+        std::shared_ptr<const LayoutItem_Field> item = std::dynamic_pointer_cast<const LayoutItem_Field>(base_item); 
         if(item)
         {
-          Gtk::TreeModel::iterator iterTree = m_model_fields->append();
+          auto iterTree = m_model_fields->append();
           Gtk::TreeModel::Row row = *iterTree;
 
           row[m_ColumnsFields.m_col_layout_item] = glom_sharedptr_clone(item);
@@ -176,7 +172,7 @@ void Dialog_Layout_Export::enable_buttons()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       //Disable Up if It can't go any higher.
@@ -188,7 +184,7 @@ void Dialog_Layout_Export::enable_buttons()
 
 
       //Disable Down if It can't go any lower.
-      Gtk::TreeModel::iterator iterNext = iter;
+      auto iterNext = iter;
       iterNext++;
 
       bool enable_down = true;
@@ -230,16 +226,14 @@ void Dialog_Layout_Export::get_layout_groups(Document::type_list_layout_groups&
   Document::type_list_layout_groups groups;
 
   //Add the fields to the one group:
-  sharedptr<LayoutGroup> others = sharedptr<LayoutGroup>::create();
+  std::shared_ptr<LayoutGroup> others = std::make_shared<LayoutGroup>();
   others->set_name("main");
 
   guint field_sequence = 1; //0 means no sequence
-  for(Gtk::TreeModel::iterator iterFields = m_model_fields->children().begin(); iterFields != m_model_fields->children().end(); ++iterFields)
+  for(const auto& row : m_model_fields->children())
   {
-    Gtk::TreeModel::Row row = *iterFields;
-
-    sharedptr<LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item];
-    const Glib::ustring field_name = item->get_name();
+    std::shared_ptr<LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item];
+    const auto field_name = item->get_name();
     if(!field_name.empty())
     {
       others->add_item(item); //Add it to the group:
@@ -261,14 +255,13 @@ void Dialog_Layout_Export::on_button_add_field()
 {
   //Get the chosen fields:
   type_list_field_items fields_list = offer_field_list(m_table_name, this);
-  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); ++iter_chosen) 
+  for(const auto& field : fields_list) 
   {
-    sharedptr<LayoutItem_Field> field = *iter_chosen;
     if(!field)
       continue;
 
     //Add the field details to the layout treeview:
-    Gtk::TreeModel::iterator iter =  m_model_fields->append();
+    auto iter =  m_model_fields->append();
 
     if(iter)
     {
@@ -295,7 +288,7 @@ void Dialog_Layout_Export::on_button_delete()
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       m_model_fields->erase(iter);
@@ -319,7 +312,7 @@ void Dialog_Layout_Export::on_cell_data_name(Gtk::CellRenderer* renderer, const
       Gtk::TreeModel::Row row = *iter;
 
       //Indicate that it's a field in another table.
-      sharedptr<LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item];
+      std::shared_ptr<LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item];
 
       //Names can never be edited.
       renderer_text->property_markup() = item->get_layout_display_name();
@@ -334,14 +327,14 @@ void Dialog_Layout_Export::on_button_edit_field()
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
+      std::shared_ptr<LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
 
       //Get the chosen field:
-      sharedptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_table_name, this);
+      std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_table_name, this);
       if(field_chosen)
       {
         //Set the field details in the layout treeview:
