@@ -39,16 +39,16 @@ const bool Dialog_Layout_List_Related::glade_developer(true);
 
 Dialog_Layout_List_Related::Dialog_Layout_List_Related(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Layout_List(cobject, builder),
-  m_combo_relationship(0),
-  m_checkbutton_show_child_relationships(0),
-  m_radio_navigation_automatic(0),
-  m_radio_navigation_none(0),
-  m_radio_navigation_specify(0),
-  m_label_navigation_automatic(0),
-  m_combo_navigation_specify(0),
-  m_spinbutton_row_line_width(0),
-  m_spinbutton_column_line_width(0),
-  m_colorbutton_line(0),
+  m_combo_relationship(nullptr),
+  m_checkbutton_show_child_relationships(nullptr),
+  m_radio_navigation_automatic(nullptr),
+  m_radio_navigation_none(nullptr),
+  m_radio_navigation_specify(nullptr),
+  m_label_navigation_automatic(nullptr),
+  m_combo_navigation_specify(nullptr),
+  m_spinbutton_row_line_width(nullptr),
+  m_spinbutton_column_line_width(nullptr),
+  m_colorbutton_line(nullptr),
   m_for_print_layout(false)
 {  
   // Show the appropriate alternate widgets:
@@ -133,7 +133,7 @@ Dialog_Layout_List_Related::~Dialog_Layout_List_Related()
 }
 
 
-void Dialog_Layout_List_Related::init_with_portal(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const sharedptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table, bool for_print_layout)
+void Dialog_Layout_List_Related::init_with_portal(const Glib::ustring& layout_name, const Glib::ustring& layout_platform, Document* document, const std::shared_ptr<const LayoutItem_Portal>& portal, const Glib::ustring& from_table, bool for_print_layout)
 {
   m_for_print_layout = for_print_layout;
 
@@ -141,7 +141,7 @@ void Dialog_Layout_List_Related::init_with_portal(const Glib::ustring& layout_na
   Glib::ustring actual_from_table;
   if(portal)
   {
-    const Glib::ustring portal_from_table = portal->get_from_table();
+    const auto portal_from_table = portal->get_from_table();
     if(portal_from_table.empty())
       actual_from_table = portal_from_table;
   }
@@ -152,7 +152,7 @@ void Dialog_Layout_List_Related::init_with_portal(const Glib::ustring& layout_na
   if(portal)
     m_portal = glom_sharedptr_clone(portal);
   else
-    m_portal = sharedptr<LayoutItem_Portal>::create(); //The rest of the class assumes that this is not null.
+    m_portal = std::make_shared<LayoutItem_Portal>(); //The rest of the class assumes that this is not null.
 
   gulong rows_count_min = 0;
   gulong rows_count_max = 0;
@@ -192,7 +192,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
   m_modified = false;
 
-  const Glib::ustring related_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant*/);
+  const auto related_table_name = m_portal->get_table_used(Glib::ustring() /* parent table - not relevant*/);
 
   //Update the tree models from the document
   Document* document = get_document();
@@ -224,7 +224,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
     }
 
     //Set the table name and title:
-    //sharedptr<LayoutItem_Portal> portal_temp = m_portal;
+    //std::shared_ptr<LayoutItem_Portal> portal_temp = m_portal;
     Document::type_list_layout_groups mapGroups;
     if(m_portal)
     {
@@ -239,23 +239,21 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
     m_model_items->clear();
 
-    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(const auto& group : mapGroups)
     {
-      sharedptr<const LayoutGroup> group = *iter;
-      sharedptr<const LayoutGroup> portal = sharedptr<const LayoutItem_Portal>::cast_dynamic(group);
+      std::shared_ptr<const LayoutGroup> portal = std::dynamic_pointer_cast<const LayoutItem_Portal>(group);
       if(portal)
       {
-        for(LayoutGroup::type_list_items::const_iterator iterInner = group->m_list_items.begin(); iterInner != group->m_list_items.end(); ++iterInner)
+        for(const auto& item : group->m_list_items)
         {
-          sharedptr<const LayoutItem> item = *iterInner;
-          sharedptr<const LayoutGroup> groupInner = sharedptr<const LayoutGroup>::cast_dynamic(item);
+          std::shared_ptr<const LayoutGroup> groupInner = std::dynamic_pointer_cast<const LayoutGroup>(item);
 
           if(groupInner)
             add_group(Gtk::TreeModel::iterator() /* null == top-level */, groupInner);
           else
           {
             //Add the item to the treeview:
-            Gtk::TreeModel::iterator iter = m_model_items->append();
+            auto iter = m_model_items->append();
             Gtk::TreeModel::Row row = *iter;
             row[m_model_items->m_columns.m_col_layout_item] = glom_sharedptr_clone(item);
           }
@@ -271,13 +269,13 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
 
   if(m_portal->get_navigation_type() == LayoutItem_Portal::NAVIGATION_SPECIFIC)
   {
-    sharedptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
+    std::shared_ptr<UsesRelationship> navrel = m_portal->get_navigation_relationship_specific();
     //std::cout << "debug navrel=" << navrel->get_relationship()->get_name() << std::endl;
     m_combo_navigation_specify->set_selected_relationship(navrel->get_relationship(), navrel->get_related_relationship());
   }
   else
   {
-    sharedptr<const Relationship> none;
+    std::shared_ptr<const Relationship> none;
     m_combo_navigation_specify->set_selected_relationship(none);
   }
 
@@ -299,7 +297,7 @@ void Dialog_Layout_List_Related::update_ui(bool including_relationship_list)
   }
 
   //Describe the automatic navigation:
-  sharedptr<const UsesRelationship> relationship_navigation_automatic = 
+  std::shared_ptr<const UsesRelationship> relationship_navigation_automatic = 
     m_portal->get_portal_navigation_relationship_automatic(document);
   Glib::ustring automatic_navigation_description = 
     m_portal->get_relationship_name_used(); //TODO: Use get_relationship_display_name() instead?
@@ -335,12 +333,10 @@ void Dialog_Layout_List_Related::save_to_document()
     m_portal->remove_all_items();
 
     guint field_sequence = 1; //0 means no sequence
-    for(Gtk::TreeModel::iterator iterFields = m_model_items->children().begin(); iterFields != m_model_items->children().end(); ++iterFields)
+    for(const auto& row : m_model_items->children())
     {
-      Gtk::TreeModel::Row row = *iterFields;
-
-      sharedptr<LayoutItem> item = row[m_model_items->m_columns.m_col_layout_item];
-      const Glib::ustring field_name = item->get_name();
+      std::shared_ptr<LayoutItem> item = row[m_model_items->m_columns.m_col_layout_item];
+      const auto field_name = item->get_name();
       if(!field_name.empty())
       {
         m_portal->add_item(item); //Add it to the group:
@@ -351,10 +347,10 @@ void Dialog_Layout_List_Related::save_to_document()
 
     if(m_radio_navigation_specify->get_active())
     {
-      sharedptr<Relationship> rel, rel_related;
+      std::shared_ptr<Relationship> rel, rel_related;
       rel = m_combo_navigation_specify->get_selected_relationship(rel_related);
 
-      sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
+      std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
       uses_rel->set_relationship(rel);
       uses_rel->set_related_relationship(rel_related);
 
@@ -368,7 +364,7 @@ void Dialog_Layout_List_Related::save_to_document()
       // go into the Glom::LayoutItem_Portal::set_navigation_relationship_type_* functions.
 
       //std::cout << "debug: set_navigation_relationship_specific(false, none)" << std::endl;
-      sharedptr<UsesRelationship> none;
+      std::shared_ptr<UsesRelationship> none;
       m_portal->set_navigation_relationship_specific(none);
     }
 
@@ -377,8 +373,8 @@ void Dialog_Layout_List_Related::save_to_document()
 
     if(m_radio_navigation_none->get_active())
     {
-      sharedptr<UsesRelationship> uses_rel = sharedptr<UsesRelationship>::create();
-      uses_rel->set_related_relationship(sharedptr<Relationship>());
+      std::shared_ptr<UsesRelationship> uses_rel = std::make_shared<UsesRelationship>();
+      uses_rel->set_related_relationship(std::shared_ptr<Relationship>());
       m_portal->set_navigation_type(LayoutItem_Portal::NAVIGATION_NONE);
     }
     
@@ -408,15 +404,15 @@ void Dialog_Layout_List_Related::on_combo_relationship_changed()
   if(!m_portal)
     return;
 
-  sharedptr<Relationship> relationship_related;
-  sharedptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(relationship_related);
+  std::shared_ptr<Relationship> relationship_related;
+  std::shared_ptr<Relationship> relationship = m_combo_relationship->get_selected_relationship(relationship_related);
   if(!relationship)
     return;
 
   //Check that the relationship is appropriate for use in a related records portal.
   //The relationship's to field may not be a unique field, because that would
   //prevent the portal from having multiple records.
-  sharedptr<Field> to_key_field =
+  std::shared_ptr<Field> to_key_field =
     DbUtils::get_fields_for_table_one_field(get_document(), 
       relationship->get_to_table(), relationship->get_to_field());
   bool relationship_invalid = false;
@@ -453,8 +449,8 @@ void Dialog_Layout_List_Related::on_combo_relationship_changed()
   //Clear the list of fields if the relationship has changed,
   //because the fields could not possible be correct for the new table:
   bool relationship_changed = false;
-  const Glib::ustring old_relationship_name = glom_get_sharedptr_name(m_portal->get_relationship());
-  const Glib::ustring old_relationship_related_name = glom_get_sharedptr_name(m_portal->get_related_relationship());
+  const auto old_relationship_name = glom_get_sharedptr_name(m_portal->get_relationship());
+  const auto old_relationship_related_name = glom_get_sharedptr_name(m_portal->get_related_relationship());
   if( (old_relationship_name != glom_get_sharedptr_name(relationship)) ||
       (old_relationship_related_name != glom_get_sharedptr_name(relationship_related)) )
   {
@@ -479,13 +475,13 @@ void Dialog_Layout_List_Related::on_spinbutton_changed()
   m_modified = true;
 }
 
-sharedptr<Relationship> Dialog_Layout_List_Related::get_relationship() const
+std::shared_ptr<Relationship> Dialog_Layout_List_Related::get_relationship() const
 {
   std::cout << "debug: I wonder if this function is used." << std::endl;
   return m_combo_relationship->get_selected_relationship();
 }
 
-sharedptr<LayoutItem_Portal> Dialog_Layout_List_Related::get_portal_layout()
+std::shared_ptr<LayoutItem_Portal> Dialog_Layout_List_Related::get_portal_layout()
 {
   return m_portal;
 }
@@ -503,14 +499,13 @@ void Dialog_Layout_List_Related::on_button_add_field()
   //std::cout << "debug table used =" << m_portal->get_table_used(m_table_name) << std::endl;
 
   type_list_field_items fields_list = offer_field_list(m_portal->get_table_used(m_table_name), this);
-  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); ++iter_chosen)
+  for(const auto& field : fields_list)
   {
-    sharedptr<LayoutItem_Field> field = *iter_chosen;
     if(!field)
       continue;
 
     //Add the field details to the layout treeview:
-    Gtk::TreeModel::iterator iter = m_model_items->append();
+    auto iter = m_model_items->append();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
@@ -532,15 +527,15 @@ void Dialog_Layout_List_Related::on_button_edit()
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
-      sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item);
+      std::shared_ptr<LayoutItem> layout_item = row[m_model_items->m_columns.m_col_layout_item];
+      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item);
 
       //Get the chosen field:
-      sharedptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
+      std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_list_select_one_field(field, m_portal->get_table_used(m_table_name), this);
       if(field_chosen)
       {
         //Set the field details in the layout treeview:
