@@ -34,42 +34,42 @@ const bool Box_Formatting::glade_developer(true);
 
 Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Box(cobject),
-  m_vbox_numeric_format(0),
-  m_checkbox_format_use_thousands(0),
-  m_checkbox_format_use_decimal_places(0),
-  m_entry_format_decimal_places(0),
-  m_entry_currency_symbol(0),
-  m_checkbox_format_color_negatives(0),
-  m_vbox_text_format(0),
-  m_combo_format_text_horizontal_alignment(0),
-  m_checkbox_format_text_multiline(0),
-  m_label_format_text_multiline_height(0),
-  m_spinbutton_format_text_multiline_height(0),
-  m_hbox_font(0),
-  m_checkbox_format_text_font(0),
-  m_fontbutton(0),
-  m_hbox_color_foreground(0),
-  m_checkbox_format_text_color_foreground(0),
-  m_colorbutton_foreground(0),
-  m_hbox_color_background(0),
-  m_checkbox_format_text_color_background(0),
-  m_colorbutton_background(0),
-  m_vbox_choices(0),
-  m_radiobutton_choices_custom(0),
-  m_radiobutton_choices_related(0),
-  m_checkbutton_choices_restricted(0),
-  m_checkbutton_choices_restricted_as_radio_buttons(0),
-  m_adddel_choices_custom(0),
+  m_vbox_numeric_format(nullptr),
+  m_checkbox_format_use_thousands(nullptr),
+  m_checkbox_format_use_decimal_places(nullptr),
+  m_entry_format_decimal_places(nullptr),
+  m_entry_currency_symbol(nullptr),
+  m_checkbox_format_color_negatives(nullptr),
+  m_vbox_text_format(nullptr),
+  m_combo_format_text_horizontal_alignment(nullptr),
+  m_checkbox_format_text_multiline(nullptr),
+  m_label_format_text_multiline_height(nullptr),
+  m_spinbutton_format_text_multiline_height(nullptr),
+  m_hbox_font(nullptr),
+  m_checkbox_format_text_font(nullptr),
+  m_fontbutton(nullptr),
+  m_hbox_color_foreground(nullptr),
+  m_checkbox_format_text_color_foreground(nullptr),
+  m_colorbutton_foreground(nullptr),
+  m_hbox_color_background(nullptr),
+  m_checkbox_format_text_color_background(nullptr),
+  m_colorbutton_background(nullptr),
+  m_vbox_choices(nullptr),
+  m_radiobutton_choices_custom(nullptr),
+  m_radiobutton_choices_related(nullptr),
+  m_checkbutton_choices_restricted(nullptr),
+  m_checkbutton_choices_restricted_as_radio_buttons(nullptr),
+  m_adddel_choices_custom(nullptr),
   m_col_index_custom_choices(0),
-  m_combo_choices_relationship(0),
-  m_combo_choices_field(0),
-  m_label_choices_extra_fields(0),
-  m_button_choices_extra_fields(0),
-  m_label_choices_sortby(0),
-  m_button_choices_sortby(0),
-  m_checkbutton_choices_related_show_all(0),
-  m_dialog_choices_extra_fields(0),
-  m_dialog_choices_sortby(0),
+  m_combo_choices_relationship(nullptr),
+  m_combo_choices_field(nullptr),
+  m_label_choices_extra_fields(nullptr),
+  m_button_choices_extra_fields(nullptr),
+  m_label_choices_sortby(nullptr),
+  m_button_choices_sortby(nullptr),
+  m_checkbutton_choices_related_show_all(nullptr),
+  m_dialog_choices_extra_fields(nullptr),
+  m_dialog_choices_sortby(nullptr),
   m_for_print_layout(false),
   m_show_numeric(true),
   m_show_editable_options(true)
@@ -109,7 +109,7 @@ Box_Formatting::Box_Formatting(BaseObjectType* cobject, const Glib::RefPtr<Gtk::
   //Fill the alignment combo:
   m_model_alignment = Gtk::ListStore::create(m_columns_alignment);
 
-  Gtk::TreeModel::iterator iter = m_model_alignment->append();
+  auto iter = m_model_alignment->append();
   (*iter)[m_columns_alignment.m_col_alignment] = Formatting::HORIZONTAL_ALIGNMENT_AUTO;
   //Translators: This is Automatic text alignment.
   (*iter)[m_columns_alignment.m_col_title] = _("Automatic");
@@ -211,7 +211,7 @@ void Box_Formatting::set_is_for_non_editable()
   enforce_constraints();
 }
 
-void Box_Formatting::set_formatting_for_field(const Formatting& format, const Glib::ustring& table_name, const sharedptr<const Field>& field)
+void Box_Formatting::set_formatting_for_field(const Formatting& format, const Glib::ustring& table_name, const std::shared_ptr<const Field>& field)
 {
   //Used for choices and some extra text formatting:
   m_table_name = table_name;
@@ -246,12 +246,11 @@ void Box_Formatting::set_formatting_for_non_field(const Formatting& format, bool
   const Formatting::HorizontalAlignment alignment =
     format.get_horizontal_alignment();
   Gtk::TreeModel::Children children = m_model_alignment->children();
-  for(Gtk::TreeModel::Children::iterator iter = children.begin(); iter != children.end(); ++iter)
+  for(const auto& row : children)
   {
-    Gtk::TreeModel::Row row = *iter;
     if(row[m_columns_alignment.m_col_alignment] == alignment)
     {
-      m_combo_format_text_horizontal_alignment->set_active(iter);
+      m_combo_format_text_horizontal_alignment->set_active(row);
       break;
     }
   }
@@ -260,15 +259,15 @@ void Box_Formatting::set_formatting_for_non_field(const Formatting& format, bool
 
   m_spinbutton_format_text_multiline_height->set_value(format.get_text_format_multiline_height_lines());
 
-  const Glib::ustring font = format.get_text_format_font();
+  const auto font = format.get_text_format_font();
   m_checkbox_format_text_font->set_active(!font.empty());
   m_fontbutton->set_font_name(font);
 
-  const Glib::ustring color_foreground = format.get_text_format_color_foreground();
+  const auto color_foreground = format.get_text_format_color_foreground();
   m_checkbox_format_text_color_foreground->set_active(!color_foreground.empty());
   m_colorbutton_foreground->set_rgba( Gdk::RGBA(color_foreground) );
 
-  const Glib::ustring color_background = format.get_text_format_color_background();
+  const auto color_background = format.get_text_format_color_background();
   m_checkbox_format_text_color_background->set_active(!color_background.empty());
   m_colorbutton_background->set_rgba( Gdk::RGBA(color_background) );
 
@@ -281,15 +280,15 @@ void Box_Formatting::set_formatting_for_non_field(const Formatting& format, bool
       format.get_choices_restricted(as_radio_buttons));
     m_checkbutton_choices_restricted_as_radio_buttons->set_active(as_radio_buttons);
 
-    const Document* document = get_document();
+    const auto document = get_document();
 
     //Fill the list of relationships:
-    const Document::type_vec_relationships vecRelationships = document->get_relationships(m_table_name);
+    const auto vecRelationships = document->get_relationships(m_table_name);
     m_combo_choices_relationship->set_relationships(vecRelationships);
 
-    sharedptr<const Relationship> choices_relationship;
-    sharedptr<const LayoutItem_Field> choices_field;
-    sharedptr<const LayoutGroup> choices_field_extras;
+    std::shared_ptr<const Relationship> choices_relationship;
+    std::shared_ptr<const LayoutItem_Field> choices_field;
+    std::shared_ptr<const LayoutGroup> choices_field_extras;
     Formatting::type_list_sort_fields choices_sort_fields;
     bool choices_show_all = false;
     format.get_choices_related(choices_relationship, choices_field, choices_field_extras, choices_sort_fields, choices_show_all);
@@ -326,17 +325,15 @@ void Box_Formatting::set_formatting_for_non_field(const Formatting& format, bool
 
     //Custom choices:
     m_adddel_choices_custom->remove_all();
-    Formatting::type_list_values list_choice_values = format.get_choices_custom();
-    for(Formatting::type_list_values::const_iterator iter = list_choice_values.begin(); iter != list_choice_values.end(); ++iter)
+    for(const auto& choicevalue : format.get_choices_custom())
     {
-      const sharedptr<ChoiceValue> choicevalue = *iter;
       Gnome::Gda::Value value;
       if(choicevalue)
         value = choicevalue->get_value();
 
       //Display the value in the choices list as it would be displayed in the format:
-      const Glib::ustring value_text = Conversions::get_text_for_gda_value(m_field->get_glom_type(), value, format.m_numeric_format);
-      Gtk::TreeModel::iterator tree_iter = m_adddel_choices_custom->add_item(value_text);
+      const auto value_text = Conversions::get_text_for_gda_value(m_field->get_glom_type(), value, format.m_numeric_format);
+      auto tree_iter = m_adddel_choices_custom->add_item(value_text);
       m_adddel_choices_custom->set_value(tree_iter, m_col_index_custom_choices, value_text);
     }
 
@@ -353,7 +350,7 @@ bool Box_Formatting::get_formatting(Formatting& format) const
   m_format.m_numeric_format.m_use_thousands_separator = m_checkbox_format_use_thousands->get_active();
   m_format.m_numeric_format.m_decimal_places_restricted = m_checkbox_format_use_decimal_places->get_active();
 
-  const Glib::ustring strDecPlaces = m_entry_format_decimal_places->get_text();
+  const auto strDecPlaces = m_entry_format_decimal_places->get_text();
   m_format.m_numeric_format.m_decimal_places = atoi(strDecPlaces.c_str());
 
   m_format.m_numeric_format.m_currency_symbol = m_entry_currency_symbol->get_entry()->get_text();
@@ -362,7 +359,7 @@ bool Box_Formatting::get_formatting(Formatting& format) const
     m_checkbox_format_color_negatives->get_active();
 
   //Text formatting:
-  Gtk::TreeModel::iterator iter = m_combo_format_text_horizontal_alignment->get_active();
+  auto iter = m_combo_format_text_horizontal_alignment->get_active();
   Formatting::HorizontalAlignment alignment = Formatting::HORIZONTAL_ALIGNMENT_LEFT;
   if(iter)
     alignment = (*iter)[m_columns_alignment.m_col_alignment];
@@ -394,14 +391,14 @@ bool Box_Formatting::get_formatting(Formatting& format) const
       m_checkbutton_choices_restricted->get_active(),
       m_checkbutton_choices_restricted_as_radio_buttons->get_active());
 
-    const sharedptr<const Relationship> choices_relationship = m_combo_choices_relationship->get_selected_relationship();
-    sharedptr<LayoutItem_Field> layout_choice_first = sharedptr<LayoutItem_Field>::create();
+    const std::shared_ptr<const Relationship> choices_relationship = m_combo_choices_relationship->get_selected_relationship();
+    std::shared_ptr<LayoutItem_Field> layout_choice_first = std::make_shared<LayoutItem_Field>();
     layout_choice_first->set_name(m_combo_choices_field->get_selected_field_name());
 
-    sharedptr<LayoutGroup> layout_choice_extra = sharedptr<LayoutGroup>::create();
+    std::shared_ptr<LayoutGroup> layout_choice_extra = std::make_shared<LayoutGroup>();
     layout_choice_extra->m_list_items = m_dialog_choices_extra_fields->get_fields();
 
-    const Formatting::type_list_sort_fields sort_fields = m_dialog_choices_sortby->get_fields();
+    const auto sort_fields = m_dialog_choices_sortby->get_fields();
 
     m_format.set_choices_related(choices_relationship,
       layout_choice_first, layout_choice_extra,
@@ -410,20 +407,20 @@ bool Box_Formatting::get_formatting(Formatting& format) const
 
     //Custom choices:
     Formatting::type_list_values list_choice_values;
-    Glib::RefPtr<Gtk::TreeModel> choices_model = m_adddel_choices_custom->get_model();
+    Glib::RefPtr<const Gtk::TreeModel> choices_model = m_adddel_choices_custom->get_model();
     if(choices_model)
     {
-      for(Gtk::TreeModel::iterator iter = choices_model->children().begin(); iter != choices_model->children().end(); ++iter)
+      for(const auto& row : choices_model->children())
       {
-        const Glib::ustring text = m_adddel_choices_custom->get_value(iter, m_col_index_custom_choices);
+        const auto text = m_adddel_choices_custom->get_value(row, m_col_index_custom_choices);
         if(!text.empty())
         {
           bool success = false;
-          const Gnome::Gda::Value value = Conversions::parse_value(m_field->get_glom_type(), text, m_format.m_numeric_format, success);
+          const auto value = Conversions::parse_value(m_field->get_glom_type(), text, m_format.m_numeric_format, success);
 
           if(success)
           {
-            sharedptr<ChoiceValue> choicevalue = sharedptr<ChoiceValue>::create();
+            std::shared_ptr<ChoiceValue> choicevalue = std::make_shared<ChoiceValue>();
             choicevalue->set_value(value);
             list_choice_values.push_back(choicevalue);
           }
@@ -442,7 +439,7 @@ bool Box_Formatting::get_formatting(Formatting& format) const
 
 void Box_Formatting::on_combo_choices_relationship_changed()
 {
-  sharedptr<Relationship> relationship = m_combo_choices_relationship->get_selected_relationship();
+  std::shared_ptr<Relationship> relationship = m_combo_choices_relationship->get_selected_relationship();
 
   Document* pDocument = get_document();
   if(pDocument)
@@ -450,20 +447,20 @@ void Box_Formatting::on_combo_choices_relationship_changed()
     //Show the list of fields from this relationship:
     if(relationship)
     {
-      const Glib::ustring related_table = relationship->get_to_table();
-      const Document::type_vec_fields vecFields = pDocument->get_table_fields(related_table);
+      const auto related_table = relationship->get_to_table();
+      const auto vecFields = pDocument->get_table_fields(related_table);
       m_combo_choices_field->set_fields(vecFields);
 
       //Default to using the Primary Key field from the related table,
       //because this is almost always what people want to use:
-      const sharedptr<Field> related_primary_key = pDocument->get_field_primary_key(related_table);
+      const auto related_primary_key = pDocument->get_field_primary_key(related_table);
       if(related_primary_key)
         m_combo_choices_field->set_selected_field(related_primary_key);
 
       //Update the show-all dialog's list:
       //If the related table name has changed then the list of fields will probably
       //be ignored, clearing the list, but we try to preserve it if possible:
-      const LayoutGroup::type_list_items list_fields = m_dialog_choices_extra_fields->get_fields();
+      const auto list_fields = m_dialog_choices_extra_fields->get_fields();
       m_dialog_choices_extra_fields->set_fields(relationship->get_to_table(), list_fields);
 
       //Update the label:
@@ -474,7 +471,7 @@ void Box_Formatting::on_combo_choices_relationship_changed()
 
       //If the related table name has changed then the list of sort fields will probably
       //be ignored, clearing the list, but we try to preserve it if possible:
-      const Formatting::type_list_sort_fields sort_fields = m_dialog_choices_sortby->get_fields();
+      const auto sort_fields = m_dialog_choices_sortby->get_fields();
       m_dialog_choices_sortby->set_fields(relationship->get_to_table(), sort_fields);
 
       //Update the label: //TODO: Do the label updating in a shared function.
@@ -516,12 +513,12 @@ void Box_Formatting::enforce_constraints()
     else
     {
       m_checkbox_format_text_multiline->show();
-      m_label_format_text_multiline_height->hide();
+      m_label_format_text_multiline_height->show();
       m_spinbutton_format_text_multiline_height->show();
     }
 
     //Do not allow the user to specify a text height if it is not going to be multiline:
-    const bool text_height_sensitive = m_checkbox_format_text_multiline->get_active();
+    const auto text_height_sensitive = m_checkbox_format_text_multiline->get_active();
     m_spinbutton_format_text_multiline_height->set_sensitive(text_height_sensitive);
   }
   else
@@ -572,7 +569,7 @@ void Box_Formatting::on_button_choices_extra()
   if(!m_dialog_choices_extra_fields)
     return;
 
-  const int response = Glom::UiUtils::dialog_run_with_help(m_dialog_choices_extra_fields);
+  const auto response = Glom::UiUtils::dialog_run_with_help(m_dialog_choices_extra_fields);
   m_dialog_choices_extra_fields->hide();
   if(response == Gtk::RESPONSE_OK && m_dialog_choices_extra_fields->get_modified())
   {
@@ -591,7 +588,7 @@ void Box_Formatting::on_button_choices_sortby()
   if(!m_dialog_choices_sortby)
     return;
 
-  const int response = Glom::UiUtils::dialog_run_with_help(m_dialog_choices_sortby);
+  const auto response = Glom::UiUtils::dialog_run_with_help(m_dialog_choices_sortby);
   m_dialog_choices_sortby->hide();
   if(response == Gtk::RESPONSE_OK && m_dialog_choices_sortby->get_modified())
   {
