@@ -32,13 +32,13 @@ const bool Dialog_SortFields::glade_developer(true);
 
 Dialog_SortFields::Dialog_SortFields(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Layout(cobject, builder, false /* means no table title */),
-  m_treeview_fields(0),
-  m_button_field_up(0),
-  m_button_field_down(0),
-  m_button_field_add(0),
-  m_button_field_delete(0),
-  m_button_field_edit(0),
-  m_label_table_name(0)
+  m_treeview_fields(nullptr),
+  m_button_field_up(nullptr),
+  m_button_field_down(nullptr),
+  m_button_field_add(nullptr),
+  m_button_field_delete(nullptr),
+  m_button_field_edit(nullptr),
+  m_label_table_name(nullptr)
 {
   builder->get_widget("label_table_name", m_label_table_name);
 
@@ -110,19 +110,17 @@ void Dialog_SortFields::set_fields(const Glib::ustring& table_name, const Layout
 
 
     //Show the field layout
-    typedef std::list< Glib::ustring > type_listStrings;
-
     m_model_fields->clear();
     guint field_sequence = 0;
-    for(LayoutItem_GroupBy::type_list_sort_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
+    for(const auto& the_pair : fields)
     {
-      sharedptr<const LayoutItem_Field> item = sharedptr<const LayoutItem_Field>::cast_dynamic(iter->first);
+      std::shared_ptr<const LayoutItem_Field> item = std::dynamic_pointer_cast<const LayoutItem_Field>(the_pair.first);
 
-      Gtk::TreeModel::iterator iterTree = m_model_fields->append();
+      auto iterTree = m_model_fields->append();
       Gtk::TreeModel::Row row = *iterTree;
 
       row[m_ColumnsFields.m_col_layout_item] = item;
-      row[m_ColumnsFields.m_col_ascending] = iter->second;
+      row[m_ColumnsFields.m_col_ascending] = the_pair.second;
       row[m_ColumnsFields.m_col_sequence] = field_sequence;
       ++field_sequence;
     }
@@ -139,7 +137,7 @@ void Dialog_SortFields::enable_buttons()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_fields->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       //Disable Up if It can't go any higher.
@@ -151,7 +149,7 @@ void Dialog_SortFields::enable_buttons()
 
 
       //Disable Down if It can't go any lower.
-      Gtk::TreeModel::iterator iterNext = iter;
+      auto iterNext = iter;
       iterNext++;
 
       bool enable_down = true;
@@ -190,15 +188,13 @@ LayoutItem_GroupBy::type_list_sort_fields Dialog_SortFields::get_fields() const
   LayoutItem_GroupBy::type_list_sort_fields result;
 
   guint field_sequence = 1; //0 means no sequence
-  for(Gtk::TreeModel::iterator iterFields = m_model_fields->children().begin(); iterFields != m_model_fields->children().end(); ++iterFields)
+  for(const auto& row : m_model_fields->children())
   {
-    Gtk::TreeModel::Row row = *iterFields;
-
-    sharedptr<const LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item];
-    const Glib::ustring field_name = item->get_name();
+    std::shared_ptr<const LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item];
+    const auto field_name = item->get_name();
     if(!field_name.empty())
     {
-      sharedptr<LayoutItem_Field> field_copy = glom_sharedptr_clone(item);
+      std::shared_ptr<LayoutItem_Field> field_copy = glom_sharedptr_clone(item);
 
       const bool ascending = row[m_ColumnsFields.m_col_ascending];
       result.push_back( LayoutItem_GroupBy::type_pair_sort_field(field_copy, ascending) );
@@ -218,16 +214,14 @@ void Dialog_SortFields::on_treeview_fields_selection_changed()
 void Dialog_SortFields::on_button_add_field()
 {
   //Get the chosen fields:
-  type_list_field_items fields_list = offer_field_list(m_table_name, this);
-  for(type_list_field_items::iterator iter_chosen = fields_list.begin(); iter_chosen != fields_list.end(); ++iter_chosen) 
+  const auto fields_list = offer_field_list(m_table_name, this);
+  for(const auto& field : fields_list) 
   {
-
-    sharedptr<LayoutItem_Field> field = *iter_chosen;
     if(!field)
       continue;
 
     //Add the field details to the layout treeview:
-    Gtk::TreeModel::iterator iter =  m_model_fields->append();
+    auto iter =  m_model_fields->append();
 
     if(iter)
     {
@@ -253,7 +247,7 @@ void Dialog_SortFields::on_button_delete()
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       m_model_fields->erase(iter);
@@ -274,7 +268,7 @@ void Dialog_SortFields::on_cell_data_name(Gtk::CellRenderer* renderer, const Gtk
     {
       Gtk::TreeModel::Row row = *iter;
 
-      sharedptr<const LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item]; //TODO_performance: Reduce copying.
+      std::shared_ptr<const LayoutItem_Field> item = row[m_ColumnsFields.m_col_layout_item]; //TODO_performance: Reduce copying.
       renderer_text->property_markup() = item->get_layout_display_name();
       renderer_text->property_editable() = false; //Names can never be edited.
     }
@@ -288,14 +282,14 @@ void Dialog_SortFields::on_button_edit_field()
   if(refTreeSelection)
   {
     //TODO: Handle multiple-selection:
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<const LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
+      std::shared_ptr<const LayoutItem_Field> field = row[m_ColumnsFields.m_col_layout_item];
 
       //Get the chosen field:
-      sharedptr<LayoutItem_Field> field_chosen = 
+      std::shared_ptr<LayoutItem_Field> field_chosen = 
         offer_field_list_select_one_field(field, m_table_name, this);
       if(field_chosen)
 
