@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <glom/mode_design/layout/treestore_layout.h>
@@ -80,9 +80,9 @@ bool TreeStore_Layout::row_drop_possible_vfunc(const Gtk::TreeModel::Path& dest,
     {
       Gtk::TreeModel::Row row = *iter_dragged;
 
-      sharedptr<LayoutItem> layout_item = row[m_columns.m_col_layout_item];
-      sharedptr<LayoutGroup> layout_group = sharedptr<LayoutGroup>::cast_dynamic(layout_item);
-      const bool is_group = layout_group;
+      std::shared_ptr<LayoutItem> layout_item = row[m_columns.m_col_layout_item];
+      std::shared_ptr<LayoutGroup> layout_group = std::dynamic_pointer_cast<LayoutGroup>(layout_item);
+      const bool is_group = (bool)layout_group;
 
       return is_group; //Only groups can be dragged to the top-level.
     }
@@ -101,9 +101,9 @@ bool TreeStore_Layout::row_drop_possible_vfunc(const Gtk::TreeModel::Path& dest,
     {
       Gtk::TreeModel::Row row_parent = *iter_dest_parent;
 
-      sharedptr<LayoutItem> layout_item = row_parent[m_columns.m_col_layout_item];
-      sharedptr<LayoutGroup> layout_group = sharedptr<LayoutGroup>::cast_dynamic(layout_item);
-      const bool is_group = layout_group;
+      std::shared_ptr<LayoutItem> layout_item = row_parent[m_columns.m_col_layout_item];
+      std::shared_ptr<LayoutGroup> layout_group = std::dynamic_pointer_cast<LayoutGroup>(layout_item);
+      const bool is_group = (bool)layout_group;
 
       return is_group; //Only groups can contain other items.
     }
