@@ -39,11 +39,11 @@ Box_Print_Layouts::Box_Print_Layouts(BaseObjectType* cobject, const Glib::RefPtr
   m_colTitle(0)
 {
   //Get the Glade-instantiated widgets, and connect signal handlers:
-  Gtk::Button* pButtonCancel = 0;
+  Gtk::Button* pButtonCancel = nullptr;
   builder->get_widget("button_cancel", pButtonCancel);
   set_button_cancel(*pButtonCancel);
 
-  Gtk::Box* pAddDelParent = 0;
+  Gtk::Box* pAddDelParent = nullptr;
   builder->get_widget("vbox_adddel_parent", pAddDelParent);
   pAddDelParent->pack_start(m_AddDel);
 
@@ -59,11 +59,11 @@ Box_Print_Layouts::~Box_Print_Layouts()
 {
 }
 
-void Box_Print_Layouts::fill_row(const Gtk::TreeModel::iterator& iter, const sharedptr<const PrintLayout>& item)
+void Box_Print_Layouts::fill_row(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const PrintLayout>& item)
 {
   if(iter)
   {
-    const Glib::ustring& name = item->get_name();
+    const auto name = item->get_name();
     m_AddDel.set_value_key(iter, name);
     m_AddDel.set_value(iter, m_colName, name);
     m_AddDel.set_value(iter, m_colTitle, item_get_title(item));
@@ -102,13 +102,12 @@ bool Box_Print_Layouts::fill_from_database()
   Document* document = get_document();
   if(document)
   {
-    listItems = document->get_print_layout_names(m_table_name);
-    for(std::vector<Glib::ustring>::const_iterator iter = listItems.begin(); iter != listItems.end(); ++iter)
+    for(const auto& print_layout_name : document->get_print_layout_names(m_table_name))
     {
-      sharedptr<PrintLayout> item = document->get_print_layout(m_table_name, *iter);
+      std::shared_ptr<PrintLayout> item = document->get_print_layout(m_table_name, print_layout_name);
       if(item)
       {
-        Gtk::TreeModel::iterator row = m_AddDel.add_item(item->get_name());
+        auto row = m_AddDel.add_item(item->get_name());
         fill_row(row, item);
       }
     }
@@ -126,9 +125,9 @@ bool Box_Print_Layouts::fill_from_database()
 
 void Box_Print_Layouts::on_adddel_user_added(const Gtk::TreeModel::iterator& row)
 {
-  sharedptr<PrintLayout> item = sharedptr<PrintLayout>::create();
+  std::shared_ptr<PrintLayout> item = std::make_shared<PrintLayout>();
 
-  const Glib::ustring name = m_AddDel.get_value(row, m_colName);
+  const auto name = m_AddDel.get_value(row, m_colName);
   if(!name.empty())
   {
     item->set_name(name);
@@ -150,7 +149,7 @@ void Box_Print_Layouts::on_adddel_user_added(const Gtk::TreeModel::iterator& row
 
 void Box_Print_Layouts::on_adddel_user_requested_delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& /* TODO: rowEnd */)
 {
-  const Glib::ustring name = m_AddDel.get_value_key(rowStart);
+  const auto name = m_AddDel.get_value_key(rowStart);
   if(!name.empty())
   {
     get_document()->remove_print_layout(m_table_name, name);
@@ -180,16 +179,16 @@ void Box_Print_Layouts::save_to_document()
     std::vector<Glib::ustring> listItems = get_document()->get_print_layout_names(m_table_name);
 
     bool modified = false;
-    for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
+    for(const auto& row : m_AddDel.get_model()->children())
     {
-      const Glib::ustring name = m_AddDel.get_value(iter, m_colName);
+      const auto name = m_AddDel.get_value(row, m_colName);
 
       if(!name.empty() && std::find(listItems.begin(), listItems.end(), name) == listItems.end())
       {
-        sharedptr<PrintLayout> item(new PrintLayout());
+        std::shared_ptr<PrintLayout> item(new PrintLayout());
         item->set_name(name);
 
-        item->set_title( m_AddDel.get_value(iter, m_colTitle) , AppWindow::get_current_locale()); //TODO: Translations: Store the original in the TreeView.
+        item->set_title( m_AddDel.get_value(row, m_colTitle) , AppWindow::get_current_locale()); //TODO: Translations: Store the original in the TreeView.
 
         get_document()->set_print_layout(m_table_name, item);
         modified = true;
@@ -205,10 +204,10 @@ void Box_Print_Layouts::on_adddel_user_changed(const Gtk::TreeModel::iterator& r
 {
   if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
   {
-    const Glib::ustring name = m_AddDel.get_value_key(row);
+    const auto name = m_AddDel.get_value_key(row);
     Document* document = get_document();
 
-    sharedptr<PrintLayout> item = document->get_print_layout(m_table_name, name);
+    std::shared_ptr<PrintLayout> item = document->get_print_layout(m_table_name, name);
     if(item)
     {
       if(column == m_colTitle)
@@ -219,7 +218,7 @@ void Box_Print_Layouts::on_adddel_user_changed(const Gtk::TreeModel::iterator& r
       }
       else if(column == m_colName)
       {
-        const Glib::ustring name_new = m_AddDel.get_value(row, m_colName);
+        const auto name_new = m_AddDel.get_value(row, m_colName);
         if(!name.empty() && !name_new.empty())
         {
           Glib::ustring strMsg = _("Are you sure that you want to rename this print layout?");  //TODO: Show old and new names?
@@ -227,7 +226,7 @@ void Box_Print_Layouts::on_adddel_user_changed(const Gtk::TreeModel::iterator& r
           dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
           dialog.add_button(_("Rename"), Gtk::RESPONSE_OK);
           dialog.set_secondary_text(strMsg);
-          const int iButtonClicked = dialog.run();
+          const auto iButtonClicked = dialog.run();
 
           //Rename the item:
           if(iButtonClicked == Gtk::RESPONSE_OK)
