@@ -46,23 +46,23 @@ static const char DRAG_TARGET_NAME_RULE[] = "application/x-glom-printoutlayout-r
 
 Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::ApplicationWindow(cobject),
-  m_entry_name(0),
-  m_entry_title(0),
-  m_label_table_name(0),
-  m_button_close(0),
-  m_box(0),
-  m_box_item_position(0),
-  m_spinbutton_x(0),
-  m_spinbutton_y(0),
-  m_spinbutton_width(0),
-  m_spinbutton_height(0),
+  m_entry_name(nullptr),
+  m_entry_title(nullptr),
+  m_label_table_name(nullptr),
+  m_button_close(nullptr),
+  m_box(nullptr),
+  m_box_item_position(nullptr),
+  m_spinbutton_x(nullptr),
+  m_spinbutton_y(nullptr),
+  m_spinbutton_width(nullptr),
+  m_spinbutton_height(nullptr),
   m_ignore_spinbutton_signals(false),
   m_drag_preview_requested(false),
   m_temp_rule_horizontal(false),
-  m_vruler(0),
-  m_hruler(0),
+  m_vruler(nullptr),
+  m_hruler(nullptr),
   m_builder(builder),
-  m_context_menu(0)
+  m_context_menu(nullptr)
 {
   //See CanvasPrintLayout's commented-out use of set_size_request()
   //for an attempt to do this properly.
@@ -119,7 +119,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
  
   //Add the ruler widgets to the table at the left and top:
   //TODO: Use C++ API here:
-  Gtk::Grid* grid = 0;
+  Gtk::Grid* grid = nullptr;
   builder->get_widget("grid_canvas", grid);
   gtk_grid_attach(grid->gobj(), GTK_WIDGET(m_vruler), 
     0, 1, 1, 1);
@@ -149,7 +149,7 @@ Window_PrintLayout_Edit::Window_PrintLayout_Edit(BaseObjectType* cobject, const
   //Make the canvas a drag-and-drop destination:
   //TODO: Does this need to be a member variable?
   m_drag_targets_all = m_drag_targets_rule;
-  const Gtk::TargetEntry toolbar_target = Gtk::ToolPalette::get_drag_target_item();
+  const auto toolbar_target = Gtk::ToolPalette::get_drag_target_item();
   m_drag_targets_all.push_back(toolbar_target);
 
   //Note that we don't use Gtk::DEST_DEFAULT_DEFAULTS because that would prevent our signal handlers from being used:
@@ -295,7 +295,7 @@ void Window_PrintLayout_Edit::init_menu()
 
 bool Window_PrintLayout_Edit::on_canvas_drag_drop(const Glib::RefPtr<Gdk::DragContext>& drag_context, int /* x */, int /* y */, guint timestamp)
 {
-  const Glib::ustring target = m_canvas.drag_dest_find_target(drag_context);
+  const auto target = m_canvas.drag_dest_find_target(drag_context);
   if(target.empty())
     return false;
 
@@ -309,7 +309,7 @@ bool Window_PrintLayout_Edit::on_canvas_drag_drop(const Glib::RefPtr<Gdk::DragCo
 
 bool Window_PrintLayout_Edit::on_canvas_drag_motion(const Glib::RefPtr<Gdk::DragContext>& drag_context, int x, int y, guint timestamp)
 {
-  const Glib::ustring target = m_canvas.drag_dest_find_target(drag_context);
+  const auto target = m_canvas.drag_dest_find_target(drag_context);
   if(target.empty())
     return false;
 
@@ -363,13 +363,13 @@ bool Window_PrintLayout_Edit::on_canvas_drag_motion(const Glib::RefPtr<Gdk::Drag
   return true; //Allow the drop.
 }
 
-sharedptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayoutToolbarButton::enumItems item_type)
+std::shared_ptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayoutToolbarButton::enumItems item_type)
 {
-  sharedptr<LayoutItem> layout_item;
+  std::shared_ptr<LayoutItem> layout_item;
 
   if(item_type == PrintLayoutToolbarButton::ITEM_FIELD)
   {
-    sharedptr<LayoutItem_Field> layout_item_derived  = sharedptr<LayoutItem_Field>::create();
+    std::shared_ptr<LayoutItem_Field> layout_item_derived  = std::make_shared<LayoutItem_Field>();
     layout_item = layout_item_derived;
     layout_item->set_print_layout_position(0, 0,
       PrintLayoutUtils::ITEM_WIDTH_WIDE, PrintLayoutUtils::ITEM_HEIGHT);
@@ -379,7 +379,7 @@ sharedptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayoutTool
   }
   else if(item_type == PrintLayoutToolbarButton::ITEM_TEXT)
   {
-    sharedptr<LayoutItem_Text> layout_item_derived = sharedptr<LayoutItem_Text>::create();
+    std::shared_ptr<LayoutItem_Text> layout_item_derived = std::make_shared<LayoutItem_Text>();
 
     // Note to translators: This is the default contents of a text item on a print layout: 
     layout_item_derived->set_text_original(_("text")); //TODO: Choose some other longer default because this is hidden under the drag icon?
@@ -389,26 +389,26 @@ sharedptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayoutTool
   }
   else if(item_type == PrintLayoutToolbarButton::ITEM_IMAGE)
   {
-    layout_item = sharedptr<LayoutItem_Image>::create();
+    layout_item = std::make_shared<LayoutItem_Image>();
     layout_item->set_print_layout_position(0, 0,
       PrintLayoutUtils::ITEM_WIDTH_WIDE, PrintLayoutUtils::ITEM_WIDTH_WIDE);
   }
   else if(item_type == PrintLayoutToolbarButton::ITEM_LINE_HORIZONTAL)
   {
-    sharedptr<LayoutItem_Line> layout_item_derived = sharedptr<LayoutItem_Line>::create();
+    std::shared_ptr<LayoutItem_Line> layout_item_derived = std::make_shared<LayoutItem_Line>();
     layout_item_derived->set_coordinates(0, 0,
       PrintLayoutUtils::ITEM_WIDTH_WIDE * 2, 0);
     layout_item = layout_item_derived;
   }
   else if(item_type == PrintLayoutToolbarButton::ITEM_LINE_VERTICAL)
   {
-    sharedptr<LayoutItem_Line> layout_item_derived = sharedptr<LayoutItem_Line>::create();
+    std::shared_ptr<LayoutItem_Line> layout_item_derived = std::make_shared<LayoutItem_Line>();
     layout_item_derived->set_coordinates(0, 0, 0, PrintLayoutUtils::ITEM_WIDTH_WIDE * 2);
     layout_item = layout_item_derived;
   }
   else if(item_type == PrintLayoutToolbarButton::ITEM_PORTAL)
   {
-    sharedptr<LayoutItem_Portal> portal = sharedptr<LayoutItem_Portal>::create();
+    std::shared_ptr<LayoutItem_Portal> portal = std::make_shared<LayoutItem_Portal>();
     portal->set_print_layout_row_height(10); //Otherwise it will be 0, which is useless.
     layout_item = portal;
     layout_item->set_print_layout_position(0, 0,
@@ -422,8 +422,8 @@ sharedptr<LayoutItem> Window_PrintLayout_Edit::create_empty_item(PrintLayoutTool
   //Set a default text style and size:
   //12pt text seems sane. It is what OpenOffice/LibreOffice and Abiword use:
   //Serif (rather than sans-serif) is sane for body text:
-  sharedptr<LayoutItem_WithFormatting> with_formatting = 
-    sharedptr<LayoutItem_WithFormatting>::cast_dynamic(layout_item);
+  std::shared_ptr<LayoutItem_WithFormatting> with_formatting = 
+    std::dynamic_pointer_cast<LayoutItem_WithFormatting>(layout_item);
   if(with_formatting)
     with_formatting->m_formatting.set_text_format_font("Serif 12");
 
@@ -436,8 +436,8 @@ void Window_PrintLayout_Edit::canvas_convert_from_drag_pixels(double& x, double&
   //so deal with that:
   if(adjust_for_scrolling)
   {
-    const double scroll_x = m_scrolled_window.get_hadjustment()->get_value();
-    const double scroll_y = m_scrolled_window.get_vadjustment()->get_value();
+    const auto scroll_x = m_scrolled_window.get_hadjustment()->get_value();
+    const auto scroll_y = m_scrolled_window.get_vadjustment()->get_value();
   
     x += scroll_x;
     y += scroll_y;
@@ -452,7 +452,7 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
   //This is called when an item is dropped on the canvas,
   //or after our drag_motion handler has called drag_get_data()): 	
 
-  const Glib::ustring target = m_canvas.drag_dest_find_target(drag_context);
+  const auto target = m_canvas.drag_dest_find_target(drag_context);
   if(target.empty())
     return;
 
@@ -481,7 +481,7 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
   }
   
   //Discover what toolbar item was dropped:
-  const PrintLayoutToolbarButton::enumItems item_type = PrintLayoutToolbarButton::get_item_type_from_selection_data(drag_context, selection_data);
+  const auto item_type = PrintLayoutToolbarButton::get_item_type_from_selection_data(drag_context, selection_data);
   if(item_type == PrintLayoutToolbarButton::ITEM_INVALID)
   {
     std::cerr << G_STRFUNC << ": item_type was invalid" << std::endl;
@@ -493,7 +493,7 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
     //Create the temporary drag item if necessary:
     if(!m_layout_item_dropping)
     {
-      sharedptr<LayoutItem> layout_item = create_empty_item(item_type);
+      std::shared_ptr<LayoutItem> layout_item = create_empty_item(item_type);
 
       //Show it on the canvas, at the position:
       if(layout_item)
@@ -516,7 +516,7 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
     m_canvas.drag_unhighlight();
 
     //Add the item to the canvas:
-    sharedptr<LayoutItem> layout_item = create_empty_item(item_type);
+    std::shared_ptr<LayoutItem> layout_item = create_empty_item(item_type);
     if(!layout_item)
     {
       std::cerr << G_STRFUNC << ": layout_item is null." << std::endl;
@@ -525,9 +525,6 @@ void Window_PrintLayout_Edit::on_canvas_drag_data_received(const Glib::RefPtr<Gd
 
     Glib::RefPtr<CanvasLayoutItem> item =
       create_canvas_layout_item_and_add(layout_item);
-    double item_x = x;
-    double item_y = y;
-    canvas_convert_from_drag_pixels(item_x, item_y, true /* adjust for scrolling */);
     item->snap_position(item_x, item_y);
     item->set_xy(item_x, item_y);
    
@@ -597,12 +594,12 @@ Glib::ustring Window_PrintLayout_Edit::get_original_name() const
   return m_name_original;
 }
 
-void Window_PrintLayout_Edit::set_print_layout(const Glib::ustring& table_name, const sharedptr<const PrintLayout>& print_layout)
+void Window_PrintLayout_Edit::set_print_layout(const Glib::ustring& table_name, const std::shared_ptr<const PrintLayout>& print_layout)
 {
   m_modified = false;
 
   m_name_original = print_layout->get_name();
-  m_print_layout = sharedptr<PrintLayout>(new PrintLayout(*print_layout)); //Copy it, so we only use the changes when we want to.
+  m_print_layout = std::make_shared<PrintLayout>(*print_layout); //Copy it, so we only use the changes when we want to.
   m_canvas.set_print_layout(table_name, m_print_layout);
   m_table_name = table_name;
 
@@ -630,7 +627,7 @@ void Window_PrintLayout_Edit::enable_buttons()
 
 }
 
-sharedptr<PrintLayout> Window_PrintLayout_Edit::get_print_layout()
+std::shared_ptr<PrintLayout> Window_PrintLayout_Edit::get_print_layout()
 {
   m_print_layout = m_canvas.get_print_layout();
   m_print_layout->set_name( m_entry_name->get_text() );
@@ -655,15 +652,15 @@ sharedptr<PrintLayout> Window_PrintLayout_Edit::get_print_layout()
   m_print_layout->get_layout_group()->remove_all_items();
 
   //The Header and Footer parts are implicit (they are the whole header or footer treeview)
-  sharedptr<LayoutItem_Header> header = sharedptr<LayoutItem_Header>::create();
-  sharedptr<LayoutGroup> group_temp = header;
+  std::shared_ptr<LayoutItem_Header> header = std::make_shared<LayoutItem_Header>();
+  std::shared_ptr<LayoutGroup> group_temp = header;
   fill_print_layout_parts(group_temp, m_model_parts_header);
   if(header->get_items_count())
     m_print_layout->get_layout_group()->add_item(header);
 
   fill_print_layout_parts(m_print_layout->get_layout_group(), m_model_parts_main);
 
-  sharedptr<LayoutItem_Footer> footer = sharedptr<LayoutItem_Footer>::create();
+  std::shared_ptr<LayoutItem_Footer> footer = std::make_shared<LayoutItem_Footer>();
   group_temp = footer;
   fill_print_layout_parts(group_temp, m_model_parts_footer);
   if(footer->get_items_count())
@@ -713,12 +710,12 @@ void Window_PrintLayout_Edit::setup_context_menu()
   m_context_menu->attach_to_widget(*this);
 }
 
-bool Window_PrintLayout_Edit::on_canvas_motion_notify_event(GdkEventMotion* event)
+bool Window_PrintLayout_Edit::on_canvas_motion_notify_event(GdkEventMotion* motion_event)
 {
   //Notice that, unlike drag-motion, motion-notify-event's x/y position already 
   //seems to have the scrolling taken into account.
-  double x = event->x;
-  double y = event->y;
+  double x = motion_event->x;
+  double y = motion_event->y;
   canvas_convert_from_drag_pixels(x, y, false /* do not adjust for scrolling */);
 
   gimp_ruler_set_position(m_hruler, x);
@@ -746,7 +743,7 @@ bool Window_PrintLayout_Edit::get_is_item_at(double x, double y)
   return layout_item;
 }
 
-void Window_PrintLayout_Edit::set_default_position(const sharedptr<LayoutItem>& item)
+void Window_PrintLayout_Edit::set_default_position(const std::shared_ptr<LayoutItem>& item)
 {
   if(!item)
     return;
@@ -774,7 +771,7 @@ void Window_PrintLayout_Edit::set_default_position(const sharedptr<LayoutItem>&
 
 void Window_PrintLayout_Edit::on_menu_insert_field()
 {
-  sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_FIELD);
+  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_FIELD);
 
   // Note to translators: This is the default contents of a text item on a print layout: 
   set_default_position(layout_item);
@@ -784,7 +781,7 @@ void Window_PrintLayout_Edit::on_menu_insert_field()
 
 void Window_PrintLayout_Edit::on_menu_insert_text()
 {
-  sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_TEXT);
+  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_TEXT);
   set_default_position(layout_item);
 
   create_canvas_layout_item_and_add(layout_item);
@@ -792,7 +789,7 @@ void Window_PrintLayout_Edit::on_menu_insert_text()
 
 void Window_PrintLayout_Edit::on_menu_insert_image()
 {
-  sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_IMAGE);
+  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_IMAGE);
   // Note to translators: This is the default contents of a text item on a print layout: 
   //layout_item->set_text_original(_("text"));
   set_default_position(layout_item);
@@ -802,7 +799,7 @@ void Window_PrintLayout_Edit::on_menu_insert_image()
 
 void Window_PrintLayout_Edit::on_menu_insert_relatedrecords()
 {
-  sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_PORTAL);
+  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_PORTAL);
   set_default_position(layout_item);
 
   create_canvas_layout_item_and_add(layout_item);
@@ -810,7 +807,7 @@ void Window_PrintLayout_Edit::on_menu_insert_relatedrecords()
 
 void Window_PrintLayout_Edit::on_menu_insert_line_horizontal()
 {
-  sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_LINE_HORIZONTAL);
+  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_LINE_HORIZONTAL);
 
   /*
   double item_x = m_drop_x;
@@ -827,7 +824,7 @@ void Window_PrintLayout_Edit::on_menu_insert_line_horizontal()
 
 void Window_PrintLayout_Edit::on_menu_insert_line_vertical()
 {
-  sharedptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_LINE_VERTICAL);
+  std::shared_ptr<LayoutItem> layout_item = create_empty_item(PrintLayoutToolbarButton::ITEM_LINE_VERTICAL);
 
   create_canvas_layout_item_and_add(layout_item);
 }
@@ -841,7 +838,7 @@ void Window_PrintLayout_Edit::on_menu_insert_create_standard()
   dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
   dialog.add_button(_("Create"), Gtk::RESPONSE_OK);
 
-  const int response = dialog.run();
+  const auto response = dialog.run();
   if(response != Gtk::RESPONSE_OK)
     return;
 
@@ -874,7 +871,7 @@ void Window_PrintLayout_Edit::on_menu_insert_add_page()
 //TODO: Disable this menu item when there is only one page:
 void Window_PrintLayout_Edit::on_menu_insert_delete_page()
 {
-  const guint page_count = m_canvas.get_page_count();
+  const auto page_count = m_canvas.get_page_count();
   if(page_count <= 1)
     return;
 
@@ -989,7 +986,7 @@ void Window_PrintLayout_Edit::on_menu_view_zoom(int parameter)
     if(child)
     {
       Gtk::Allocation widget_allocation = child->get_allocation();
-      const double viewport_width = widget_allocation.get_width();
+      const auto viewport_width = widget_allocation.get_width();
       if(canvas_width_pixels)
       {
         //scale the canvas so it fits perfectly in the viewport:
@@ -1027,8 +1024,8 @@ void Window_PrintLayout_Edit::on_menu_file_print_preview()
   if(!document)
     return;
 
-  const Glib::ustring original_name = get_original_name();
-  sharedptr<PrintLayout> print_layout = get_print_layout();
+  const auto original_name = get_original_name();
+  std::shared_ptr<PrintLayout> print_layout = get_print_layout();
   if(print_layout && (original_name != get_name()))
     document->remove_print_layout(m_table_name, original_name);
 
@@ -1053,14 +1050,12 @@ void Window_PrintLayout_Edit::on_menu_edit_copy()
 
   m_layout_items_to_paste.clear();
 
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> item = *iter;
     if(item)
       item->update_layout_position_from_canvas();
 
-    sharedptr<LayoutItem> cloned = 
+    std::shared_ptr<LayoutItem> cloned = 
       glom_sharedptr_clone(item->get_layout_item());
 
     m_layout_items_to_paste.push_back(cloned);
@@ -1074,10 +1069,8 @@ void Window_PrintLayout_Edit::on_menu_edit_paste()
   if(m_layout_items_to_paste.empty())
     return;
 
-  for(type_list_items::iterator iter = m_layout_items_to_paste.begin();
-    iter != m_layout_items_to_paste.end(); ++iter)
+  for(const auto& item : m_layout_items_to_paste)
   {
-    sharedptr<LayoutItem> item = *iter;
     if(!item)
       continue;
 
@@ -1099,7 +1092,7 @@ void Window_PrintLayout_Edit::on_menu_edit_paste()
   }
 }
 
-Glib::RefPtr<CanvasLayoutItem> Window_PrintLayout_Edit::create_canvas_layout_item_and_add(const sharedptr<LayoutItem>& layout_item)
+Glib::RefPtr<CanvasLayoutItem> Window_PrintLayout_Edit::create_canvas_layout_item_and_add(const std::shared_ptr<LayoutItem>& layout_item)
 {
   Glib::RefPtr<CanvasLayoutItem> canvas_item = CanvasLayoutItem::create();
   m_canvas.add_canvas_layout_item(canvas_item);
@@ -1136,7 +1129,7 @@ void Window_PrintLayout_Edit::on_menu_align_top()
 {
   //Get the top-most position:
   double top = 0;
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
+  for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
     Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
@@ -1154,10 +1147,8 @@ void Window_PrintLayout_Edit::on_menu_align_top()
   }
   
   //Give all items the same top position:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& selected_item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1172,7 +1163,7 @@ void Window_PrintLayout_Edit::on_menu_align_bottom()
 {
   //Get the bottom-most position:
   double bottom = 0;
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
+  for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
     Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
@@ -1195,10 +1186,8 @@ void Window_PrintLayout_Edit::on_menu_align_bottom()
   }
   
   //Give all items the same top position:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& selected_item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1220,7 +1209,7 @@ void Window_PrintLayout_Edit::on_menu_align_left()
 {
   //Get the left-most position:
   double left = 0;
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
+  for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
     Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
@@ -1238,10 +1227,8 @@ void Window_PrintLayout_Edit::on_menu_align_left()
   }
   
   //Give all items the same left position:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& selected_item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1256,10 +1243,11 @@ void Window_PrintLayout_Edit::on_menu_align_right()
 {
   //Get the right-most position:
   double right = 0;
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
+  for(auto iter = m_layout_items_selected.begin();
     iter != m_layout_items_selected.end(); ++iter)
   {
     Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
+
     if(!selected_item)
       continue;
 
@@ -1279,10 +1267,8 @@ void Window_PrintLayout_Edit::on_menu_align_right()
   }
   
   //Give all items the same top position:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& selected_item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
     if(!selected_item)
       continue;
 
@@ -1345,9 +1331,9 @@ void Window_PrintLayout_Edit::on_scroll_value_changed()
   gimp_ruler_set_range(m_vruler, y, y + height, y + height);
 }
 
-bool Window_PrintLayout_Edit::on_configure_event(GdkEventConfigure* event)
+bool Window_PrintLayout_Edit::on_configure_event(GdkEventConfigure* configure_event)
 {
-  const bool result = Gtk::Window::on_configure_event(event);
+  const auto result = Gtk::Window::on_configure_event(configure_event);
 
   //If we are in fit-page-width then rescale the canvas:
   int percent = 0;
@@ -1369,10 +1355,8 @@ void Window_PrintLayout_Edit::get_dimensions_of_multiple_selected_items(double&
   double x2 = 0;
   double y2 = 0;
   bool first = true;
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> item = Glib::RefPtr<CanvasLayoutItem>::cast_dynamic(*iter);
     if(!item)
       continue;
 
@@ -1412,10 +1396,9 @@ void Window_PrintLayout_Edit::on_canvas_selection_changed()
 
   //Forget about any previously selected items:
   m_layout_items_selected.clear();
-  for(type_vec_connections::iterator iter = m_connections_items_selected_moved.begin();
-    iter != m_connections_items_selected_moved.end(); ++iter)
+  for(auto item : m_connections_items_selected_moved)
   {
-    iter->disconnect();
+    item.disconnect();
   }
   m_connections_items_selected_moved.clear();
   
@@ -1453,8 +1436,8 @@ void Window_PrintLayout_Edit::on_canvas_selection_changed()
   //Disable the spinbuttons if there are no items selected,
   //or if there are more than 1.
   //TODO: Let the user resize groups of items.
-  const bool one_selected = (m_layout_items_selected.size() == 1);
-  const bool some_selected = !m_layout_items_selected.empty();
+  const auto one_selected = (m_layout_items_selected.size() == 1);
+  const auto some_selected = !m_layout_items_selected.empty();
 
   //Allow x/y editing via the numbers for multiple items,
   //but not width/height for multiple items (TODO: Stretch them in that case?)
@@ -1478,10 +1461,8 @@ void Window_PrintLayout_Edit::on_canvas_selection_changed()
 void Window_PrintLayout_Edit::on_selected_item_moved(const Glib::RefPtr<CanvasItemMovable>& item, double x_offset, double y_offset)
 {
   //Move the other selected items too:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& selected_item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> selected_item = *iter;
     if(!selected_item || (item == selected_item))
       continue;
 
@@ -1522,13 +1503,11 @@ void Window_PrintLayout_Edit::on_spinbutton_x()
   get_dimensions_of_multiple_selected_items(x, y, width, height);
 
   //Discover the offset:
-  const double offset_x = m_spinbutton_x->get_value() - x;
+  const auto offset_x = m_spinbutton_x->get_value() - x;
 
   //Apply the offset to all items:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> item = *iter;
     if(!item)
       continue;
 
@@ -1557,13 +1536,11 @@ void Window_PrintLayout_Edit::on_spinbutton_y()
   get_dimensions_of_multiple_selected_items(x, y, width, height);
 
   //Discover the offset:
-  const double offset_y = m_spinbutton_y->get_value() - y;
+  const auto offset_y = m_spinbutton_y->get_value() - y;
 
   //Apply the offset to all items:
-  for(type_vec_canvas_items::iterator iter = m_layout_items_selected.begin();
-    iter != m_layout_items_selected.end(); ++iter)
+  for(const auto& item : m_layout_items_selected)
   {
-    Glib::RefPtr<CanvasLayoutItem> item = *iter;
     if(!item)
       continue;
 
@@ -1615,9 +1592,9 @@ void Window_PrintLayout_Edit::on_spinbutton_height()
     m_spinbutton_height->get_value());
 }
 
-bool Window_PrintLayout_Edit::on_hruler_button_press_event(GdkEventButton* event)
+bool Window_PrintLayout_Edit::on_hruler_button_press_event(GdkEventButton* button_event)
 {
-  if(event->button != 1)
+  if(button_event->button != 1)
     return true;
 
   m_temp_rule_horizontal = true;
@@ -1625,9 +1602,9 @@ bool Window_PrintLayout_Edit::on_hruler_button_press_event(GdkEventButton* event
   return false;
 }
 
-bool Window_PrintLayout_Edit::on_vruler_button_press_event(GdkEventButton* event)
+bool Window_PrintLayout_Edit::on_vruler_button_press_event(GdkEventButton* button_event)
 {
-  if(event->button != 1)
+  if(button_event->button != 1)
     return true;
 
   m_temp_rule_horizontal = false; //vertical.
