@@ -44,11 +44,11 @@ const bool Window_RelationshipsOverview::glade_developer(true);
 Window_RelationshipsOverview::Window_RelationshipsOverview(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
   : Gtk::ApplicationWindow(cobject),
     m_builder(builder),
-    m_menu(0),
+    m_menu(nullptr),
     m_modified(false),
-    m_scrolledwindow_canvas(0)
+    m_scrolledwindow_canvas(nullptr)
 {
-  Gtk::Button* button_close = 0;
+  Gtk::Button* button_close = nullptr;
   builder->get_widget("button_close",  button_close);
   if(button_close)
     button_close->signal_clicked().connect( sigc::mem_fun(*this, &Window_RelationshipsOverview::on_button_close) );
@@ -57,7 +57,7 @@ Window_RelationshipsOverview::Window_RelationshipsOverview(BaseObjectType* cobje
   m_refSettings = Gtk::PrintSettings::create();
 
   //Add a menu:
-  Gtk::Box* vbox = 0;
+  Gtk::Box* vbox = nullptr;
   builder->get_widget("vbox_placeholder_menubar", vbox);
 
   Glib::RefPtr<Gio::SimpleActionGroup> action_group = Gio::SimpleActionGroup::create();
@@ -90,7 +90,7 @@ Window_RelationshipsOverview::Window_RelationshipsOverview(BaseObjectType* cobje
 
 
   //Get the scolled window and add the canvas to it:
-  m_scrolledwindow_canvas = 0;
+  m_scrolledwindow_canvas = nullptr;
   builder->get_widget("scrolledwindow_canvas", m_scrolledwindow_canvas);
 
   m_scrolledwindow_canvas->add(m_canvas);
@@ -126,7 +126,7 @@ Window_RelationshipsOverview::~Window_RelationshipsOverview()
   //so sigc::bind()ed RefPtrs can be released.
   while(m_list_table_connections.size())
   {
-     type_list_connections::iterator iter = m_list_table_connections.begin();
+     auto iter = m_list_table_connections.begin();
      sigc::connection the_connection = *iter;
      the_connection.disconnect();
      m_list_table_connections.erase(iter);
@@ -142,9 +142,9 @@ void Window_RelationshipsOverview::draw_tables()
 {
   //Disconnect signal handlers for all current items,
   //so sigc::bind()ed RefPtrs can be released.
-  while(!m_list_table_connections.empty())
+  while(m_list_table_connections.size())
   {
-     type_list_connections::iterator iter = m_list_table_connections.begin();
+     auto iter = m_list_table_connections.begin();
      sigc::connection the_connection = *iter;
      the_connection.disconnect();
      m_list_table_connections.erase(iter);
@@ -154,7 +154,7 @@ void Window_RelationshipsOverview::draw_tables()
   while(m_group_tables->get_n_children() > 0)
     m_group_tables->remove_child(0);
 
-  Document* document = dynamic_cast<Document*>(get_document());
+  const auto document = dynamic_cast<Document*>(get_document());
   if(document)
   {
     double max_table_height = 0;
@@ -162,11 +162,10 @@ void Window_RelationshipsOverview::draw_tables()
     double sizey = 10;
 
     //Create tables canvas items, with lists of fields:
-    Document::type_listTableInfo tables = document->get_tables();
-    for(Document::type_listTableInfo::iterator iter = tables.begin(); iter != tables.end(); ++iter)
+    const auto tables = document->get_tables();
+    for(const auto& info : tables)
     {
-      sharedptr<TableInfo> info = *iter;
-      const Glib::ustring table_name = info->get_name();
+      const auto table_name = info->get_name();
 
       float table_x = 0;
       float table_y = 0;
@@ -212,22 +211,19 @@ void Window_RelationshipsOverview::draw_lines()
   while(m_group_lines->get_n_children() > 0)
     m_group_lines->remove_child(0);
 
-  Document* document = dynamic_cast<Document*>(get_document());
+  const auto document = dynamic_cast<Document*>(get_document());
   if(document)
   {
     //Create the lines linking tables to show relationships:
-    Document::type_listTableInfo tables = document->get_tables();
-    for(Document::type_listTableInfo::iterator iter = tables.begin(); iter != tables.end(); ++iter)
+    for(const auto& info : document->get_tables())
     {
-      sharedptr<TableInfo> info = *iter;
-      const Glib::ustring table_name = info->get_name();
+      const auto table_name = info->get_name();
 
       Document::type_vec_relationships m_relationships = document->get_relationships(table_name);
       Document::type_vec_fields fields = document->get_table_fields(table_name);
 
-      for(Document::type_vec_relationships::const_iterator rit = m_relationships.begin(); rit != m_relationships.end(); ++rit)
+      for(const auto& relationship : m_relationships)
       {
-        sharedptr<const Relationship> relationship = *rit;
         if(!relationship)
           continue;
 
@@ -303,7 +299,7 @@ void Window_RelationshipsOverview::draw_lines()
             y_offset = (from_field_y < to_field_y) ? -10 : +10;
 
           const double text_x = (from_field_x + to_field_x) / 2;
-          const double text_y = ((from_field_y + to_field_y) / 2) + y_offset;
+          const auto text_y = ((from_field_y + to_field_y) / 2) + y_offset;
           Glib::RefPtr<CanvasTextMovable> text = CanvasTextMovable::create(item_get_title_or_name(relationship),
             text_x, text_y, -1, //TODO: Calc a suitable width.
             Goocanvas::ANCHOR_CENTER);
@@ -395,7 +391,7 @@ void Window_RelationshipsOverview::print_or_preview(Gtk::PrintOperationAction pr
 
 Glib::RefPtr<CanvasGroupDbTable> Window_RelationshipsOverview::get_table_group(const Glib::ustring& table_name)
 {
-  const int count = m_group_tables->get_n_children();
+  const auto count = m_group_tables->get_n_children();
   for(int i = 0; i < count; ++i)
   {
     Glib::RefPtr<Goocanvas::Item> item = m_group_tables->get_child(i);
