@@ -48,21 +48,21 @@ const bool Dialog_Layout_Report::glade_developer(true);
 
 Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Dialog_Layout(cobject, builder, false /* No table title */),
-  m_notebook_parts(0),
-  m_treeview_parts_header(0),
-  m_treeview_parts_footer(0),
-  m_treeview_parts_main(0),
-  m_treeview_available_parts(0),
-  m_button_up(0),
-  m_button_down(0),
-  m_button_add(0),
-  m_button_delete(0),
-  m_button_edit(0),
-  m_button_formatting(0),
-  m_label_table_name(0),
-  m_entry_name(0),
-  m_entry_title(0),
-  m_checkbutton_table_title(0)
+  m_notebook_parts(nullptr),
+  m_treeview_parts_header(nullptr),
+  m_treeview_parts_footer(nullptr),
+  m_treeview_parts_main(nullptr),
+  m_treeview_available_parts(nullptr),
+  m_button_up(nullptr),
+  m_button_down(nullptr),
+  m_button_add(nullptr),
+  m_button_delete(nullptr),
+  m_button_edit(nullptr),
+  m_button_formatting(nullptr),
+  m_label_table_name(nullptr),
+  m_entry_name(nullptr),
+  m_entry_title(nullptr),
+  m_checkbutton_table_title(nullptr)
 {
   builder->get_widget("label_table_name", m_label_table_name);
   builder->get_widget("entry_name", m_entry_name);
@@ -101,48 +101,48 @@ Dialog_Layout_Report::Dialog_Layout_Report(BaseObjectType* cobject, const Glib::
     {
       m_model_available_parts_main = type_model::create();
 
-  //     Gtk::TreeModel::iterator iterHeader = m_model_available_parts_main->append();
-  //     (*iterHeader)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Header()));
+  //     auto iterHeader = m_model_available_parts_main->append();
+  //     (*iterHeader)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_Header>();
 
-      Gtk::TreeModel::iterator iter = m_model_available_parts_main->append();
-      (*iter)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_GroupBy()));
+      auto iter = m_model_available_parts_main->append();
+      (*iter)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_GroupBy>();
 
-      Gtk::TreeModel::iterator iterField = m_model_available_parts_main->append(iter->children()); //Place Field under GroupBy to indicate that that's where it belongs in the actual layout.
-      (*iterField)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Field()));
+      auto iterField = m_model_available_parts_main->append(iter->children()); //Place Field under GroupBy to indicate that that's where it belongs in the actual layout.
+      (*iterField)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_Field>();
 
-      Gtk::TreeModel::iterator iterText = m_model_available_parts_main->append(iter->children());
-      (*iterText)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Text()));
+      auto iterText = m_model_available_parts_main->append(iter->children());
+      (*iterText)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_Text>();
 
-      Gtk::TreeModel::iterator iterImage = m_model_available_parts_main->append(iter->children());
-      (*iterImage)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Image()));
+      auto iterImage = m_model_available_parts_main->append(iter->children());
+      (*iterImage)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_Image>();
 
-      Gtk::TreeModel::iterator iterVerticalGroup = m_model_available_parts_main->append(iter->children());
-      (*iterVerticalGroup)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_VerticalGroup()));
+      auto iterVerticalGroup = m_model_available_parts_main->append(iter->children());
+      (*iterVerticalGroup)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_VerticalGroup>();
 
       iter = m_model_available_parts_main->append();
-      (*iter)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Summary()));
+      (*iter)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_Summary>();
       iter = m_model_available_parts_main->append(iter->children());
-      (*iter)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_FieldSummary()));
+      (*iter)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_FieldSummary>();
 
-//     Gtk::TreeModel::iterator iterFooter = m_model_available_parts_main->append();
-//     (*iterFooter)[m_model_available_parts_main->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Footer()));
+//     auto iterFooter = m_model_available_parts_main->append();
+//     (*iterFooter)[m_model_available_parts_main->m_columns.m_col_item] = std::make_shared<LayoutItem_Footer>();
     }
 
     //Header/Footer parts:
     {
       m_model_available_parts_headerfooter = type_model::create();
 
-      Gtk::TreeModel::iterator iterVerticalGroup = m_model_available_parts_headerfooter->append();
-      (*iterVerticalGroup)[m_model_available_parts_headerfooter->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_VerticalGroup()));
+      auto iterVerticalGroup = m_model_available_parts_headerfooter->append();
+      (*iterVerticalGroup)[m_model_available_parts_headerfooter->m_columns.m_col_item] = std::make_shared<LayoutItem_VerticalGroup>();
 
-      Gtk::TreeModel::iterator iterField = m_model_available_parts_headerfooter->append(iterVerticalGroup->children());
-      (*iterField)[m_model_available_parts_headerfooter->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Field()));
+      auto iterField = m_model_available_parts_headerfooter->append(iterVerticalGroup->children());
+      (*iterField)[m_model_available_parts_headerfooter->m_columns.m_col_item] = std::make_shared<LayoutItem_Field>();
 
-      Gtk::TreeModel::iterator iterText = m_model_available_parts_headerfooter->append(iterVerticalGroup->children());
-      (*iterText)[m_model_available_parts_headerfooter->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Text()));
+      auto iterText = m_model_available_parts_headerfooter->append(iterVerticalGroup->children());
+      (*iterText)[m_model_available_parts_headerfooter->m_columns.m_col_item] = std::make_shared<LayoutItem_Text>();
 
-      Gtk::TreeModel::iterator iterImage = m_model_available_parts_headerfooter->append(iterVerticalGroup->children());
-      (*iterImage)[m_model_available_parts_headerfooter->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(new LayoutItem_Image()));
+      auto iterImage = m_model_available_parts_headerfooter->append(iterVerticalGroup->children());
+      (*iterImage)[m_model_available_parts_headerfooter->m_columns.m_col_item] = std::make_shared<LayoutItem_Image>();
     }
 
     m_treeview_available_parts->set_model(m_model_available_parts_main);
@@ -235,14 +235,14 @@ void Dialog_Layout_Report::setup_model(Gtk::TreeView& treeview, Glib::RefPtr<typ
   //m_model_parts_main->signal_row_changed().connect( sigc::mem_fun(*this, &Dialog_Layout_Report::on_treemodel_row_changed) );
 }
 
-sharedptr<LayoutGroup> Dialog_Layout_Report::fill_group(const Gtk::TreeModel::iterator& iter, const Glib::RefPtr<const type_model> model)
+std::shared_ptr<LayoutGroup> Dialog_Layout_Report::fill_group(const Gtk::TreeModel::iterator& iter, const Glib::RefPtr<const type_model> model)
 {
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
 
-    sharedptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
-    sharedptr<LayoutGroup> pGroup = sharedptr<LayoutGroup>::cast_dynamic(pItem);
+    std::shared_ptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
+    std::shared_ptr<LayoutGroup> pGroup = std::dynamic_pointer_cast<LayoutGroup>(pItem);
     if(pGroup)
     {
       //Make sure that it contains the child items:
@@ -252,25 +252,24 @@ sharedptr<LayoutGroup> Dialog_Layout_Report::fill_group(const Gtk::TreeModel::it
 
   }
 
-  return  sharedptr<LayoutGroup>();
+  return  std::shared_ptr<LayoutGroup>();
 }
 
-void Dialog_Layout_Report::fill_group_children(const sharedptr<LayoutGroup>& group, const Gtk::TreeModel::iterator& iter, const Glib::RefPtr<const type_model> model)
+void Dialog_Layout_Report::fill_group_children(const std::shared_ptr<LayoutGroup>& group, const Gtk::TreeModel::iterator& iter, const Glib::RefPtr<const type_model> model)
 {
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
 
     group->remove_all_items();
-    for(Gtk::TreeModel::iterator iterChild = row.children().begin(); iterChild != row.children().end(); ++iterChild)
+    for(const auto& child_row : row.children())
     {
-      Gtk::TreeModel::Row row = *iterChild;
-      sharedptr<LayoutItem> item = row[model->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> item = child_row[model->m_columns.m_col_item];
 
       //Recurse:
-      sharedptr<LayoutGroup> child_group = sharedptr<LayoutGroup>::cast_dynamic(item);
+      std::shared_ptr<LayoutGroup> child_group = std::dynamic_pointer_cast<LayoutGroup>(item);
       if(child_group)
-        fill_group_children(child_group, iterChild, model);
+        fill_group_children(child_group, child_row, model);
 
       //std::cout << "debug: " << G_STRFUNC << ": Adding group child: parent part type=" << group->get_part_type_name() << ", child part type=" << item->get_part_type_name() << std::endl;
       group->add_item(item);
@@ -279,30 +278,29 @@ void Dialog_Layout_Report::fill_group_children(const sharedptr<LayoutGroup>& gro
   }
 }
 
-void Dialog_Layout_Report::add_group_children(const Glib::RefPtr<type_model>& model_parts, const Gtk::TreeModel::iterator& parent, const sharedptr<const LayoutGroup>& group)
+void Dialog_Layout_Report::add_group_children(const Glib::RefPtr<type_model>& model_parts, const Gtk::TreeModel::iterator& parent, const std::shared_ptr<const LayoutGroup>& group)
 {
-  for(LayoutGroup::type_list_items::const_iterator iter = group->m_list_items.begin(); iter != group->m_list_items.end(); ++iter)
+  for(const auto& item : group->m_list_items)
   {
-    sharedptr<const LayoutItem> item = *iter;
-    sharedptr<const LayoutGroup> group = sharedptr<const LayoutGroup>::cast_dynamic(item);
-    if(group)
+    std::shared_ptr<const LayoutGroup> child_group = std::dynamic_pointer_cast<const LayoutGroup>(item);
+    if(child_group)
     {
-      sharedptr<const LayoutItem_Header> header = sharedptr<const LayoutItem_Header>::cast_dynamic(item);
-      sharedptr<const LayoutItem_Footer> footer = sharedptr<const LayoutItem_Footer>::cast_dynamic(item);
+      std::shared_ptr<const LayoutItem_Header> header = std::dynamic_pointer_cast<const LayoutItem_Header>(item);
+      std::shared_ptr<const LayoutItem_Footer> footer = std::dynamic_pointer_cast<const LayoutItem_Footer>(item);
 
       //Special-case the header and footer so that their items go into the separate treeviews:
       if(header)
-        add_group_children(m_model_parts_header, parent, group); //Without the Header group being explicitly shown.
+        add_group_children(m_model_parts_header, parent, child_group); //Without the Header group being explicitly shown.
       else if(footer)
-        add_group_children(m_model_parts_footer, parent, group);  //Without the Footer group being explicitly shown.
+        add_group_children(m_model_parts_footer, parent, child_group);  //Without the Footer group being explicitly shown.
       else
       {
-        add_group(model_parts, parent, group);
+        add_group(model_parts, parent, child_group);
       }
     }
     else
     {
-      Gtk::TreeModel::iterator iter = model_parts->append(parent->children());
+      auto iter = model_parts->append(parent->children());
       Gtk::TreeModel::Row row = *iter;
       row[model_parts->m_columns.m_col_item] = glom_sharedptr_clone(item);
     }
@@ -311,7 +309,7 @@ void Dialog_Layout_Report::add_group_children(const Glib::RefPtr<type_model>& mo
   m_modified = true;
 }
 
-void Dialog_Layout_Report::add_group(const Glib::RefPtr<type_model>& model_parts, const Gtk::TreeModel::iterator& parent, const sharedptr<const LayoutGroup>& group)
+void Dialog_Layout_Report::add_group(const Glib::RefPtr<type_model>& model_parts, const Gtk::TreeModel::iterator& parent, const std::shared_ptr<const LayoutGroup>& group)
 {
   Gtk::TreeModel::iterator iterNewItem;
   if(!parent)
@@ -328,7 +326,7 @@ void Dialog_Layout_Report::add_group(const Glib::RefPtr<type_model>& model_parts
   {
     Gtk::TreeModel::Row row = *iterNewItem;
 
-    row[model_parts->m_columns.m_col_item] = sharedptr<LayoutItem>(static_cast<LayoutItem*>(group->clone()));
+    row[model_parts->m_columns.m_col_item] = glom_sharedptr_clone(group);
 
     add_group_children(model_parts, iterNewItem /* parent */, group);
 
@@ -337,12 +335,12 @@ void Dialog_Layout_Report::add_group(const Glib::RefPtr<type_model>& model_parts
 }
 
 //void Dialog_Layout_Report::set_document(const Glib::ustring& layout, Document* document, const Glib::ustring& table_name, const type_vecLayoutFields& table_fields)
-void Dialog_Layout_Report::set_report(const Glib::ustring& table_name, const sharedptr<const Report>& report)
+void Dialog_Layout_Report::set_report(const Glib::ustring& table_name, const std::shared_ptr<const Report>& report)
 {
   m_modified = false;
 
   m_name_original = report->get_name();
-  m_report = sharedptr<Report>(new Report(*report)); //Copy it, so we only use the changes when we want to.
+  m_report = std::make_shared<Report>(*report); //Copy it, so we only use the changes when we want to.
   m_table_name = table_name;
 
   //Dialog_Layout::set_document(layout, document, table_name, table_fields);
@@ -389,14 +387,14 @@ void Dialog_Layout_Report::set_report(const Glib::ustring& table_name, const sha
 
 void Dialog_Layout_Report::enable_buttons()
 {
-  sharedptr<LayoutItem> layout_item_available;
+  std::shared_ptr<LayoutItem> layout_item_available;
   bool enable_add = false;
 
   //Available Parts:
   Glib::RefPtr<Gtk::TreeView::Selection> refSelectionAvailable = m_treeview_available_parts->get_selection();
   if(refSelectionAvailable)
   {
-    Gtk::TreeModel::iterator iter = refSelectionAvailable->get_selected();
+    auto iter = refSelectionAvailable->get_selected();
     if(iter)
     {
       layout_item_available = (*iter)[m_model_available_parts_main->m_columns.m_col_item];
@@ -409,7 +407,7 @@ void Dialog_Layout_Report::enable_buttons()
     }
   }
 
-  sharedptr<LayoutItem> layout_item_parent;
+  std::shared_ptr<LayoutItem> layout_item_parent;
 
   Gtk::TreeView* treeview = get_selected_treeview();
   if(!treeview)
@@ -421,7 +419,7 @@ void Dialog_Layout_Report::enable_buttons()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       layout_item_parent = (*iter)[model->m_columns.m_col_item];
@@ -435,7 +433,7 @@ void Dialog_Layout_Report::enable_buttons()
 
 
       //Disable Down if It can't go any lower.
-      Gtk::TreeModel::iterator iterNext = iter;
+      auto iterNext = iter;
       iterNext++;
 
       bool enable_down = true;
@@ -448,7 +446,7 @@ void Dialog_Layout_Report::enable_buttons()
 
       //The [Formatting] button:
       bool enable_formatting = false;
-      sharedptr<LayoutItem_Field> item_field = sharedptr<LayoutItem_Field>::cast_dynamic(layout_item_parent);
+      std::shared_ptr<LayoutItem_Field> item_field = std::dynamic_pointer_cast<LayoutItem_Field>(layout_item_parent);
       if(item_field)
         enable_formatting = true;
 
@@ -468,15 +466,15 @@ void Dialog_Layout_Report::enable_buttons()
      //Not all parts may be children of all other parts.
     if(layout_item_available && layout_item_parent)
     {
-      const bool may_be_child_of_parent = TreeStore_ReportLayout::may_be_child_of(layout_item_parent, layout_item_available);
+      const auto may_be_child_of_parent = TreeStore_ReportLayout::may_be_child_of(layout_item_parent, layout_item_available);
       enable_add = may_be_child_of_parent;
 
       if(!may_be_child_of_parent)
       {
         //Maybe it can be a sibling of the parent instead (and that's what would happen if Add was clicked).
-        sharedptr<LayoutItem> layout_item_parent_of_parent;
+        std::shared_ptr<LayoutItem> layout_item_parent_of_parent;
 
-        Gtk::TreeModel::iterator iterParent = iter->parent();
+        auto iterParent = iter->parent();
         if(iterParent)
           layout_item_parent_of_parent = (*iterParent)[model->m_columns.m_col_item];
 
@@ -544,7 +542,7 @@ void Dialog_Layout_Report::on_button_delete()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       model->erase(iter);
@@ -565,10 +563,10 @@ void Dialog_Layout_Report::on_button_up()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
-      Gtk::TreeModel::iterator parent = iter->parent();
+      auto parent = iter->parent();
       bool is_first = false;
       if(parent)
         is_first = (iter == parent->children().begin());
@@ -577,7 +575,7 @@ void Dialog_Layout_Report::on_button_up()
 
       if(!is_first)
       {
-        Gtk::TreeModel::iterator iterBefore = iter;
+        auto iterBefore = iter;
         --iterBefore;
 
         model->iter_swap(iter, iterBefore);
@@ -602,13 +600,13 @@ void Dialog_Layout_Report::on_button_down()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = treeview->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
-      Gtk::TreeModel::iterator iterNext = iter;
+      auto iterNext = iter;
       iterNext++;
 
-      Gtk::TreeModel::iterator parent = iter->parent();
+      auto parent = iter->parent();
       bool is_last = false;
       if(parent)
         is_last = (iterNext == parent->children().end());
@@ -638,19 +636,19 @@ void Dialog_Layout_Report::on_button_add()
   Glib::RefPtr<type_model> model = get_selected_model();
   Glib::RefPtr<type_model> model_available = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
 
-  Gtk::TreeModel::iterator parent = get_selected_group_parent();
-  sharedptr<const LayoutItem> pParentPart;
+  auto parent = get_selected_group_parent();
+  std::shared_ptr<const LayoutItem> pParentPart;
   if(parent)
   {
-    sharedptr<LayoutItem> temp = (*parent)[m_model_available_parts_main->m_columns.m_col_item];
+    std::shared_ptr<LayoutItem> temp = (*parent)[m_model_available_parts_main->m_columns.m_col_item];
     pParentPart = temp;
   }
 
-  Gtk::TreeModel::iterator available = get_selected_available();
-  sharedptr<const LayoutItem> pAvailablePart;
+  auto available = get_selected_available();
+  std::shared_ptr<const LayoutItem> pAvailablePart;
   if(available)
   {
-    sharedptr<LayoutItem> temp = (*available)[model_available->m_columns.m_col_item];
+    std::shared_ptr<LayoutItem> temp = (*available)[model_available->m_columns.m_col_item];
     pAvailablePart = temp;
   }
 
@@ -663,7 +661,7 @@ void Dialog_Layout_Report::on_button_add()
     parent = (*parent).parent();
     if(parent)
     {
-      sharedptr<LayoutItem> temp = (*parent)[model_available->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> temp = (*parent)[model_available->m_columns.m_col_item];
       pParentPart = temp;
 
       if(!TreeStore_ReportLayout::may_be_child_of(pParentPart, pAvailablePart))
@@ -683,7 +681,7 @@ void Dialog_Layout_Report::on_button_add()
     else
       iter = model->append();
 
-    (*iter)[model->m_columns.m_col_item] = sharedptr<LayoutItem>(pAvailablePart->clone());
+    (*iter)[model->m_columns.m_col_item] = glom_sharedptr_clone(pAvailablePart);
   }
 
   if(parent)
@@ -693,20 +691,20 @@ void Dialog_Layout_Report::on_button_add()
 }
 
 
-sharedptr<Relationship> Dialog_Layout_Report::offer_relationship_list()
+std::shared_ptr<Relationship> Dialog_Layout_Report::offer_relationship_list()
 {
-  sharedptr<Relationship> result;
+  std::shared_ptr<Relationship> result;
 
-  Dialog_ChooseRelationship* dialog = 0;
+  Dialog_ChooseRelationship* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return result;
 
   dialog->set_document(get_document(), m_table_name);
   dialog->set_transient_for(*this);
-  const int response = dialog->run();
+  const auto dialog_response = dialog->run();
   dialog->hide();
-  if(response == Gtk::RESPONSE_OK)
+  if(dialog_response == Gtk::RESPONSE_OK)
   {
     //Get the chosen relationship:
     result = dialog->get_relationship_chosen();
@@ -733,12 +731,12 @@ Gtk::TreeModel::iterator Dialog_Layout_Report::get_selected_group_parent() const
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem> layout_item = row[model->m_columns.m_col_item];
-      if(sharedptr<LayoutGroup>::cast_dynamic(layout_item))
+      std::shared_ptr<LayoutItem> layout_item = row[model->m_columns.m_col_item];
+      if(std::dynamic_pointer_cast<LayoutGroup>(layout_item))
       {
         //Add a group under this group:
         parent = iter;
@@ -782,16 +780,16 @@ void Dialog_Layout_Report::on_button_formatting()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem> item = row[model->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> item = row[model->m_columns.m_col_item];
 
-      sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
       if(field)
       {
-        sharedptr<LayoutItem_Field> field_chosen = offer_field_formatting(field, m_table_name, this, false /* no editing options */);
+        std::shared_ptr<LayoutItem_Field> field_chosen = offer_field_formatting(field, m_table_name, this, false /* no editing options */);
         if(field_chosen)
         {
           *field = *field_chosen;
@@ -814,29 +812,29 @@ void Dialog_Layout_Report::on_button_edit()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = treeview->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       //Do something different for each type of item:
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem> item = row[model->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> item = row[model->m_columns.m_col_item];
 
-      sharedptr<LayoutItem_FieldSummary> fieldsummary = sharedptr<LayoutItem_FieldSummary>::cast_dynamic(item);
+      std::shared_ptr<LayoutItem_FieldSummary> fieldsummary = std::dynamic_pointer_cast<LayoutItem_FieldSummary>(item);
       if(fieldsummary)
       {
-        Dialog_FieldSummary* dialog = 0;
+        Dialog_FieldSummary* dialog = nullptr;
         Utils::get_glade_widget_derived_with_warning(dialog);
         add_view(dialog);
         dialog->set_item(fieldsummary, m_table_name);
         dialog->set_transient_for(*this);
 
-        const int response = dialog->run();
+        const auto dialog_response = dialog->run();
         dialog->hide();
 
-        if(response == Gtk::RESPONSE_OK)
+        if(dialog_response == Gtk::RESPONSE_OK)
         {
           //Get the chosen relationship:
-          sharedptr<LayoutItem_FieldSummary> chosenitem = dialog->get_item();
+          std::shared_ptr<LayoutItem_FieldSummary> chosenitem = dialog->get_item();
           if(chosenitem)
           {
             *fieldsummary = *chosenitem; //TODO_Performance.
@@ -851,10 +849,10 @@ void Dialog_Layout_Report::on_button_edit()
       }
       else
       {
-        sharedptr<LayoutItem_Field> field = sharedptr<LayoutItem_Field>::cast_dynamic(item);
+        std::shared_ptr<LayoutItem_Field> field = std::dynamic_pointer_cast<LayoutItem_Field>(item);
         if(field)
         {
-          sharedptr<LayoutItem_Field> chosenitem = offer_field_list_select_one_field(field, m_table_name, this);
+          std::shared_ptr<LayoutItem_Field> chosenitem = offer_field_list_select_one_field(field, m_table_name, this);
           if(chosenitem)
           {
             *field = *chosenitem; //TODO_Performance.
@@ -864,10 +862,10 @@ void Dialog_Layout_Report::on_button_edit()
         }
         else
         {
-          sharedptr<LayoutItem_Text> layout_item_text = sharedptr<LayoutItem_Text>::cast_dynamic(item);
+          std::shared_ptr<LayoutItem_Text> layout_item_text = std::dynamic_pointer_cast<LayoutItem_Text>(item);
           if(layout_item_text)
           {
-            sharedptr<LayoutItem_Text> chosen = offer_textobject(layout_item_text);
+            std::shared_ptr<LayoutItem_Text> chosen = offer_textobject(layout_item_text);
             if(chosen)
             {
               *layout_item_text = *chosen;
@@ -877,10 +875,10 @@ void Dialog_Layout_Report::on_button_edit()
           }
           else
           {
-            sharedptr<LayoutItem_Image> layout_item_image = sharedptr<LayoutItem_Image>::cast_dynamic(item);
+            std::shared_ptr<LayoutItem_Image> layout_item_image = std::dynamic_pointer_cast<LayoutItem_Image>(item);
             if(layout_item_image)
             {
-              sharedptr<LayoutItem_Image> chosen = offer_imageobject(layout_item_image);
+              std::shared_ptr<LayoutItem_Image> chosen = offer_imageobject(layout_item_image);
               if(chosen)
               {
                 *layout_item_image = *chosen;
@@ -890,10 +888,10 @@ void Dialog_Layout_Report::on_button_edit()
             }
             else
             {
-              sharedptr<LayoutItem_GroupBy> group_by = sharedptr<LayoutItem_GroupBy>::cast_dynamic(item);
+              std::shared_ptr<LayoutItem_GroupBy> group_by = std::dynamic_pointer_cast<LayoutItem_GroupBy>(item);
               if(group_by)
               {
-                Dialog_GroupBy* dialog = 0;
+                Dialog_GroupBy* dialog = nullptr;
                 Utils::get_glade_widget_derived_with_warning(dialog);
                 if(!dialog)
                   return;
@@ -902,13 +900,13 @@ void Dialog_Layout_Report::on_button_edit()
                 dialog->set_item(group_by, m_table_name);
                 dialog->set_transient_for(*this);
 
-                const int response = dialog->run();
+                const auto dialog_response = dialog->run();
                 dialog->hide();
 
-                if(response == Gtk::RESPONSE_OK)
+                if(dialog_response == Gtk::RESPONSE_OK)
                 {
                   //Get the chosen relationship:
-                  sharedptr<LayoutItem_GroupBy> chosenitem = dialog->get_item();
+                  std::shared_ptr<LayoutItem_GroupBy> chosenitem = dialog->get_item();
                   if(chosenitem)
                   {
                     *group_by = *chosenitem;
@@ -955,8 +953,8 @@ void Dialog_Layout_Report::on_cell_data_part(Gtk::CellRenderer* renderer, const
     {
       Gtk::TreeModel::Row row = *iter;
 
-      sharedptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
-      const Glib::ustring part = pItem->get_part_type_name();
+      std::shared_ptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
+      const auto part = pItem->get_part_type_name();
 
       renderer_text->property_text() = part;
       renderer_text->property_editable() = false; //Part names can never be edited.
@@ -975,7 +973,7 @@ void Dialog_Layout_Report::on_cell_data_details(Gtk::CellRenderer* renderer, con
       Glib::ustring text;
 
       Gtk::TreeModel::Row row = *iter;
-      sharedptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
       renderer_text->property_text() = pItem->get_layout_display_name();
       renderer_text->property_editable() = false;
     }
@@ -995,7 +993,7 @@ void Dialog_Layout_Report::on_cell_data_available_part(Gtk::CellRenderer* render
     {
       Gtk::TreeModel::Row row = *iter;
       Glib::RefPtr<type_model> model = Glib::RefPtr<type_model>::cast_dynamic(m_treeview_available_parts->get_model());
-      sharedptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> pItem = row[model->m_columns.m_col_item];
       Glib::ustring part = pItem->get_part_type_name();
 
       renderer_text->property_text() = part;
@@ -1009,25 +1007,25 @@ Glib::ustring Dialog_Layout_Report::get_original_report_name() const
   return m_name_original;
 }
 
-sharedptr<Report> Dialog_Layout_Report::get_report()
+std::shared_ptr<Report> Dialog_Layout_Report::get_report()
 {
   m_report->set_name( m_entry_name->get_text() );
   m_report->set_title( m_entry_title->get_text() , AppWindow::get_current_locale());
   m_report->set_show_table_title( m_checkbutton_table_title->get_active() );
 
-  sharedptr<LayoutGroup> group = m_report->get_layout_group();
+  std::shared_ptr<LayoutGroup> group = m_report->get_layout_group();
   group->remove_all_items();
 
   //The Header and Footer parts are implicit (they are the whole header or footer treeview)
-  sharedptr<LayoutItem_Header> header = sharedptr<LayoutItem_Header>::create();
-  sharedptr<LayoutGroup> group_temp = header;
+  std::shared_ptr<LayoutItem_Header> header = std::make_shared<LayoutItem_Header>();
+  std::shared_ptr<LayoutGroup> group_temp = header;
   fill_report_parts(group_temp, m_model_parts_header);
   if(header->get_items_count())
     group->add_item(header);
 
   fill_report_parts(group, m_model_parts_main);
 
-  sharedptr<LayoutItem_Footer> footer = sharedptr<LayoutItem_Footer>::create();
+  std::shared_ptr<LayoutItem_Footer> footer = std::make_shared<LayoutItem_Footer>();
   group_temp = footer;
   fill_report_parts(group_temp, m_model_parts_footer);
   if(footer->get_items_count())
@@ -1036,12 +1034,12 @@ sharedptr<Report> Dialog_Layout_Report::get_report()
   return m_report;
 }
 
-void Dialog_Layout_Report::fill_report_parts(sharedptr<LayoutGroup>& group, const Glib::RefPtr<const type_model> parts_model)
+void Dialog_Layout_Report::fill_report_parts(std::shared_ptr<LayoutGroup>& group, const Glib::RefPtr<const type_model> parts_model)
 {
-  for(Gtk::TreeModel::iterator iter = parts_model->children().begin(); iter != parts_model->children().end(); ++iter)
+  for(const auto& row : parts_model->children())
   {
     //Recurse into a group if necessary:
-    sharedptr<LayoutGroup> group_child = fill_group(iter, parts_model);
+    std::shared_ptr<LayoutGroup> group_child = fill_group(row, parts_model);
     if(group_child)
     {
       //Add the group:
@@ -1049,7 +1047,7 @@ void Dialog_Layout_Report::fill_report_parts(sharedptr<LayoutGroup>& group, cons
     }
     else
     {
-      sharedptr<LayoutItem> item = (*iter)[parts_model->m_columns.m_col_item];
+      std::shared_ptr<LayoutItem> item = row[parts_model->m_columns.m_col_item];
       if(item)
       {
         group->add_item(item);
