@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "combobox_locale.h"
@@ -32,13 +32,11 @@ ComboBox_Locale::ComboBox_Locale(BaseObjectType* cobject, const Glib::RefPtr<Gtk
   m_model = Gtk::ListStore::create(m_model_columns);
 
   //Fill the model:
-  const IsoCodes::type_list_locales list_locales = IsoCodes::get_list_of_locales();
-  for(IsoCodes::type_list_locales::const_iterator iter = list_locales.begin(); iter != list_locales.end(); ++iter)
+  for(const auto& the_locale : IsoCodes::get_list_of_locales())
   {
-    Gtk::TreeModel::iterator tree_iter = m_model->append();
+    auto tree_iter = m_model->append();
     Gtk::TreeModel::Row row = *tree_iter;
 
-    const IsoCodes::Locale& the_locale = *iter;
     row[m_model_columns.m_identifier] = the_locale.m_identifier;
     row[m_model_columns.m_name] = the_locale.m_name;
   }
@@ -65,7 +63,7 @@ ComboBox_Locale::~ComboBox_Locale()
 
 Glib::ustring ComboBox_Locale::get_selected_locale() const
 {
-  Gtk::TreeModel::iterator iter = get_active();
+  auto iter = get_active();
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
@@ -81,14 +79,14 @@ void ComboBox_Locale::set_selected_locale(const Glib::ustring& locale)
   Glib::RefPtr<Gtk::TreeModel> model = get_model();
   if(model)
   {
-    for(Gtk::TreeModel::iterator iter = model->children().begin(); iter != model->children().end(); ++iter)
+    for(const auto& row : model->children())
     {
-      const Glib::ustring& this_text = (*iter)[m_model_columns.m_identifier];
+      const Glib::ustring& this_text = row[m_model_columns.m_identifier];
       //std::cout << G_STRFUNC << ": DEBUG: locale=" << locale << ", this_text=" << this_text << "." << std::endl;
  
       if(this_text == locale)
       {
-        set_active(iter);
+        set_active(row);
         return; //success
       }
     }
@@ -101,7 +99,6 @@ void ComboBox_Locale::set_selected_locale(const Glib::ustring& locale)
     std::cerr << G_STRFUNC << ": locale not found in list: " << locale << ". The model is empty." << std::endl;
   }
 
-  std::cerr << "ComboBox_Locale::set_selected_locale(): locale not found in list: " << locale << std::endl;
   unset_active();
 }
 
