@@ -39,10 +39,10 @@ const bool Dialog_GroupsList::glade_developer(true);
 
 Dialog_GroupsList::Dialog_GroupsList(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_treeview_groups(0),
-  m_button_group_new(0),
-  m_button_group_delete(0),
-  m_button_group_users(0)
+  m_treeview_groups(nullptr),
+  m_button_group_new(nullptr),
+  m_button_group_delete(nullptr),
+  m_button_group_users(nullptr)
 {
   //set_default_size(600, -1);
 
@@ -142,10 +142,8 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document* docu
       group.m_columns_count = 2;
 
       guint field_sequence = 1; //0 means no sequence
-      for(type_vecLayoutFields::const_iterator iter = table_fields.begin(); iter != table_fields.end(); ++iter)
+      for(const auto& item : table_fields)
       {
-        LayoutItem_Field item = *iter;
-
         group.add_item(item);
 
         ++field_sequence;
@@ -159,9 +157,9 @@ void Dialog_GroupsList::set_document(const Glib::ustring& layout, Document* docu
 
     m_model_groups->clear();
 
-    for(Document::type_list_layout_groups::const_iterator iter = mapGroups.begin(); iter != mapGroups.end(); ++iter)
+    for(const auto& the_pair : mapGroups)
     {
-      sharedptr<const LayoutGroup> group = iter->second;
+      std::shared_ptr<const LayoutGroup> group = the_pairsecond;
 
       add_group(Gtk::TreeModel::iterator(), group);
     }
@@ -185,7 +183,7 @@ void Dialog_GroupsList::enable_buttons()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       m_button_group_users->set_sensitive(true);
@@ -206,7 +204,7 @@ void Dialog_GroupsList::on_button_group_delete()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_groups->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
@@ -219,13 +217,13 @@ void Dialog_GroupsList::on_button_group_delete()
         dialog.set_secondary_text(_("Are your sure that you wish to delete this group?"));
         dialog.set_transient_for(*this);
 
-        int response = dialog.run();
+        int dialog_response = dialog.run();
         dialog.hide();
 
-        if(response == Gtk::RESPONSE_OK)
+        if(dialog_response == Gtk::RESPONSE_OK)
         {
           const Glib::ustring strQuery = "DROP GROUP " + DbUtils::escape_sql_id(group);
-          const bool test = DbUtils::query_execute_string(strQuery);
+          const auto test = DbUtils::query_execute_string(strQuery);
           if(!test)
             std::cerr << G_STRFUNC << ": DROP GROUP failed." << std::endl;
 
@@ -240,19 +238,19 @@ void Dialog_GroupsList::on_button_group_delete()
 
 void Dialog_GroupsList::on_button_group_new()
 {
-  Dialog_NewGroup* dialog = 0;
+  Dialog_NewGroup* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
     
   dialog->set_transient_for(*this);
-  const int response = Glom::UiUtils::dialog_run_with_help(dialog);
+  const auto dialog_response = Glom::UiUtils::dialog_run_with_help(dialog);
 
-  const Glib::ustring group_name = dialog->m_entry_name->get_text();
+  const auto group_name = dialog->m_entry_name->get_text();
 
   delete dialog;
 
-  if(response != Gtk::RESPONSE_OK)
+  if(dialog_response != Gtk::RESPONSE_OK)
     return;
 
   if(group_name.empty())
@@ -276,13 +274,13 @@ void Dialog_GroupsList::on_button_group_users()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_groups->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
       const Glib::ustring group_name = row[m_model_columns_groups.m_col_name];
 
-      Dialog_UsersList* dialog = 0;
+      Dialog_UsersList* dialog = nullptr;
       Utils::get_glade_widget_derived_with_warning(dialog);
       if(!dialog) //Unlikely and it already warns on stderr.
         return;
@@ -323,7 +321,7 @@ Glib::ustring Dialog_GroupsList::get_selected_group() const
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
@@ -337,7 +335,7 @@ Glib::ustring Dialog_GroupsList::get_selected_group() const
 void Dialog_GroupsList::on_treeview_groups_selection_changed()
 {
   //Update the tables list for the currently-selected group:
-  const Glib::ustring group_name = get_selected_group();
+  const auto group_name = get_selected_group();
   if(!group_name.empty()) //This can happen when clearing the list, just before filling it, so something real can be selected.
     fill_table_list(group_name);
 
@@ -349,15 +347,14 @@ void Dialog_GroupsList::fill_group_list()
   //Fill the model rows:
   m_model_groups->clear();
 
-  type_vec_strings group_list = Privs::get_database_groups();
-  for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
+  for(const auto& group : Privs::get_database_groups())
   {
-    Gtk::TreeModel::iterator iterTree = m_model_groups->append();
+    auto iterTree = m_model_groups->append();
     Gtk::TreeModel::Row row = *iterTree;
 
-    row[m_model_columns_groups.m_col_name] = *iter;
+    row[m_model_columns_groups.m_col_name] = group;
 
-    if(*iter == GLOM_STANDARD_GROUP_NAME_DEVELOPER)
+    if(group == GLOM_STANDARD_GROUP_NAME_DEVELOPER)
       row[m_model_columns_groups.m_col_description] = _("Full access.");
   }
 
@@ -367,7 +364,7 @@ void Dialog_GroupsList::fill_group_list()
     Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_groups->get_selection();
     if(refSelection)
     {
-      Gtk::TreeModel::iterator iterFirst = m_model_groups->children().begin();
+      auto iterFirst = m_model_groups->children().begin();
       if(iterFirst)
       {
         refSelection->select(iterFirst);
@@ -386,7 +383,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
   //Fill the model rows:
   m_model_tables->clear();
 
-  Document* pDocument = get_document();
+ Document* pDocument = get_document();
   if(pDocument)
   {
     // Make sure that these are in the document,
@@ -396,17 +393,17 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
 
     Document::type_listTableInfo table_list = pDocument->get_tables(true /* plus system prefs */);
 
-    for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
+    for(const auto& table : table_list)
     {
-      Gtk::TreeModel::iterator iterTree = m_model_tables->append();
+      auto iterTree = m_model_tables->append();
       Gtk::TreeModel::Row row = *iterTree;
 
-      const Glib::ustring table_name = (*iter)->get_name();
+      const auto table_name = table->get_name();
 
       row[m_model_columns_tables.m_col_name] = table_name;
-      row[m_model_columns_tables.m_col_title] = item_get_title_or_name(*iter);
+      row[m_model_columns_tables.m_col_title] = item_get_title_or_name(table);
 
-      const Privileges privs = Privs::get_table_privileges(group_name, table_name);
+      const auto privs = Privs::get_table_privileges(group_name, table_name);
       row[m_model_columns_tables.m_col_view] = privs.m_view;
       row[m_model_columns_tables.m_col_edit] = privs.m_edit;
       row[m_model_columns_tables.m_col_create] = privs.m_create;
@@ -416,7 +413,7 @@ void Dialog_GroupsList::fill_table_list(const Glib::ustring& group_name)
       group_info.m_map_privileges[table_name] = privs;
     }
 
-     pDocument->set_group(group_info);
+    pDocument->set_group(group_info);
   }
 }
 
@@ -485,7 +482,7 @@ bool Dialog_GroupsList::set_table_privilege(const Glib::ustring& table_name, con
 
   strQuery += " GROUP " + DbUtils::escape_sql_id(group_name);
 
-  const bool test = DbUtils::query_execute_string(strQuery); //TODO: Handle errors.
+  const auto test = DbUtils::query_execute_string(strQuery); //TODO: Handle errors.
   if(!test)
     std::cerr << G_STRFUNC << ": GRANT/REVOKE failed." << std::endl;
 
@@ -497,7 +494,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_view(const Glib::ustring& pat
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
+  auto iter = m_model_tables->get_iter(path);
   if(iter)
   {
     Gtk::TreeRow row = *iter;
@@ -506,26 +503,22 @@ void Dialog_GroupsList::on_treeview_tables_toggled_view(const Glib::ustring& pat
     bool bActive = row[m_model_columns_tables.m_col_view];
     bActive = !bActive;
 
-    const Glib::ustring group_name = get_selected_group();
+    const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    bool test = set_table_privilege(table_name, group_name, bActive, PRIV_VIEW);
-    if(test)
+    if(set_table_privilege(table_name, group_name, bActive, PRIV_VIEW))
       row[m_model_columns_tables.m_col_view] = bActive;
 
     //If the group cannot view, then it should not do anything else either:
     if(!bActive)
     {
-      bool test = set_table_privilege(table_name, group_name, bActive, PRIV_EDIT);
-      if(test)
+     if(set_table_privilege(table_name, group_name, bActive, PRIV_EDIT))
         row[m_model_columns_tables.m_col_edit] = false;
 
-      test = set_table_privilege(table_name, group_name, bActive, PRIV_CREATE);
-      if(test)
+      if(set_table_privilege(table_name, group_name, bActive, PRIV_CREATE))
         row[m_model_columns_tables.m_col_create] = false;
 
-      test = set_table_privilege(table_name, group_name, bActive, PRIV_DELETE);
-      if(test)
+      if(set_table_privilege(table_name, group_name, bActive, PRIV_DELETE))
         row[m_model_columns_tables.m_col_delete] = false;
     }
   }
@@ -536,7 +529,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_edit(const Glib::ustring& pat
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
+  auto iter = m_model_tables->get_iter(path);
   if(iter)
   {
     Gtk::TreeRow row = *iter;
@@ -545,7 +538,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_edit(const Glib::ustring& pat
     bool bActive = row[m_model_columns_tables.m_col_edit];
     bActive = !bActive;
 
-    const Glib::ustring group_name = get_selected_group();
+    const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
     bool test = set_table_privilege(table_name, group_name, bActive, PRIV_EDIT);
@@ -560,7 +553,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_create(const Glib::ustring& p
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
+  auto iter = m_model_tables->get_iter(path);
   if(iter)
   {
     Gtk::TreeRow row = *iter;
@@ -569,10 +562,10 @@ void Dialog_GroupsList::on_treeview_tables_toggled_create(const Glib::ustring& p
     bool bActive = row[m_model_columns_tables.m_col_create];
     bActive = !bActive;
 
-    const Glib::ustring group_name = get_selected_group();
+    const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    const bool test = set_table_privilege(table_name, group_name, bActive, PRIV_CREATE);
+    const auto test = set_table_privilege(table_name, group_name, bActive, PRIV_CREATE);
 
     if(test)
       row[m_model_columns_tables.m_col_create] = bActive;
@@ -584,7 +577,7 @@ void Dialog_GroupsList::on_treeview_tables_toggled_delete(const Glib::ustring& p
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_model_tables->get_iter(path);
+  auto iter = m_model_tables->get_iter(path);
   if(iter)
   {
     Gtk::TreeRow row = *iter;
@@ -593,10 +586,10 @@ void Dialog_GroupsList::on_treeview_tables_toggled_delete(const Glib::ustring& p
     bool bActive = row[m_model_columns_tables.m_col_delete];
     bActive = !bActive;
 
-    const Glib::ustring group_name = get_selected_group();
+    const auto group_name = get_selected_group();
     const Glib::ustring table_name = row[m_model_columns_tables.m_col_name];
 
-    const bool test = set_table_privilege(table_name, group_name, bActive, PRIV_DELETE);
+    const auto test = set_table_privilege(table_name, group_name, bActive, PRIV_DELETE);
 
     if(test)
       row[m_model_columns_tables.m_col_delete] = bActive;
