@@ -36,13 +36,13 @@ const bool Dialog_UsersList::glade_developer(true);
 
 Dialog_UsersList::Dialog_UsersList(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Gtk::Dialog(cobject),
-  m_treeview_users(0),
-  m_combo_group(0),
-  m_button_user_add(0),
-  m_button_user_remove(0),
-  m_button_user_new(0),
-  m_button_user_delete(0),
-  m_button_user_edit(0)
+  m_treeview_users(nullptr),
+  m_combo_group(nullptr),
+  m_button_user_add(nullptr),
+  m_button_user_remove(nullptr),
+  m_button_user_new(nullptr),
+  m_button_user_delete(nullptr),
+  m_button_user_edit(nullptr)
 {
   builder->get_widget("combobox_group", m_combo_group);
   m_combo_group->signal_changed().connect(sigc::mem_fun(*this, &Dialog_UsersList::on_combo_group_changed));
@@ -100,7 +100,7 @@ void Dialog_UsersList::enable_buttons()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_treeview_users->get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       m_button_user_edit->set_sensitive(true);
@@ -121,7 +121,7 @@ void Dialog_UsersList::on_button_user_remove()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_users->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       if(warn_about_empty_standard_group())
@@ -148,7 +148,7 @@ void Dialog_UsersList::on_button_user_delete()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_users->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       if(warn_about_empty_standard_group())
@@ -162,10 +162,10 @@ void Dialog_UsersList::on_button_user_delete()
           dialog.set_secondary_text(_("Are your sure that you wish to delete this user?"));
           dialog.set_transient_for(*this);
 
-          const int response = dialog.run();
+          const auto dialog_response = dialog.run();
           dialog.hide();
 
-          if(response == Gtk::RESPONSE_OK)
+          if(dialog_response == Gtk::RESPONSE_OK)
           {
             DbUtils::remove_user(user); //TODO: Warn about failure when this returns false?
             fill_list();
@@ -181,7 +181,7 @@ void Dialog_UsersList::on_button_user_delete()
 void Dialog_UsersList::on_button_user_add()
 {
   //Fill it with the list of users:
-  const Privs::type_vec_strings users = Privs::get_database_users();
+  const auto users = Privs::get_database_users();
   if(users.empty())
   {
     UiUtils::show_ok_dialog(_("Error Retrieving the List of Users"),
@@ -189,7 +189,7 @@ void Dialog_UsersList::on_button_user_add()
     return;
   }
 
-  Dialog_ChooseUser* dialog = 0;
+  Dialog_ChooseUser* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
@@ -198,32 +198,29 @@ void Dialog_UsersList::on_button_user_add()
 
   dialog->set_user_list(users);
 
-  const int response = Glom::UiUtils::dialog_run_with_help(dialog);
+  const auto dialog_response = Glom::UiUtils::dialog_run_with_help(dialog);
 
-  const Glib::ustring user = dialog->get_user();
+  const auto user = dialog->get_user();
 
   delete dialog;
 
-  if(response != Gtk::RESPONSE_OK)
+  if(dialog_response != Gtk::RESPONSE_OK)
     return;
 
   if(!user.empty())
   {
     //Add it to the group:
-    const Glib::ustring strQuery = DbUtils::build_query_add_user_to_group(m_combo_group->get_active_text(), user);
-    const bool test = DbUtils::query_execute_string(strQuery);
-    if(!test)
+    const auto query_add_user = DbUtils::build_query_add_user_to_group(m_combo_group->get_active_text(), user);
+    if(!DbUtils::query_execute_string(query_add_user))
       std::cerr << G_STRFUNC << ": ALTER GROUP failed." << std::endl;
 
     //Remove any user rights, so that all rights come from the user's presence in the group:
-    Document::type_listTableInfo table_list = get_document()->get_tables();
-
-    for(Document::type_listTableInfo::const_iterator iter = table_list.begin(); iter != table_list.end(); ++iter)
+    const auto document = get_document();
+    for(const auto& table : document->get_tables())
     {
-      const Glib::ustring table_name = (*iter)->get_name();
-      const Glib::ustring strQuery = "REVOKE ALL PRIVILEGES ON " + DbUtils::escape_sql_id(table_name) + " FROM " + DbUtils::escape_sql_id(user);
-      const bool test = DbUtils::query_execute_string(strQuery);
-      if(!test)
+      const auto table_name = table->get_name();
+      const Glib::ustring query_revoke = "REVOKE ALL PRIVILEGES ON " + DbUtils::escape_sql_id(table_name) + " FROM " + DbUtils::escape_sql_id(user);
+      if(!DbUtils::query_execute_string(query_revoke))
         std::cerr << G_STRFUNC << ": REVOKE failed." << std::endl;
     }
 
@@ -233,7 +230,7 @@ void Dialog_UsersList::on_button_user_add()
 
 void Dialog_UsersList::on_button_user_new()
 {
-  Dialog_User* dialog = 0;
+  Dialog_User* dialog = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog);
   if(!dialog) //Unlikely and it already warns on stderr.
     return;
@@ -241,16 +238,16 @@ void Dialog_UsersList::on_button_user_new()
   dialog->set_transient_for(*this);
   dialog->m_combo_group->set_sensitive(false); //It is being added to the current group, so don't offer a different group.
  
-  int response = Gtk::RESPONSE_OK;
+  int dialog_response = Gtk::RESPONSE_OK;
   bool keep_trying = true;
   while(keep_trying)
   {
-    response = Glom::UiUtils::dialog_run_with_help(dialog);
+    dialog_response = Glom::UiUtils::dialog_run_with_help(dialog);
 
     //Check the password is acceptable:
-    if(response == Gtk::RESPONSE_OK)
+    if(dialog_response == Gtk::RESPONSE_OK)
     {
-      const bool password_ok = dialog->check_password();
+      const auto password_ok = dialog->check_password();
       if(password_ok)
         keep_trying = false;
     }
@@ -258,12 +255,12 @@ void Dialog_UsersList::on_button_user_new()
       keep_trying = false;
   }
 
-  const Glib::ustring user = dialog->m_entry_user->get_text();
-  const Glib::ustring password = dialog->m_entry_password->get_text();
+  const auto user = dialog->m_entry_user->get_text();
+  const auto password = dialog->m_entry_password->get_text();
 
   delete dialog;
 
-  if(response != Gtk::RESPONSE_OK)
+  if(dialog_response != Gtk::RESPONSE_OK)
     return;
 
   if(!DbUtils::add_user(get_document(), user, password, m_combo_group->get_active_text() /* group */))
@@ -280,12 +277,12 @@ void Dialog_UsersList::on_button_user_edit()
   Glib::RefPtr<Gtk::TreeSelection> refTreeSelection = m_treeview_users->get_selection();
   if(refTreeSelection)
   {
-    Gtk::TreeModel::iterator iter = refTreeSelection->get_selected();
+    auto iter = refTreeSelection->get_selected();
     if(iter)
     {
       Gtk::TreeModel::Row row = *iter;
 
-      Dialog_User* dialog = 0;
+      Dialog_User* dialog = nullptr;
       Utils::get_glade_widget_derived_with_warning(dialog);
       if(!dialog) //Unlikely and it already warns on stderr.
         return;
@@ -300,25 +297,25 @@ void Dialog_UsersList::on_button_user_edit()
       dialog->m_combo_group->remove_all();
 
       type_vec_strings group_list = Privs::get_database_groups();
-      for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
+      for(const auto& group : group_list)
       {
-         dialog->m_combo_group->append(*iter);
+         dialog->m_combo_group->append(group);
       }
 
       dialog->m_combo_group->set_active_text(m_combo_group->get_active_text());
       dialog->m_combo_group->set_sensitive(false); //TODO: Allow, and handle, changes to this.
 
 
-      int response = Gtk::RESPONSE_OK;
+      int dialog_response = Gtk::RESPONSE_OK;
       bool keep_trying = true;
       while(keep_trying)
       {
-        response = Glom::UiUtils::dialog_run_with_help(dialog);
+        dialog_response = Glom::UiUtils::dialog_run_with_help(dialog);
 
         //Check the password is acceptable:
-        if(response == Gtk::RESPONSE_OK)
+        if(dialog_response == Gtk::RESPONSE_OK)
         {
-          const bool password_ok = dialog->check_password();
+          const auto password_ok = dialog->check_password();
           if(password_ok)
             keep_trying = false;
         }
@@ -326,12 +323,12 @@ void Dialog_UsersList::on_button_user_edit()
           keep_trying = false;
       }
 
-      const Glib::ustring user = dialog->m_entry_user->get_text();
-      const Glib::ustring password = dialog->m_entry_password->get_text();
+      const auto user = dialog->m_entry_user->get_text();
+      const auto password = dialog->m_entry_password->get_text();
 
       delete dialog;
 
-      if(response != Gtk::RESPONSE_OK)
+      if(dialog_response != Gtk::RESPONSE_OK)
         return;
 
       if(!user.empty() && !password.empty())
@@ -339,7 +336,7 @@ void Dialog_UsersList::on_button_user_edit()
         //TODO: Can this change the username too?
         //Note: If using MySQL, we need MySQL 5.6.7 for ALTER USER:
         const Glib::ustring strQuery = "ALTER USER " + DbUtils::escape_sql_id(user) + " PASSWORD '" + password + "'" ; //TODO: Escape the password.
-        const bool test = DbUtils::query_execute_string(strQuery);
+        const auto test = DbUtils::query_execute_string(strQuery);
         if(!test)
           std::cerr << G_STRFUNC << ": ALTER USER failed." << std::endl;
 
@@ -377,14 +374,14 @@ void Dialog_UsersList::fill_list()
 
   if(m_combo_group)
   {
-    const Glib::ustring group_name = m_combo_group->get_active_text();
-    const type_vec_strings user_list = Privs::get_database_users(group_name);
-    for(type_vec_strings::const_iterator iter = user_list.begin(); iter != user_list.end(); ++iter)
+    const auto group_name = m_combo_group->get_active_text();
+    const auto user_list = Privs::get_database_users(group_name);
+    for(const auto& user : user_list)
     {
-      Gtk::TreeModel::iterator iterTree = m_model_users->append();
+      auto iterTree = m_model_users->append();
       Gtk::TreeModel::Row row = *iterTree;
 
-      row[m_model_columns_users.m_col_name] = Privs::get_user_visible_group_name(*iter);
+      row[m_model_columns_users.m_col_name] = Privs::get_user_visible_group_name(user);
     }
   }
 }
@@ -395,9 +392,9 @@ void Dialog_UsersList::set_group(const Glib::ustring& group_name)
   m_combo_group->remove_all();
 
   type_vec_strings group_list = Privs::get_database_groups();
-  for(type_vec_strings::const_iterator iter = group_list.begin(); iter != group_list.end(); ++iter)
+  for(const auto& group : group_list)
   {
-    m_combo_group->append(*iter);
+    m_combo_group->append(group);
   }
 
   m_combo_group->set_active_text(group_name);
