@@ -55,7 +55,7 @@ bool Box_Data_List_Find::fill_from_database()
 {
   BusyCursor busy_cursor(get_app_window());
 
-  const bool result = Base_DB_Table_Data::fill_from_database();
+  const auto result = Base_DB_Table_Data::fill_from_database();
   if(!result)
     return false;
 
