@@ -34,7 +34,7 @@ const bool Box_Tables::glade_developer(false);
 
 Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& builder)
 : Box_WithButtons(cobject, builder),
-  m_pCheckButtonShowHidden(0),
+  m_pCheckButtonShowHidden(nullptr),
   m_colTableName(0),
   m_colHidden(0),
   m_colTitle(0),
@@ -42,14 +42,14 @@ Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>
   m_colTitleSingular(0)
 {
   //Get the Glade-instantiated widgets, and connect signal handlers:
-  Gtk::Button* pButtonCancel = 0;
+  Gtk::Button* pButtonCancel = nullptr;
   builder->get_widget("button_cancel_tables", pButtonCancel);
   set_button_cancel(*pButtonCancel);
 
   // Set a name for the AddDel TreeView, so it can be accessed by LDTP
   m_AddDel.set_treeview_accessible_name("Tables");
 
-  Gtk::Box* pAddDelParent = 0;
+  Gtk::Box* pAddDelParent = nullptr;
   builder->get_widget("vbox_adddel_parent", pAddDelParent);
   pAddDelParent->pack_start(m_AddDel);
 
@@ -70,7 +70,7 @@ Box_Tables::~Box_Tables()
 {
 }
 
-void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const sharedptr<const TableInfo>& table_info)
+void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const std::shared_ptr<const TableInfo>& table_info)
 {
   if(!table_info)
   {
@@ -80,7 +80,7 @@ void Box_Tables::fill_table_row(const Gtk::TreeModel::iterator& iter, const shar
   
   if(iter)
   {
-    const bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
+    const auto developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
 
     m_AddDel.set_value_key(iter, table_info->get_name());
     m_AddDel.set_value(iter, m_colTableName, table_info->get_name());
@@ -109,7 +109,7 @@ bool Box_Tables::fill_from_database()
   bool result = Base_DB::fill_from_database();
 
   //Enable/Disable extra widgets:
-  const bool developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
+  const auto developer_mode = (get_userlevel() == AppState::USERLEVEL_DEVELOPER);
 
   //Developers see more columns, so make it bigger:
   if(developer_mode)
@@ -153,20 +153,18 @@ bool Box_Tables::fill_from_database()
     std::cerr << G_STRFUNC << ": document is null" << std::endl;
 
   //Get the list of tables in the database, from the server:
-  sharedptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
+  std::shared_ptr<SharedConnection> sharedconnection = connect_to_server(AppWindow::get_appwindow());
 
   if(sharedconnection)
   {
     m_AddDel.remove_all();
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
-    const type_vec_strings vecTables = DbUtils::get_table_names_from_database();
+    const auto vecTables = DbUtils::get_table_names_from_database();
 
-    for(type_vec_strings::const_iterator iter = vecTables.begin(); iter != vecTables.end(); ++iter)
+    for(const auto& strName : vecTables)
     {
-      const Glib::ustring strName = *iter;
-
-      sharedptr<TableInfo> table_info;
+      std::shared_ptr<TableInfo> table_info;
 
       //Check whether it should be hidden:
       Document::type_listTableInfo::const_iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
@@ -180,12 +178,12 @@ bool Box_Tables::fill_from_database()
       {
         //This table is in the database, but not in the document.
         //Show it as hidden:
-        table_info = sharedptr<TableInfo>(new TableInfo());
+        table_info = std::make_shared<TableInfo>();
         table_info->set_name(strName);
         table_info->set_hidden(true);
       }
 
-      const bool hidden = table_info->get_hidden();
+      const auto hidden = table_info->get_hidden();
 
       bool bAddIt = true;
       if(hidden && !developer_mode) //Don't add hidden tables unless we are in developer mode:
@@ -198,13 +196,13 @@ bool Box_Tables::fill_from_database()
 
       //Check whether it's a system table, though they should never be in this list:
       const Glib::ustring prefix = "glom_system_";
-      const Glib::ustring table_prefix = strName.substr(0, prefix.size());
+      const auto table_prefix = strName.substr(0, prefix.size());
       if(table_prefix == prefix)
         bAddIt = false;
 
       if(bAddIt)
       {
-        Gtk::TreeModel::iterator iter = m_AddDel.add_item(strName);
+        auto iter = m_AddDel.add_item(strName);
         fill_table_row(iter, table_info);
       }
     }
@@ -221,14 +219,14 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 {
   //TODO: Handle cell renderer changes to prevent illegal table names (e.g. starting with numbers.).
 
-  const Glib::ustring table_name = m_AddDel.get_value(row, m_colTableName);
+  const auto table_name = m_AddDel.get_value(row, m_colTableName);
   if(table_name.empty())
     return;
 
   bool created = false; 
 
   //Check whether it exists already. (Maybe it is somehow in the database but not in the document. That shouldn't happen.)
-  const bool exists_in_db = DbUtils::get_table_exists_in_database(table_name);
+  const auto exists_in_db = DbUtils::get_table_exists_in_database(table_name);
   if(exists_in_db)
   {
     //Ask the user if they want us to try to cope with this:
@@ -236,7 +234,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     dialog.set_secondary_text(_("This table already exists on the database server, though it is not mentioned in the .glom file. This should not happen. Would you like Glom to attempt to use the existing table?"));
     dialog.set_transient_for(*AppWindow::get_appwindow());
 
-    const int response = dialog.run();
+    const auto response = dialog.run();
     dialog.hide();
 
     if(response == Gtk::RESPONSE_OK)
@@ -257,7 +255,7 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
     Document* document = get_document();
     if(document)
     {
-      sharedptr<TableInfo> table_info = document->get_table(table_name);
+      std::shared_ptr<TableInfo> table_info = document->get_table(table_name);
       fill_table_row(row, table_info);
 
       //Save the field information directly into the database, because we cannot get all the correct information from the database.
@@ -276,13 +274,13 @@ void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 
 void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, const Gtk::TreeModel::iterator& rowEnd)
 {
-  Gtk::TreeModel::iterator iterAfter = rowEnd;
+  auto iterAfter = rowEnd;
   ++iterAfter;
 
   bool something_changed = false;
-  for(Gtk::TreeModel::iterator iter = rowStart; iter != iterAfter; ++iter)
+  for(auto iter = rowStart; iter != iterAfter; ++iter)
   {
-    const Glib::ustring table_name = m_AddDel.get_value_key(iter);
+    const auto table_name = m_AddDel.get_value_key(iter);
 
     if(!table_name.empty())
     {
@@ -300,23 +298,20 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
         else
         {
           //Ask the user to confirm:
-          const Glib::ustring strMsg = Glib::ustring::compose(_("Are you sure that you want to delete this table?\nTable name: %1"), table_name);
-          Gtk::MessageDialog dialog(UiUtils::bold_message(_("Delete Table")),
-            true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE,
-            true /* modal */);
+          const auto strMsg = Glib::ustring::compose(_("Are you sure that you want to delete this table?\nTable name: %1"), table_name);
+          Gtk::MessageDialog dialog(UiUtils::bold_message(_("Delete Table")), true);
           dialog.set_secondary_text(strMsg);
           dialog.set_transient_for(*AppWindow::get_appwindow());
-          dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
-          dialog.add_button(_("Delete Table"), Gtk::RESPONSE_OK);
-          const int iButtonClicked = dialog.run();
+          const auto iButtonClicked = dialog.run();
           
           //Get a list of autoincrementing fields in the table:
-          const Glom::Document::type_vec_fields fields = document->get_table_fields(table_name);
+          const auto fields = document->get_table_fields(table_name);
+   
 
           //Delete the table:
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
-            const bool test = DbUtils::drop_table(table_name);
+            const auto test = DbUtils::drop_table(table_name);
             if(!test)
               std::cerr << G_STRFUNC << ": DROP TABLE failed." << std::endl;
             else
@@ -329,13 +324,12 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
             
             //Remove the auto-increment rows.
             //Otherwise it would not start at 0 if a table with the same name, and same field, is added again later.
-            for(Glom::Document::type_vec_fields::const_iterator iter = fields.begin(); iter != fields.end(); ++iter)
+            for(const auto& field : fields)
             {
-              const Glom::sharedptr<const Glom::Field> field = *iter;
               if(!field || !field->get_auto_increment())
                 continue;
                 
-              const Glib::ustring field_name = field->get_name();
+              const auto field_name = field->get_name();
             
               if(!field_name.empty())
                 DbUtils::remove_auto_increment(table_name, field_name);
@@ -379,15 +373,14 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
     else if(column == m_colDefault)
     {
       //Only one table can be the default, so ensure that:
-      const bool is_default = m_AddDel.get_value_as_bool(row, m_colDefault);
+      const auto is_default = m_AddDel.get_value_as_bool(row, m_colDefault);
       if(is_default)
       {
         //Set all the other rows to false:
         Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
-        for(Gtk::TreeModel::iterator iter = model->children().begin(); iter != model->children().end(); ++iter)
+        for(const auto& child_row : model->children())
         {
-          if(iter != row)
-            m_AddDel.set_value(iter, m_colDefault, false);
+          m_AddDel.set_value(child_row, m_colDefault, false);
         }
       }
 
@@ -409,7 +402,7 @@ void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint co
         //Rename the table:
         if(iButtonClicked == Gtk::RESPONSE_OK)
         {
-          const bool test = DbUtils::rename_table(table_name, table_name_new);
+          const auto test = DbUtils::rename_table(table_name, table_name_new);
           if(test)
           {
             //Change the AddDel item's key:
@@ -469,21 +462,21 @@ void Box_Tables::save_to_document()
 
     Document* document = get_document();
 
-    for(Gtk::TreeModel::iterator iter = m_AddDel.get_model()->children().begin(); iter != m_AddDel.get_model()->children().end(); ++iter)
+    for(const auto& row : m_AddDel.get_model()->children())
     {
-      const Glib::ustring table_name = m_AddDel.get_value(iter, m_colTableName); //The name has already been changed in the document.
-      sharedptr<TableInfo> table_info = document->get_table(table_name); //Start with the existing table_info, to preserve extra information, such as translations.
+      const auto table_name = m_AddDel.get_value(row, m_colTableName); //The name has already been changed in the document.
+      std::shared_ptr<TableInfo> table_info = document->get_table(table_name); //Start with the existing table_info, to preserve extra information, such as translations.
       if(table_info)
       {
-        table_info->set_name( m_AddDel.get_value(iter, m_colTableName) );
+        table_info->set_name( m_AddDel.get_value(row, m_colTableName) );
 
         if(!table_info->get_name().empty())
         {
-          table_info->set_hidden( m_AddDel.get_value_as_bool(iter, m_colHidden) );
-          table_info->set_title( m_AddDel.get_value(iter, m_colTitle) , AppWindow::get_current_locale()); //TODO_Translations: Store the TableInfo in the TreeView.
-          table_info->set_title_singular( m_AddDel.get_value(iter, m_colTitleSingular), AppWindow::get_current_locale()); //TODO_Translations: Store the TableInfo in the TreeView.
+          table_info->set_hidden( m_AddDel.get_value_as_bool(row, m_colHidden) );
+          table_info->set_title( m_AddDel.get_value(row, m_colTitle) , AppWindow::get_current_locale()); //TODO_Translations: Store the TableInfo in the TreeView.
+          table_info->set_title_singular( m_AddDel.get_value(row, m_colTitleSingular), AppWindow::get_current_locale()); //TODO_Translations: Store the TableInfo in the TreeView.
           //std::cout << "debug: " << G_STRFUNC << ": title=" << item_get_title(table_info) << std::endl;
-          table_info->set_default( m_AddDel.get_value_as_bool(iter, m_colDefault) );
+          table_info->set_default( m_AddDel.get_value_as_bool(row, m_colDefault) );
 
           listTables.push_back(table_info);
         }
