@@ -84,9 +84,9 @@ static Glib::ustring get_traceback()
   //   for the Boost::Python code that this is based on:
 
 
-  PyObject* type = 0;
-  PyObject* value = 0;
-  PyObject* traceback = 0;
+  PyObject* type = nullptr;
+  PyObject* value = nullptr;
+  PyObject* traceback = nullptr;
   PyErr_Fetch(&type, &value, &traceback);
 
   if(!traceback)
@@ -107,9 +107,9 @@ static Glib::ustring get_traceback()
   }
   else
   {
-    boost::python::object traceback(boost::python::import("traceback"));
-    boost::python::object format_exception(traceback.attr("format_exception"));
-    boost::python::object formatted_list(format_exception(hexc,hval,htb));
+    boost::python::object cpp_traceback(boost::python::import("traceback"));
+    boost::python::object format_exception(cpp_traceback.attr("format_exception"));
+    boost::python::object formatted_list(format_exception(hexc, hval, htb));
     boost::python::object formatted(boost::python::str("").join(formatted_list));
     const std::string result = boost::python::extract<std::string>(formatted);
     return result;
@@ -164,8 +164,6 @@ bool gda_python_module_is_available()
 {
   //TODO: How can we requests a specific version to avoid confusion
   //between the parallel-installed Gda-5.0 and Gda-6.0 APIs?
-  //In a python script we would do this, but how do we do it with the boost::python API?
-  //  gi.require_version('Gda', '5.0')
   const char* name = "gi.repository.Gda";
   const boost::python::object module_glom = import_module(name);
   return module_glom != boost::python::object();
@@ -179,7 +177,7 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   const boost::python::object& param2 = boost::python::object())
 {
   //std::cout << "glom_evaluate_python_function_implementation()" << std::endl;
-  //for(type_map_fields::const_iterator iter = field_values.begin(); iter != field_values.end(); ++iter)
+  //for(const auto& item : field_values)
   //{
   //  std::cout << "  field_value: name=" << iter->first << ", value=" << iter->second.to_string() << std::endl;
   //}
@@ -193,11 +191,10 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   Glib::ustring func_def;
 
   //Indent the function implementation (required by python syntax):
-  typedef std::list<Glib::ustring> type_listStrings;
-  type_listStrings listStrings = ustring_tokenize(func_impl, "\n", -1);
-  for(type_listStrings::const_iterator iter = listStrings.begin(); iter != listStrings.end(); ++iter)
+  const auto listStrings = ustring_tokenize(func_impl, "\n", -1);
+  for(const auto& item : listStrings)
   {
-    func_def += "  " + *iter + '\n';
+    func_def += "  " + item + '\n';
   }
 
 
@@ -211,11 +208,7 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
 
   //TODO: How can we requests a specific version to avoid confusion
   //between the parallel-installed Gda-5.0 and Gda-6.0 APIs?
-  func_def = "def " + func_signature + ":\n"
-  "  import glom_" GLOM_ABI_VERSION_UNDERLINED "\n"
-  "  import gi\n"
-  "  gi.require_version('Gda', '5.0')\n"
-  "  from gi.repository import Gda\n" + func_def;
+  func_def = "def " + func_signature + ":\n  import glom_" GLOM_ABI_VERSION_UNDERLINED "\n  from gi.repository import Gda\n" + func_def;
 
   //We did this in main(): Py_Initialize();
 
@@ -233,11 +226,9 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
   //Allow the function to import from our script library:
   if(pDocument)
   {
-    const std::vector<Glib::ustring> module_names = pDocument->get_library_module_names();
-    for(std::vector<Glib::ustring>::const_iterator iter = module_names.begin(); iter != module_names.end(); ++iter)
+    for(const auto& name : pDocument->get_library_module_names())
     {
-      const Glib::ustring name = *iter;
-      const Glib::ustring script = pDocument->get_library_module(name);
+      const auto script = pDocument->get_library_module(name);
       if(!name.empty() && !script.empty())
       {
         //TODO: Is there a boost::python equivalent for Py_CompileString()?
@@ -266,19 +257,15 @@ static boost::python::object glom_python_call(Field::glom_field_type result_type
     return boost::python::object(); // don't crash
   }
 
-  //This doesn't seem to be necessary,
-  //because we do an import in the python script anyway.
-  //And we don't want to do this because the boost::python::import() API
-  //doesn't let us first say:
-  //  gi.require_version('Gda', '5.0')
-  //to specify a particular parallel-installable version.
-  //(There are 5.0 and 6.0 versions of Gda, for instance.)
-  //boost::python::object module_gda = import_module("gi.repository.Gda");
-  //if(module_gda == boost::python::object())
-  //{
-  //  g_warning("Could not import python gi.repository.Gda module.");
-  //  return boost::python::object();
-  //}
+  //TODO: Is this necessary?
+  //TODO: How can we requests a specific version to avoid confusion
+  //between the parallel-installed Gda-5.0 and Gda-6.0 APIs?
+  boost::python::object module_gda = import_module("gi.repository.Gda");
+  if(module_gda == boost::python::object())
+  {
+    g_warning("Could not import python gi.repository.Gda module.");
+    return boost::python::object();
+  }
 
   //Create the function definition:
   /*
@@ -387,7 +374,7 @@ void glom_execute_python_function_implementation(const Glib::ustring& func_impl,
   const type_map_fields& field_values,
   const Document* pDocument,
   const Glib::ustring& table_name,
-  const sharedptr<const Field>& key_field,
+  const std::shared_ptr<const Field>& key_field,
   const Gnome::Gda::Value& key_field_value,
   const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection,
   const PythonUICallbacks& callbacks,
@@ -427,7 +414,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
   const type_map_fields& field_values,
   const Document* pDocument,
   const Glib::ustring& table_name,
-  const sharedptr<const Field>& key_field,
+  const std::shared_ptr<const Field>& key_field,
   const Gnome::Gda::Value& key_field_value,
   const Glib::RefPtr<Gnome::Gda::Connection>& opened_connection,
   Glib::ustring& error_message)
@@ -505,7 +492,7 @@ Gnome::Gda::Value glom_evaluate_python_function_implementation(Field::glom_field
       //(though I don't think this code is ever reached. murrayc)
 
       //Treat this as a string or something that can be converted to a string:
-      const char* pchResult = 0;
+      const char* pchResult = nullptr;
       try
       {
         pchResult = boost::python::extract<const char*>(pyResultCpp);
