@@ -75,7 +75,7 @@ AddDelColumnInfo& AddDelColumnInfo::operator=(const AddDelColumnInfo& src)
 AddDel::AddDel()
 : Gtk::Box(Gtk::ORIENTATION_VERTICAL),
   m_col_key(0),
-  m_pMenuPopup(0),
+  m_pMenuPopup(nullptr),
   m_auto_add(true),
   m_allow_add(true),
   m_allow_delete(true)
@@ -87,7 +87,7 @@ AddDel::AddDel()
 AddDel::AddDel(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::Box(cobject),
   m_col_key(0),
-  m_pMenuPopup(0),
+  m_pMenuPopup(nullptr),
   m_auto_add(true),
   m_allow_add(true),
   m_allow_delete(true)
@@ -173,7 +173,7 @@ AddDel::on_MenuPopup_activate_Edit()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       //Discover whether it's the last (empty) row:
@@ -192,7 +192,7 @@ AddDel::on_MenuPopup_activate_Edit()
           bool bRowAdded = true;
 
           //The rows might be re-ordered:
-          Gtk::TreeModel::iterator rowAdded = iter;
+          auto rowAdded = iter;
           Glib::ustring strValue_Added =  get_value_key(iter);
           if(strValue_Added != strValue)
             rowAdded = get_row(strValue);
@@ -219,7 +219,7 @@ void AddDel::on_MenuPopup_activate_Delete()
   Glib::RefPtr<Gtk::TreeView::Selection> refSelection = m_TreeView.get_selection();
   if(refSelection)
   {
-    Gtk::TreeModel::iterator iter = refSelection->get_selected();
+    auto iter = refSelection->get_selected();
     if(iter)
     {
       //TODO: We can't handle multiple-selections yet.
@@ -254,18 +254,18 @@ void AddDel::setup_menu(Gtk::Widget* /* widget */)
   m_pMenuPopup->attach_to_widget(*this);
 }
 
-bool AddDel::on_button_press_event_Popup(GdkEventButton *event)
+bool AddDel::on_button_press_event_Popup(GdkEventButton *button_event)
 {
   GdkModifierType mods;
-  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
   if(mods & GDK_BUTTON3_MASK)
   {
     //Give user choices of actions on this item:
-    m_pMenuPopup->popup(event->button, event->time);
+    m_pMenuPopup->popup(button_event->button, button_event->time);
   }
   else
   {
-    if(event->type == GDK_2BUTTON_PRESS)
+    if(button_event->type == GDK_2BUTTON_PRESS)
     {
       //Double-click means edit.
       //Disable this, because it is confusing when single-click activates editable cells too.
@@ -278,7 +278,7 @@ bool AddDel::on_button_press_event_Popup(GdkEventButton *event)
 Gtk::TreeModel::iterator AddDel::get_item_placeholder()
 {
   //Get the existing placeholder row, or add one if necessary:
-  Gtk::TreeModel::iterator iter = get_last_row();
+  auto iter = get_last_row();
   if( get_is_placeholder_row(iter) )
   {
     return iter;
@@ -291,7 +291,7 @@ Gtk::TreeModel::iterator AddDel::get_item_placeholder()
 
 Gtk::TreeModel::iterator AddDel::add_item_placeholder()
 {
-  Gtk::TreeModel::iterator iter = m_refListStore->append();
+  auto iter = m_refListStore->append();
   if(iter)
   {
     iter->set_value(m_col_key, Glib::ustring("")); //Remove temporary key value.
@@ -303,7 +303,7 @@ Gtk::TreeModel::iterator AddDel::add_item_placeholder()
 
 Gtk::TreeModel::iterator AddDel::add_item(const Glib::ustring& strKey)
 {
-  Gtk::TreeModel::iterator result = get_next_available_row_with_add_if_necessary();
+  auto result = get_next_available_row_with_add_if_necessary();
 
   if(result)
   {
@@ -326,7 +326,7 @@ void AddDel::remove_all()
 
   if(m_refListStore)
   {
-    Gtk::TreeModel::iterator iter = m_refListStore->children().begin();
+    auto iter = m_refListStore->children().begin();
     while(iter)
     {
       m_refListStore->erase(iter);
@@ -398,9 +398,9 @@ Gtk::TreeModel::iterator AddDel::get_item_selected()
 
 Gtk::TreeModel::iterator AddDel::get_row(const Glib::ustring& key)
 {
-  for(Gtk::TreeModel::iterator iter = m_refListStore->children().begin(); iter != m_refListStore->children().end(); ++iter)
+  for(auto iter = m_refListStore->children().begin(); iter != m_refListStore->children().end(); ++iter)
   {
-    const Glib::ustring strTemp = get_value(iter, m_col_key);
+    const auto strTemp = get_value(iter, m_col_key);
     if(strTemp == key)
     {
       return iter;
@@ -457,7 +457,7 @@ bool AddDel::select_item(const Gtk::TreeModel::iterator& iter, guint column, boo
 
 bool AddDel::select_item(const Glib::ustring& strItemText, guint column, bool start_editing)
 {
-  Gtk::TreeModel::iterator iter = get_row(strItemText);
+  auto iter = get_row(strItemText);
   if(iter)
   {
     return select_item(iter, column, start_editing);
@@ -492,7 +492,7 @@ void AddDel::add_blank()
 
   if(get_allow_user_actions()) //The extra blank line is only used if the user may add items:
   {
-    Gtk::TreeModel::iterator iter = get_last_row();
+    auto iter = get_last_row();
     if(get_is_placeholder_row(iter))
     {
         bAddNewBlank  = false; //One already exists.
@@ -555,11 +555,10 @@ void AddDel::construct_specified_columns()
   Gtk::TreeModel::ColumnRecord record;
   {
     type_vecModelColumns::size_type i = 0;
-    for(type_ColumnTypes::iterator iter = m_ColumnTypes.begin(); iter != m_ColumnTypes.end(); ++iter)
+    for(const auto& column_info : m_ColumnTypes)
     {
-      Gtk::TreeModelColumnBase* pModelColumn = 0;
+      Gtk::TreeModelColumnBase* pModelColumn = nullptr;
 
-      AddDelColumnInfo column_info = *iter;
       switch(column_info.m_style)
       {
         //Create an appropriate type of Model Column:
@@ -598,10 +597,8 @@ void AddDel::construct_specified_columns()
   //Add new View Colums:
   int model_column_index = 0;
   int view_column_index = 0;
-  for(type_vecModelColumns::iterator iter = vecModelColumns.begin(); iter != vecModelColumns.end(); ++iter)
+  for(const auto& pModelColumn : vecModelColumns)
   {
-    type_vecModelColumns::value_type& pModelColumn = *iter;
-
     if(m_ColumnTypes[model_column_index].m_visible)
     {
       const Glib::ustring column_name = m_ColumnTypes[model_column_index].m_name;
@@ -612,19 +609,18 @@ void AddDel::construct_specified_columns()
         case(AddDelColumnInfo::STYLE_Choices):
         {
           //Use a custom CellRenderer:
-          CellRendererList* pCellRenderer = Gtk::manage( new CellRendererList() );
+          CellRendererList* pCellRendererList = Gtk::manage( new CellRendererList() );
 
           //Add the choices:
-          const type_vec_strings vecStrings = m_ColumnTypes[model_column_index].m_choices;
-          for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+          for(const auto& item : m_ColumnTypes[model_column_index].m_choices)
           {
-            pCellRenderer->append_list_item(*iter);
+            pCellRendererList->append_list_item(item);
           }
 
           // Append the View column.
           // We use a derived Gtk::TreeViewColumn so that we can store extra information in it.
           // This means that we must reimplement the code from the convenience template methods from gtkmm.
-          treeview_append_column( Utils::string_escape_underscores(column_name), *pCellRenderer,  *pModelColumn, column_id);
+          treeview_append_column( Utils::string_escape_underscores(column_name), *pCellRendererList,  *pModelColumn, column_id);
 
           break;
         }
@@ -657,29 +653,29 @@ void AddDel::construct_specified_columns()
 
       if(m_ColumnTypes[model_column_index].m_editable)
       {
-        Gtk::CellRendererText* pCellRenderer = dynamic_cast<Gtk::CellRendererText*>(m_TreeView.get_column_cell_renderer(view_column_index));
-        if(pCellRenderer)
+        Gtk::CellRendererText* pCellRendererText = dynamic_cast<Gtk::CellRendererText*>(m_TreeView.get_column_cell_renderer(view_column_index));
+        if(pCellRendererText)
         {
           //Connect a signal handler:
-          if(pCellRenderer)
+          if(pCellRendererText)
           {
             //Make it editable:
-            pCellRenderer->property_editable() = true;
+            pCellRendererText->property_editable() = true;
 
             //Connect to its signal:
-            pCellRenderer->signal_edited().connect(
+            pCellRendererText->signal_edited().connect(
               sigc::bind( sigc::mem_fun(*this, &AddDel::on_treeview_cell_edited), model_column_index) );
           }
         }
         else
         {
-           Gtk::CellRendererToggle* pCellRenderer = dynamic_cast<Gtk::CellRendererToggle*>(m_TreeView.get_column_cell_renderer(view_column_index));
-           if(pCellRenderer)
+           Gtk::CellRendererToggle* pCellRendererToggle = dynamic_cast<Gtk::CellRendererToggle*>(m_TreeView.get_column_cell_renderer(view_column_index));
+           if(pCellRendererToggle)
            {
-             pCellRenderer->property_activatable() = true;
+             pCellRendererToggle->property_activatable() = true;
 
              //Connect to its signal:
-             pCellRenderer->signal_toggled().connect(
+             pCellRendererToggle->signal_toggled().connect(
                sigc::bind( sigc::mem_fun(*this, &AddDel::on_treeview_cell_edited_bool), model_column_index ) );
            }
         }
@@ -699,10 +695,8 @@ void AddDel::construct_specified_columns()
 
   //Delete the vector's items:
   model_column_index = 0;
-  for(type_vecModelColumns::iterator iter = vecModelColumns.begin(); iter != vecModelColumns.end(); ++iter)
+  for(auto& pModelColumn : vecModelColumns)
   {
-    Gtk::TreeModelColumnBase* pModelColumn = *iter;
-
     if(model_column_index < (int)m_ColumnTypes.size())
     {
       AddDelColumnInfo::enumStyles style = m_ColumnTypes[model_column_index].m_style;
@@ -730,7 +724,7 @@ void AddDel::construct_specified_columns()
         }
       }
 
-      *iter = 0;
+      pModelColumn = 0;
     }
     else
     {
@@ -931,9 +925,9 @@ void AddDel::set_column_choices(guint col, const type_vec_strings& vecStrings)
     {
       //Add the choices:
       pCellRenderer->remove_all_list_items();
-      for(type_vec_strings::const_iterator iter = vecStrings.begin(); iter != vecStrings.end(); ++iter)
+      for(const auto& item : vecStrings)
       {
-        pCellRenderer->append_list_item(*iter);
+        pCellRenderer->append_list_item(item);
       }
     }
     else
@@ -1023,7 +1017,7 @@ void AddDel::remove_item(const Gtk::TreeModel::iterator& iter)
 
 void AddDel::remove_item_by_key(const Glib::ustring& strKey)
 {
-  Gtk::TreeModel::iterator iter = get_row(strKey);
+  auto iter = get_row(strKey);
   remove_item(iter);
 }
 
@@ -1078,7 +1072,7 @@ void AddDel::on_treeview_cell_edited_bool(const Glib::ustring& path_string, int
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
+  auto iter = m_refListStore->get_iter(path);
   if(iter)
   {
     Gtk::TreeModel::Row row = *iter;
@@ -1153,7 +1147,7 @@ void AddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const Gli
   Gtk::TreeModel::Path path(path_string);
 
   //Get the row from the path:
-  Gtk::TreeModel::iterator iter = m_refListStore->get_iter(path);
+  auto iter = m_refListStore->get_iter(path);
   if(iter != get_model()->children().end())
   {
     Gtk::TreeModel::Row row = *iter;
@@ -1239,9 +1233,9 @@ void AddDel::on_treeview_cell_edited(const Glib::ustring& path_string, const Gli
                 {
                   refTreeSelection->select(row); //TODO: This does not seem to work.
 
-                 Gtk::TreeModel::Path path = m_refListStore->get_path(row);
+                 Gtk::TreeModel::Path path_to_activate = m_refListStore->get_path(row);
                  Gtk::TreeView::Column* pColumn = m_TreeView.get_column(model_column_index); //TODO: This might the the view column index, not the model column index.
-                 m_TreeView.set_cursor(path, *pColumn, true /* start_editing */); //This highlights the cell, but does not seem to actually start the editing.
+                 m_TreeView.set_cursor(path_to_activate, *pColumn, true /* start_editing */); //This highlights the cell, but does not seem to actually start the editing.
                }
              }
 
@@ -1270,7 +1264,7 @@ void AddDel::on_treeview_cell_editing_started(Gtk::CellEditable* /* editable */,
   if(!m_refListStore)
     return;
 
-  Gtk::TreeModel::iterator iterRow = m_refListStore->get_iter(path);
+  auto iterRow = m_refListStore->get_iter(path);
   if(iterRow)
     signal_user_activated().emit(iterRow, model_column_index);
 }
@@ -1315,9 +1309,9 @@ AddDel::type_signal_user_reordered_columns AddDel::signal_user_reordered_columns
   return m_signal_user_reordered_columns;
 }
 
-void AddDel::on_treeview_button_press_event(GdkEventButton* event)
+void AddDel::on_treeview_button_press_event(GdkEventButton* button_event)
 {
-  on_button_press_event_Popup(event);
+  on_button_press_event_Popup(button_event);
 }
 
 bool AddDel::on_treeview_column_drop(Gtk::TreeView* /* treeview */, Gtk::TreeViewColumn* /* column */, Gtk::TreeViewColumn* /* prev_column */, Gtk::TreeViewColumn* /* next_column */)
@@ -1354,15 +1348,12 @@ void AddDel::on_treeview_columns_changed()
     //Get the new column order, and save it in m_vecColumnIDs:
     m_vecColumnIDs.clear();
 
-    typedef std::vector<Gtk::TreeViewColumn*> type_vecViewColumns;
-    type_vecViewColumns vecViewColumns = m_TreeView.get_columns();
-
-    for(type_vecViewColumns::iterator iter = vecViewColumns.begin(); iter != vecViewColumns.end(); ++iter)
+    for(const auto& item : m_TreeView.get_columns())
     {
-      TreeViewColumnGlom* pViewColumn = dynamic_cast<TreeViewColumnGlom*>(*iter);
+      auto pViewColumn = dynamic_cast<TreeViewColumnGlom*>(item);
       if(pViewColumn)
       {
-        const Glib::ustring column_id = pViewColumn->get_column_id();
+        const auto column_id = pViewColumn->get_column_id();
         m_vecColumnIDs.push_back(column_id);
 
       }
@@ -1415,7 +1406,7 @@ Gtk::TreeModel::iterator AddDel::get_next_available_row_with_add_if_necessary()
 
   if(get_allow_user_actions()) //The extra blank line is only used if the user may add items:
   {
-    Gtk::TreeModel::iterator iter = get_last_row();
+    auto iter = get_last_row();
 
     if(iter != get_model()->children().end())
     {
@@ -1449,7 +1440,7 @@ Gtk::TreeModel::iterator AddDel::get_next_available_row_with_add_if_necessary()
 Gtk::TreeModel::iterator AddDel::get_last_row() const
 {
   //TODO_performance: Hopefully there is a better way to do this.
-  Gtk::TreeModel::iterator iter = get_model()->children().begin();
+  auto iter = get_model()->children().begin();
   guint size = get_model()->children().size();
   if(size > 1)
   {
@@ -1465,7 +1456,7 @@ Gtk::TreeModel::iterator AddDel::get_last_row() const
 Gtk::TreeModel::iterator AddDel::get_last_row()
 {
   //TODO_performance: Hopefully there is a better way to do this.
-  Gtk::TreeModel::iterator iter = get_model()->children().begin();
+  auto iter = get_model()->children().begin();
   guint size = get_model()->children().size();
   if(size > 1)
   {
@@ -1517,8 +1508,8 @@ bool AddDel::get_model_column_index(guint view_column_index, guint& model_column
   //Initialize output parameter:
   model_column_index = 0;
 
-  const guint hidden = get_count_hidden_system_columns();
-  const guint count = m_ColumnTypes.size();
+  const auto hidden = get_count_hidden_system_columns();
+  const auto count = m_ColumnTypes.size();
   if(hidden > count)
     return false; //This should never happen.
 
@@ -1571,7 +1562,7 @@ void AddDel::set_prevent_duplicates_warning(const Glib::ustring& warning_text)
 
 bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
 {
-  const type_ColumnTypes::size_type cols_count = m_ColumnTypes.size();
+  const auto cols_count = m_ColumnTypes.size();
   for(type_ColumnTypes::size_type col = 0; col < cols_count; ++col)
   {
     if(m_ColumnTypes[col].m_prevent_duplicates)
@@ -1597,7 +1588,7 @@ bool AddDel::row_has_duplicates(const Gtk::TreeModel::iterator& iter) const
       //std::cout << "value_text=" << value_text << std::endl;
 
       //Look at each other row to see whether the value exists there already:
-      for(Gtk::TreeModel::iterator iterCheck = m_refListStore->children().begin(); iterCheck != m_refListStore->children().end(); ++iterCheck)
+      for(auto iterCheck = m_refListStore->children().begin(); iterCheck != m_refListStore->children().end(); ++iterCheck)
       {
         if(iterCheck != iter) //Don't compare the row with itself
         {
