@@ -41,7 +41,9 @@ class AddDelColumnInfo
 public:
   AddDelColumnInfo();
   AddDelColumnInfo(const AddDelColumnInfo& src);
+  AddDelColumnInfo(AddDelColumnInfo&& src) = delete;
   AddDelColumnInfo& operator=(const AddDelColumnInfo& src);
+  AddDelColumnInfo& operator=(AddDelColumnInfo&& src) = delete;
 
   //If we need any more complicated style (e.g. number of decimal digits) then we will need a separate AddDelStyle class.
   enum enumStyles
@@ -80,11 +82,11 @@ public:
   // Set the accessible name for the TreeView widget
   void set_treeview_accessible_name(const Glib::ustring& name);
 
-  void set_allow_user_actions(bool bVal = true);
+  virtual void set_allow_user_actions(bool bVal = true);
   bool get_allow_user_actions() const;
 
-  void set_allow_add(bool val = true);
-  void set_allow_delete(bool val = true);
+  virtual void set_allow_add(bool val = true);
+  virtual void set_allow_delete(bool val = true);
 
   Gtk::TreeModel::iterator add_item(const Glib::ustring& strKey); //Return index of new row.
 
@@ -261,9 +263,9 @@ private:
   bool on_treeview_column_drop(Gtk::TreeView* treeview, Gtk::TreeViewColumn* column, Gtk::TreeViewColumn* prev_column, Gtk::TreeViewColumn* next_column);
   void on_treeview_columns_changed();
 
-  bool on_button_press_event_Popup(GdkEventButton* event);
+  bool on_button_press_event_Popup(GdkEventButton* button_event);
 
-  void on_treeview_button_press_event(GdkEventButton* event);
+  void on_treeview_button_press_event(GdkEventButton* button_event);
 
   /** Set the menu to popup when the user right-clicks on the column titles.
    * This method does not take ownership of the Gtk::Menu.
@@ -352,7 +354,7 @@ private:
 template<class T_ModelColumnType>
 guint AddDel::treeview_append_column(const Glib::ustring& title, const Gtk::TreeModelColumn<T_ModelColumnType>& column, const Glib::ustring& column_id)
 {
-  Gtk::CellRenderer* pCellRenderer = manage( Gtk::CellRenderer_Generation::generate_cellrenderer<T_ModelColumnType>() );
+  auto pCellRenderer = manage( Gtk::CellRenderer_Generation::generate_cellrenderer<T_ModelColumnType>() );
   return treeview_append_column(title, *pCellRenderer, column, column_id);
 }
 
