@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "canvas_group_grid.h"
@@ -74,9 +74,8 @@ double CanvasGroupGrid::snap_position_rules(const type_vec_doubles& rules, doubl
 {
   double result = a;
 
-  for(type_vec_doubles::const_iterator iter = rules.begin(); iter != rules.end(); ++iter)
+  for(const auto& rule_a : rules)
   {
-    const double rule_a = *iter;
     if(is_close(a, rule_a))
     {
       if(result == a) //Prefer some snap to no snap
@@ -92,13 +91,13 @@ double CanvasGroupGrid::snap_position_rules(const type_vec_doubles& rules, doubl
 
 double CanvasGroupGrid::snap_position_rules_x(double x) const
 {
-  const type_vec_doubles rules = get_vertical_rules();
+  const auto rules = get_vertical_rules();
   return snap_position_rules(rules, x);
 }
 
 double CanvasGroupGrid::snap_position_rules_y(double y) const
 {
-  const type_vec_doubles rules = get_horizontal_rules();
+  const auto rules = get_horizontal_rules();
   return snap_position_rules(rules, y);
 }
 
@@ -238,10 +237,8 @@ void CanvasGroupGrid::remove_rules()
 CanvasGroupGrid::type_vec_doubles CanvasGroupGrid::get_horizontal_rules() const
 {
   type_vec_doubles result;
-  for(type_vec_lines::const_iterator iter = m_rules_y.begin();
-    iter != m_rules_y.end(); ++iter)
+  for(const auto& line : m_rules_y)
   {
-    Glib::RefPtr<CanvasLineMovable> line = *iter;
     if(!line)
       continue;
 
@@ -257,10 +254,8 @@ CanvasGroupGrid::type_vec_doubles CanvasGroupGrid::get_horizontal_rules() const
 CanvasGroupGrid::type_vec_doubles CanvasGroupGrid::get_vertical_rules() const
 {
   type_vec_doubles result;
-  for(type_vec_lines::const_iterator iter = m_rules_x.begin();
-    iter != m_rules_x.end(); ++iter)
+  for(const auto& line : m_rules_x)
   {
-    Glib::RefPtr<CanvasLineMovable> line = *iter;
     if(!line)
       continue;
 
