@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <glom/utility_widgets/eggspreadtable/eggspreadtablednd.h>
@@ -39,10 +39,10 @@ static const guint INITIAL_VSPACING = 2;
 static const guint INITIAL_LINES = 3;
 static const Gtk::Align INITIAL_HALIGN = Gtk::ALIGN_FILL;
 
-static Egg::SpreadTableDnd *paper = 0;
-static Gtk::ComboBoxText* combo_halign = 0;
-static Gtk::ComboBoxText* combo_orientation = 0;
-static Gtk::SpinButton* spinbutton_lines = 0;
+static Egg::SpreadTableDnd *paper = nullptr;
+static Gtk::ComboBoxText* combo_halign = nullptr;
+static Gtk::ComboBoxText* combo_orientation = nullptr;
+static Gtk::SpinButton* spinbutton_lines = nullptr;
 static Gtk::Align child_halign = INITIAL_HALIGN;
 static bool child_accepts_drops = true;
 static bool parent_accepts_drops = true;
@@ -61,12 +61,8 @@ populate_spread_table_wrappy(Egg::SpreadTableDnd* spread_table)
   };
 
   /* Remove all children first */
-  typedef std::vector<Gtk::Widget*> type_vec_widgets;
-  type_vec_widgets children = paper->get_children();
-  for(type_vec_widgets::iterator iter = children.begin();
-    iter != children.end(); ++iter)
+  for(const auto& child : paper->get_children())
   {
-    Gtk::Widget *child = *iter;
     paper->remove_child(*child);
     delete child;
   }
@@ -104,7 +100,7 @@ on_combo_orientation_changed()
 static void
 on_spinbutton_lines_changed()
 {
-  const int lines = spinbutton_lines->get_value_as_int();
+  const auto lines = spinbutton_lines->get_value_as_int();
 
   paper->set_lines(lines);
 }
@@ -112,7 +108,7 @@ on_spinbutton_lines_changed()
 static void
 on_spinbutton_spacing_changed(Gtk::SpinButton* spinbutton, Gtk::Orientation orientation)
 {
-  const int state = spinbutton->get_value_as_int();
+  const auto state = spinbutton->get_value_as_int();
 
   if(orientation == Gtk::ORIENTATION_HORIZONTAL)
     paper->set_horizontal_spacing(state);
