@@ -47,29 +47,25 @@ ImageGlom::type_vec_ustrings ImageGlom::m_evince_supported_mime_types;
 ImageGlom::type_vec_ustrings ImageGlom::m_gdkpixbuf_supported_mime_types;
 
 ImageGlom::ImageGlom()
-: m_ev_scrolled_window(0),
-  m_ev_view(0),
-  m_ev_document_model(0),
-  m_pMenuPopup_UserMode(0)
+: m_ev_view(nullptr),
+  m_ev_document_model(nullptr),
+  m_pMenuPopup_UserMode(nullptr)
 {
   init();
 }
 
 ImageGlom::ImageGlom(BaseObjectType* cobject, const Glib::RefPtr<Gtk::Builder>& /* builder */)
 : Gtk::EventBox(cobject),
-  m_ev_scrolled_window(0),
-  m_ev_view(0),
-  m_ev_document_model(0),
-  m_pMenuPopup_UserMode(0)
+  m_ev_view(nullptr),
+  m_ev_document_model(nullptr),
+  m_pMenuPopup_UserMode(nullptr)
 {
   init();
 }
 
 void ImageGlom::init()
 {
-  //TODO: Don't instantiate this unnecessarily.
   m_ev_view = EV_VIEW(ev_view_new());
-
   //gtk_widget_add_events(GTK_WIDGET(m_ev_view), GDK_BUTTON_PRESS_MASK);
 
   //Connect the the EvView's button-press-event signal, 
@@ -103,7 +99,7 @@ ImageGlom::~ImageGlom()
   delete m_pMenuPopup_UserMode;
 }
 
-void ImageGlom::set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
+void ImageGlom::set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name)
 {
   LayoutWidgetField::set_layout_item(layout_item, table_name);
 #ifdef GTKMM_ATKMM_ENABLED
@@ -111,10 +107,10 @@ void ImageGlom::set_layout_item(const sharedptr<LayoutItem>& layout_item, const
 #endif  
 }
 
-bool ImageGlom::on_button_press_event(GdkEventButton *event)
+bool ImageGlom::on_button_press_event(GdkEventButton *button_event)
 {
   GdkModifierType mods;
-  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), event->device, 0, 0, &mods );
+  gdk_window_get_device_position( gtk_widget_get_window (Gtk::Widget::gobj()), button_event->device, 0, 0, &mods );
 
   //Enable/Disable items.
   //We did this earlier, but get_appwindow is more likely to work now:
@@ -138,7 +134,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        popup_menu(event->button, event->time);
+        popup_menu(button_event->button, button_event->time);
        
         return true; //We handled this event.
       }
@@ -150,7 +146,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
       if(mods & GDK_BUTTON3_MASK)
       {
         //Give user choices of actions on this item:
-        popup_menu(event->button, event->time);
+        popup_menu(button_event->button, button_event->time);
 
         return true; //We handled this event.
       }
@@ -165,7 +161,7 @@ bool ImageGlom::on_button_press_event(GdkEventButton *event)
     }
   }
 
-  return Gtk::EventBox::on_button_press_event(event);
+  return Gtk::EventBox::on_button_press_event(button_event);
 }
 
 AppWindow* ImageGlom::get_appwindow() const
@@ -209,7 +205,7 @@ void ImageGlom::on_size_allocate(Gtk::Allocation& allocation)
   //Resize the GtkImage if necessary:
   if(m_pixbuf_original)
   {
-    const Glib::RefPtr<Gdk::Pixbuf> pixbuf_scaled = get_scaled_image();
+    const auto pixbuf_scaled = get_scaled_image();
     m_image.set(pixbuf_scaled);
   }
 }
@@ -243,12 +239,12 @@ void ImageGlom::on_ev_job_finished(EvJob* job)
 
 const GdaBinary* ImageGlom::get_binary() const
 {
-  const GdaBinary* gda_binary = 0;
+  const GdaBinary* gda_binary = nullptr;
   if(m_original_data.get_value_type() == GDA_TYPE_BINARY)
     gda_binary = gda_value_get_binary(m_original_data.gobj());
   else if(m_original_data.get_value_type() == GDA_TYPE_BLOB)
   {
-    const GdaBlob* gda_blob = gda_value_get_blob(m_original_data.gobj());
+    const auto gda_blob = gda_value_get_blob(m_original_data.gobj());
     if(gda_blob && gda_blob_op_read_all(const_cast<GdaBlobOp*>(gda_blob->op), const_cast<GdaBlob*>(gda_blob)))
       gda_binary = &(gda_blob->data);
   }
@@ -258,7 +254,7 @@ const GdaBinary* ImageGlom::get_binary() const
 
 Glib::ustring ImageGlom::get_mime_type() const
 {
-  const GdaBinary* gda_binary = get_binary();
+  const auto gda_binary = get_binary();
 
   if(!gda_binary)
     return Glib::ustring();
@@ -267,7 +263,7 @@ Glib::ustring ImageGlom::get_mime_type() const
     return Glib::ustring();
 
   bool uncertain = false;
-  const Glib::ustring result = Gio::content_type_guess(std::string(),
+  const auto result = Gio::content_type_guess(std::string(),
     gda_binary->data, gda_binary->binary_length,
     uncertain);
 
@@ -296,7 +292,7 @@ void ImageGlom::fill_evince_supported_mime_types()
     if(!info)
       continue;
 
-    const char* mime_type = 0;
+    const char* mime_type = nullptr;
     int i = 0;
     while((mime_type = info->mime_types[i++]))
     {
@@ -312,15 +308,10 @@ void ImageGlom::fill_gdkpixbuf_supported_mime_types()
   //Fill the static list if it has not already been filled:
   if(!m_gdkpixbuf_supported_mime_types.empty())
     return;
-    
-  typedef std::vector<Gdk::PixbufFormat> type_vec_formats;
-  const type_vec_formats formats = Gdk::Pixbuf::get_formats();
-  
-  for(type_vec_formats::const_iterator iter = formats.begin();
-    iter != formats.end(); ++iter)
+
+  for(const auto& format : Gdk::Pixbuf::get_formats())
   {
-    const Gdk::PixbufFormat& format = *iter;
-    const std::vector<Glib::ustring> mime_types = format.get_mime_types();
+    const auto mime_types = format.get_mime_types();
     m_gdkpixbuf_supported_mime_types.insert(
       m_gdkpixbuf_supported_mime_types.end(),
       mime_types.begin(), mime_types.end());
@@ -331,12 +322,12 @@ void ImageGlom::show_image_data()
 {
   bool use_evince = false;
   
-  const Glib::ustring mime_type = get_mime_type();
+  const auto mime_type = get_mime_type();
 
   //std::cout << "mime_type=" << mime_type << std::endl; 
   
   fill_evince_supported_mime_types();
-  const type_vec_ustrings::iterator iterFind = 
+  const auto iterFind = 
     std::find(m_evince_supported_mime_types.begin(),
       m_evince_supported_mime_types.end(),
       mime_type);
@@ -354,7 +345,7 @@ void ImageGlom::show_image_data()
   if(m_ev_document_model)
   {
     g_object_unref(m_ev_document_model);
-    m_ev_document_model = 0;
+    m_ev_document_model = nullptr;
   }
 
   if(use_evince)
@@ -363,21 +354,12 @@ void ImageGlom::show_image_data()
     m_image.hide();
     
     gtk_widget_show(GTK_WIDGET(m_ev_view));
-
-    if (!m_ev_scrolled_window)
-    {
-      m_ev_scrolled_window = Gtk::manage(new Gtk::ScrolledWindow());
-      m_ev_scrolled_window->show();
-      gtk_container_add(GTK_CONTAINER(m_ev_scrolled_window->gobj()), GTK_WIDGET(m_ev_view));
-    }
-
-    m_frame.add(*m_ev_scrolled_window);
-
+    gtk_container_add(GTK_CONTAINER(m_frame.gobj()), GTK_WIDGET(m_ev_view));
 
     // Try loading from data in memory:
     // TODO: Uncomment this if this API is added: https://bugzilla.gnome.org/show_bug.cgi?id=654832
     /*
-    const GdaBinary* gda_binary = get_binary();
+    const auto gda_binary = get_binary();
     if(!gda_binary || !gda_binary->data || !gda_binary->binary_length)
     {
        std::cerr << G_STRFUNC << "Data was null or empty." << std::endl;
@@ -389,7 +371,7 @@ void ImageGlom::show_image_data()
     */
     //TODO: Test failure asynchronously.
     
-    const Glib::ustring uri = save_to_temp_file(false /* don't show progress */);
+    const auto uri = save_to_temp_file(false /* don't show progress */);
     if(uri.empty())
     {
       std::cerr << G_STRFUNC << "Could not save temp file to show in the EvView." << std::endl;
@@ -419,11 +401,11 @@ void ImageGlom::show_image_data()
       
     bool use_gdkpixbuf = false;
     fill_gdkpixbuf_supported_mime_types();
-    const type_vec_ustrings::iterator iterFind = 
+    const auto iter_find_mime_type = 
       std::find(m_gdkpixbuf_supported_mime_types.begin(),
         m_gdkpixbuf_supported_mime_types.end(),
         mime_type);
-    if(iterFind != m_gdkpixbuf_supported_mime_types.end())
+    if(iter_find_mime_type != m_gdkpixbuf_supported_mime_types.end())
     {
       use_gdkpixbuf = true;
     }
@@ -462,12 +444,12 @@ Glib::RefPtr<Gdk::Pixbuf> ImageGlom::get_scaled_image()
   if(!pixbuf)
     return pixbuf;
  
-  const Gtk::Allocation allocation = m_image.get_allocation();
-  const int pixbuf_height = pixbuf->get_height();
-  const int pixbuf_width = pixbuf->get_width();
+  const auto allocation = m_image.get_allocation();
+  const auto pixbuf_height = pixbuf->get_height();
+  const auto pixbuf_width = pixbuf->get_width();
     
-  const int allocation_height = allocation.get_height();
-  const int allocation_width = allocation.get_width();
+  const auto allocation_height = allocation.get_height();
+  const auto allocation_width = allocation.get_width();
       
   //std::cout << "pixbuf_height=" << pixbuf_height << ", pixbuf_width=" << pixbuf_width << std::endl;
   //std::cout << "allocation_height=" << allocation.get_height() << ", allocation_width=" << allocation.get_width() << std::endl;
@@ -521,7 +503,7 @@ void ImageGlom::on_menupopup_activate_open_file_with()
   AppWindow* pApp = get_appwindow();
 
   //Offer the user a choice of suitable applications:
-  const Glib::ustring mime_type = get_mime_type();
+  const auto mime_type = get_mime_type();
   if(mime_type.empty())
   {
     std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
@@ -562,7 +544,7 @@ static void make_file_read_only(const Glib::ustring& uri)
     std::cerr << G_STRFUNC << ": filepath is empty." << std::endl;
   }
   
-  const int result = chmod(filepath.c_str(), S_IRUSR);
+  const auto result = chmod(filepath.c_str(), S_IRUSR);
   if(result != 0)
   {
     std::cerr << G_STRFUNC << ": chmod() failed." << std::endl;
@@ -641,7 +623,7 @@ Glib::ustring ImageGlom::save_to_temp_file(bool show_progress)
 
 void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
 {
-  const Glib::ustring uri = save_to_temp_file();
+  const auto uri = save_to_temp_file();
   if(uri.empty())
     return;
 
@@ -699,12 +681,12 @@ void ImageGlom::on_menupopup_activate_save_file()
 
   dialog.add_button(_("_Cancel"), Gtk::RESPONSE_CANCEL);
   dialog.add_button(_("_Save"), Gtk::RESPONSE_OK);
-  const int response = dialog.run();
+  const auto response = dialog.run();
   dialog.hide();
   if(response != Gtk::RESPONSE_OK)
     return;
     
-  const Glib::ustring uri = dialog.get_uri();
+  const auto uri = dialog.get_uri();
   if(uri.empty())
     return;
     
@@ -718,7 +700,7 @@ bool ImageGlom::save_file_sync(const Glib::ustring& uri)
   //because we don't want to offer feedback.
   //Ideally, EvView would just load from data anyway.
   
-  const GdaBinary* gda_binary = get_binary();
+  const auto gda_binary = get_binary();
   if(!gda_binary)
   {
     std::cerr << G_STRFUNC << ": GdaBinary is null" << std::endl;
@@ -733,7 +715,7 @@ bool ImageGlom::save_file_sync(const Glib::ustring& uri)
 
   try
   {
-    const std::string filepath = Glib::filename_from_uri(uri);
+    const auto filepath = Glib::filename_from_uri(uri);
     Glib::file_set_contents(filepath, (const char*)gda_binary->data, gda_binary->binary_length);
   }
   catch(const Glib::Error& ex)
@@ -747,19 +729,19 @@ bool ImageGlom::save_file_sync(const Glib::ustring& uri)
 
 bool ImageGlom::save_file(const Glib::ustring& uri)
 {
-  DialogImageSaveProgress* dialog_save = 0;
+  DialogImageSaveProgress* dialog_save = nullptr;
   Utils::get_glade_widget_derived_with_warning(dialog_save);
   if(!dialog_save)
     return false;
     
   // Automatically delete the dialog when we no longer need it:
-  std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog_save);
+  std::shared_ptr<Gtk::Dialog> dialog_keeper(dialog_save);
 
   AppWindow* pApp = get_appwindow();
   if(pApp)
     dialog_save->set_transient_for(*pApp);
 
-  const GdaBinary* gda_binary = get_binary();
+  const auto gda_binary = get_binary();
   if(!gda_binary)
     return false;
 
@@ -791,25 +773,25 @@ void ImageGlom::on_menupopup_activate_select_file()
 
   if((response != Gtk::RESPONSE_CANCEL) && (response != Gtk::RESPONSE_DELETE_EVENT))
   {
-    const Glib::ustring uri = dialog.get_uri();
+    const auto uri = dialog.get_uri();
     if(!uri.empty())
     {
-      DialogImageLoadProgress* dialog;
-      Utils::get_glade_widget_derived_with_warning(dialog);
-      if(dialog)
+      DialogImageLoadProgress* dialog_progress = nullptr;
+      Utils::get_glade_widget_derived_with_warning(dialog_progress);
+      if(dialog_progress)
       {
         // Automatically delete the dialog when we no longer need it:
-        std::auto_ptr<Gtk::Dialog> dialog_keeper(dialog);
+        std::shared_ptr<Gtk::Dialog> dialog_keeper(dialog_progress);
 
         if(pApp)
-          dialog->set_transient_for(*pApp);
+          dialog_progress->set_transient_for(*pApp);
 
-        dialog->load(uri);
+        dialog_progress->load(uri);
 
-        if(dialog->run() == Gtk::RESPONSE_ACCEPT)
+        if(dialog_progress->run() == Gtk::RESPONSE_ACCEPT)
         {
           GdaBinary* bin = g_new(GdaBinary, 1);
-          std::auto_ptr<GdaBinary> image_data = dialog->get_image_data();
+          std::shared_ptr<GdaBinary> image_data = dialog_progress->get_image_data();
           bin->data = image_data->data;
           bin->binary_length = image_data->binary_length;
 
@@ -832,9 +814,9 @@ void ImageGlom::on_clipboard_get(Gtk::SelectionData& selection_data, guint /* in
   //info is meant to indicate the target, but it seems to be always 0,
   //so we use the selection_data's target instead.
 
-  const std::string target = selection_data.get_target(); 
+  const auto target = selection_data.get_target(); 
 
-  const Glib::ustring mime_type = get_mime_type();
+  const auto mime_type = get_mime_type();
   if(mime_type.empty())
   {
     std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
@@ -842,7 +824,7 @@ void ImageGlom::on_clipboard_get(Gtk::SelectionData& selection_data, guint /* in
   
   if(target == mime_type)
   {
-    const GdaBinary* gda_binary = get_binary();
+    const auto gda_binary = get_binary();
     if(!gda_binary)
       return;
     
@@ -881,7 +863,7 @@ void ImageGlom::on_menupopup_activate_copy()
   Glib::RefPtr<Gtk::Clipboard> refClipboard = Gtk::Clipboard::get();
 
   //Targets:
-  const Glib::ustring mime_type = get_mime_type();
+  const auto mime_type = get_mime_type();
   if(mime_type.empty())
   {
     std::cerr << G_STRFUNC << ": mime_type is empty." << std::endl;
