@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #ifndef GLOM_UTILITY_WIDGETS_LAYOUT_WIDGET_BASE_H
@@ -39,11 +39,11 @@ public:
   virtual ~LayoutWidgetBase();
 
   ///Takes ownership.
-  virtual void set_layout_item(const sharedptr<LayoutItem>& layout_item, const Glib::ustring& table_name);
+  virtual void set_layout_item(const std::shared_ptr<LayoutItem>& layout_item, const Glib::ustring& table_name);
 
   //The caller should call clone().
-  sharedptr<const LayoutItem> get_layout_item() const;
-  sharedptr<LayoutItem> get_layout_item();
+  std::shared_ptr<const LayoutItem> get_layout_item() const;
+  std::shared_ptr<LayoutItem> get_layout_item();
 
   enum enumType
   {
@@ -87,10 +87,10 @@ protected:
   virtual AppWindow* get_appwindow() const; // = 0;
 
 
-  static void apply_formatting(Gtk::Widget& widget, const sharedptr<const LayoutItem_WithFormatting>& layout_item);
+  static void apply_formatting(Gtk::Widget& widget, const std::shared_ptr<const LayoutItem_WithFormatting>& layout_item);
 
 protected: //TODO: Add accessor?
-  sharedptr<LayoutItem> m_pLayoutItem;
+  std::shared_ptr<LayoutItem> m_pLayoutItem;
 
 protected: //TODO: Add accessor?
   Glib::ustring m_table_name;
