@@ -30,7 +30,7 @@ namespace Glom
 {
   
 LayoutWidgetUtils::LayoutWidgetUtils() :
-  m_pPopupMenuUtils(0)
+  m_pPopupMenuUtils(nullptr)
 {
   //Derived class's constructors must call this:
   //setup_util_menu(this);
@@ -73,7 +73,7 @@ void LayoutWidgetUtils::on_menu_delete_activate()
     return;
   }
 
-  LayoutWidgetBase* base = 0;
+  LayoutWidgetBase* base = nullptr;
   do
   {
     parent = parent->get_parent();
@@ -86,8 +86,8 @@ void LayoutWidgetUtils::on_menu_delete_activate()
 
   if(base)
   {
-    sharedptr<LayoutGroup> group = 
-      sharedptr<LayoutGroup>::cast_dynamic(base->get_layout_item());
+    std::shared_ptr<LayoutGroup> group = 
+      std::dynamic_pointer_cast<LayoutGroup>(base->get_layout_item());
     if(!group)
       return;
 
