@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include <gtkmm/window.h>
@@ -87,9 +87,8 @@ static void clear_flowtable(Glom::FlowTable& flowtable)
   flowtable.remove_all();
 
   //std::cout << G_STRFUNC << ": debug 1" << std::endl;
-  for(type_vec_widgets::iterator iter = vec_child_widgets.begin(); iter != vec_child_widgets.end(); ++iter)
+  for(const auto& widget : vec_child_widgets)
   {
-    Gtk::Widget* widget = *iter;
     //std::cout << "  loop: widget=" << widget << std::endl;
     delete widget; //TODO: This crashes 
   }
