@@ -39,7 +39,7 @@ VariablesMap::~VariablesMap()
 
 void VariablesMap::connect_widget(const Glib::ustring& widget_name, bool& variable)
 {
-  Gtk::ToggleButton* pToggleButton = 0;
+  Gtk::ToggleButton* pToggleButton = nullptr;
   m_builder->get_widget(widget_name, pToggleButton); //Glade::Xml will complain if it is not a ToggleButton.
   if(pToggleButton)
   {
@@ -49,7 +49,7 @@ void VariablesMap::connect_widget(const Glib::ustring& widget_name, bool& variab
 
 void VariablesMap::connect_widget(const Glib::ustring& widget_name, Glib::ustring& variable)
 {
-  Gtk::Widget* pWidget = 0;
+  Gtk::Widget* pWidget = nullptr;
   m_builder->get_widget(widget_name, pWidget); 
 
   Gtk::Entry* pEntry = dynamic_cast<Gtk::Entry*>(pWidget); //it mange both Gtk::entry and Gtk::SpinButton
@@ -58,6 +58,7 @@ void VariablesMap::connect_widget(const Glib::ustring& widget_name, Glib::ustrin
   {
     m_mapWidgetsToVariables[pEntry] = (void*)(&variable);
   }
+
   if(pComboBox)
   {
     m_mapWidgetsToVariables[pComboBox] = (void*)(&variable);
@@ -66,7 +67,7 @@ void VariablesMap::connect_widget(const Glib::ustring& widget_name, Glib::ustrin
 
 void VariablesMap::connect_widget(const Glib::ustring& widget_name, double& variable)
 {
-  Gtk::Widget* pWidget = 0;
+  Gtk::Widget* pWidget = nullptr;
   m_builder->get_widget(widget_name, pWidget); 
 
   Gtk::Scale* pScale = dynamic_cast<Gtk::Scale*>(pWidget); 
@@ -78,7 +79,7 @@ void VariablesMap::connect_widget(const Glib::ustring& widget_name, double& vari
 
 void VariablesMap::connect_widget(const Glib::ustring& widget_name, Glib::Date& variable)
 {
-  Gtk::Widget* pWidget = 0;
+  Gtk::Widget* pWidget = nullptr;
   m_builder->get_widget(widget_name, pWidget); 
 
   Gtk::Calendar* pCalendar = dynamic_cast<Gtk::Calendar*>(pWidget); 
@@ -92,18 +93,18 @@ void VariablesMap::transfer_widgets_to_variables()
 {
   if(validate_widgets()) //If the widgets' data is correct. Useful to override.
   {
-    for(type_mapWidgetsToVariables::iterator iter =  m_mapWidgetsToVariables.begin(); iter != m_mapWidgetsToVariables.end(); ++iter)
+    for(const auto& the_pair : m_mapWidgetsToVariables)
     {
-      transfer_one_widget(iter->first, true); //true = to_variable.
+      transfer_one_widget(the_pair.first, true); //true = to_variable.
     }
   }
 }
 
 void VariablesMap::transfer_variables_to_widgets()
 {
-  for(type_mapWidgetsToVariables::iterator iter =  m_mapWidgetsToVariables.begin(); iter != m_mapWidgetsToVariables.end(); ++iter)
+  for(const auto& the_pair : m_mapWidgetsToVariables)
   {
-    transfer_one_widget(iter->first, false); //false = to_widget.
+    transfer_one_widget(the_pair.first, false); //false = to_widget.
   }
 }
 
@@ -111,7 +112,7 @@ void VariablesMap::transfer_variables_to_widgets()
 void VariablesMap::transfer_one_widget(Gtk::Widget* pWidget, bool to_variable)
 {
   //Find the widget in the map:
-  type_mapWidgetsToVariables::iterator iterFind = m_mapWidgetsToVariables.find(pWidget);
+  auto iterFind = m_mapWidgetsToVariables.find(pWidget);
   if(iterFind != m_mapWidgetsToVariables.end())
   {
     //Get the variable for the widget:
