@@ -27,8 +27,8 @@
 
 static bool attempt_instantiation(const std::string& filepath, const xmlpp::Element* child)
 {
-  const Glib::ustring id = child->get_attribute_value("id");
-  const Glib::ustring gclassname = child->get_attribute_value("class");
+  const auto id = child->get_attribute_value("id");
+  const auto gclassname = child->get_attribute_value("class");
 
   // Try to instantiate the object:
   Glib::RefPtr<Gtk::Builder> builder;
@@ -44,16 +44,16 @@ static bool attempt_instantiation(const std::string& filepath, const xmlpp::Elem
   }
 
   // Try to get the widget, checking that it has the correct type:
-  Gtk::Widget* widget = 0;
+  Gtk::Widget* widget = nullptr;
   if(gclassname == "GtkWindow")
   {
-    Gtk::Window* window = 0;
+    Gtk::Window* window = nullptr;
     builder->get_widget(id, window);
     widget = window;
   }
   else if(gclassname == "GtkDialog")
   {
-    Gtk::Dialog* dialog = 0;
+    Gtk::Dialog* dialog = nullptr;
     builder->get_widget(id, dialog);
     widget = dialog;
   }
@@ -114,14 +114,13 @@ int main(int argc, char* argv[])
     if(!parser)
       return EXIT_FAILURE;
 
-    const xmlpp::Node* root = parser.get_document()->get_root_node(); //deleted by DomParser.
+    const auto root = parser.get_document()->get_root_node(); //deleted by DomParser.
     if(!root)
       return EXIT_FAILURE;
 
-    const xmlpp::Node::NodeList children = root->get_children("object");
-    for(xmlpp::Node::NodeList::const_iterator iter = children.begin(); iter != children.end(); ++iter)
+    for(const auto& item : root->get_children("object"))
     {
-       const xmlpp::Element* child = dynamic_cast<const xmlpp::Element*>(*iter);
+       const xmlpp::Element* child = dynamic_cast<const xmlpp::Element*>(item);
 
        //Try to instante the object with Gtk::Builder:
        if(child && !attempt_instantiation(filepath, child))
