@@ -71,7 +71,7 @@ int main()
   {
     // 2 CSV lines, first one contains newlines inside quotes
     const char* raw = "\"some\n quoted\r\n newlines\n\", \"token2\"\n\"token3\"\n";
-    const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
+    const auto finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
 
     const bool passed = (finished_parsing &&
                    2 == get_line_scanned_count_instance() &&
@@ -87,7 +87,7 @@ int main()
   {
     // 5 CSV lines, but only 2 contain data
     const char* raw = "token1\n\n\n\ntoken2, token3\n";
-    const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
+    const auto finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw);
 
     const bool passed = (finished_parsing &&
                    2 == get_line_scanned_count_instance() &&
@@ -144,7 +144,7 @@ int main()
   {
     // An incomplete Unicode sequence.
     const char raw[] = "\0xc0\n";
-    const bool finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw, G_N_ELEMENTS(raw));
+    const auto finished_parsing = ImportTests::run_parser_from_buffer(&connect_signals, raw, G_N_ELEMENTS(raw));
 
     const bool passed = (finished_parsing &&
                    1 == get_encoding_error_count_instance() &&
