@@ -20,7 +20,7 @@ int main()
     value = Glom::glom_evaluate_python_function_implementation(
       Glom::Field::TYPE_NUMERIC, calculation, field_values,
       0 /* document */, "" /* table name */,
-      Glom::sharedptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
+      std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
       connection,
       error_message);
   }
@@ -39,16 +39,13 @@ int main()
   //std::cout << "type=" << g_type_name(value.get_value_type()) << std::endl;
 
   //Check that there was no python error:
-  if(!error_message.empty()) {
-    std::cerr << "Unexpected error message: " << error_message << "\n";
-    return EXIT_FAILURE;
-  }
+  g_assert(error_message.empty());
 
   //Check that the return value is of the expected type:
   g_assert(value.get_value_type() == GDA_TYPE_NUMERIC);
 
   //Check that the return value is of the expected value:
-  const double numeric = Glom::Conversions::get_double_for_gda_value_numeric(value);
+  const auto numeric = Glom::Conversions::get_double_for_gda_value_numeric(value);
   g_assert(numeric == 4950.0);
 
   //std::cout << "value=" << value.to_string() << std::endl;
