@@ -22,7 +22,7 @@ int main()
     value = Glom::glom_evaluate_python_function_implementation(
       result_type, calculation, field_values,
       0 /* document */, "" /* table name */,
-      Glom::sharedptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
+      std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
       connection,
       error_message);
   }
@@ -40,16 +40,13 @@ int main()
   //std::cout << "type=" << g_type_name(value.get_value_type()) << std::endl;
 
   //Check that there was no python error:
-  if(!error_message.empty()) {
-    std::cerr << "Unexpected error message: " << error_message << "\n";
-    return EXIT_FAILURE;
-  }
+  g_assert(error_message.empty());
 
   //Check that the return value is of the expected type:
   g_assert(Glom::Field::get_glom_type_for_gda_type(value.get_value_type()) == result_type);
 
   //Check that the return value is of the expected value:
-  const Glib::ustring text = value.get_string();
+  const auto text = value.get_string();
   //std::cout << "text=" << text << std::endl;
   g_assert(text == "4950"); //This should always be as per ISO, not according to the user's locale, because it's generally passed to the database. Presentation is separate to calculation or storage.
 
