@@ -7,7 +7,6 @@
 #include <glom/libglom/init.h>
 #include <glom/python_embed/glom_python.h>
 #include <libglom/data_structure/glomconversions.h>
-#include <iostream>
 
 void execute_func_with_date_return_value()
 {
@@ -17,19 +16,16 @@ void execute_func_with_date_return_value()
 
   //Execute a python function:
   Glib::ustring error_message;
-  const Gnome::Gda::Value value = Glom::glom_evaluate_python_function_implementation(
+  const auto value = Glom::glom_evaluate_python_function_implementation(
     Glom::Field::TYPE_DATE, calculation, field_values,
     0 /* document */, "" /* table name */,
-    Glom::sharedptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
+    std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
     connection,
     error_message);
 
   //std::cout << "type=" << g_type_name(value.get_value_type()) << std::endl;
 
   //Check that there was no python error:
-  if(!error_message.empty()) {
-    std::cerr << "Unexpected error message: " << error_message << "\n";
-  }
   g_assert(error_message.empty());
   
   //Check that the return value is of the expected type:
@@ -49,25 +45,22 @@ void execute_func_with_date_input_value()
   const char* calculation = "import datetime\n"
                             "return record[\"test_field\"].year";
   Glom::type_map_fields field_values;
-  const Glib::Date input_date = Glib::Date(11, Glib::Date::MAY, 1973);
+  const auto input_date = Glib::Date(11, Glib::Date::MAY, 1973);
   field_values["test_field"] = Gnome::Gda::Value(input_date);
   Glib::RefPtr<Gnome::Gda::Connection> connection;
 
   //Execute a python function:
   Glib::ustring error_message;
-  const Gnome::Gda::Value value = Glom::glom_evaluate_python_function_implementation(
+  const auto value = Glom::glom_evaluate_python_function_implementation(
     Glom::Field::TYPE_NUMERIC, calculation, field_values,
     0 /* document */, "" /* table name */,
-    Glom::sharedptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
+    std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
     connection,
     error_message);
 
   //std::cout << "type=" << g_type_name(value.get_value_type()) << std::endl;
 
   //Check that there was no python error:
-  if(!error_message.empty()) {
-    std::cerr << "Unexpected error message: " << error_message << "\n";
-  }
   g_assert(error_message.empty());
   
   //Check that the return value is of the expected type:
@@ -90,15 +83,15 @@ void execute_func_with_date_input_value_relativedelta()
                             "rd = relativedelta(today, date_of_birth)\n"
                             "return rd.year";
   Glom::type_map_fields field_values;
-  const Glib::Date input_date = Glib::Date(11, Glib::Date::MAY, 1973);
+  const auto input_date = Glib::Date(11, Glib::Date::MAY, 1973);
   field_values["test_field"] = Gnome::Gda::Value(input_date);
   Glib::RefPtr<Gnome::Gda::Connection> connection;
 
   //Execute a python function:
-  const Gnome::Gda::Value value = Glom::glom_evaluate_python_function_implementation(
+  const auto value = Glom::glom_evaluate_python_function_implementation(
     Glom::Field::TYPE_NUMERIC, calculation, field_values,
     0, "",
-    Glom::sharedptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
+    std::shared_ptr<Glom::Field>(), Gnome::Gda::Value(), // primary key details. Not used in this test.
     connection);
 
   //std::cout << "type=" << g_type_name(value.get_value_type()) << std::endl;
