@@ -39,7 +39,7 @@ bool contains(const T_Container& container, const T_Value& name)
 template<typename T_Container>
 bool contains_named(const T_Container& container, const Glib::ustring& name)
 {
-  typedef typename T_Container::value_type::object_type type_item;
+  typedef typename T_Container::value_type::element_type type_item;
   typename T_Container::const_iterator iter =
     std::find_if(container.begin(), container.end(),
       Glom::predicate_FieldHasName<type_item>(name));
@@ -49,12 +49,8 @@ bool contains_named(const T_Container& container, const Glib::ustring& name)
 template<typename T_Container>
 bool contains_value(const T_Container& container, const Glib::ustring& name)
 {
-  typedef typename T_Container::value_type type_item;
-  typedef typename T_Container::const_iterator type_iterator;
-
-  for(type_iterator iter = container.begin(); iter != container.end(); ++iter)
+  for(const auto& item : container)
   {
-    const type_item item = *iter;
     if(item->get_value() == Gnome::Gda::Value(name))
       return true;
   }
@@ -80,43 +76,36 @@ static bool get_group_named(const Glom::Document::type_list_groups& container, c
 
 static bool needs_navigation(Glom::Document& document, const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
-  Glom::sharedptr<Glom::LayoutItem_Field> layout_item = Glom::sharedptr<Glom::LayoutItem_Field>::create();
+  std::shared_ptr<Glom::LayoutItem_Field> layout_item = std::make_shared<Glom::LayoutItem_Field>();
   layout_item->set_name(field_name);
   layout_item->set_full_field_details(
     document.get_field(table_name, field_name));
 
-  Glom::sharedptr<const Glom::Relationship> field_used_in_relationship_to_one;
+  std::shared_ptr<Glom::Relationship> field_used_in_relationship_to_one;
   return Glom::DbUtils::layout_field_should_have_navigation(table_name, 
     layout_item, &document, field_used_in_relationship_to_one);
 }
 
-static Glom::sharedptr<const Glom::LayoutItem_Portal> get_portal_from_details_layout(const Glom::Document& document, const Glib::ustring& table_name, const Glib::ustring& relationship_name)
+static std::shared_ptr<const Glom::LayoutItem_Portal> get_portal_from_details_layout(const Glom::Document& document, const Glib::ustring& table_name, const Glib::ustring& relationship_name)
 {
-  const Glom::Document::type_list_layout_groups groups = 
+  const auto groups = 
     document.get_data_layout_groups("details", table_name);
   if(groups.empty())
   {
     std::cerr << G_STRFUNC << ": groups is empty." << std::endl;
   }
   
-  for(Glom::Document::type_list_layout_groups::const_iterator iter = groups.begin(); iter != groups.end(); ++iter)
+  for(const auto& group : groups)
   {
-    const Glom::sharedptr<const Glom::LayoutGroup> group = *iter;
-
-    const Glom::LayoutGroup::type_list_const_items items = 
-      group->get_items_recursive_with_groups();
-    for(Glom::LayoutGroup::type_list_const_items::const_iterator iter = items.begin(); 
-      iter != items.end(); ++iter)
-    {
-      const Glom::sharedptr<const Glom::LayoutItem> layout_item = *iter;
- 
-      const Glom::sharedptr<const Glom::LayoutGroup> group =
-        Glom::sharedptr<const Glom::LayoutGroup>::cast_dynamic(layout_item);
-      if(!group)
+    for(const auto& layout_item : group->get_items_recursive_with_groups())
+    { 
+      const std::shared_ptr<const Glom::LayoutGroup> child_group =
+        std::dynamic_pointer_cast<const Glom::LayoutGroup>(layout_item);
+      if(!child_group)
         continue;
 
-      const Glom::sharedptr<const Glom::LayoutItem_Portal> portal =
-        Glom::sharedptr<const Glom::LayoutItem_Portal>::cast_dynamic(layout_item);
+      const std::shared_ptr<const Glom::LayoutItem_Portal> portal =
+        std::dynamic_pointer_cast<const Glom::LayoutItem_Portal>(layout_item);
       if(!portal)
         continue;
 
@@ -125,7 +114,7 @@ static Glom::sharedptr<const Glom::LayoutItem_Portal> get_portal_from_details_la
     }
   }
       
-  return Glom::sharedptr<Glom::LayoutItem_Portal>();
+  return std::shared_ptr<Glom::LayoutItem_Portal>();
 }
   
  
@@ -156,7 +145,7 @@ int main()
   Glom::Document document;
   document.set_file_uri(uri);
   int failure_code = 0;
-  const bool test = document.load(failure_code);
+  const auto test = document.load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -169,7 +158,7 @@ int main()
   g_assert(document.get_is_example_file());
   g_assert(document.get_database_title_original() == "Openismus Film Manager");
 
-  const std::vector<Glib::ustring> table_names = document.get_table_names();
+  const auto table_names = document.get_table_names();
   g_assert(contains(table_names, "accommodation"));
   g_assert(contains(table_names, "cars"));
   g_assert(contains(table_names, "characters"));
@@ -179,26 +168,26 @@ int main()
   g_assert(contains(table_names, "scenes"));
   g_assert(!contains(table_names, "Scenes")); //The title, not the name.
 
-  Glom::sharedptr<Glom::TableInfo> table = document.get_table("scenes");
+  std::shared_ptr<Glom::TableInfo> table = document.get_table("scenes");
   g_assert(table);
   g_assert( table->get_title_original() == "Scenes" );
   g_assert( table->get_title_singular_original() == "Scene" );
 
   //Test known fields of one table:
-  const Glom::Document::type_vec_fields fields = document.get_table_fields("scenes");
+  const auto fields = document.get_table_fields("scenes");
   g_assert(contains_named(fields, "scene_id"));
   g_assert(contains_named(fields, "comments"));
   g_assert(contains_named(fields, "description"));
   g_assert(contains_named(fields, "date"));
   g_assert(!contains_named(fields, "nosuchfield"));
 
-  const Glom::Document::type_vec_relationships relationships = document.get_relationships("scenes");
+  const auto relationships = document.get_relationships("scenes");
   g_assert(contains_named(relationships, "location"));
   g_assert(contains_named(relationships, "scene_crew"));
   g_assert(contains_named(relationships, "scene_cast"));
 
   //Check some fields:
-  Glom::sharedptr<const Glom::Field> field = document.get_field("contacts", "contact_id");
+  std::shared_ptr<const Glom::Field> field = document.get_field("contacts", "contact_id");
   g_assert(field);
   g_assert( field->get_title_original() == "Contact ID" );
   g_assert(field->get_glom_type() == Glom::Field::TYPE_NUMERIC);
@@ -211,7 +200,7 @@ int main()
   g_assert(!field->get_unique_key());
 
   //Check a relationship:
-  const Glom::sharedptr<const Glom::Relationship> relationship = document.get_relationship("characters", "contacts_actor");
+  const std::shared_ptr<const Glom::Relationship> relationship = document.get_relationship("characters", "contacts_actor");
   g_assert(relationship);
   g_assert(relationship->get_from_field() == "contact_id");
   g_assert(relationship->get_to_table() == "contacts");
@@ -222,7 +211,7 @@ int main()
   const Glom::Document::type_list_layout_groups groups = 
     document.get_data_layout_groups("details", "scenes");
   g_assert(groups.size() == 3);
-  const Glom::sharedptr<const Glom::LayoutGroup> group =
+  const std::shared_ptr<const Glom::LayoutGroup> group =
     groups[1];
   const Glom::LayoutGroup::type_list_const_items items = 
     group->get_items_recursive();
@@ -234,7 +223,7 @@ int main()
   g_assert(items_with_groups.size() == 15);
 
   //Check that expected fields can be found on a layout.
-  Glom::sharedptr<const Glom::LayoutItem_Field> field_on_layout = 
+  std::shared_ptr<const Glom::LayoutItem_Field> field_on_layout = 
     get_field_on_layout(document, "scenes", "locations", "address_town");
   g_assert(field_on_layout);
   g_assert(field_on_layout->get_table_used("scenes") == "locations");
@@ -270,7 +259,7 @@ int main()
 
 
   //Test library modules:
-  const std::vector<Glib::ustring> module_names = document.get_library_module_names();
+  const auto module_names = document.get_library_module_names();
   if(!module_names.empty()) //TODO: Test a document that actually has some?
   {
     std::cerr << G_STRFUNC << ": Failure: Unexpected library module names." << std::endl;
@@ -293,7 +282,7 @@ int main()
     return false;
   }
   
-  const Glom::sharedptr<const Glom::PrintLayout> print_layout = document.get_print_layout("contacts", "contact_details");
+  const std::shared_ptr<const Glom::PrintLayout> print_layout = document.get_print_layout("contacts", "contact_details");
   if(!print_layout)
   {
     std::cerr << G_STRFUNC << ": Failure: Could not get an expected print layout." << std::endl;
@@ -327,7 +316,7 @@ int main()
     return false;
   }
 
-  const Glom::sharedptr<const Glom::Report> report = document.get_report("contacts", "by_country_by_town");
+  const std::shared_ptr<const Glom::Report> report = document.get_report("contacts", "by_country_by_town");
   if(!report)
   {
     std::cerr << G_STRFUNC << ": Failure: Could not get an expected report." << std::endl;
@@ -382,7 +371,7 @@ int main()
   //Note that related records portals don't have names.
   //This example portal shows the scenes_cast table, but should navigate though that to the cast table.
   const Glib::ustring portal_relationship_name = "scene_cast";
-  Glom::sharedptr<const Glom::LayoutItem_Portal> portal =
+  std::shared_ptr<const Glom::LayoutItem_Portal> portal =
     get_portal_from_details_layout(document, "scenes", portal_relationship_name);
   if(!portal)
   {
@@ -391,7 +380,7 @@ int main()
   }
 
   Glib::ustring navigation_table_name;
-  Glom::sharedptr<const Glom::UsesRelationship> navigation_relationship;
+  std::shared_ptr<const Glom::UsesRelationship> navigation_relationship;
   portal->get_suitable_table_to_view_details(navigation_table_name, navigation_relationship, &document);
 
   if(navigation_table_name != "characters")
