@@ -30,16 +30,10 @@
 static bool field_is_on_a_layout(Glom::Document& document, const Glib::ustring& table_name, const Glib::ustring& field_name)
 {
   //Check that the field name is no longer used on a layout:
-  const std::vector<Glib::ustring> table_names = document.get_table_names();
-  for(std::vector<Glib::ustring>::const_iterator iter = table_names.begin(); iter != table_names.end(); ++iter)
+  for(const auto& layout_table_name : document.get_table_names())
   {
-    const Glib::ustring layout_table_name = *iter;
-    const Glom::Document::type_list_layout_groups groups = 
-      document.get_data_layout_groups("details", layout_table_name);
-
-    for(Glom::Document::type_list_layout_groups::const_iterator iter = groups.begin(); iter != groups.end(); ++iter)
+    for(const auto& group : document.get_data_layout_groups("details", layout_table_name))
     {
-      const Glom::sharedptr<Glom::LayoutGroup> group = *iter;
       if(group->has_field(layout_table_name, table_name, field_name))
       {
         //std::cerr << G_STRFUNC << ": Failure: The field is still used on a layout for table: " << layout_table_name << std::endl;
@@ -86,7 +80,7 @@ int main()
   Glom::Document document;
   document.set_file_uri(uri);
   int failure_code = 0;
-  const bool test = document.load(failure_code);
+  const auto test = document.load(failure_code);
   //std::cout << "Document load result=" << test << std::endl;
 
   if(!test)
@@ -119,7 +113,7 @@ int main()
   }
 
   //Check that the original field name is no longer used in the relationship:
-  Glom::sharedptr<const Glom::Relationship> relationship = document.get_relationship("invoice_lines", "products");
+  std::shared_ptr<const Glom::Relationship> relationship = document.get_relationship("invoice_lines", "products");
   if(!relationship)
   {
     std::cerr << G_STRFUNC << ": Failure: The relationship could not be found in the document." << std::endl;
@@ -141,10 +135,10 @@ int main()
 
   {
     //Change a relationship name:
-    const Glib::ustring table_name = "invoices";
+    const Glib::ustring table_name_invoices = "invoices";
     const Glib::ustring relationship_name_original = "contacts";
     const Glib::ustring relationship_name_new = "newrelationshipname";
-    document.change_relationship_name(table_name, 
+    document.change_relationship_name(table_name_invoices, 
       relationship_name_original, relationship_name_new);
     if(document.get_relationship(table_name, relationship_name_original))
     {
@@ -159,7 +153,7 @@ int main()
     }
 
     //Check that the old relationship name is not used.
-    Glom::sharedptr<const Glom::LayoutItem_Field> field_on_layout = 
+    std::shared_ptr<const Glom::LayoutItem_Field> field_on_layout = 
       get_field_on_layout(document, table_name, "contacts", "name_full");
     g_assert(field_on_layout);
     if(field_on_layout->get_relationship_name() != relationship_name_new)
@@ -217,7 +211,7 @@ int main()
 
  
   //Remove a print layout:
-  Glom::sharedptr<const Glom::PrintLayout> print_layout = 
+  std::shared_ptr<const Glom::PrintLayout> print_layout = 
     document.get_print_layout("contacts", "contact_details");
   if(!print_layout)
   {
