@@ -26,10 +26,10 @@
 
 static bool test_value(Glom::Field::glom_field_type field_type, const Gnome::Gda::Value& value)
 {
-  const Glib::ustring str = Glom::Field::to_file_format(value, field_type);
+  const auto str = Glom::Field::to_file_format(value, field_type);
 
   bool success = false;
-  const Gnome::Gda::Value value_retrieved = Glom::Field::from_file_format(
+  const auto value_retrieved = Glom::Field::from_file_format(
     str, field_type, success);
   if(!success)
   {
@@ -39,7 +39,7 @@ static bool test_value(Glom::Field::glom_field_type field_type, const Gnome::Gda
 
   if(value != value_retrieved)
   {
-    std::cerr << "Unexpected: value=" << value.to_string() << ", value_retrieved=" << value_retrieved.to_string() << std::endl;
+    std::shared_ptr<Glom::Field> field = std::make_shared<Glom::Field>();
     std::cerr << "  value_retrieved type=" << g_type_name(value_retrieved.get_value_type()) << ", value type=" << g_type_name(value.get_value_type()) << std::endl;
     return false;
   }
@@ -88,9 +88,6 @@ int main()
   if(!test_value(Glom::Field::TYPE_NUMERIC, Glom::Conversions::parse_value((double)3.91l)))
     return EXIT_FAILURE;
 
-  if(!test_value(Glom::Field::TYPE_NUMERIC, Glom::Conversions::parse_value(1004914l)))
-    return EXIT_FAILURE;
-
 
   //TODO: Image.
 
